@@ -15,7 +15,6 @@ Debusine integration tests.
 Test signing service.
 """
 
-import base64
 import json
 import socket
 import subprocess
@@ -89,7 +88,7 @@ class IntegrationSigningTests(IntegrationTestHelpersMixin, TestCase):
         """Verify a signed file against its UEFI signing key."""
         with cls._temporary_directory() as temp_path:
             (certificate := temp_path / "uefi.crt").write_bytes(
-                base64.b64decode(signing_key_data.public_key)
+                signing_key_data.public_key
             )
             (image := temp_path / "image").write_bytes(image_data)
             (signature := temp_path / "image.sig").write_bytes(
@@ -279,7 +278,9 @@ class IntegrationSigningTests(IntegrationTestHelpersMixin, TestCase):
             )
 
         work_request_id = Client.execute_command(
-            "create-work-request",
+            "work-request",
+            "create",
+            "--yaml",
             "assemblesignedsource",
             stdin=yaml.safe_dump(
                 {
@@ -288,7 +289,7 @@ class IntegrationSigningTests(IntegrationTestHelpersMixin, TestCase):
                     "signed": [signing_output_artifact_id],
                 }
             ),
-        )["work_request_id"]
+        )["id"]
         assert isinstance(work_request_id, int)
         return work_request_id
 
@@ -342,7 +343,7 @@ class IntegrationSigningTests(IntegrationTestHelpersMixin, TestCase):
         generate_task_id = self.generate_signing_key()
         self.wait_and_assert_result(generate_task_id)
         signing_asset = self.find_created_asset(generate_task_id)
-        signing_key_data = SigningKeyData.parse_obj(signing_asset["data"])
+        signing_key_data = SigningKeyData.model_validate(signing_asset["data"])
         signed_package_name = self.grub_signed_package_name()
         if signed_package_name is None:
             # Not all architectures have signed grub, just stop here
@@ -391,10 +392,12 @@ class IntegrationSigningTests(IntegrationTestHelpersMixin, TestCase):
         assert workflow_template_result.returncode == 0
 
         workflow_id = Client.execute_command(
-            "create-workflow",
+            "workflow",
+            "start",
             "update-suites",
+            "--yaml",
             stdin=yaml.safe_dump({"force_basic_indexes": True}),
-        )["workflow_id"]
+        )["id"]
         assert Client.wait_for_work_request_completed(workflow_id, "success")
 
         # Check that APT is happy with the resulting archive.
