@@ -89,10 +89,12 @@ class IntegrationTaskSimpleSystemImageBuildTests(
         }
 
         work_request_id = Client.execute_command(
-            "create-work-request",
+            "work-request",
+            "create",
+            "--yaml",
             self.TASK_NAME,
             stdin=yaml.safe_dump(task_data),
-        )["work_request_id"]
+        )["id"]
 
         # The worker should get the new work request and start executing it
         status = Client.wait_for_work_request_completed(
