@@ -337,10 +337,7 @@ class IntegrationWorkflowDebianPipelineTests(
         # source and binary packages for "hello" to it.  We'll also use this
         # source artifact to start our pipeline.
         suite_name = "trixie"
-        self.create_suite(
-            suite_name,
-            {"components": ["main"], "architectures": [self.architecture]},
-        )
+        self.create_suite(suite_name, architectures=[self.architecture])
         with self.apt_indexes(suite_name) as apt_path:
             source_artifact_id = self.create_artifact_source(apt_path, "hello")
             self.add_artifact_to_suite(
@@ -388,10 +385,12 @@ class IntegrationWorkflowDebianPipelineTests(
 
         # Start a workflow with the source artifact downloaded earlier.
         workflow_id = Client.execute_command(
-            "create-workflow",
+            "workflow",
+            "start",
+            "--yaml",
             template_name,
             stdin=yaml.safe_dump({"source_artifact": source_artifact_id}),
-        )["workflow_id"]
+        )["id"]
         assert Client.wait_for_work_request_completed(workflow_id, "success")
 
         # Verify artifacts produced by various parts of the workflow.
@@ -407,21 +406,9 @@ class IntegrationWorkflowDebianPipelineTests(
 
     def test_publish(self) -> None:
         """Publish source and binary packages to a suite."""
-        suite_name = "trixie-publish"
-        self.create_suite(
-            suite_name,
-            {"components": ["main"], "architectures": [self.architecture]},
-        )
-        self.add_suite_to_archive(suite_name)
-        with self.apt_indexes("trixie") as apt_path:
-            source_artifact_id = self.create_artifact_source(
-                apt_path, "base-files"
-            )
-
-        template_name = "test-publish"
-        template_data = {
+        base_template_name = "base-publish"
+        base_template_data = {
             "static_parameters": {
-                "suite": f"{suite_name}@{CollectionCategory.SUITE}",
                 "vendor": "debian",
                 "codename": "trixie",
                 "architectures": [self.architecture],
@@ -439,24 +426,38 @@ class IntegrationWorkflowDebianPipelineTests(
             "workflow-template",
             "create",
             "debian_pipeline",
-            template_name,
-            stdin=yaml.safe_dump(template_data),
+            base_template_name,
+            stdin=yaml.safe_dump(base_template_data),
         )
         assert workflow_template_result.returncode == 0
 
+        suite_name = "trixie-publish"
+        self.create_suite(
+            suite_name,
+            architectures=[self.architecture],
+            base_workflow_template=base_template_name,
+        )
+        self.add_suite_to_archive(suite_name)
+        with self.apt_indexes("trixie") as apt_path:
+            source_artifact_id = self.create_artifact_source(
+                apt_path, "base-files"
+            )
+
         workflow_id = Client.execute_command(
-            "create-workflow",
-            template_name,
+            "workflow",
+            "start",
+            "--yaml",
+            f"publish-to-{suite_name}",
             stdin=yaml.safe_dump({"source_artifact": source_artifact_id}),
-        )["workflow_id"]
+        )["id"]
         assert Client.wait_for_work_request_completed(workflow_id, "success")
 
         work_requests = Client.execute_command(
-            "list-work-requests", "--limit", "1000"
+            "work-request", "list", "--yaml", "--limit", "1000"
         )
         update_suites_id = next(
             wr
-            for wr in work_requests["results"]
+            for wr in work_requests.parsed_stdout
             if wr["task_type"] == "Workflow"
             and wr["task_name"] == "update_suites"
         )["id"]
