@@ -29,12 +29,12 @@ sudo -u postgres createdb --owner debusine-server debusine || true
 
 # Set up nginx
 sed "s/server_name .*;/server_name $canonical_hostname;/" \
-	/usr/share/doc/debusine-server/examples/nginx-vhost.conf \
+	examples/nginx/nginx-vhost.conf \
 	>/etc/nginx/sites-available/debusine.example.net
 # TODO: TLS won't work properly for this vhost yet, as the default snakeoil
 # certificate doesn't include a SubjectAltName for it.
 sed "s/server_name .*;/server_name deb.$canonical_hostname;/" \
-	/usr/share/doc/debusine-server/examples/nginx-vhost-deb.conf \
+	examples/nginx/nginx-vhost-deb.conf \
 	>/etc/nginx/sites-available/deb.debusine.example.net
 
 ln -sf /etc/nginx/sites-available/debusine.example.net \
@@ -48,6 +48,9 @@ cp /etc/ssl/certs/ssl-cert-snakeoil.pem \
 	"/usr/local/share/ca-certificates/$canonical_hostname.crt"
 update-ca-certificates
 
+# Limit the memory usage on multi-core machines
+echo "workers = 2" >> /etc/debusine/server/gunicorn.conf.py
+
 systemctl reset-failed debusine-server-migrate
 systemctl restart debusine-server-migrate
 systemctl restart debusine-server
