@@ -1,4 +1,4 @@
-# Copyright 2022 The Debusine Developers
+# Copyright © The Debusine Developers
 # See the AUTHORS file at the top-level directory of this distribution
 #
 # This file is part of Debusine. It is subject to the license terms
@@ -13,6 +13,7 @@ import logging
 
 import requests
 import yaml
+from prometheus_client.parser import text_string_to_metric_families
 
 from utils import common
 from utils.common import Configuration, RunResult
@@ -55,6 +56,11 @@ class DebusineServer:
         cmd = ["debusine-admin"] + [command] + [*args]
         result = common.run_as(user, cmd, stdin=stdin)
 
+        if result.stdout:
+            logger.info("stdout: %s", result.stdout)
+        if result.stderr:
+            logger.info("stderr: %s", result.stderr)
+
         return result
 
     @classmethod
@@ -66,27 +72,19 @@ class DebusineServer:
         list_workers: str | None = None,
     ) -> bool:
         """
-        Return True if list_workers has token with the specified state.
+        Return True if ``worker list`` has token with the specified state.
 
         :param token: token that is being verified
         :param connected: True if it is expected that the worker is connected
         :param enabled: True if it is expected that the worker's token enabled
-        :param list_workers: output of the command 'list-workers' or None.
-          If None it executes list-workers
+        :param list_workers: output of the command ``worker list --yaml`` or
+          None.  If None it executes ``worker list --yaml``
         :return: True if a token is connected and enabled as per connected
           and enabled parameters
-
-        list_workers looks like:
-
-        Name Registered           Connected            Token hash  Enabled
-        ---- -------------------  -------------------  ----------  -------
-        pin  date and time+00:00  date and time+00:00  10f14       False
-
-        Connected is a date and time with a timezone or "-"
         """
         if list_workers is None:
             list_workers_output = cls.execute_command(
-                'list_workers', '--yaml'
+                "worker", "list", "--yaml"
             ).stdout
 
         token_hash = hashlib.sha256(token.encode()).hexdigest()
@@ -107,3 +105,19 @@ class DebusineServer:
             return cls.verify_worker(token, connected=True, enabled=True)
 
         return Waiter.wait_for_success(30, token_is_connected)
+
+    @classmethod
+    def get_metric(
+        cls, *, metric_name: str, sample_name: str, **labels: str
+    ) -> float | None:
+        """Get the value of a metric from the server."""
+        response = requests.get(
+            f"{Configuration.get_base_url()}/api/1.0/open-metrics/"
+        )
+        response.raise_for_status()
+        for metric in text_string_to_metric_families(response.text):
+            if metric.name == metric_name:
+                for sample in metric.samples:
+                    if sample.name == sample_name and sample.labels == labels:
+                        return sample.value
+        return None
