@@ -17,11 +17,6 @@ from unittest import mock
 
 import debian.deb822 as deb822
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 import debusine.artifacts.models as data_models
 from debusine.artifacts import (
     BinaryPackage,
@@ -42,11 +37,14 @@ from debusine.artifacts.local_artifact import (
     AutopkgtestArtifact,
     DebianSystemImageArtifact,
     DebianSystemTarballArtifact,
+    NewLocalFile,
+    NewRemoteFile,
     deb822dict_to_dict,
 )
+from debusine.artifacts.playground import ArtifactPlayground
 from debusine.assets import KeyPurpose
 from debusine.client.debusine import serialize_local_artifact
-from debusine.client.models import FileRequest, StrMaxLength255
+from debusine.client.models import FileRequest
 from debusine.test import TestCase
 
 
@@ -79,34 +77,29 @@ class LocalArtifactTests(TestCase):
             unregister_local_artifact_subclass, TestArtifact._category
         )
 
+        self.test_artifact_class = TestArtifact
         self.category = TestArtifact._category
         self.data = data_models.EmptyArtifactData()
-        self.files: dict[str, Path] = {}
-
-        self.local_artifact = TestArtifact(
-            category=self.category,
-            files=self.files,
-            data=self.data,
-        )
 
     def test_add_local_file_in_root(self) -> None:
         """add_local_file() add the file in .files."""
         file = self.create_temporary_file()
-        self.local_artifact.add_local_file(file)
-
-        self.assertEqual(
-            self.local_artifact.files,
-            {file.name: file},
+        artifact = self.test_artifact_class._create(
+            data=self.data, files=[NewLocalFile(file=file)]
         )
 
+        self.assertEqual(artifact.files, {file.name: file})
+
     def test_add_local_file_in_override_name(self) -> None:
         """add_local_file() with override_name."""
         file = self.create_temporary_file()
 
         name = "new_name.txt"
-        self.local_artifact.add_local_file(file, override_name=name)
+        artifact = self.test_artifact_class._create(
+            data=self.data, files=[NewLocalFile(file=file, override_name=name)]
+        )
 
-        self.assertEqual(self.local_artifact.files, {name: file})
+        self.assertEqual(artifact.files, {name: file})
 
     def test_add_local_file_artifact_base_dir_does_not_exist(self) -> None:
         """add_local_file() raise ValueError: directory does not exist."""
@@ -116,8 +109,11 @@ class LocalArtifactTests(TestCase):
             ValueError,
             f'"{artifact_base_dir}" does not exist or is not a directory',
         ):
-            self.local_artifact.add_local_file(
-                file, artifact_base_dir=artifact_base_dir
+            self.test_artifact_class._create(
+                data=self.data,
+                files=[
+                    NewLocalFile(file=file, artifact_base_dir=artifact_base_dir)
+                ],
             )
 
     def test_add_local_file_relative_to_artifact_base_dir_does_not_exist(
@@ -132,8 +128,13 @@ class LocalArtifactTests(TestCase):
         with self.assertRaisesRegex(
             ValueError, f'"{filename_absolute}" does not exist'
         ):
-            self.local_artifact.add_local_file(
-                filename, artifact_base_dir=artifact_base_dir
+            self.test_artifact_class._create(
+                data=self.data,
+                files=[
+                    NewLocalFile(
+                        file=filename, artifact_base_dir=artifact_base_dir
+                    )
+                ],
             )
 
     def test_add_local_file_absolute_does_not_exist(self) -> None:
@@ -143,14 +144,18 @@ class LocalArtifactTests(TestCase):
         filename = empty_dir / "a-file-does-not-exist.txt"
 
         with self.assertRaisesRegex(ValueError, f'"{filename}" does not exist'):
-            self.local_artifact.add_local_file(filename)
+            self.test_artifact_class._create(
+                data=self.data, files=[NewLocalFile(file=filename)]
+            )
 
     def test_add_local_file_is_not_a_file(self) -> None:
         """add_local_file() raise ValueError: expected file is a directory."""
         empty_dir = self.create_temporary_directory()
 
         with self.assertRaisesRegex(ValueError, f'"{empty_dir}" is not a file'):
-            self.local_artifact.add_local_file(empty_dir)
+            self.test_artifact_class._create(
+                data=self.data, files=[NewLocalFile(file=empty_dir)]
+            )
 
     def test_add_local_file_relative_to_artifact_base_dir(self) -> None:
         """add_local_file() add relative file from an absolute directory."""
@@ -159,11 +164,14 @@ class LocalArtifactTests(TestCase):
 
         (file := artifact_base_dir / filename).write_bytes(b"")
 
-        self.local_artifact.add_local_file(
-            filename, artifact_base_dir=artifact_base_dir
+        artifact = self.test_artifact_class._create(
+            data=self.data,
+            files=[
+                NewLocalFile(file=filename, artifact_base_dir=artifact_base_dir)
+            ],
         )
 
-        self.assertEqual(self.local_artifact.files, {'README.txt': file})
+        self.assertEqual(artifact.files, {'README.txt': file})
 
     def test_add_local_file_artifact_raise_value_error_dir_is_relative(
         self,
@@ -174,25 +182,24 @@ class LocalArtifactTests(TestCase):
         with self.assertRaisesRegex(
             ValueError, f'"{directory}" must be absolute'
         ):
-            self.local_artifact.add_local_file(
-                file, artifact_base_dir=directory
+            self.test_artifact_class._create(
+                data=self.data,
+                files=[NewLocalFile(file=file, artifact_base_dir=directory)],
             )
 
     def test_add_local_file_absolute_path_no_artifact_base_dir(self) -> None:
         """add_local_file() adds file. No artifact path or artifact_dir."""
         file = self.create_temporary_file()
 
-        self.local_artifact.add_local_file(file)
-
-        self.assertEqual(
-            self.local_artifact.files,
-            {file.name: file},
+        artifact = self.test_artifact_class._create(
+            data=self.data, files=[NewLocalFile(file=file)]
         )
 
+        self.assertEqual(artifact.files, {file.name: file})
+
     def test_add_local_file_duplicated_raise_value_error(self) -> None:
         """add_local_file() raise ValueError: file is already added."""
         file = self.create_temporary_file()
-        self.local_artifact.add_local_file(file)
 
         with self.assertRaisesRegex(
             ValueError,
@@ -202,13 +209,15 @@ class LocalArtifactTests(TestCase):
                 f'is already in the artifact ("{file}" and "{file}")'
             ),
         ):
-            self.local_artifact.add_local_file(file)
+            self.test_artifact_class._create(
+                data=self.data,
+                files=[NewLocalFile(file=file), NewLocalFile(file=file)],
+            )
 
     def test_add_local_file_already_remote(self) -> None:
         """add_local_file() raise ValueError: remote file is already added."""
         file = self.create_temporary_file()
         file_request = FileRequest.create_from(file)
-        self.local_artifact.add_remote_file(file.name, file_request)
 
         with self.assertRaisesRegex(
             ValueError,
@@ -218,27 +227,35 @@ class LocalArtifactTests(TestCase):
                 f'is already in the artifact ("{file_request}" and "{file}")'
             ),
         ):
-            self.local_artifact.add_local_file(file)
+            self.test_artifact_class._create(
+                data=self.data,
+                files=[
+                    NewRemoteFile(
+                        path_in_artifact=file.name, file_request=file_request
+                    ),
+                    NewLocalFile(file=file),
+                ],
+            )
 
     def test_add_remote_file(self) -> None:
         """add_remote_file() adds a file that does not exist locally."""
         file_request = FileRequest(
-            size=1,
-            checksums={
-                "sha256": pydantic.parse_obj_as(StrMaxLength255, "0" * 64)
-            },
-            type="file",
+            size=1, checksums={"sha256": "0" * 64}, type="file"
+        )
+        artifact = self.test_artifact_class._create(
+            data=self.data,
+            files=[
+                NewRemoteFile(
+                    path_in_artifact="path", file_request=file_request
+                )
+            ],
         )
-        self.local_artifact.add_remote_file("path", file_request)
 
-        self.assertEqual(
-            self.local_artifact.remote_files, {"path": file_request}
-        )
+        self.assertEqual(artifact.remote_files, {"path": file_request})
 
     def test_add_remote_file_already_local(self) -> None:
         """add_remote_file() raise ValueError: local file is already added."""
         file = self.create_temporary_file()
-        self.local_artifact.add_local_file(file)
         file_request = FileRequest.create_from(file)
 
         with self.assertRaisesRegex(
@@ -249,7 +266,15 @@ class LocalArtifactTests(TestCase):
                 f'is already in the artifact ("{file}" and "{file_request}")'
             ),
         ):
-            self.local_artifact.add_remote_file(file.name, file_request)
+            self.test_artifact_class._create(
+                data=self.data,
+                files=[
+                    NewLocalFile(file=file),
+                    NewRemoteFile(
+                        path_in_artifact=file.name, file_request=file_request
+                    ),
+                ],
+            )
 
     def test_validate_category(self) -> None:
         """Creating a new artifact validates its category."""
@@ -258,8 +283,8 @@ class LocalArtifactTests(TestCase):
             r"Invalid category: 'nonexistent'",
             WorkRequestDebugLogs,
             category="nonexistent",
-            files=self.files,
             data=self.data,
+            files=[],
         )
 
     def test_validate_files_length(self) -> None:
@@ -285,13 +310,6 @@ class PackageBuildLogTests(TestCase):
     def setUp(self) -> None:
         """Set up for the tests."""
         super().setUp()
-        self.file = FileRequest(
-            size=10,
-            checksums={
-                "sha256": pydantic.parse_obj_as(StrMaxLength255, "hash")
-            },
-            type="file",
-        )
 
         self.directory = self.create_temporary_directory()
 
@@ -341,7 +359,7 @@ class PackageBuildLogTests(TestCase):
 
     def test_validate_files_number_success(self) -> None:
         """files_number_must_be_one() return files."""
-        files = {"log.build": self.file}
+        files = {"log.build": self.build_file}
 
         self.assertEqual(
             PackageBuildLog.validate_files_length_is_one(files),
@@ -350,7 +368,7 @@ class PackageBuildLogTests(TestCase):
 
     def test_validate_file_ends_with_build(self) -> None:
         """File ends with .build: files_must_end_in_build return files."""
-        files = {"log.build": self.file}
+        files = {"log.build": self.build_file}
 
         self.assertEqual(PackageBuildLog.file_must_end_in_build(files), files)
 
@@ -359,8 +377,8 @@ class PackageBuildLogTests(TestCase):
         file = self.create_temporary_file(suffix=".txt")
 
         expected_message = (
-            fr"""^Valid file suffixes: \['\.build'\]. """
-            fr"""Invalid filename: "{file.name}"$"""
+            rf"""^Valid file suffixes: \['\.build'\]. """
+            rf"""Invalid filename: "{file.name}"$"""
         )
 
         with self.assertRaisesRegex(ValueError, expected_message):
@@ -390,11 +408,7 @@ class UploadTests(TestCase):
         self.workspace = "workspace"
 
         self.file = FileRequest(
-            size=10,
-            checksums={
-                "sha256": pydantic.parse_obj_as(StrMaxLength255, "hash")
-            },
-            type="file",
+            size=10, checksums={"sha256": "hash"}, type="file"
         )
 
     def test_create(self) -> None:
@@ -429,22 +443,6 @@ class UploadTests(TestCase):
 
         self.assertEqual(artifact, expected)
 
-    def test_create_skip_excluded_files(self) -> None:
-        """Upload.create() does not add the excluded file."""
-        changes_file = self.create_temporary_file(suffix=".changes")
-
-        extra_file = self.create_temporary_file()
-
-        self.write_changes_file(changes_file, files=[extra_file])
-
-        binary_upload = Upload.create(
-            changes_file=changes_file, exclude_files={extra_file}
-        )
-
-        files = {changes_file.name: changes_file}
-
-        self.assertEqual(binary_upload.files, files)
-
     def test_create_no_files_in_changes(self) -> None:
         """Upload.create() return a package, .changes has no files."""
         changes_file = self.create_temporary_file(suffix=".changes")
@@ -497,25 +495,41 @@ class UploadTests(TestCase):
         """Raise ValueError: missing expected .changes file."""
         file = self.create_temporary_file()
 
-        files = {file.name: file}
+        upload = Upload.model_construct(
+            category=Upload._category,
+            files={file.name: file},
+            data=data_models.DebianUpload.model_construct(
+                type="dpkg", changes_fields={}
+            ),
+        )
 
-        expected_message = fr"Expecting 1 \.changes file in \['{file.name}'\]"
+        expected_message = rf"Expecting 1 \.changes file in \['{file.name}'\]"
         with self.assertRaisesRegex(ValueError, expected_message):
-            Upload.files_contain_changes({"files": files})
+            # Model validators appear as non-callable proxies while
+            # type-checking, but can be called at run-time.
+            upload.files_contain_changes()  # type: ignore[operator]
 
     def test_files_contain_2_changes_raise_value_error(self) -> None:
-        """Raise ValueError: missing expected .changes file."""
+        """Raise ValueError: two .changes files."""
         file1 = self.create_temporary_file(suffix=".changes")
         file2 = self.create_temporary_file(suffix=".changes")
 
-        files = {
-            file1.name: file1,
-            file2.name: file2,
-        }
+        upload = Upload.model_construct(
+            category=Upload._category,
+            files={
+                file1.name: file1,
+                file2.name: file2,
+            },
+            data=data_models.DebianUpload.model_construct(
+                type="dpkg", changes_fields={}
+            ),
+        )
 
         expected_message = r"Expecting 1 \.changes file in \["
         with self.assertRaisesRegex(ValueError, expected_message):
-            Upload.files_contain_changes({"files": files})
+            # Model validators appear as non-callable proxies while
+            # type-checking, but can be called at run-time.
+            upload.files_contain_changes()  # type: ignore[operator]
 
     def test_files_contain_changes_return_files(self) -> None:
         """Return files: .changes found."""
@@ -523,10 +537,19 @@ class UploadTests(TestCase):
 
         self.write_changes_file(changes_file, files=[changes_file])
 
-        files = {changes_file.name: changes_file}
+        upload = Upload.model_construct(
+            category=Upload._category,
+            files={changes_file.name: changes_file},
+            data=data_models.DebianUpload.model_construct(
+                type="dpkg", changes_fields={}
+            ),
+        )
 
+        # Model validators appear as non-callable proxies while
+        # type-checking, but can be called at run-time.
         self.assertEqual(
-            Upload.files_contain_changes({"files": files}), {"files": files}
+            upload.files_contain_changes(),  # type: ignore[operator]
+            upload,
         )
 
     def test_files_contains_files_in_changes_call_implementation(self) -> None:
@@ -538,9 +561,19 @@ class UploadTests(TestCase):
         mocked = patcher.start()
         self.addCleanup(patcher.stop)
 
+        upload = Upload.model_construct(
+            category=Upload._category,
+            files=files,
+            data=data_models.DebianUpload.model_construct(
+                type="dpkg", changes_fields={}
+            ),
+        )
+
         self.assertEqual(
-            Upload.files_contains_files_in_changes({"files": files}),
-            {"files": files},
+            # Model validators appear as non-callable proxies while
+            # type-checking, but can be called at run-time.
+            upload.files_contains_files_in_changes(),  # type: ignore[operator]
+            upload,
         )
 
         mocked.assert_called_with(
@@ -630,14 +663,14 @@ class BinaryPackageTests(TestCase):
         """files_must_end_in_deb_or_udeb() returns the files."""
         for name in ("hello_2.10-2_amd64.deb", "hello_2.10-2_amd64.udeb"):
             self.assertEqual(
-                BinaryPackage.files_must_end_in_deb_or_udeb({name: None}),
-                {name: None},
+                BinaryPackage.files_must_end_in_deb_or_udeb({name: Path(name)}),
+                {name: Path(name)},
             )
 
     def test_files_must_end_in_deb_raise_value_error(self) -> None:
         """files_must_end_in_deb_or_udeb() raises ValueError."""
         filename = "README.txt"
-        files = {filename: None}
+        files = {filename: Path(filename)}
         with self.assertRaisesRegex(
             ValueError,
             rf"^Valid file suffixes: \['.deb', '.udeb'\]. "
@@ -647,7 +680,7 @@ class BinaryPackageTests(TestCase):
 
     def test_files_exactly_one(self) -> None:
         """files_exactly_one() returns the files."""
-        files = {"hello.deb": None}
+        files = {"hello.deb": Path("hello.deb")}
 
         self.assertEqual(BinaryPackage.files_exactly_one(files), files)
 
@@ -660,7 +693,10 @@ class BinaryPackageTests(TestCase):
         """files_exactly_one() raises ValueError: too many files."""
         with self.assertRaisesRegex(ValueError, "Must have exactly one file"):
             BinaryPackage.files_exactly_one(
-                {"hello.deb": None, "hello2.deb": None}
+                {
+                    "hello.deb": Path("hello.deb"),
+                    "hello2.deb": Path("hello2.deb"),
+                }
             )
 
     def test_json_serializable(self) -> None:
@@ -722,8 +758,8 @@ class BinaryPackagesTests(TestCase):
     def test_files_must_end_in_deb_or_udeb(self) -> None:
         """files_must_end_in_deb_or_udeb() return the files."""
         files = {
-            "hello_2.10-2_amd64.deb": None,
-            "hello_2.10-2_amd64.udeb": None,
+            name: Path(name)
+            for name in ("hello_2.10-2_amd64.deb", "hello_2.10-2_amd64.udeb")
         }
         self.assertEqual(
             BinaryPackages.files_must_end_in_deb_or_udeb(files),
@@ -733,7 +769,7 @@ class BinaryPackagesTests(TestCase):
     def test_files_must_end_in_deb_raise_value_error(self) -> None:
         """files_must_end_in_deb_or_udeb() raise ValueError."""
         filename = "README.txt"
-        files = {filename: None}
+        files = {filename: Path(filename)}
         with self.assertRaisesRegex(
             ValueError,
             rf"^Valid file suffixes: \['.deb', '.udeb'\]. "
@@ -743,7 +779,7 @@ class BinaryPackagesTests(TestCase):
 
     def test_files_more_than_zero(self) -> None:
         """files_more_than_zero() return the files."""
-        files = {"hello.deb": None, "hello2.deb": None}
+        files = {name: Path(name) for name in ("hello.deb", "hello2.deb")}
 
         self.assertEqual(BinaryPackages.files_more_than_zero(files), files)
 
@@ -814,15 +850,18 @@ class SourcePackageTests(TestCase):
 
     def test_create(self) -> None:
         """Test create(): return expected instance."""
-        file = self.create_temporary_file()
-        dsc_file = self.create_temporary_file(suffix=".dsc")
-
-        dsc_fields = self.write_dsc_example_file(dsc_file)
+        temp_directory = self.create_temporary_directory()
+        tar_file = temp_directory / "hello_1.0.tar.gz"
+        tar_file.write_bytes(b"test")
+        dsc_file = temp_directory / "pkg_1.0.dsc"
+        dsc_fields = ArtifactPlayground.write_deb822_file(
+            deb822.Dsc, dsc_file, [tar_file], source="hello", version="1.0"
+        )
 
         name = dsc_fields["Source"]
         version = dsc_fields["Version"]
 
-        expected_files = {file.name: file, dsc_file.name: dsc_file}
+        expected_files = {tar_file.name: tar_file, dsc_file.name: dsc_file}
         expected_data = data_models.DebianSourcePackage(
             name=name,
             version=version,
@@ -831,7 +870,7 @@ class SourcePackageTests(TestCase):
         )
 
         package = SourcePackage.create(
-            name=name, version=version, files=[file, dsc_file]
+            name=name, version=version, files=[tar_file, dsc_file]
         )
 
         self.assertEqual(package.category, SourcePackage._category)
@@ -842,7 +881,7 @@ class SourcePackageTests(TestCase):
         """Raise ValueError: invalid .dsc file."""
         file = self.create_temporary_file(suffix=".dsc")
 
-        expected_message = fr"{file.name} is not a valid \.dsc file"
+        expected_message = rf"{file.name} is not a valid \.dsc file"
         with self.assertRaisesRegex(ValueError, expected_message):
             SourcePackage.create(name="hello", version="1.0", files=[file])
 
@@ -852,7 +891,7 @@ class SourcePackageTests(TestCase):
 
         files = {file.name: file}
 
-        expected_message = fr"Expecting 1 \.dsc file in \['{file.name}'\]"
+        expected_message = rf"Expecting 1 \.dsc file in \['{file.name}'\]"
         with self.assertRaisesRegex(ValueError, expected_message):
             SourcePackage.files_contain_one_dsc(
                 files,
@@ -1015,7 +1054,7 @@ class LintianTests(TestCase):
 
     def test_validate_required_files_valid(self) -> None:
         """Test validate_required_files: is valid. return files."""
-        files = {"analysis.json": "", "lintian.txt": ""}
+        files = {name: Path(name) for name in ("analysis.json", "lintian.txt")}
 
         self.assertEqual(LintianArtifact._validate_required_files(files), files)
 
@@ -1026,7 +1065,9 @@ class LintianTests(TestCase):
         msg = r"^Files required: \['analysis.json', 'lintian.txt'\]$"
 
         with self.assertRaisesRegex(ValueError, msg):
-            LintianArtifact._validate_required_files({"summary.json": ""})
+            LintianArtifact._validate_required_files(
+                {"summary.json": Path("summary.json")}
+            )
 
     def test_json_serializable(self) -> None:
         """Artifact returned by create is JSON serializable."""
@@ -1142,7 +1183,7 @@ class DebianSystemTarballArtifactTests(TestCase):
                 "mirror": "https://deb.debian.org",
                 "components": ["main"],
                 "variant": "minbase",
-                "pkglist": [],
+                "pkglist": {},
                 "architecture": "amd64",
                 "with_dev": True,
                 "with_init": True,
@@ -1453,9 +1494,11 @@ class SigningInputArtifactTests(TestCase):
 
         artifact = SigningInputArtifact.create([unsigned], base_dir)
 
-        artifact.validate_model()
         self.assertEqual(
-            artifact.data, {"trusted_certs": None, "binary_package_name": None}
+            artifact.data,
+            data_models.DebusineSigningInput(
+                trusted_certs=None, binary_package_name=None
+            ),
         )
         self.assertEqual(artifact.files, {"package/dir/file": unsigned})
         self.assertEqual(
@@ -1477,10 +1520,11 @@ class SigningInputArtifactTests(TestCase):
             [unsigned_1, unsigned_2], base_dir, trusted_certs=["0" * 64]
         )
 
-        artifact.validate_model()
         self.assertEqual(
             artifact.data,
-            {"trusted_certs": ["0" * 64], "binary_package_name": None},
+            data_models.DebusineSigningInput(
+                trusted_certs=["0" * 64], binary_package_name=None
+            ),
         )
         self.assertEqual(
             artifact.files,
@@ -1508,10 +1552,11 @@ class SigningInputArtifactTests(TestCase):
             [unsigned], base_dir, binary_package_name="hello"
         )
 
-        artifact.validate_model()
         self.assertEqual(
             artifact.data,
-            {"trusted_certs": None, "binary_package_name": "hello"},
+            data_models.DebusineSigningInput(
+                trusted_certs=None, binary_package_name="hello"
+            ),
         )
         self.assertEqual(artifact.files, {"package/dir/file": unsigned})
         self.assertEqual(
@@ -1523,10 +1568,8 @@ class SigningInputArtifactTests(TestCase):
         """A SigningInputArtifact must have at least one file."""
         base_dir = self.create_temporary_directory()
 
-        artifact = SigningInputArtifact.create([], base_dir)
-
         with self.assertRaisesRegex(ValueError, "Expected at least one file"):
-            artifact.validate_model()
+            SigningInputArtifact.create([], base_dir)
 
 
 class SigningOutputArtifactTests(TestCase):
@@ -1550,15 +1593,14 @@ class SigningOutputArtifactTests(TestCase):
             base_dir,
         )
 
-        artifact.validate_model()
         self.assertEqual(
             artifact.data,
-            {
-                "purpose": KeyPurpose.UEFI,
-                "fingerprint": "0" * 64,
-                "results": [result],
-                "binary_package_name": None,
-            },
+            data_models.DebusineSigningOutput(
+                purpose=KeyPurpose.UEFI,
+                fingerprint="0" * 64,
+                results=[result],
+                binary_package_name=None,
+            ),
         )
         self.assertEqual(artifact.files, {"package/dir/file.sig": output_file})
         self.assertEqual(
@@ -1585,15 +1627,14 @@ class SigningOutputArtifactTests(TestCase):
             binary_package_name="hello",
         )
 
-        artifact.validate_model()
         self.assertEqual(
             artifact.data,
-            {
-                "purpose": KeyPurpose.UEFI,
-                "fingerprint": "0" * 64,
-                "results": [result],
-                "binary_package_name": "hello",
-            },
+            data_models.DebusineSigningOutput(
+                purpose=KeyPurpose.UEFI,
+                fingerprint="0" * 64,
+                results=[result],
+                binary_package_name="hello",
+            ),
         )
         self.assertEqual(artifact.files, {"package/dir/file.sig": output_file})
         self.assertEqual(
@@ -1614,7 +1655,6 @@ class RepositoryIndexTests(TestCase):
 
         artifact = RepositoryIndex.create(file=release, path="Release")
 
-        artifact.validate_model()
         self.assertEqual(
             artifact,
             RepositoryIndex(
@@ -1637,7 +1677,6 @@ class RepositoryIndexTests(TestCase):
             content_type="text/plain; charset=utf-8",
         )
 
-        artifact.validate_model()
         self.assertEqual(
             artifact,
             RepositoryIndex(
