@@ -1,4 +1,4 @@
-# Copyright 2024 The Debusine Developers
+# Copyright © The Debusine Developers
 # See the AUTHORS file at the top-level directory of this distribution
 #
 # This file is part of Debusine. It is subject to the license terms
@@ -135,10 +135,7 @@ class ArtifactPlaygroundTest(TestCase):
             "Changes": "\n".join(
                 (
                     "",
-                    (
-                        f"  hello ({expected_version}) unstable; "
-                        f"urgency=medium"
-                    ),
+                    f"  hello ({expected_version}) unstable; urgency=medium",
                     "  .",
                     "    * Test upload.",
                 )
@@ -203,7 +200,7 @@ class ArtifactPlaygroundTest(TestCase):
         """Check building a source+binary upload."""
         workdir = self.create_temporary_directory()
         upload = ArtifactPlayground.create_upload(
-            workdir, binary=True, binaries=["hello"]
+            workdir, binary=True, binaries=[("hello", "all")]
         )
         self.assertUpload(
             upload,
