@@ -17,11 +17,13 @@ from debusine.assets.models import (
     BaseAssetDataModel,
     CloudProviderAccountData,
     CloudProvidersType,
+    DummyProviderAccountData,
     HetznerProviderAccountConfiguration,
     HetznerProviderAccountCredentials,
     HetznerProviderAccountData,
     KeyPurpose,
     SigningKeyData,
+    asset_categories,
     asset_data_model,
 )
 
@@ -33,10 +35,12 @@ __all__ = [
     "BaseAssetDataModel",
     "CloudProviderAccountData",
     "CloudProvidersType",
+    "DummyProviderAccountData",
     "HetznerProviderAccountConfiguration",
     "HetznerProviderAccountCredentials",
     "HetznerProviderAccountData",
     "KeyPurpose",
     "SigningKeyData",
+    "asset_categories",
     "asset_data_model",
 ]
