@@ -35,7 +35,7 @@ class TestBaseAssetDataModel(TestCase):
             public_key=base64.b64encode(b"PUBLIC").decode(),
             description="A Test Signing Key",
         )
-        model = asset_data_model(AssetCategory.SIGNING_KEY, data.dict())
+        model = asset_data_model(AssetCategory.SIGNING_KEY, data.model_dump())
         self.assertEqual(model, data)
 
     def test_asset_data_model_unknown(self) -> None:
@@ -60,7 +60,7 @@ class TestBaseAssetDataModel(TestCase):
             ),
         )
         model = asset_data_model(
-            AssetCategory.CLOUD_PROVIDER_ACCOUNT, data.dict()
+            AssetCategory.CLOUD_PROVIDER_ACCOUNT, data.model_dump()
         )
         self.assertEqual(model, data)
 
@@ -101,15 +101,20 @@ class SigningKeyDataTests(TestCase):
     """Test the SigningKeyData model."""
 
     def test_public_key_base64(self) -> None:
-        SigningKeyData(
+        signing_key_data = SigningKeyData(
             purpose=KeyPurpose.UEFI,
             fingerprint="ABC123",
             public_key=base64.b64encode(b"PUBLIC").decode(),
             description=None,
         )
+        self.assertEqual(signing_key_data.public_key, b"PUBLIC")
+        self.assertEqual(
+            signing_key_data.model_dump()["public_key"],
+            base64.b64encode(b"PUBLIC").decode(),
+        )
 
     def test_public_key_not_base64(self) -> None:
-        with self.assertRaisesRegex(ValueError, "data must be base64-encoded"):
+        with self.assertRaisesRegex(ValueError, r"Base64 decoding error"):
             SigningKeyData(
                 purpose=KeyPurpose.UEFI,
                 fingerprint="ABC123",
