@@ -22,6 +22,7 @@ import rich.console
 import yaml
 
 from debusine.client import exceptions
+from debusine.client.cli import Cli
 from debusine.client.commands.base import (
     Command,
     DebusineCommand,
@@ -31,10 +32,7 @@ from debusine.client.commands.base import (
 )
 from debusine.client.commands.tests.base import BaseCliTests
 from debusine.client.exceptions import DebusineError, NotFoundError
-from debusine.client.models import (
-    StrictBaseModel,
-    model_to_json_serializable_dict,
-)
+from debusine.client.models import StrictBaseModel
 
 
 class CommandTests(BaseCliTests):
@@ -55,8 +53,7 @@ class CommandTests(BaseCliTests):
             def run(self) -> None:
                 raise NotImplementedError("MockCommand.run")
 
-        args = self.build_parsed_namespace(**kwargs)
-        return MockCommand(args)
+        return self.command(MockCommand, **kwargs)
 
     def make_base_parser(
         self,
@@ -101,7 +98,7 @@ class CommandTests(BaseCliTests):
         self.assertNotIn(Abstract, Command.commands_by_group[None])
 
     def test_add_subparsers_group_not_found(self) -> None:
-        parser, subparsers = self.make_base_parser()
+        _, subparsers = self.make_base_parser()
         with self.assertRaisesRegex(
             KeyError, r"Command group 'does-not-exist' not found in "
         ):
@@ -118,7 +115,7 @@ class CommandTests(BaseCliTests):
             def run(self) -> None:
                 pass  # pragma: no cover
 
-        parser, subparsers = self.make_base_parser()
+        _, subparsers = self.make_base_parser()
         with self.assertRaisesRegex(AssertionError, r".+ lacks a docstring"):
             Command.add_subparser(
                 subparsers,
@@ -130,12 +127,12 @@ class CommandTests(BaseCliTests):
     @Command.preserve_registry()
     def test_create_not_found(self) -> None:
         args = self.build_parsed_namespace()
-        self.assertIsNone(Command.create(args))
+        self.assertIsNone(Command.create(Cli.build_argument_parser(), args))
 
     def test_print_yaml(self) -> None:
         cmd = self.build_command()
         data = {"message": "x" * 100}
-        stderr, stdout = self.capture_output(cmd._print_yaml, args=[data])
+        _, stdout = self.capture_output(cmd._print_yaml, args=[data])
         self.assertEqual(stdout.count("\n"), 1)
 
     def test_print_yaml_stderr(self) -> None:
@@ -357,8 +354,7 @@ class DebusineCommandTests(BaseCliTests):
             def run(self) -> None:
                 raise NotImplementedError("MockCommand.run")
 
-        args = self.build_parsed_namespace(**kwargs)
-        return MockCommand(args)
+        return self.command(MockCommand, **kwargs)
 
     def test_debug(self) -> None:
         """Cli with --debug."""
@@ -422,7 +418,7 @@ class DebusineCommandTests(BaseCliTests):
 
     def test_no_server_found_by_fqdn_and_scope(self) -> None:
         """Cli fails if no matching server is found by FQDN/scope."""
-        stderr, stdout = self.capture_output(
+        stderr, _ = self.capture_output(
             partial(
                 self.build_debusine_command,
                 server="nonexistent.example.org/scope",
@@ -438,7 +434,7 @@ class DebusineCommandTests(BaseCliTests):
 
     def test_no_server_found_by_name(self) -> None:
         """Cli fails if no matching server is found by name."""
-        stderr, stdout = self.capture_output(
+        stderr, _ = self.capture_output(
             partial(self.build_debusine_command, server="nonexistent"),
             assert_system_exit_code=3,
         )
@@ -477,7 +473,7 @@ class DebusineCommandTests(BaseCliTests):
             with cmd._api_call_or_fail():
                 raise NotFoundError("Not found")
 
-        stderr, stdout = self.capture_output(
+        stderr, _ = self.capture_output(
             raiseNotFound, assert_system_exit_code=3
         )
 
@@ -491,7 +487,7 @@ class DebusineCommandTests(BaseCliTests):
             with cmd._api_call_or_fail():
                 raise exceptions.UnexpectedResponseError("Not available")
 
-        stderr, stdout = self.capture_output(
+        stderr, _ = self.capture_output(
             raiseUnexpectedResponseError, assert_system_exit_code=3
         )
 
@@ -509,7 +505,7 @@ class DebusineCommandTests(BaseCliTests):
             with cmd._api_call_or_fail():
                 raise exceptions.ClientForbiddenError("Invalid token")
 
-        stderr, stdout = self.capture_output(
+        stderr, _ = self.capture_output(
             raiseClientForbiddenError, assert_system_exit_code=3
         )
 
@@ -527,7 +523,7 @@ class DebusineCommandTests(BaseCliTests):
             with cmd._api_call_or_fail():
                 raise exceptions.ClientConnectionError("Connection refused")
 
-        stderr, stdout = self.capture_output(
+        stderr, _ = self.capture_output(
             raiseClientConnectionError, assert_system_exit_code=3
         )
 
@@ -566,8 +562,7 @@ class WorkspaceCommandTests(BaseCliTests):
             def run(self) -> None:
                 raise NotImplementedError("MockWorkspaceCommand.run")
 
-        args = self.build_parsed_namespace(**kwargs)
-        return MockWorkspaceCommand(args)
+        return self.command(MockWorkspaceCommand, **kwargs)
 
     def test_workspace_default(self) -> None:
         config = self.create_temporary_file()
@@ -624,17 +619,18 @@ class ModelCommandTests(BaseCliTests):
                 raise NotImplementedError("MockWorkspaceCommand.run")
 
             def _list_rich(
-                self, instances: Iterable[StrictBaseModel]  # noqa: U100
+                self,
+                instances: Iterable[StrictBaseModel],  # noqa: ARG002, U100
             ) -> None:
                 print("LIST")
 
             def _show_rich(
-                self, instance: StrictBaseModel  # noqa: U100
+                self,
+                instance: StrictBaseModel,  # noqa: ARG002, U100
             ) -> None:
                 print("SHOW")
 
-        args = self.build_parsed_namespace(**kwargs)
-        return MockModelCommand(args)
+        return self.command(MockModelCommand, **kwargs)
 
     def test_list_yaml(self) -> None:
         sample = StrictBaseModel()
@@ -643,7 +639,7 @@ class ModelCommandTests(BaseCliTests):
             partial(command._list_yaml, [sample])
         )
         self.assertEqual(
-            yaml.safe_load(stdout), [model_to_json_serializable_dict(sample)]
+            yaml.safe_load(stdout), [sample.model_dump(mode="json")]
         )
         self.assertEqual(stderr, "")
         self.assertEqual(stdout.splitlines()[0], "- {}")
@@ -656,7 +652,7 @@ class ModelCommandTests(BaseCliTests):
             partial(command._list_yaml, [sample])
         )
         self.assertEqual(
-            yaml.safe_load(stdout), [model_to_json_serializable_dict(sample)]
+            yaml.safe_load(stdout), [sample.model_dump(mode="json")]
         )
         self.assertEqual(stderr, "")
         self.assertEqual(stdout.splitlines()[0], "---")
@@ -699,9 +695,7 @@ class ModelCommandTests(BaseCliTests):
         stderr, stdout = self.capture_output(
             partial(command._show_yaml, sample)
         )
-        self.assertEqual(
-            yaml.safe_load(stdout), model_to_json_serializable_dict(sample)
-        )
+        self.assertEqual(yaml.safe_load(stdout), sample.model_dump(mode="json"))
         self.assertNotEqual(stdout.splitlines()[0], "---")
         self.assertEqual(stderr, "")
 
@@ -712,9 +706,7 @@ class ModelCommandTests(BaseCliTests):
         stderr, stdout = self.capture_output(
             partial(command._show_yaml, sample)
         )
-        self.assertEqual(
-            yaml.safe_load(stdout), model_to_json_serializable_dict(sample)
-        )
+        self.assertEqual(yaml.safe_load(stdout), sample.model_dump(mode="json"))
         self.assertEqual(stdout.splitlines()[0], "---")
         self.assertEqual(stderr, "")
 
@@ -769,8 +761,7 @@ class InputDataCommandTests(BaseCliTests):
             def run(self) -> None:
                 raise NotImplementedError("MockWorkspaceCommand.run")
 
-        args = self.build_parsed_namespace(**kwargs)
-        return MockCommand(args)
+        return self.command(MockCommand, **kwargs)
 
     def test_read_file(self) -> None:
         path = self.create_temporary_file()
@@ -781,7 +772,7 @@ class InputDataCommandTests(BaseCliTests):
     def test_read_file_empty(self) -> None:
         path = self.create_temporary_file()
         command = self.build_command()
-        stderr, stdout = self.capture_output(
+        stderr, _ = self.capture_output(
             partial(command.read_input_data, path.as_posix()),
             assert_system_exit_code=3,
         )
