@@ -19,6 +19,8 @@ from pathlib import Path
 from typing import NamedTuple, NoReturn, Self, TextIO
 from urllib.parse import urlparse
 
+from debusine.utils.urls import URLPath
+
 
 class ServerInfo(NamedTuple):
     """Information about a known server."""
@@ -130,16 +132,13 @@ class ServerInfo(NamedTuple):
         if not server_url_parsed.scheme:
             server_url_parsed = server_url_parsed._replace(scheme="https")
 
-        if os.path.basename(server_url_parsed.path.rstrip("/")) != "api":
-            api_url_parsed = server_url_parsed._replace(
-                path=os.path.join(server_url_parsed.path, "api")
-            )
-        else:
-            api_url_parsed = server_url_parsed
+        api_path = URLPath(server_url_parsed.path, is_file=False)
+        if not api_path or api_path[-1] != "api":
+            api_path += "api/"
 
-        api_url = urllib.parse.urlunparse(api_url_parsed)
-        if not api_url.endswith("/"):
-            api_url += "/"
+        api_url = urllib.parse.urlunparse(
+            server_url_parsed._replace(path=str(api_path))
+        )
 
         return cls(
             name=server_name, desc=desc, api_url=api_url, scope="debusine"
