@@ -8,23 +8,18 @@
 # contained in the LICENSE file.
 
 """DebusineHttpClient interact with the debusine server API."""
-from collections.abc import Callable, Generator
-from typing import Any, TypeVar, overload
 
-try:
-    from pydantic.v1 import BaseModel, ValidationError
-except ImportError:
-    from pydantic import BaseModel, ValidationError  # type: ignore
+from collections.abc import Callable, Generator
+from typing import Any, overload
 
 import requests
-from requests.compat import json  # type: ignore  # noqa: I202
+from pydantic import BaseModel, ValidationError
+from requests.compat import json  # type: ignore
 from urllib3.util import Retry
 
 from debusine.client import exceptions
 from debusine.client.models import PaginatedResponse
 
-ClientModel = TypeVar("ClientModel", bound=BaseModel)
-
 
 class DebusineHttpClient:
     """DebusineHttpClient interact with the debusine server API."""
@@ -39,11 +34,13 @@ class DebusineHttpClient:
 
         self._session: requests.Session | None = None
 
-    def get(self, path: str, expected_class: type[ClientModel]) -> ClientModel:
+    def get[ClientModel: BaseModel](
+        self, path: str, expected_class: type[ClientModel]
+    ) -> ClientModel:
         """Make an HTTP GET request to path, return object of expected_class."""
         return self._api_request("GET", self._api_url + path, expected_class)
 
-    def iter_paginated_get(
+    def iter_paginated_get[ClientModel: BaseModel](
         self, path: str, expected_class: type[ClientModel]
     ) -> Generator[ClientModel]:
         """
@@ -56,7 +53,7 @@ class DebusineHttpClient:
             r = self._api_request("GET", url, PaginatedResponse)
             for result in r.results:
                 try:
-                    yield expected_class.parse_obj(result)
+                    yield expected_class.model_validate(result)
                 except ValidationError as exc:
                     raise exceptions.UnexpectedResponseError(
                         f"Server ({url}) did not return valid object. "
@@ -64,7 +61,7 @@ class DebusineHttpClient:
                     ) from exc
             if not r.next:
                 break
-            url = r.next
+            url = str(r.next)
 
     @overload
     def post(
@@ -77,7 +74,7 @@ class DebusineHttpClient:
     ) -> None: ...
 
     @overload
-    def post(
+    def post[ClientModel: BaseModel](
         self,
         path: str,
         expected_class: type[ClientModel],
@@ -86,7 +83,7 @@ class DebusineHttpClient:
         expected_statuses: list[int] | None = None,
     ) -> ClientModel: ...
 
-    def post(
+    def post[ClientModel: BaseModel](
         self,
         path: str,
         expected_class: type[ClientModel] | None,
@@ -107,7 +104,7 @@ class DebusineHttpClient:
             expected_statuses=expected_statuses,
         )
 
-    def put(
+    def put[ClientModel: BaseModel](
         self,
         path: str,
         expected_class: type[ClientModel] | None,
@@ -139,7 +136,7 @@ class DebusineHttpClient:
     ) -> None: ...
 
     @overload
-    def patch(
+    def patch[ClientModel: BaseModel](
         self,
         path: str,
         expected_class: type[ClientModel],
@@ -148,7 +145,7 @@ class DebusineHttpClient:
         expected_statuses: list[int] | None = None,
     ) -> ClientModel: ...
 
-    def patch(
+    def patch[ClientModel: BaseModel](
         self,
         path: str,
         expected_class: type[ClientModel] | None,
@@ -169,7 +166,7 @@ class DebusineHttpClient:
             expected_statuses=expected_statuses,
         )
 
-    def delete(
+    def delete[ClientModel: BaseModel](
         self,
         path: str,
         *,
@@ -202,7 +199,7 @@ class DebusineHttpClient:
         return method_to_func[method]
 
     @staticmethod
-    def _handle_response_content(
+    def _handle_response_content[ClientModel: BaseModel](
         content: bytes,
         expected_class: type[ClientModel] | None,
         url: str,
@@ -217,7 +214,7 @@ class DebusineHttpClient:
                 return None
         else:
             try:
-                return expected_class.parse_raw(content)
+                return expected_class.model_validate_json(content)
             except ValidationError as exc:
                 raise exceptions.UnexpectedResponseError(
                     f"Server ({url}) did not return valid object. "
@@ -236,7 +233,7 @@ class DebusineHttpClient:
     ) -> None: ...
 
     @overload
-    def _api_request(
+    def _api_request[ClientModel: BaseModel](
         self,
         method: str,
         url: str,
@@ -246,7 +243,7 @@ class DebusineHttpClient:
         expected_statuses: list[int] | None = None,
     ) -> ClientModel: ...
 
-    def _api_request(
+    def _api_request[ClientModel: BaseModel](
         self,
         method: str,
         url: str,
