@@ -20,11 +20,7 @@ from typing import Any, NamedTuple, Self, TypeAlias
 import yaml
 
 from debusine.artifacts.models import DebusineTaskConfiguration, TaskTypes
-from debusine.client.models import (
-    StrictBaseModel,
-    TaskConfigurationCollection,
-    model_to_json_serializable_dict,
-)
+from debusine.client.models import StrictBaseModel, TaskConfigurationCollection
 
 
 class InvalidRepository(Exception):
@@ -155,7 +151,7 @@ class LocalTaskConfigurationRepository(TaskConfigurationRepositoryBase):
         """Return the hash of the current git commit."""
         return None
 
-    def has_commit(self, commit: str) -> bool:  # noqa: U100
+    def has_commit(self, commit: str) -> bool:  # noqa: ARG002, U100
         """Check if the given commit hash is in our history."""
         return False
 
@@ -169,7 +165,7 @@ class LocalTaskConfigurationRepository(TaskConfigurationRepositoryBase):
             raise InvalidRepository("Repository manifest has not been set")
         try:
             with self.manifest_path.open("wt") as fd:
-                yaml.safe_dump(self.manifest.dict(), fd)
+                yaml.safe_dump(self.manifest.model_dump(), fd)
         except Exception as exc:
             exc.add_note(f"manifest: {self.manifest_path}")
             raise
@@ -189,7 +185,7 @@ class LocalTaskConfigurationRepository(TaskConfigurationRepositoryBase):
 
     def _merge_manifest(self, manifest: Manifest) -> None:
         if self.manifest is None:
-            self.manifest = manifest.copy()
+            self.manifest = manifest.model_copy()
         elif (
             self.manifest.workspace != manifest.workspace
             or self.manifest.collection.id != manifest.collection.id
@@ -292,11 +288,9 @@ class LocalTaskConfigurationRepository(TaskConfigurationRepositoryBase):
 
                 new_data: Any
                 if len(entries) == 1:
-                    new_data = model_to_json_serializable_dict(entries[0].item)
+                    new_data = entries[0].item.model_dump(mode="json")
                 else:
-                    new_data = [
-                        model_to_json_serializable_dict(e.item) for e in entries
-                    ]
+                    new_data = [e.item.model_dump(mode="json") for e in entries]
 
                 # If the file content is unchanged, leave it alone
                 if old_data == new_data:
@@ -313,11 +307,9 @@ class LocalTaskConfigurationRepository(TaskConfigurationRepositoryBase):
         # Write out new files
         for relpath, entries in entries_by_path.items():
             if len(entries) == 1:
-                new_data = model_to_json_serializable_dict(entries[0].item)
+                new_data = entries[0].item.model_dump(mode="json")
             else:
-                # new_data = [
-                #     model_to_json_serializable_dict(e.item) for e in entries
-                # ]
+                # new_data = [e.item.model_dump(mode="json") for e in entries]
                 raise NotImplementedError(
                     "Writing new files with multiple entries is not supported,"
                     " since new entries are never bundled into a single file"
