@@ -8,17 +8,15 @@
 #  contained in the LICENSE file.
 
 """Test server for the tests."""
+
+import datetime as dt
 from dataclasses import dataclass
-from datetime import datetime, timezone
 from typing import Any
 
 from aiohttp import web
 from aiohttp.test_utils import AioHTTPTestCase
 
-from debusine.client.models import (
-    OnWorkRequestCompleted,
-    model_to_json_serializable_dict,
-)
+from debusine.client.models import OnWorkRequestCompleted
 
 
 @dataclass
@@ -31,7 +29,7 @@ class DebusineAioHTTPTestCase(AioHTTPTestCase):
 
     WORK_REQUEST_ID = 10
     WORK_REQUEST_RESULT = "success"
-    COMPLETED_AT = datetime.now(timezone.utc)
+    COMPLETED_AT = dt.datetime.now(dt.UTC)
     ON_COMPLETED_WORK_REQUESTS = 1
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
@@ -60,13 +58,11 @@ class DebusineAioHTTPTestCase(AioHTTPTestCase):
                 await ws.send_json(
                     {
                         "text": "work_request_completed",
-                        **model_to_json_serializable_dict(
-                            OnWorkRequestCompleted(
-                                work_request_id=self.WORK_REQUEST_ID + loop,
-                                result=self.WORK_REQUEST_RESULT,
-                                completed_at=self.COMPLETED_AT,
-                            )
-                        ),
+                        **OnWorkRequestCompleted(
+                            work_request_id=self.WORK_REQUEST_ID + loop,
+                            result=self.WORK_REQUEST_RESULT,
+                            completed_at=self.COMPLETED_AT,
+                        ).model_dump(mode="json"),
                     }
                 )
 
