@@ -43,6 +43,7 @@ from debusine.artifacts.models import (
     DebusineTaskConfiguration,
     EmptyArtifactData,
     TaskTypes,
+    WorkRequestResults,
 )
 from debusine.assets import AssetCategory, KeyPurpose, SigningKeyData
 from debusine.client.debusine import Debusine, serialize_local_artifact
@@ -508,7 +509,7 @@ class DebusineTests(TestCase):
         )
 
         self.debusine.work_request_completed_update(
-            work_request_id, "success", OutputData()
+            work_request_id, WorkRequestResults.SUCCESS, OutputData()
         )
 
     @responses.activate
