@@ -60,7 +60,7 @@ def make_data_field_renamer(
         filters: dict[str, Any],
         renames: list[tuple[str, str]],
         apps: StateApps,
-        schema_editor: BaseDatabaseSchemaEditor,  # noqa: U100
+        schema_editor: BaseDatabaseSchemaEditor,  # noqa: ARG001, U100
     ) -> None:
         Model = apps.get_model("db", model_name)
         rename_paths = [
