@@ -12,7 +12,7 @@
 import datetime as dt
 from functools import partial
 from pathlib import Path
-from typing import Any, Generic, Optional, TYPE_CHECKING, TypeVar
+from typing import Any, Optional, TYPE_CHECKING
 
 from django.conf import settings
 from django.core.exceptions import PermissionDenied, ValidationError
@@ -20,6 +20,7 @@ from django.db import models, transaction
 from django.db.models import Exists, F, OuterRef, Q, QuerySet, UniqueConstraint
 from django.db.models.functions import Coalesce
 from django.urls import reverse
+from django_cte import CTEQuerySet, With
 
 from debusine.artifacts import LocalArtifact
 from debusine.artifacts.models import ArtifactCategory, ArtifactData
@@ -43,8 +44,6 @@ if TYPE_CHECKING:
 else:
     TypedModelMeta = object
 
-A = TypeVar("A")
-
 ARTIFACT_CATEGORY_ICON_NAMES = {
     ArtifactCategory.AUTOPKGTEST: "folder",
     ArtifactCategory.BINARY_PACKAGE: "folder",
@@ -80,7 +79,7 @@ ARTIFACT_CATEGORY_SHORT_NAMES = {
 }
 
 
-class ArtifactQuerySet(QuerySet["Artifact", A], Generic[A]):
+class ArtifactQuerySet[A](QuerySet["Artifact", A]):
     """Custom QuerySet for Artifact."""
 
     def in_current_scope(self) -> "ArtifactQuerySet[A]":
@@ -91,6 +90,26 @@ class ArtifactQuerySet(QuerySet["Artifact", A], Generic[A]):
         """Filter to artifacts in the current workspace."""
         return self.filter(workspace=context.require_workspace())
 
+    def visible_to_current_workspace(self) -> "ArtifactQuerySet[A]":
+        """Filter to artifacts that the current workspace inherits from."""
+        visible = With(
+            Workspace.objects.can_display(context.user), name="visible"
+        )
+        chain = With.recursive(
+            context.require_workspace().make_inheritance_chain_cte(visible),
+            name="chain",
+        )
+        return self.filter(
+            workspace__in=(
+                chain.join(
+                    CTEQuerySet(Workspace, using=Workspace.objects._db),
+                    pk=chain.col.chain_parent,
+                )
+                .with_cte(visible)
+                .with_cte(chain)
+            )
+        )
+
     @permission_filter(workers=Allow.ALWAYS, anonymous=Allow.PASS)
     def can_display(self, user: PermissionUser) -> "ArtifactQuerySet[A]":
         """Keep only Artifacts that can be displayed."""
@@ -201,7 +220,7 @@ class ArtifactManager(models.Manager["Artifact"]):
         artifact = Artifact.objects.create(
             category=local_artifact.category,
             workspace=workspace,
-            data=local_artifact.data.dict(),
+            data=local_artifact.data.model_dump(),
             created_by_work_request=created_by_work_request,
         )
 
@@ -257,6 +276,52 @@ class Artifact(models.Model):
             )
         ]
 
+    def __str__(self) -> str:
+        """Return basic information of Artifact."""
+        return (
+            f"Id: {self.id} "
+            f"Category: {self.category} "
+            f"Workspace: {self.workspace.id}"
+        )
+
+    @copy_signature_from(models.Model.save)
+    def save(self, **kwargs: Any) -> None:
+        """Wrap save with permission checks."""
+        from debusine.db.context import context
+
+        if self._state.adding:
+            # Create
+            if not self.workspace.can_create_artifacts(context.user):
+                raise PermissionDenied(
+                    f"{context.user} cannot create artifacts"
+                    f" in {self.workspace}"
+                )
+        else:
+            # Update
+            ...  # TODO: check for update permissions
+
+        return super().save(**kwargs)
+
+    def get_absolute_url(self) -> str:
+        """Return the canonical URL to display the artifact."""
+        from debusine.server.scopes import urlconf_scope
+
+        with urlconf_scope(self.workspace.scope.name):
+            return reverse(
+                "workspaces:artifacts:detail",
+                kwargs={"wname": self.workspace.name, "artifact_id": self.id},
+            )
+
+    def get_absolute_url_download(self) -> str:
+        """Return the canonical URL to download the artifact."""
+        from debusine.server.scopes import urlconf_scope
+
+        with urlconf_scope(self.workspace.scope.name):
+            return reverse(
+                "workspaces:artifacts:download",
+                kwargs={"wname": self.workspace.name, "artifact_id": self.id},
+            )
+
     def clean(self) -> None:
         """
         Ensure that data is valid for this artifact category.
@@ -296,24 +361,6 @@ class Artifact(models.Model):
         assert isinstance(artifact_data, ArtifactData)
         return artifact_data
 
-    @copy_signature_from(models.Model.save)
-    def save(self, **kwargs: Any) -> None:
-        """Wrap save with permission checks."""
-        from debusine.db.context import context
-
-        if self._state.adding:
-            # Create
-            if not self.workspace.can_create_artifacts(context.user):
-                raise PermissionDenied(
-                    f"{context.user} cannot create artifacts"
-                    f" in {self.workspace}"
-                )
-        else:
-            # Update
-            ...  # TODO: check for update permissions
-
-        return super().save(**kwargs)
-
     def get_label(self, data: ArtifactData | None = None) -> str:
         """
         Return a label for this artifact.
@@ -361,34 +408,6 @@ class Artifact(models.Model):
 
         return ArtifactUI.get(request, self)
 
-    def get_absolute_url(self) -> str:
-        """Return the canonical URL to display the artifact."""
-        from debusine.server.scopes import urlconf_scope
-
-        with urlconf_scope(self.workspace.scope.name):
-            return reverse(
-                "workspaces:artifacts:detail",
-                kwargs={"wname": self.workspace.name, "artifact_id": self.id},
-            )
-
-    def get_absolute_url_download(self) -> str:
-        """Return the canonical URL to download the artifact."""
-        from debusine.server.scopes import urlconf_scope
-
-        with urlconf_scope(self.workspace.scope.name):
-            return reverse(
-                "workspaces:artifacts:download",
-                kwargs={"wname": self.workspace.name, "artifact_id": self.id},
-            )
-
-    def __str__(self) -> str:
-        """Return basic information of Artifact."""
-        return (
-            f"Id: {self.id} "
-            f"Category: {self.category} "
-            f"Workspace: {self.workspace.id}"
-        )
-
 
 class FileInArtifact(models.Model):
     """File in artifact."""
@@ -402,7 +421,9 @@ class FileInArtifact(models.Model):
     # added.  (debusine.debian.net only had a single workspace at the time
     # of this migration, so that's not a problem there.)
     complete = models.BooleanField(default=False)
-    content_type = models.CharField(blank=True, null=True)
+    # TODO: ruff is correct that we shouldn't use null=True on a CharField,
+    # but fixing that retroactively is non-trivial.
+    content_type = models.CharField(blank=True, null=True)  # noqa: DJ001
 
     class Meta(TypedModelMeta):
         constraints = [
@@ -419,12 +440,6 @@ class FileInArtifact(models.Model):
             f"Path: {self.path} File: {self.file.id}"
         )
 
-    def ui(self, request: "HttpRequest") -> "FileInArtifactUI":
-        """Return a UI helper for this instance."""
-        from debusine.web.views.ui.artifacts import FileInArtifactUI
-
-        return FileInArtifactUI.get(request, self)
-
     def get_absolute_url(self) -> str:
         """Return an absolute URL to view this file."""
         from debusine.server.scopes import urlconf_scope
@@ -467,6 +482,12 @@ class FileInArtifact(models.Model):
                 },
             )
 
+    def ui(self, request: "HttpRequest") -> "FileInArtifactUI":
+        """Return a UI helper for this instance."""
+        from debusine.web.views.ui.artifacts import FileInArtifactUI
+
+        return FileInArtifactUI.get(request, self)
+
 
 class FileUpload(models.Model):
     """File that is being/has been uploaded."""
@@ -481,6 +502,10 @@ class FileUpload(models.Model):
     )
     last_activity_at = models.DateTimeField(auto_now_add=True)
 
+    def __str__(self) -> str:
+        """Return basic information."""
+        return f"{self.id}"
+
     @classmethod
     def current_size(cls, artifact: Artifact, path_in_artifact: str) -> int:
         """
@@ -546,12 +571,8 @@ class FileUpload(models.Model):
         """
         return Path(settings.DEBUSINE_UPLOAD_DIRECTORY) / self.path
 
-    def __str__(self) -> str:
-        """Return basic information."""
-        return f"{self.id}"
 
-
-class ArtifactRelationQuerySet(QuerySet["ArtifactRelation", A], Generic[A]):
+class ArtifactRelationQuerySet[A](QuerySet["ArtifactRelation", A]):
     """Custom QuerySet for ArtifactRelation."""
 
     def in_current_scope(self) -> "ArtifactRelationQuerySet[A]":
@@ -589,8 +610,6 @@ class ArtifactRelation(models.Model):
         RELATES_TO = "relates-to", "Relates to"
         BUILT_USING = "built-using", "Built using"
 
-    objects = ArtifactRelationManager.from_queryset(ArtifactRelationQuerySet)()
-
     artifact = models.ForeignKey(
         Artifact, on_delete=models.PROTECT, related_name="relations"
     )
@@ -599,9 +618,7 @@ class ArtifactRelation(models.Model):
     )
     type = models.CharField(max_length=11, choices=Relations.choices)
 
-    def __str__(self) -> str:
-        """Return str for the object."""
-        return f"{self.artifact.id} {self.type} {self.target.id}"
+    objects = ArtifactRelationManager.from_queryset(ArtifactRelationQuerySet)()
 
     class Meta(TypedModelMeta):
         base_manager_name = "objects"
@@ -612,6 +629,10 @@ class ArtifactRelation(models.Model):
             )
         ]
 
+    def __str__(self) -> str:
+        """Return str for the object."""
+        return f"{self.artifact.id} {self.type} {self.target.id}"
+
     @permission_check(
         "{user} cannot display artifact relation {resource}",
         workers=Allow.ALWAYS,
