@@ -9,10 +9,9 @@
 
 """Data models for assets."""
 
-import base64
 import enum
 from collections.abc import Generator, Iterable
-from typing import Any, Generic, Self, TYPE_CHECKING, TypeAlias, TypeVar, cast
+from typing import Any, Self, TYPE_CHECKING, TypeAlias, cast
 
 from django.core.exceptions import ImproperlyConfigured, ValidationError
 from django.db import models
@@ -47,9 +46,6 @@ else:
     TypedModelMeta = object
 
 
-A = TypeVar("A")
-
-
 class AssetRoles(permissions.Roles, permissions.RoleBase, enum.ReprEnum):
     """Available roles for an Asset."""
 
@@ -147,7 +143,7 @@ class AssetUsageRoles(permissions.Roles, AssetUsageRoleBase, enum.ReprEnum):
 AssetUsageRoles.setup()
 
 
-class AssetQuerySet(models.QuerySet["Asset", A], Generic[A]):
+class AssetQuerySet[A](models.QuerySet["Asset", A]):
     """Custom QuerySet for Asset."""
 
     def in_current_scope(self) -> "AssetQuerySet[A]":
@@ -197,7 +193,7 @@ class AssetManager(models.Manager["Asset"]):
                 raise ValueError(f"No slug defined for category '{category}'")
 
 
-class AssetUsageQuerySet(models.QuerySet["AssetUsage", A], Generic[A]):
+class AssetUsageQuerySet[A](models.QuerySet["AssetUsage", A]):
     """Custom QuerySet for AssetUsage."""
 
     def with_role(self, user: PermissionUser, role: AssetUsageRoles) -> Self:
@@ -274,6 +270,28 @@ class Asset(models.Model):
             ),
         ]
 
+    def __str__(self) -> str:
+        """Return basic information of Asset."""
+        return (
+            f"Id: {self.id} "
+            f"Category: {self.category} "
+            f"Workspace: {self.workspace}"
+        )
+
+    @copy_signature_from(models.Model.save)
+    def save(self, **kwargs: Any) -> None:
+        """Wrap save with permission checks."""
+        from debusine.db.context import context
+
+        if context.permission_checks_disabled:
+            pass
+        elif self._state.adding:
+            enforce(self.can_create)
+        else:
+            enforce(self.can_edit)
+
+        return super().save(**kwargs)
+
     def clean(self) -> None:
         """
         Ensure that data is valid for this asset category.
@@ -348,28 +366,6 @@ class Asset(models.Model):
                 },
             ) from e
 
-    @copy_signature_from(models.Model.save)
-    def save(self, **kwargs: Any) -> None:
-        """Wrap save with permission checks."""
-        from debusine.db.context import context
-
-        if context.permission_checks_disabled:
-            pass
-        elif self._state.adding:
-            enforce(self.can_create)
-        else:
-            enforce(self.can_edit)
-
-        return super().save(**kwargs)
-
-    def __str__(self) -> str:
-        """Return basic information of Asset."""
-        return (
-            f"Id: {self.id} "
-            f"Category: {self.category} "
-            f"Workspace: {self.workspace}"
-        )
-
 
 class AssetRole(models.Model):
     """Role assignment for assets."""
@@ -461,4 +457,4 @@ def get_public_keys(signing_keys: Iterable[Asset]) -> Generator[bytes]:
     for signing_key in signing_keys:
         signing_key_data = signing_key.data_model
         assert isinstance(signing_key_data, SigningKeyData)
-        yield base64.b64decode(signing_key_data.public_key)
+        yield signing_key_data.public_key
