@@ -13,16 +13,7 @@ import datetime as dt
 import re
 from collections.abc import Generator
 from functools import cached_property
-from typing import (
-    Any,
-    ClassVar,
-    Generic,
-    Optional,
-    Self,
-    TYPE_CHECKING,
-    TypeAlias,
-    TypeVar,
-)
+from typing import Any, ClassVar, Optional, Self, TYPE_CHECKING, TypeAlias
 
 import jsonpath_rw
 from django.conf import settings
@@ -53,7 +44,6 @@ from debusine.artifacts.models import (
     DebusinePromise,
     SINGLETON_COLLECTION_CATEGORIES,
 )
-from debusine.client.models import model_to_json_serializable_dict
 from debusine.db.constraints import JsonDataUniqueConstraint
 from debusine.db.context import context
 from debusine.db.models.permissions import (
@@ -76,8 +66,6 @@ if TYPE_CHECKING:
 else:
     TypedModelMeta = object
 
-A = TypeVar("A")
-
 #: Regexp matching the structure of collection names
 collection_name_regex = re.compile(r"^[A-Za-z][A-Za-z0-9+._-]*$")
 
@@ -103,7 +91,7 @@ class _CollectionRetainsArtifacts(models.TextChoices):
     ALWAYS = "always", "Always"
 
 
-class CollectionQuerySet(QuerySet["Collection", A], Generic[A]):
+class CollectionQuerySet[A](QuerySet["Collection", A]):
     """Custom QuerySet for Collection."""
 
     def in_current_scope(self) -> Self:
@@ -174,8 +162,6 @@ class CollectionManager(models.Manager["Collection"]):
 class Collection(models.Model):
     """Model representing a collection."""
 
-    objects = CollectionManager.from_queryset(CollectionQuerySet)()
-
     RetainsArtifacts: TypeAlias = _CollectionRetainsArtifacts
 
     name = models.CharField(
@@ -222,6 +208,8 @@ class Collection(models.Model):
 
     data = models.JSONField(default=dict, blank=True)
 
+    objects = CollectionManager.from_queryset(CollectionQuerySet)()
+
     class Meta(TypedModelMeta):
         base_manager_name = "objects"
         constraints = [
@@ -248,19 +236,15 @@ class Collection(models.Model):
             ),
         ]
 
-    @cached_property
-    def manager(self) -> "CollectionManagerInterface":
-        """Get collection manager for this collection category."""
-        # Local import to avoid circular dependency
-        from debusine.server.collections import CollectionManagerInterface
+    def __str__(self) -> str:
+        """Return id, name, category."""
+        # Stringify using a valid lookup syntax
+        return f"{self.name}@{self.category}"
 
-        return CollectionManagerInterface.get_manager_for(self)
-
-    def ui(self, request: "HttpRequest") -> "CollectionUI":
-        """Return a UI helper for this instance."""
-        from debusine.web.views.ui.collections import CollectionUI
-
-        return CollectionUI.get(request, self)
+    def __repr__(self) -> str:
+        """Return id, name, category."""
+        # Stringify using a valid lookup syntax
+        return f"<Collection: {self.name}@{self.category} ({self.pk})>"
 
     def get_absolute_url(self) -> str:
         """Return the canonical URL to display the collection."""
@@ -290,6 +274,20 @@ class Collection(models.Model):
                 },
             )
 
+    @cached_property
+    def manager(self) -> "CollectionManagerInterface":
+        """Get collection manager for this collection category."""
+        # Local import to avoid circular dependency
+        from debusine.server.collections import CollectionManagerInterface
+
+        return CollectionManagerInterface.get_manager_for(self)
+
+    def ui(self, request: "HttpRequest") -> "CollectionUI":
+        """Return a UI helper for this instance."""
+        from debusine.web.views.ui.collections import CollectionUI
+
+        return CollectionUI.get(request, self)
+
     @permission_check(
         "{user} cannot display collection {resource}",
         workers=Allow.ALWAYS,
@@ -316,16 +314,6 @@ class Collection(models.Model):
             and self.workspace.can_configure(user)
         )
 
-    def __str__(self) -> str:
-        """Return id, name, category."""
-        # Stringify using a valid lookup syntax
-        return f"{self.name}@{self.category}"
-
-    def __repr__(self) -> str:
-        """Return id, name, category."""
-        # Stringify using a valid lookup syntax
-        return f"<Collection: {self.name}@{self.category} ({self.pk})>"
-
     def get_item_stats(
         self,
     ) -> Generator[dict[str, Any]]:
@@ -404,7 +392,7 @@ class CollectionItemManager(models.Manager["CollectionItem"]):
     ) -> "CollectionItem":
         """Create a CollectionItem from bare data."""
         if isinstance(data, BaseArtifactDataModel):
-            data = model_to_json_serializable_dict(data, exclude_unset=True)
+            data = data.model_dump(mode="json", exclude_unset=True)
 
         match category:
             case BareDataCategory.PROMISE:
@@ -520,7 +508,9 @@ class CollectionItemManager(models.Manager["CollectionItem"]):
         self.get_queryset().exclude(removed_at__isnull=True).filter(
             # https://github.com/typeddjango/django-stubs/issues/1548
             removed_at__lt=(
-                at - F("parent_collection__full_history_retention_period") - F("parent_collection__metadata_only_retention_period")  # type: ignore[operator] # noqa: E501
+                at  # type: ignore[operator]
+                - F("parent_collection__full_history_retention_period")
+                - F("parent_collection__metadata_only_retention_period")
             )
         ).delete()
 
@@ -536,8 +526,6 @@ class _CollectionItemTypes(models.TextChoices):
 class CollectionItem(models.Model):
     """CollectionItem model."""
 
-    objects = CollectionItemManager.from_queryset(CollectionItemQuerySet)()
-
     name = models.CharField(max_length=255)
 
     Types: TypeAlias = _CollectionItemTypes
@@ -598,94 +586,7 @@ class CollectionItem(models.Model):
         related_name="workflow_removed_%(class)s",
     )
 
-    @staticmethod
-    def expand_variables(
-        variables: dict[str, str], reference_data: dict[Any, Any]
-    ) -> dict[str, str]:
-        """
-        Expand JSONPath variables against some data.
-
-        The data will normally come from an Artifact.
-        """
-        jsonpaths = {}
-        for name, path in variables.items():
-            if name.startswith("$"):
-                try:
-                    jsonpaths[name[1:]] = jsonpath_rw.parse(path)
-                except Exception as e:
-                    raise ValueError(e)
-
-        expanded_variables = {}
-        for name, jsonpath in jsonpaths.items():
-            matches = jsonpath.find(reference_data)
-            if len(matches) == 1:
-                expanded_variables[name] = matches[0].value
-            elif len(matches) > 1:
-                raise ValueError(
-                    "Too many values expanding",
-                    variables[f"${name}"],
-                    reference_data,
-                )
-            else:
-                raise KeyError(variables[f"${name}"], reference_data)
-
-        for name, value in variables.items():
-            if not name.startswith("$"):
-                if name in expanded_variables:
-                    raise ValueError(
-                        f"Cannot set both '${name}' and '{name}' variables"
-                    )
-                expanded_variables[name] = value
-
-        return expanded_variables
-
-    @staticmethod
-    def expand_name(
-        name_template: str, expanded_variables: dict[str, str]
-    ) -> str:
-        """Format item name following item_template."""
-        return name_template.format(**expanded_variables)
-
-    def ui(self, request: "HttpRequest") -> "CollectionItemUI":
-        """Return a UI helper for this instance."""
-        from debusine.web.views.ui.collections import CollectionItemUI
-
-        return CollectionItemUI.get(request, self)
-
-    def get_absolute_url(self) -> str:
-        """Return the canonical URL to display the item."""
-        from debusine.server.scopes import urlconf_scope
-
-        with urlconf_scope(self.parent_collection.workspace.scope.name):
-            return reverse(
-                "workspaces:collections:item_detail",
-                kwargs={
-                    "wname": self.parent_collection.workspace.name,
-                    "ccat": self.parent_collection.category,
-                    "cname": self.parent_collection.name,
-                    "iid": self.pk,
-                    "iname": self.name,
-                },
-            )
-
-    def __str__(self) -> str:
-        """Return id, name, collection_id, child_type."""
-        item_info = (
-            f" Artifact id: {self.artifact.id}"
-            if self.artifact
-            else (
-                f" Collection id: {self.collection.id}"
-                if self.collection
-                else ""
-            )
-        )
-
-        return (
-            f"Id: {self.id} Name: {self.name} "
-            f"Parent collection id: {self.parent_collection_id} "
-            f"Child type: {self.child_type}"
-            f"{item_info}"
-        )
+    objects = CollectionItemManager.from_queryset(CollectionItemQuerySet)()
 
     class Meta(TypedModelMeta):
         base_manager_name = "objects"
@@ -821,12 +722,101 @@ class CollectionItem(models.Model):
             ),
         ]
 
+    def __str__(self) -> str:
+        """Return id, name, collection_id, child_type."""
+        item_info = (
+            f" Artifact id: {self.artifact.id}"
+            if self.artifact
+            else (
+                f" Collection id: {self.collection.id}"
+                if self.collection
+                else ""
+            )
+        )
+
+        return (
+            f"Id: {self.id} Name: {self.name} "
+            f"Parent collection id: {self.parent_collection_id} "
+            f"Child type: {self.child_type}"
+            f"{item_info}"
+        )
+
     def save(self, *args: Any, **kwargs: Any) -> None:
         """Populate `parent_category` on save."""
         if not self.parent_category:
             self.parent_category = self.parent_collection.category
         super().save(*args, **kwargs)
 
+    def get_absolute_url(self) -> str:
+        """Return the canonical URL to display the item."""
+        from debusine.server.scopes import urlconf_scope
+
+        with urlconf_scope(self.parent_collection.workspace.scope.name):
+            return reverse(
+                "workspaces:collections:item_detail",
+                kwargs={
+                    "wname": self.parent_collection.workspace.name,
+                    "ccat": self.parent_collection.category,
+                    "cname": self.parent_collection.name,
+                    "iid": self.pk,
+                    "iname": self.name,
+                },
+            )
+
+    @staticmethod
+    def expand_variables(
+        variables: dict[str, str], reference_data: dict[Any, Any]
+    ) -> dict[str, str]:
+        """
+        Expand JSONPath variables against some data.
+
+        The data will normally come from an Artifact.
+        """
+        jsonpaths = {}
+        for name, path in variables.items():
+            if name.startswith("$"):
+                try:
+                    jsonpaths[name[1:]] = jsonpath_rw.parse(path)
+                except Exception as e:
+                    raise ValueError(e)
+
+        expanded_variables = {}
+        for name, jsonpath in jsonpaths.items():
+            matches = jsonpath.find(reference_data)
+            if len(matches) == 1:
+                expanded_variables[name] = matches[0].value
+            elif len(matches) > 1:
+                raise ValueError(
+                    "Too many values expanding",
+                    variables[f"${name}"],
+                    reference_data,
+                )
+            else:
+                raise KeyError(variables[f"${name}"], reference_data)
+
+        for name, value in variables.items():
+            if not name.startswith("$"):
+                if name in expanded_variables:
+                    raise ValueError(
+                        f"Cannot set both '${name}' and '{name}' variables"
+                    )
+                expanded_variables[name] = value
+
+        return expanded_variables
+
+    @staticmethod
+    def expand_name(
+        name_template: str, expanded_variables: dict[str, str]
+    ) -> str:
+        """Format item name following item_template."""
+        return name_template.format(**expanded_variables)
+
+    def ui(self, request: "HttpRequest") -> "CollectionItemUI":
+        """Return a UI helper for this instance."""
+        from debusine.web.views.ui.collections import CollectionItemUI
+
+        return CollectionItemUI.get(request, self)
+
 
 class CollectionItemMatchConstraint(models.Model):
     """
