@@ -157,7 +157,7 @@ class AssetManagerTests(TestCase):
                 credentials=AWSProviderAccountCredentials(
                     access_key_id="access-key", secret_access_key="secret-key"
                 ),
-            ).dict(),
+            ).model_dump(),
             created_by=user,
         )
         self.playground.create_group_role(asset, AssetRoles.OWNER, users=[user])
@@ -234,7 +234,7 @@ class AssetTests(TestCase):
                 fingerprint="ABC123",
                 public_key=base64.b64encode(b"PUBLIC KEY").decode(),
                 description="A Description",
-            ).dict(),
+            ).model_dump(),
             created_by=self.playground.get_default_user(),
         )
 
@@ -253,7 +253,7 @@ class AssetTests(TestCase):
                 credentials=AWSProviderAccountCredentials(
                     access_key_id="access-key", secret_access_key="secret-key"
                 ),
-            ).dict(),
+            ).model_dump(),
             created_by=self.playground.get_default_user(),
         )
 
