@@ -669,7 +669,7 @@ class CollectionItemManagerTests(TestCase):
         self.assertEqual(collection_item.name, name)
         self.assertEqual(collection_item.child_type, CollectionItem.Types.BARE)
         self.assertEqual(collection_item.category, category)
-        self.assertEqual(collection_item.data, data)
+        self.assertEqual(collection_item.data, data.model_dump())
         self.assertEqual(collection_item.created_by_user, self.user)
 
     def test_create_from_bare_data_debusine_promise_invalid_data(self) -> None:
@@ -1107,13 +1107,13 @@ class CollectionItemManagerTests(TestCase):
         item = self.playground.create_debian_environment(
             collection=self.collection, codename="bookworm"
         )
-        item.created_at = dt.datetime(2024, 12, 1, tzinfo=dt.timezone.utc)
+        item.created_at = dt.datetime(2024, 12, 1, tzinfo=dt.UTC)
         item.save()
         items.append(item)
         for timestamp in (
-            dt.datetime(2025, 1, 1, tzinfo=dt.timezone.utc),
-            dt.datetime(2025, 2, 1, tzinfo=dt.timezone.utc),
-            dt.datetime(2025, 3, 1, tzinfo=dt.timezone.utc),
+            dt.datetime(2025, 1, 1, tzinfo=dt.UTC),
+            dt.datetime(2025, 2, 1, tzinfo=dt.UTC),
+            dt.datetime(2025, 3, 1, tzinfo=dt.UTC),
         ):
             self.collection.child_items.active().filter(
                 data__codename="trixie"
@@ -1131,38 +1131,38 @@ class CollectionItemManagerTests(TestCase):
             data__codename="trixie"
         ).update(
             removed_by_user=self.playground.get_default_user(),
-            removed_at=dt.datetime(2025, 4, 1, tzinfo=dt.timezone.utc),
+            removed_at=dt.datetime(2025, 4, 1, tzinfo=dt.UTC),
         )
 
         for timestamp, expected_items in (
-            (dt.datetime(2024, 11, 30, tzinfo=dt.timezone.utc), []),
-            (dt.datetime(2024, 12, 1, tzinfo=dt.timezone.utc), [items[0]]),
-            (dt.datetime(2024, 12, 15, tzinfo=dt.timezone.utc), [items[0]]),
+            (dt.datetime(2024, 11, 30, tzinfo=dt.UTC), []),
+            (dt.datetime(2024, 12, 1, tzinfo=dt.UTC), [items[0]]),
+            (dt.datetime(2024, 12, 15, tzinfo=dt.UTC), [items[0]]),
             (
-                dt.datetime(2025, 1, 1, tzinfo=dt.timezone.utc),
+                dt.datetime(2025, 1, 1, tzinfo=dt.UTC),
                 [items[0], items[1]],
             ),
             (
-                dt.datetime(2025, 1, 15, tzinfo=dt.timezone.utc),
+                dt.datetime(2025, 1, 15, tzinfo=dt.UTC),
                 [items[0], items[1]],
             ),
             (
-                dt.datetime(2025, 2, 1, tzinfo=dt.timezone.utc),
+                dt.datetime(2025, 2, 1, tzinfo=dt.UTC),
                 [items[0], items[2]],
             ),
             (
-                dt.datetime(2025, 2, 15, tzinfo=dt.timezone.utc),
+                dt.datetime(2025, 2, 15, tzinfo=dt.UTC),
                 [items[0], items[2]],
             ),
             (
-                dt.datetime(2025, 3, 1, tzinfo=dt.timezone.utc),
+                dt.datetime(2025, 3, 1, tzinfo=dt.UTC),
                 [items[0], items[3]],
             ),
             (
-                dt.datetime(2025, 3, 15, tzinfo=dt.timezone.utc),
+                dt.datetime(2025, 3, 15, tzinfo=dt.UTC),
                 [items[0], items[3]],
             ),
-            (dt.datetime(2025, 4, 1, tzinfo=dt.timezone.utc), [items[0]]),
+            (dt.datetime(2025, 4, 1, tzinfo=dt.UTC), [items[0]]),
         ):
             self.assertQuerySetEqual(
                 self.collection.child_items.active_at(timestamp),
