@@ -70,7 +70,9 @@ class TaskDatabaseTests(TestCase):
                 "debian@debian:environments/match:codename=bookworm"
             ),
             ArtifactInfo(
-                id=artifact.id, category=artifact.category, data=artifact.data
+                id=artifact.id,
+                category=artifact.category,
+                data=artifact.create_data(),
             ),
         )
         self.assertEqual(
@@ -79,7 +81,9 @@ class TaskDatabaseTests(TestCase):
                 default_category=CollectionCategory.ENVIRONMENTS,
             ),
             ArtifactInfo(
-                id=artifact.id, category=artifact.category, data=artifact.data
+                id=artifact.id,
+                category=artifact.category,
+                data=artifact.create_data(),
             ),
         )
         with self.assertRaisesRegex(
@@ -110,7 +114,7 @@ class TaskDatabaseTests(TestCase):
 
         self.assertCountEqual(
             task_db.lookup_multiple_artifacts(
-                LookupMultiple.parse_obj(
+                LookupMultiple.model_validate(
                     {"collection": "debian@debian:environments"}
                 )
             ),
@@ -118,21 +122,21 @@ class TaskDatabaseTests(TestCase):
                 ArtifactInfo(
                     id=artifact.id,
                     category=artifact.category,
-                    data=artifact.data,
+                    data=artifact.create_data(),
                 )
                 for artifact in artifacts
             ],
         )
         self.assertCountEqual(
             task_db.lookup_multiple_artifacts(
-                LookupMultiple.parse_obj({"collection": "debian"}),
+                LookupMultiple.model_validate({"collection": "debian"}),
                 default_category=CollectionCategory.ENVIRONMENTS,
             ),
             [
                 ArtifactInfo(
                     id=artifact.id,
                     category=artifact.category,
-                    data=artifact.data,
+                    data=artifact.create_data(),
                 )
                 for artifact in artifacts
             ],
@@ -143,7 +147,7 @@ class TaskDatabaseTests(TestCase):
             "supply a default",
         ):
             task_db.lookup_multiple_artifacts(
-                LookupMultiple.parse_obj({"collection": "debian"})
+                LookupMultiple.model_validate({"collection": "debian"})
             )
 
     def test_find_related_artifacts(self) -> None:
@@ -169,7 +173,7 @@ class TaskDatabaseTests(TestCase):
                 ArtifactInfo(
                     id=upload_artifacts.source.id,
                     category=upload_artifacts.source.category,
-                    data=upload_artifacts.source.data,
+                    data=upload_artifacts.source.create_data(),
                 )
             ],
         )
@@ -189,7 +193,7 @@ class TaskDatabaseTests(TestCase):
                 ArtifactInfo(
                     id=artifact.id,
                     category=artifact.category,
-                    data=artifact.data,
+                    data=artifact.create_data(),
                 )
                 for artifact in upload_artifacts.binaries
             ],
@@ -208,7 +212,7 @@ class TaskDatabaseTests(TestCase):
                 ArtifactInfo(
                     id=upload_artifacts.source.id,
                     category=upload_artifacts.source.category,
-                    data=upload_artifacts.source.data,
+                    data=upload_artifacts.source.create_data(),
                 )
             ],
         )
