@@ -12,15 +12,7 @@
 import copy
 import datetime as dt
 import hashlib
-from typing import (
-    Any,
-    Generic,
-    Optional,
-    TYPE_CHECKING,
-    TypeVar,
-    cast,
-    overload,
-)
+from typing import Any, Optional, TYPE_CHECKING, cast, overload
 
 from django.db import IntegrityError, models, transaction
 from django.db.models import (
@@ -54,10 +46,8 @@ if TYPE_CHECKING:
 else:
     TypedModelMeta = object
 
-A = TypeVar("A")
 
-
-class WorkerQuerySet(QuerySet["Worker", A], Generic[A]):
+class WorkerQuerySet[A](QuerySet["Worker", A]):
     """Custom QuerySet for Worker."""
 
     def connected(self) -> "WorkerQuerySet[Any]":
@@ -124,8 +114,14 @@ class WorkerQuerySet(QuerySet["Worker", A], Generic[A]):
         """
         tasks = WorkRequest.objects.filter(worker=OuterRef("pk"))
 
+        running_tasks = tasks.filter(status=WorkRequest.Statuses.RUNNING)
+
+        last_tasks = tasks.filter(
+            completed_at__gt=F("worker__instance_created_at")
+        )
+
         last_completed_at = Subquery(
-            tasks.annotate(last_completed_at=Max("completed_at")).values(
+            last_tasks.annotate(last_completed_at=Max("completed_at")).values(
                 "last_completed_at"
             )
         )
@@ -136,11 +132,11 @@ class WorkerQuerySet(QuerySet["Worker", A], Generic[A]):
         return self.annotate(
             idle_time=Case(
                 When(
-                    Exists(tasks.filter(status=WorkRequest.Statuses.RUNNING)),
+                    Exists(running_tasks),
                     then=0,
                 ),
                 When(
-                    Exists(tasks),
+                    Exists(last_tasks),
                     then=Extract(Now() - last_completed_at, "epoch"),
                 ),
                 default=Extract(
@@ -374,6 +370,14 @@ class Worker(models.Model):
             )
         ]
 
+    def __str__(self) -> str:
+        """Return the id and name of the Worker."""
+        return f"Id: {self.id} Name: {self.name}"
+
+    def get_absolute_url(self) -> str:
+        """Return an absolute URL to view this worker."""
+        return reverse("workers:detail", kwargs={"name": self.name})
+
     def mark_disconnected(self) -> None:
         """Update and save relevant Worker fields after disconnecting."""
         self.connected_at = None
@@ -437,16 +441,8 @@ class Worker(models.Model):
         self.dynamic_metadata_updated_at = timezone.now()
         self.save()
 
-    def __str__(self) -> str:
-        """Return the id and name of the Worker."""
-        return f"Id: {self.id} Name: {self.name}"
-
     def ui(self, request: "HttpRequest") -> "WorkerUI":
         """Return a UI helper for this instance."""
         from debusine.web.views.ui.workers import WorkerUI
 
         return WorkerUI.get(request, self)
-
-    def get_absolute_url(self) -> str:
-        """Return an absolute URL to view this worker."""
-        return reverse("workers:detail", kwargs={"name": self.name})
