@@ -25,6 +25,6 @@ workers = os.cpu_count() * 2 + 1
 worker_class = "uvicorn.workers.UvicornWorker"
 
 
-def child_exit(server: Arbiter, worker: Worker) -> None:  # noqa: U100
+def child_exit(server: Arbiter, worker: Worker) -> None:  # noqa: ARG001, U100
     """Tell the Prometheus client that a worker has died."""
     multiprocess.mark_process_dead(worker.pid)
