@@ -160,6 +160,7 @@ class ChecksTests(TestCase):
                 "DEBUSINE_TEMPLATE_DIRECTORY",
                 "DEBUSINE_UPLOAD_DIRECTORY",
                 "DEBUSINE_STORE_DIRECTORY",
+                "DEBUSINE_TOKENS_DIRECTORY",
             ],
             missing_ok=True,
         )
@@ -236,7 +237,7 @@ class ChecksTests(TestCase):
             settings.DEBUG = param["DEBUG"]
             settings.SECRET_KEY = param["SECRET_KEY"]
 
-            with self.subTest(params=param):
+            with self.subTest(params=repr(param)):
                 self.assertEqual(
                     checks.secret_key_not_default_in_debug_0(app_configs=None),
                     param["result"],
