@@ -19,7 +19,9 @@ class ServerConfig(AppConfig):
 
     def ready(self) -> None:
         """Mark workers as disconnected. Runs on Django startup."""
-        # Import the scheduler so that its signal receiver is registered.
+        # Import the provisioner and scheduler so that their Celery tasks
+        # and signal receivers are registered.
+        import debusine.server.provisioning  # noqa: F401
         import debusine.server.scheduler  # noqa: F401
 
         # Import various tasks so that they are registered.
