@@ -24,7 +24,6 @@ from debusine.artifacts.models import (
     BaseArtifactDataModel,
     CollectionCategory,
 )
-from debusine.client.models import model_to_json_serializable_dict
 from debusine.db.models import (
     Artifact,
     Collection,
@@ -150,7 +149,7 @@ class CollectionManagerInterface(ABC):
                 f'not supported by the collection'
             )
         if isinstance(data, BaseArtifactDataModel):
-            data = model_to_json_serializable_dict(data, exclude_unset=True)
+            data = data.model_dump(mode="json", exclude_unset=True)
 
         return self.do_add_bare_data(
             category,
@@ -362,15 +361,15 @@ class CollectionManagerInterface(ABC):
 
     def do_add_bare_data(
         self,
-        category: BareDataCategory,  # noqa: U100
+        category: BareDataCategory,  # noqa: ARG002, U100
         *,
-        user: User,  # noqa: U100
-        workflow: WorkRequest | None,  # noqa: U100
-        data: dict[str, Any] | None = None,  # noqa: U100
-        name: str | None = None,  # noqa: U100
-        replace: bool = False,  # noqa: U100
-        created_at: dt.datetime | None = None,  # noqa: U100
-        replaced_by: CollectionItem | None = None,  # noqa: U100
+        user: User,  # noqa: ARG002, U100
+        workflow: WorkRequest | None,  # noqa: ARG002, U100
+        data: dict[str, Any] | None = None,  # noqa: ARG002, U100
+        name: str | None = None,  # noqa: ARG002, U100
+        replace: bool = False,  # noqa: ARG002, U100
+        created_at: dt.datetime | None = None,  # noqa: ARG002, U100
+        replaced_by: CollectionItem | None = None,  # noqa: ARG002, U100
     ) -> CollectionItem:  # pragma: no cover
         """
         Add bare data into the managed collection.
@@ -386,15 +385,15 @@ class CollectionManagerInterface(ABC):
 
     def do_add_artifact(
         self,
-        artifact: Artifact,  # noqa: U100
+        artifact: Artifact,  # noqa: ARG002, U100
         *,
-        user: User,  # noqa: U100
-        workflow: WorkRequest | None = None,  # noqa: U100
-        variables: dict[str, Any] | None = None,  # noqa: U100
-        name: str | None = None,  # noqa: U100
-        replace: bool = False,  # noqa: U100
-        created_at: dt.datetime | None = None,  # noqa: U100
-        replaced_by: CollectionItem | None = None,  # noqa: U100
+        user: User,  # noqa: ARG002, U100
+        workflow: WorkRequest | None = None,  # noqa: ARG002, U100
+        variables: dict[str, Any] | None = None,  # noqa: ARG002, U100
+        name: str | None = None,  # noqa: ARG002, U100
+        replace: bool = False,  # noqa: ARG002, U100
+        created_at: dt.datetime | None = None,  # noqa: ARG002, U100
+        replaced_by: CollectionItem | None = None,  # noqa: ARG002, U100
     ) -> CollectionItem:  # pragma: no cover
         """
         Add the artifact into the managed collection.
@@ -410,15 +409,15 @@ class CollectionManagerInterface(ABC):
 
     def do_add_collection(
         self,
-        collection: Collection,  # noqa: U100
+        collection: Collection,  # noqa: ARG002, U100
         *,
-        user: User,  # noqa: U100
-        workflow: WorkRequest | None = None,  # noqa: U100
-        variables: dict[str, Any] | None = None,  # noqa: U100
-        name: str | None = None,  # noqa: U100
-        replace: bool = False,  # noqa: U100
-        created_at: dt.datetime | None = None,  # noqa: U100
-        replaced_by: CollectionItem | None = None,  # noqa: U100
+        user: User,  # noqa: ARG002, U100
+        workflow: WorkRequest | None = None,  # noqa: ARG002, U100
+        variables: dict[str, Any] | None = None,  # noqa: ARG002, U100
+        name: str | None = None,  # noqa: ARG002, U100
+        replace: bool = False,  # noqa: ARG002, U100
+        created_at: dt.datetime | None = None,  # noqa: ARG002, U100
+        replaced_by: CollectionItem | None = None,  # noqa: ARG002, U100
     ) -> CollectionItem:
         """
         Add the collection into the managed collection.
@@ -434,10 +433,10 @@ class CollectionManagerInterface(ABC):
 
     def do_remove_item(
         self,
-        item: CollectionItem,  # noqa: U100
+        item: CollectionItem,  # noqa: ARG002, U100
         *,
-        user: User | None = None,  # noqa: U100
-        workflow: WorkRequest | None = None,  # noqa: U100
+        user: User | None = None,  # noqa: ARG002, U100
+        workflow: WorkRequest | None = None,  # noqa: ARG002, U100
     ) -> None:  # pragma: no cover
         """
         Remove an item from the managed collection.
@@ -464,11 +463,11 @@ class CollectionManagerInterface(ABC):
     def do_lookup_filter(
         self,
         key: str,
-        value: LookupSingle | LookupMultiple,  # noqa: U100
+        value: LookupSingle | LookupMultiple,  # noqa: ARG002, U100
         *,
-        workspace: Workspace,  # noqa: U100
-        user: User | AnonymousUser,  # noqa: U100
-        workflow_root: WorkRequest | None = None,  # noqa: U100
+        workspace: Workspace,  # noqa: ARG002, U100
+        user: User | AnonymousUser,  # noqa: ARG002, U100
+        workflow_root: WorkRequest | None = None,  # noqa: ARG002, U100
     ) -> Q:
         """
         Return :py:class:`CollectionItem` conditions for a lookup filter.
