@@ -192,7 +192,9 @@ class DebianSuiteManager(CollectionManagerInterface):
         self,
         new_version: Version,
         existing_items: QuerySet[CollectionItem],
+        *,
         kind: str,
+        package_name: str,
     ) -> None:
         if not self.may_rewind_versions and not self.collection.data.get(
             "may_rewind_versions", False
@@ -200,7 +202,8 @@ class DebianSuiteManager(CollectionManagerInterface):
             for existing_item in existing_items:
                 if new_version < Version(existing_item.data["version"]):
                     raise ItemAdditionError(
-                        f"New {kind} version {new_version} < "
+                        f"{self.collection}: New {kind} version "
+                        f"{package_name} {new_version} < "
                         f"existing version {existing_item.data["version"]}"
                     )
 
@@ -245,13 +248,14 @@ class DebianSuiteManager(CollectionManagerInterface):
             name = "{package}_{version}".format(**data)
             source_package_name = source_package_data.name
             self._check_existing_versions(
-                Version(source_package_data.version),
+                Version(data["version"]),
                 self.collection.child_items.active().filter(
                     child_type=CollectionItem.Types.ARTIFACT,
                     category=ArtifactCategory.SOURCE_PACKAGE,
-                    data__package=source_package_data.name,
+                    data__package=data["package"],
                 ),
-                "source",
+                kind="source",
+                package_name=data["package"],
             )
         elif artifact.category == ArtifactCategory.BINARY_PACKAGE:
             binary_package_data = BinaryPackage.create_data(artifact.data)
@@ -268,16 +272,15 @@ class DebianSuiteManager(CollectionManagerInterface):
             name = "{package}_{version}_{architecture}".format(**data)
             source_package_name = binary_package_data.srcpkg_name
             self._check_existing_versions(
-                Version(binary_package_data.deb_fields["Version"]),
+                Version(data["version"]),
                 self.collection.child_items.active().filter(
                     child_type=CollectionItem.Types.ARTIFACT,
                     category=ArtifactCategory.BINARY_PACKAGE,
-                    data__package=binary_package_data.deb_fields["Package"],
-                    data__architecture=binary_package_data.deb_fields[
-                        "Architecture"
-                    ],
+                    data__package=data["package"],
+                    data__architecture=data["architecture"],
                 ),
-                "binary",
+                kind="binary",
+                package_name=f"{data['package']}:{data['architecture']}",
             )
         else:
             assert artifact.category == ArtifactCategory.REPOSITORY_INDEX
