@@ -10,6 +10,7 @@
 """Unit tests for DebianSuiteManager."""
 
 import datetime as dt
+import re
 from pathlib import PurePath
 from typing import ClassVar
 
@@ -470,7 +471,10 @@ class DebianSuiteManagerTests(TestCase):
         )
         with self.assertRaisesRegex(
             ItemAdditionError,
-            r"New source version 1\.0 < existing version 1\.1",
+            re.escape(
+                f"{self.collection}: New source version hello 1.0"
+                f" < existing version 1.1"
+            ),
         ):
             self.manager.add_artifact(
                 source_package_artifact2,
@@ -827,7 +831,10 @@ class DebianSuiteManagerTests(TestCase):
         )
         with self.assertRaisesRegex(
             ItemAdditionError,
-            r"New binary version 1:1\.0 < existing version 1:1\.1",
+            re.escape(
+                f"{self.collection}: New binary version libhello1:amd64 1:1.0"
+                f" < existing version 1:1.1"
+            ),
         ):
             self.manager.add_artifact(
                 binary_package_artifact2,
