@@ -281,7 +281,8 @@ class WorkerConsumer(DebusineAsyncWebsocketConsumer):
             )
 
     async def worker_disabled(
-        self, event: dict[str, Any]  # noqa: U100
+        self,
+        event: dict[str, Any],  # noqa: ARG002, U100
     ) -> None:
         """Worker has been disabled. Send a connection_closed msg."""
         assert self._worker is not None
@@ -298,7 +299,8 @@ class WorkerConsumer(DebusineAsyncWebsocketConsumer):
         await self.send(text_data=json.dumps(msg), close=True)
 
     async def work_request_assigned(
-        self, event: dict[str, Any]  # noqa: U100
+        self,
+        event: dict[str, Any],  # noqa: ARG002, U100
     ) -> None:
         """Work Request has been assigned to the worker. Send channel msg."""
         await self._send_work_request_available()
@@ -365,8 +367,7 @@ class OnWorkRequestCompletedConsumer(DebusineAsyncWebsocketConsumer):
 
         if not await self.has_permission(IsTokenUserAuthenticated):
             await self.reject_connection(
-                "No token header, token not associated to a user "
-                "or not enabled"
+                "No token header, token not associated to a user or not enabled"
             )
             return
 
