@@ -76,7 +76,10 @@ class ExternalDebianSuiteFileBackendEntry(
             temp_file.close()
             yield Path(temp_file.name)
 
-    def get_url(self, content_type: str | None = None) -> str:  # noqa: U100
+    def get_url(
+        self,
+        content_type: str | None = None,  # noqa: ARG002, U100
+    ) -> str:
         """
         Return a URL pointing to the content.
 
@@ -128,7 +131,7 @@ class ExternalDebianSuiteFileBackend(
             self, fileobj
         )
 
-    def remove_file(self, db_file: File) -> None:  # noqa: U100
+    def remove_file(self, db_file: File) -> None:  # noqa: ARG002, U100
         """
         Remove the file from the FileStore.
 
@@ -139,7 +142,9 @@ class ExternalDebianSuiteFileBackend(
         )
 
     def add_file(
-        self, local_path: Path, db_file: File | None = None  # noqa: U100
+        self,
+        local_path: Path,  # noqa: ARG002, U100
+        db_file: File | None = None,  # noqa: ARG002, U100
     ) -> File:
         """
         Copy local_path to underlying storage and register it in the FileStore.
@@ -162,7 +167,7 @@ class ExternalDebianSuiteFileBackend(
             File.current_hash_algorithm: hash_digest,
             'size': size,
         }
-        db_file, created = File.objects.get_or_create(**db_file_kwargs)
+        db_file, _ = File.objects.get_or_create(**db_file_kwargs)
         FileInStore.objects.get_or_create(
             store=self.db_store,
             file=db_file,
