@@ -16,7 +16,7 @@ from abc import ABCMeta, abstractmethod
 from collections.abc import Callable, Generator, Hashable
 from functools import cached_property
 from pathlib import Path
-from typing import Any, Generic, Protocol, TypeVar
+from typing import Any, Protocol
 
 import requests
 from django.db import transaction
@@ -27,10 +27,6 @@ from debusine.utils import NotSupportedError, extract_generic_type_arguments
 
 logger = logging.getLogger(__name__)
 
-FBC = TypeVar("FBC", bound=FileBackendConfiguration)
-FBI = TypeVar("FBI", bound="FileBackendInterface[Any]")
-H = TypeVar("H", bound=Hashable)
-
 
 class FileBackendStream(Protocol):
     """Returned by :py:meth:`FileBackendEntryInterface.get_stream`."""
@@ -42,7 +38,9 @@ class FileBackendStream(Protocol):
         """Return the file descriptor number, if available."""
 
 
-class FileBackendEntryInterface(Generic[FBI, H], metaclass=ABCMeta):
+class FileBackendEntryInterface[FBI: FileBackendInterface[Any], H: Hashable](
+    metaclass=ABCMeta
+):
     """A representation of an entry in a file backend."""
 
     # The backend containing this entry.
@@ -145,7 +143,7 @@ class FileBackendEntryInterface(Generic[FBI, H], metaclass=ABCMeta):
         """
 
 
-class FileBackendInterface(Generic[FBC], metaclass=ABCMeta):
+class FileBackendInterface[FBC: FileBackendConfiguration](metaclass=ABCMeta):
     """Interface to operate files in a storage."""
 
     db_store: FileStore
@@ -232,7 +230,7 @@ class FileBackendInterface(Generic[FBC], metaclass=ABCMeta):
                 f"fileobj.size: {fileobj.size}"
             )
 
-        file_in_store, created = FileInStore.objects.get_or_create(
+        _, created = FileInStore.objects.get_or_create(
             store=self.db_store, file=fileobj, data={}
         )
         entry = self.get_entry(fileobj)
