@@ -99,9 +99,10 @@ class Command(DebusineBaseCommand):
 
         with context.disable_permission_checks(), transaction.atomic():
             try:
-                WorkRequest.objects.create_workflow(
+                workflow = WorkRequest.objects.create_workflow(
                     template=template, data=data
                 )
+                workflow.mark_pending()
             except Exception as e:
                 raise CommandError(
                     f"Failed to create workflow: {e}", returncode=3
