@@ -53,7 +53,7 @@ class CreateWorkRequestCommandTests(TestCase):
 
     def test_data_from_file(self) -> None:
         """`create_work_request` accepts data from a file."""
-        data = {"result": True}
+        data = {"result": WorkRequest.Results.SUCCESS}
         data_file = self.create_temporary_file(
             contents=yaml.safe_dump(data).encode()
         )
@@ -77,7 +77,7 @@ class CreateWorkRequestCommandTests(TestCase):
 
     def test_data_from_stdin(self) -> None:
         """`create_work_request` accepts data from stdin."""
-        data = {"result": True}
+        data = {"result": WorkRequest.Results.SUCCESS}
         stdout, stderr, exit_code = call_command(
             "create_work_request",
             "worker",
@@ -97,7 +97,7 @@ class CreateWorkRequestCommandTests(TestCase):
 
     def test_event_reactions(self) -> None:
         """`create_work_request` handles event reactions."""
-        data = {"result": True}
+        data = {"result": WorkRequest.Results.SUCCESS}
         event_reactions = {
             "on_success": [{"action": "send-notification", "channel": "foo"}]
         }
@@ -130,7 +130,7 @@ class CreateWorkRequestCommandTests(TestCase):
         self.assertEqual(exit_code, 0)
 
     def test_server(self) -> None:
-        data = {"result": True}
+        data = {"result": WorkRequest.Results.SUCCESS}
         stdout, stderr, exit_code = call_command(
             "create_work_request",
             "server",
@@ -149,7 +149,7 @@ class CreateWorkRequestCommandTests(TestCase):
         self.assertEqual(exit_code, 0)
 
     def test_server_no_event_reactions(self) -> None:
-        data = {"result": True}
+        data = {"result": WorkRequest.Results.SUCCESS}
         event_reactions = {
             "on_success": [
                 {
@@ -225,7 +225,7 @@ class CreateWorkRequestCommandTests(TestCase):
 
     def test_wait_not_implemented(self) -> None:
         """`create_work_request` refuses to create wait work requests."""
-        data = {"result": True}
+        data = {"result": WorkRequest.Results.SUCCESS}
         with self.assertRaisesRegex(
             CommandError, r"^Error: argument task_type: invalid choice: 'wait'"
         ) as exc:
@@ -263,7 +263,7 @@ class CreateWorkRequestCommandTests(TestCase):
     def test_different_created_by(self) -> None:
         """`create_work_request` can use a different created-by user."""
         user = self.playground.get_default_user()
-        data = {"result": True}
+        data = {"result": WorkRequest.Results.SUCCESS}
         stdout, stderr, exit_code = call_command(
             "create_work_request",
             "worker",
