@@ -36,7 +36,7 @@ class EditWorkerMetadataCommandTests(TestCase):
         static_metadata_file = self.create_temporary_file()
         static_metadata_file.write_bytes(
             b'sbuild:\n  architectures:\n    - amd64\n    - i386\n'
-            b'  distributions:\n    - jessie\n    - stretch'
+            b'  distributions:\n    - stretch\n    - buster'
         )
         with self.assertWarnsMessage(
             DeprecationWarning,
@@ -57,7 +57,7 @@ class EditWorkerMetadataCommandTests(TestCase):
             {
                 'sbuild': {
                     'architectures': ['amd64', 'i386'],
-                    'distributions': ['jessie', 'stretch'],
+                    'distributions': ['stretch', 'buster'],
                 }
             },
         )
