@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Tests for the management command list_notification_channels."""
+
 from django.test import TestCase
 from rich.pretty import pretty_repr
 
@@ -34,9 +35,7 @@ class ListNotificationChannelsTests(TabularOutputTests, TestCase):
     def test_list_notification_channels(self) -> None:
         """list_notification_channels print the channels."""
         with self.assertPrintsTable() as output:
-            stdout, stderr, exit_code = call_command(
-                "list_notification_channels"
-            )
+            _, stderr, exit_code = call_command("list_notification_channels")
         self.assertEqual(output.col(0), [self.notification_channel.name])
         self.assertEqual(output.col(1), [self.notification_channel.method])
         self.assertEqual(
