@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Tests for the management command manage_user."""
+
 from unittest import mock
 
 from django.contrib.auth import get_user_model
@@ -44,7 +45,7 @@ class ManageUserCommandTests(TestCase):
         self.addCleanup(patcher.stop)
         mocked.return_value = True
 
-        stdout, stderr, exit_code = call_command("manage_user", "change-email")
+        _, _, exit_code = call_command("manage_user", "change-email")
 
         self.assertEqual(exit_code, 2)
 
