@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Tests for the management command scope."""
+
 from typing import ClassVar
 from unittest import mock
 
@@ -155,17 +156,13 @@ class CreateScopeCommandTests(TestCase):
 
     def test_idempotent(self) -> None:
         """Test idempotence in creating twice."""
-        stdout, stderr, exit_code = call_command(
-            "scope", "create", "scope", "--with-owners-group"
-        )
+        call_command("scope", "create", "scope", "--with-owners-group")
         scope = Scope.objects.get(name="scope")
         admin_group = Group.objects.get(scope=scope, name="Owners")
         admin_group.users.set([self.playground.get_default_user()])
 
         # Recreate: the existing database objects are maintained
-        stdout, stderr, exit_code = call_command(
-            "scope", "create", "scope", "--with-owners-group"
-        )
+        call_command("scope", "create", "scope", "--with-owners-group")
         new_scope = Scope.objects.get(name="scope")
         self.assertEqual(new_scope.pk, scope.pk)
         new_group = Group.objects.get(scope=new_scope, name="Owners")
@@ -587,8 +584,8 @@ class EditFileStoreScopeCommandTests(TestCase):
         """Editing a nonexistent file store in a scope fails."""
         with self.assertRaisesRegex(
             CommandError,
-            fr"Scope '{self.scope.name}' has no file store named "
-            fr"'does-not-exist'",
+            rf"Scope '{self.scope.name}' has no file store named "
+            rf"'does-not-exist'",
         ) as exc:
             call_command(
                 "scope", "edit_file_store", self.scope.name, "does-not-exist"
@@ -600,8 +597,8 @@ class EditFileStoreScopeCommandTests(TestCase):
         """Editing a file store that is not in the given scope fails."""
         with self.assertRaisesRegex(
             CommandError,
-            fr"Scope '{self.scope.name}' has no file store named "
-            fr"'{self.file_store.name}'",
+            rf"Scope '{self.scope.name}' has no file store named "
+            rf"'{self.file_store.name}'",
         ) as exc:
             call_command(
                 "scope",
@@ -663,8 +660,8 @@ class RemoveFileStoreScopeCommandTests(TestCase):
 
         with self.assertRaisesRegex(
             CommandError,
-            fr"Scope '{self.scope.name}' contains some files that are only in "
-            fr"file store '{self.file_store.name}'; drain it first",
+            rf"Scope '{self.scope.name}' contains some files that are only in "
+            rf"file store '{self.file_store.name}'; drain it first",
         ) as exc:
             call_command(
                 "scope",
@@ -693,8 +690,8 @@ class RemoveFileStoreScopeCommandTests(TestCase):
         """Removing a nonexistent file store from a scope fails."""
         with self.assertRaisesRegex(
             CommandError,
-            fr"Scope '{self.scope.name}' has no file store named "
-            fr"'does-not-exist'",
+            rf"Scope '{self.scope.name}' has no file store named "
+            rf"'does-not-exist'",
         ) as exc:
             call_command(
                 "scope", "remove_file_store", self.scope.name, "does-not-exist"
@@ -706,8 +703,8 @@ class RemoveFileStoreScopeCommandTests(TestCase):
         """Removing a file store that is not in the given scope fails."""
         with self.assertRaisesRegex(
             CommandError,
-            fr"Scope '{self.scope.name}' has no file store named "
-            fr"'{self.file_store.name}'",
+            rf"Scope '{self.scope.name}' has no file store named "
+            rf"'{self.file_store.name}'",
         ) as exc:
             call_command(
                 "scope",
@@ -768,7 +765,7 @@ class ShowScopeCommandTests(TabularOutputTests, TestCase):
             self.file_stores[1].files.add(artifact.files.get())
 
         with self.assertPrintsTable() as output:
-            stdout, stderr, _ = call_command("scope", "show", self.scope.name)
+            call_command("scope", "show", self.scope.name)
 
         self.assertEqual(output.col(0), ["scope", "", ""])
         self.assertEqual(output.col(1), ["Label", "", ""])
