@@ -18,7 +18,6 @@ from django.core.management.base import CommandError
 from django.test import override_settings
 
 from debusine.assets import CloudProvidersType, DummyProviderAccountData
-from debusine.client.models import model_to_json_serializable_dict
 from debusine.db.models import Worker, WorkerPool
 from debusine.django.management.tests import call_command
 from debusine.server.management.commands.tests.utils import TabularOutputTests
@@ -54,7 +53,7 @@ class WorkerPoolCommandTests(TabularOutputTests, TestCase):
             "amd64,i386",
             "--specifications",
             "-",
-            stdin=StringIO(yaml.safe_dump(specifications.dict())),
+            stdin=StringIO(yaml.safe_dump(specifications.model_dump())),
         )
 
         self.assertEqual(stdout, "")
@@ -66,10 +65,10 @@ class WorkerPoolCommandTests(TabularOutputTests, TestCase):
         self.assertEqual(pool.architectures, ["amd64", "i386"])
         self.assertEqual(pool.tags, [])
         self.assertEqual(pool.provider_account, provider_account)
-        self.assertEqual(pool.specifications, specifications.dict())
+        self.assertEqual(pool.specifications, specifications.model_dump())
         self.assertTrue(pool.instance_wide)
         self.assertFalse(pool.ephemeral)
-        self.assertEqual(pool.limits, WorkerPoolLimits().dict())
+        self.assertEqual(pool.limits, WorkerPoolLimits().model_dump())
 
     def test_create_all_args_from_files(self) -> None:
         name = "test"
@@ -78,12 +77,12 @@ class WorkerPoolCommandTests(TabularOutputTests, TestCase):
         assert isinstance(provider_account_data, DummyProviderAccountData)
         specifications = DummyWorkerPoolSpecification(features=["something"])
         specifications_file = self.create_temporary_file(
-            contents=specifications.json().encode()
+            contents=specifications.model_dump_json().encode()
         )
 
         limits = WorkerPoolLimits(max_idle_seconds=60)
         limits_file = self.create_temporary_file(
-            contents=limits.json().encode()
+            contents=limits.model_dump_json().encode()
         )
 
         stdout, stderr, exit_code = call_command(
@@ -114,10 +113,10 @@ class WorkerPoolCommandTests(TabularOutputTests, TestCase):
         self.assertEqual(pool.architectures, ["i386"])
         self.assertEqual(pool.tags, ["tag-1"])
         self.assertEqual(pool.provider_account, provider_account)
-        self.assertEqual(pool.specifications, specifications.dict())
+        self.assertEqual(pool.specifications, specifications.model_dump())
         self.assertFalse(pool.instance_wide)
         self.assertTrue(pool.ephemeral)
-        self.assertEqual(pool.limits, limits.dict())
+        self.assertEqual(pool.limits, limits.model_dump())
 
     def test_create_idempotent(self) -> None:
         pool = self.playground.create_worker_pool()
@@ -126,7 +125,7 @@ class WorkerPoolCommandTests(TabularOutputTests, TestCase):
         )
         limits = WorkerPoolLimits(max_idle_seconds=60)
         limits_file = self.create_temporary_file(
-            contents=limits.json().encode()
+            contents=limits.model_dump_json().encode()
         )
         stdout, stderr, exit_code = call_command(
             "worker_pool",
@@ -158,7 +157,7 @@ class WorkerPoolCommandTests(TabularOutputTests, TestCase):
         self.assertEqual(pool.tags, ["tag-1"])
         self.assertFalse(pool.instance_wide)
         self.assertTrue(pool.ephemeral)
-        self.assertEqual(pool.limits, limits.dict())
+        self.assertEqual(pool.limits, limits.model_dump())
 
     def test_create_invalid_specifications(self) -> None:
         name = "test"
@@ -196,7 +195,7 @@ class WorkerPoolCommandTests(TabularOutputTests, TestCase):
         assert isinstance(provider_account_data, DummyProviderAccountData)
         specifications = DummyWorkerPoolSpecification(features=["something"])
         specifications_file = self.create_temporary_file(
-            contents=specifications.json().encode()
+            contents=specifications.model_dump_json().encode()
         )
         limits_file = self.create_temporary_file(
             contents=yaml.dump(
@@ -341,13 +340,13 @@ class WorkerPoolCommandTests(TabularOutputTests, TestCase):
                 "provider_account": pool.provider_account.data["name"],
                 "enabled": pool.enabled,
                 "specifications": sort_keys(
-                    model_to_json_serializable_dict(
-                        pool.specifications_model, exclude_unset=True
+                    pool.specifications_model.model_dump(
+                        mode="json", exclude_unset=True
                     )
                 ),
                 "limits": sort_keys(
-                    model_to_json_serializable_dict(
-                        pool.limits_model, exclude_unset=True
+                    pool.limits_model.model_dump(
+                        mode="json", exclude_unset=True
                     )
                 ),
             }
@@ -480,19 +479,19 @@ class WorkerPoolCommandTests(TabularOutputTests, TestCase):
 
     def test_edit_aborted(self) -> None:
         pool = self.playground.create_worker_pool()
-        stdout, stderr, exit_code = self.call_edit(pool.name, success=False)
+        _, stderr, exit_code = self.call_edit(pool.name, success=False)
         self.assertEqual(exit_code, 1)
         self.assertEqual(stderr, "Edit aborted.\n")
 
     def test_edit_noop(self) -> None:
         pool = self.playground.create_worker_pool()
-        stdout, stderr, exit_code = self.call_edit(pool.name)
+        _, stderr, exit_code = self.call_edit(pool.name)
         self.assertEqual(exit_code, 1)
         self.assertEqual(stderr, "No changes.\n")
 
     def test_edit_updates_only_changed_data(self) -> None:
         pool = self.playground.create_worker_pool()
-        stdout, stderr, exit_code = self.call_edit(
+        stdout, _, exit_code = self.call_edit(
             pool.name,
             output={
                 "architectures": ["m68k"],
@@ -510,7 +509,7 @@ class WorkerPoolCommandTests(TabularOutputTests, TestCase):
         provider_account = self.playground.create_cloud_provider_account_asset(
             name="different-provider"
         )
-        stdout, stderr, exit_code = self.call_edit(
+        stdout, _, exit_code = self.call_edit(
             pool.name,
             output={
                 "provider_account": "different-provider",
