@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Tests for the management command workspace."""
+
 import datetime as dt
 import io
 from typing import ClassVar
@@ -165,7 +166,7 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
         ):
             call_command("workspace", "rename", "localtest/toto", "toto2")
 
-        stdout, stderr, exit_code = call_command(
+        _, stderr, exit_code = call_command(
             "workspace", "rename", "localtest/myws", "my ws"
         )
         self.assertEqual(
@@ -182,7 +183,7 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
         call_command(
             "workspace", "create", "localtest/myws-exists", "Owners-myws"
         )
-        stdout, stderr, exit_code = call_command(
+        _, stderr, exit_code = call_command(
             "workspace", "rename", "localtest/myws", "myws-exists"
         )
         self.assertEqual(
@@ -194,7 +195,7 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
         self.assertEqual(exit_code, 3)
 
         # rename, idempotent
-        stdout, stderr, exit_code = call_command(
+        _, stderr, exit_code = call_command(
             "workspace", "rename", "localtest/myws", "myws-renamed"
         )
         self.assertEqual(exit_code, 0)
@@ -207,7 +208,7 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
             ).exists()
         )
 
-        stdout, stderr, exit_code = call_command(
+        _, stderr, exit_code = call_command(
             "workspace", "rename", "localtest/myws-renamed", "myws-renamed"
         )
         self.assertEqual(exit_code, 0)
@@ -232,7 +233,7 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
 
         # list
         with self.assertPrintsTable() as output:
-            stdout, stderr, _ = call_command("workspace", "list")
+            stdout, _, _ = call_command("workspace", "list")
 
         self.assertEqual(
             output.col(0),
@@ -247,7 +248,7 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
         self.assertEqual(output.col(2), ["Never", "30", "30", "Never"])
 
         # --yaml
-        stdout, stderr, _ = call_command("workspace", "list", "--yaml")
+        stdout, _, _ = call_command("workspace", "list", "--yaml")
         data = yaml.safe_load(stdout)
         expected_data = [
             {
@@ -274,9 +275,7 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
         self.assertEqual(data, expected_data)
 
         # scope
-        stdout, stderr, _ = call_command(
-            "workspace", "list", "localtest", "--yaml"
-        )
+        stdout, _, _ = call_command("workspace", "list", "localtest", "--yaml")
         data = yaml.safe_load(stdout)
         self.assertEqual(data, expected_data[1:])
 
@@ -304,14 +303,14 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
         )
 
         with self.assertPrintsTable() as output:
-            stdout, stderr, exit_code = call_command(
+            stdout, _, exit_code = call_command(
                 "workspace", "list_roles", "localtest/myws"
             )
         self.assertEqual(output.col(0), ["Admins", "Contractors", "Employees"])
         self.assertEqual(output.col(1), ["owner", "contributor", "contributor"])
         self.assertEqual(exit_code, 0)
 
-        stdout, stderr, exit_code = call_command(
+        stdout, _, exit_code = call_command(
             "workspace", "list_roles", "localtest/myws", "--yaml"
         )
         data = yaml.safe_load(stdout)
@@ -328,18 +327,18 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
             "workspace", "grant_role", "localtest/myws",
             "contributor", "Employees", "Contractors",
         )
-        stdout, stderr, exit_code = call_command(
+        stdout, _, exit_code = call_command(
             "workspace", "list_roles", "localtest/myws", "--yaml"
         )
         data = yaml.safe_load(stdout)
         self.assertEqual(data, expected_data)
 
         # revoke_role
-        stdout, stderr, exit_code = call_command(
+        stdout, _, exit_code = call_command(
             "workspace", "revoke_role", "localtest/myws",
             "contributor", "Employees"
         )
-        stdout, stderr, exit_code = call_command(
+        stdout, _, exit_code = call_command(
             "workspace", "list_roles", "localtest/myws", "--yaml"
         )
         data = yaml.safe_load(stdout)
@@ -461,11 +460,8 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
         """Delete an existing workspace."""
         workspace = self.create_workspace_for_delete()
 
-        stdout, stderr, _ = call_command(
-            "workspace",
-            "delete",
-            "scope/Test",
-            "--yes",
+        stdout, _, _ = call_command(
+            "workspace", "delete", "scope/Test", "--yes"
         )
         self.assertEqual("", stdout)
 
@@ -511,11 +507,8 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
         scenario = scenarios.UIPlayground()
         playground.build_scenario(scenario)
 
-        stdout, stderr, _ = call_command(
-            "workspace",
-            "delete",
-            str(scenario.workspace),
-            "--yes",
+        stdout, _, _ = call_command(
+            "workspace", "delete", str(scenario.workspace), "--yes"
         )
         self.assertEqual("", stdout)
 
@@ -556,7 +549,7 @@ class WorkspaceCommandsTests(TabularOutputTests, TestCase):
         workspace = default_workspace()
         with self.assertRaisesRegex(
             CommandError,
-            fr"^Workspace {workspace.scope.name}/{workspace.name}"
+            rf"^Workspace {workspace.scope.name}/{workspace.name}"
             " cannot be deleted$",
         ) as exc:
             call_command(
