@@ -9,21 +9,14 @@
 
 """Assign the correct URL configuration for the requested virtual host."""
 
-from collections.abc import Callable
-
 from django.conf import settings
-from django.http import HttpRequest, HttpResponse
+from django.http import HttpRequest
+from django.utils.deprecation import MiddlewareMixin
 
 
-class VirtualHostMiddleware:
+class VirtualHostMiddleware(MiddlewareMixin):
     """Assign appropriate URL configuration."""
 
-    def __init__(
-        self, get_response: Callable[[HttpRequest], HttpResponse]
-    ) -> None:
-        """Middleware API entry point."""
-        self.get_response = get_response
-
     @property
     def _archive_fqdns(self) -> list[str]:
         """Hosts used for serving archives."""
@@ -32,9 +25,11 @@ class VirtualHostMiddleware:
         else:
             return [settings.DEBUSINE_DEBIAN_ARCHIVE_FQDN]
 
-    def __call__(self, request: HttpRequest) -> HttpResponse:
-        """Middleware entry point."""
+    def process_request(self, request: HttpRequest) -> None:
+        """Process request in middleware."""
         host = request.get_host()
         if host in self._archive_fqdns:
             setattr(request, "urlconf", "debusine.web.archives.urls")
-        return self.get_response(request)
+            setattr(request, "is_archive_view", True)
+        else:
+            setattr(request, "is_archive_view", False)
