@@ -35,8 +35,11 @@ The `restrict` setting can be used to restrict local account creation to
 remote users that have a specific set of claims. It can be set to a sequence of
 strings, each specifying a restriction:
 
-* `group:name` the given group name must be present
-* `email-verified` the primary email needs to be reported as verified
+* ``group:name``: the given group name must be present. Multiple groups can be
+  OR-ed together by separating them with commas; for example
+  ``group:debian,ubuntu`` requires the user to be in one of the ``debian`` or
+  ``ubuntu`` groups.
+* ``email-verified``: the primary email needs to be reported as verified
 
 All listed restrictions must be met (i.e. they are AND-ed together).
 """
@@ -49,6 +52,9 @@ from typing import Any, TYPE_CHECKING
 if TYPE_CHECKING:  # pragma: no cover
     import django.http
     import jwcrypto.jwk
+    from requests_oauthlib.oauth2_session import _Token
+
+    _Token  # fake usage for vulture
 
 # Note: this module is supposed to be imported from settings.py
 #
@@ -188,7 +194,7 @@ class BoundOIDCProvider(BoundProvider):
                 reverse("signon:oidc_callback", args=(self.name,))
             ),
         )
-        self.tokens = None
+        self.tokens: "_Token" | None = None
         self.id_token_claims: dict[str, Any] | None = None
         self.options: Collection[str] | None = None
 
