@@ -9,6 +9,7 @@
 # contained in the LICENSE file.
 
 """Logic to authenticate a request using signon Providers."""
+
 import functools
 import logging
 from collections.abc import Iterable, Sequence
@@ -140,13 +141,22 @@ class Signon:
                                 " does not have a verified email"
                             )
                     elif restriction.startswith("group:"):
-                        group_name = restriction[6:]
-                        if group_name not in identity.claims.get(
-                            "groups_direct", ()
-                        ):
+                        group_names = restriction[6:].split(",")
+                        group_claims = identity.claims.get("groups_direct", ())
+                        for group_name in group_names:
+                            if group_name in group_claims:
+                                break
+                        else:
+                            if len(group_names) == 1:
+                                group_list = repr(group_names[0])
+                            else:
+                                group_list = (
+                                    ", ".join(repr(x) for x in group_names[:-1])
+                                    + f" or {group_names[-1]!r}"
+                                )
                             res.append(
                                 f"identity {identity}"
-                                f" is not in group {group_name!r}"
+                                f" is not in group {group_list}"
                             )
                     else:
                         raise ImproperlyConfigured(
