@@ -15,6 +15,7 @@ Login and logout hooks are implemented as mixing for the normal
 django.contrib.auth.LoginView/LogoutView.
 """
 
+import logging
 from collections.abc import Sequence
 from typing import Any
 
@@ -35,6 +36,8 @@ from debusine.db.models import Identity
 from debusine.server.signon import providers
 from debusine.server.signon.middleware import RequestSignonProtocol
 
+log = logging.getLogger("debusine.server.signon")
+
 signon_oidc_callbacks = Counter(
     "debusine_signon_oidc_callbacks",
     "OpenID Connect authentication callbacks",
@@ -107,7 +110,13 @@ class OIDCAuthenticationCallbackView(View):
             raise http.Http404
 
         bound_provider = provider.bind(request)
-        bound_provider.load_tokens()
+        try:
+            bound_provider.load_tokens()
+        except providers.OIDCValidationError as e:
+            log.info(  # noqa: G200
+                "OIDC validation for provider %r failed: %s", name, str(e)
+            )
+            raise PermissionDenied
 
         return bound_provider.id_token_claims, bound_provider.options
 
@@ -123,7 +132,11 @@ class OIDCAuthenticationCallbackView(View):
         recompute authentication information with the new information.
         """
         name = self.kwargs["name"]
-        claims, options = self._validate(request)
+        try:
+            claims, options = self._validate(request)
+        except Exception:
+            signon_oidc_callbacks.labels(issuer=name, activated=False).inc()
+            raise
 
         try:
             identity = Identity.objects.get(issuer=name, subject=claims["sub"])
