@@ -20,7 +20,7 @@ from collections.abc import Generator, Sequence
 from contextlib import ExitStack, contextmanager
 from dataclasses import dataclass, field
 from pathlib import Path, PurePath
-from typing import Generic, TypeVar
+from typing import override
 
 from debian.deb822 import Deb822, Packages, Sources
 from django.db import transaction
@@ -31,7 +31,11 @@ from debusine.artifacts.local_artifact import (
     RepositoryIndex,
     SourcePackage,
 )
-from debusine.artifacts.models import ArtifactCategory, CollectionCategory
+from debusine.artifacts.models import (
+    ArtifactCategory,
+    CollectionCategory,
+    WorkRequestResults,
+)
 from debusine.db.locks import LockError, LockType
 from debusine.db.models import (
     Artifact,
@@ -39,17 +43,16 @@ from debusine.db.models import (
     Collection,
     CollectionItem,
 )
+from debusine.server.collections import DebianSuiteManager
 from debusine.server.tasks import BaseServerTask
 from debusine.server.tasks.models import APTMirrorData
 from debusine.tasks import DefaultDynamicData, TaskConfigError
 from debusine.tasks.models import BaseDynamicTaskData
 from debusine.utils import calculate_hash
 
-T = TypeVar("T", bound=Deb822)
-
 
 @dataclass
-class PlanAdd(Generic[T]):
+class PlanAdd[T: Deb822]:
     """A plan for adding a single item to a collection."""
 
     name: str
@@ -58,14 +61,14 @@ class PlanAdd(Generic[T]):
 
 
 @dataclass
-class PlanReplace(PlanAdd[T]):
+class PlanReplace[T: Deb822](PlanAdd[T]):
     """A plan for replacing a single item in a collection."""
 
     item: CollectionItem
 
 
 @dataclass
-class Plan(Generic[T]):
+class Plan[T: Deb822]:
     """A plan for updating items in a collection."""
 
     add: list[PlanAdd[T]] = field(default_factory=list)
@@ -109,14 +112,23 @@ class APTMirror(
         """The `debian:suite` collection this task is updating."""
         try:
             return Collection.objects.get(
-                name=self.data.collection, category=CollectionCategory.SUITE
+                name=self.data.collection,
+                category=CollectionCategory.SUITE,
+                workspace=self.workspace,
             )
         except Collection.DoesNotExist:
             raise TaskConfigError(
-                f"Collection '{self.data.collection}' with category "
-                f"'{CollectionCategory.SUITE}' not found"
+                f"Collection '{self.data.collection}' in '{self.workspace}' "
+                f"with category '{CollectionCategory.SUITE}' not found"
             )
 
+    @functools.cached_property
+    def collection_manager(self) -> DebianSuiteManager:
+        """The manager for the suite this task is updating."""
+        manager = self.collection.manager
+        assert isinstance(manager, DebianSuiteManager)
+        return manager
+
     @functools.cached_property
     def parent_archive(self) -> Collection | None:
         """
@@ -133,11 +145,7 @@ class APTMirror(
         # across suites even if may_reuse_versions=True.
         if self.collection.data.get("may_reuse_versions", False):
             return None
-        try:
-            archive = self.collection.parent_collections.get(
-                category=CollectionCategory.ARCHIVE
-            )
-        except Collection.DoesNotExist:
+        if (archive := self.collection_manager.get_archive()) is None:
             return None
         if archive.data.get("may_reuse_versions", False):
             return None
@@ -209,7 +217,7 @@ class APTMirror(
 
         source = {
             "Types": "deb deb-src",
-            "URIs": self.data.url,
+            "URIs": str(self.data.url),
             "Suites": self.data.suite,
         }
         if self.data.components is not None:
@@ -268,9 +276,8 @@ class APTMirror(
         # Source packages from the local collection
         items: dict[str, tuple[CollectionItem, dict[str, str]]] = {}
         for item in (
-            CollectionItem.objects.active()
+            self.collection.child_items.active()
             .filter(
-                parent_collection=self.collection,
                 child_type=CollectionItem.Types.ARTIFACT,
                 category=ArtifactCategory.SOURCE_PACKAGE,
             )
@@ -374,14 +381,15 @@ class APTMirror(
                     created_by_work_request=self.work_request,
                 )
 
-            self.collection.manager.add_artifact(
-                source_artifact,
-                user=self.work_request.created_by,
-                variables={
-                    "component": component,
-                    "section": source["Section"],
-                },
-            )
+            with self.collection_manager.allow_rewinding_versions():
+                self.collection_manager.add_artifact(
+                    source_artifact,
+                    user=self.work_request.created_by,
+                    variables={
+                        "component": component,
+                        "section": source["Section"],
+                    },
+                )
 
     def update_sources(self, temp_path: Path, plan: Plan[Sources]) -> None:
         """
@@ -402,7 +410,7 @@ class APTMirror(
 
         for replace in plan.replace:
             with transaction.atomic():
-                self.collection.manager.remove_item(replace.item)
+                self.collection_manager.remove_item(replace.item)
                 self.add_source(
                     temp_path,
                     name=replace.name,
@@ -412,7 +420,7 @@ class APTMirror(
 
         with transaction.atomic():
             for remove in plan.remove:
-                self.collection.manager.remove_item(remove)
+                self.collection_manager.remove_item(remove)
 
     def add_binary(
         self,
@@ -476,7 +484,7 @@ class APTMirror(
                 )
                 srcpkg_name = binary_package.data.srcpkg_name
                 srcpkg_version = binary_package.data.srcpkg_version
-                source_item = self.collection.manager.lookup(
+                source_item = self.collection_manager.lookup(
                     f"source-version:{srcpkg_name}_{srcpkg_version}"
                 )
                 # Add a built-using relationship to the corresponding source
@@ -495,15 +503,16 @@ class APTMirror(
                         type=ArtifactRelation.Relations.BUILT_USING,
                     )
 
-            self.collection.manager.add_artifact(
-                binary_artifact,
-                user=self.work_request.created_by,
-                variables={
-                    "component": component,
-                    "section": binary["Section"],
-                    "priority": binary["Priority"],
-                },
-            )
+            with self.collection_manager.allow_rewinding_versions():
+                self.collection_manager.add_artifact(
+                    binary_artifact,
+                    user=self.work_request.created_by,
+                    variables={
+                        "component": component,
+                        "section": binary["Section"],
+                        "priority": binary["Priority"],
+                    },
+                )
 
     def plan_binaries(self, temp_path: Path) -> Plan[Packages]:
         """Plan the update of all binary packages in the collection."""
@@ -534,9 +543,8 @@ class APTMirror(
         # Binary packages from the local collection
         items: dict[str, tuple[CollectionItem, dict[str, str]]] = {}
         for item in (
-            CollectionItem.objects.active()
+            self.collection.child_items.active()
             .filter(
-                parent_collection=self.collection,
                 child_type=CollectionItem.Types.ARTIFACT,
                 category=ArtifactCategory.BINARY_PACKAGE,
             )
@@ -602,7 +610,7 @@ class APTMirror(
 
         for replace in plan.replace:
             with transaction.atomic():
-                self.collection.manager.remove_item(replace.item)
+                self.collection_manager.remove_item(replace.item)
                 self.add_binary(
                     temp_path,
                     name=replace.name,
@@ -612,7 +620,7 @@ class APTMirror(
 
         with transaction.atomic():
             for remove in plan.remove:
-                self.collection.manager.remove_item(remove)
+                self.collection_manager.remove_item(remove)
 
     @contextmanager
     def apt_config(self, temp_path: Path) -> Generator[None]:
@@ -676,9 +684,8 @@ class APTMirror(
         # Repository index files from the local collection
         items: dict[str, tuple[CollectionItem, dict[str, str]]] = {}
         for item in (
-            CollectionItem.objects.active()
+            self.collection.child_items.active()
             .filter(
-                parent_collection=self.collection,
                 child_type=CollectionItem.Types.ARTIFACT,
                 category=ArtifactCategory.REPOSITORY_INDEX,
             )
@@ -739,7 +746,7 @@ class APTMirror(
         index_artifact = Artifact.objects.create_from_local_artifact(
             index, self.workspace, created_by_work_request=self.work_request
         )
-        self.collection.manager.add_artifact(
+        self.collection_manager.add_artifact(
             index_artifact,
             user=self.work_request.created_by,
             variables={"path": name},
@@ -758,13 +765,14 @@ class APTMirror(
                 self.add_index(name=add.name, paragraph=add.contents)
 
             for replace in plan.replace:
-                self.collection.manager.remove_item(replace.item)
+                self.collection_manager.remove_item(replace.item)
                 self.add_index(name=replace.name, paragraph=replace.contents)
 
             for remove in plan.remove:
-                self.collection.manager.remove_item(remove)
+                self.collection_manager.remove_item(remove)
 
-    def _execute(self) -> bool:
+    @override
+    def _execute(self) -> WorkRequestResults:
         """Execute the task."""
         with advisory_lock(
             (
@@ -796,8 +804,9 @@ class APTMirror(
                 self.update_sources(temp_path, self.plan_sources(temp_path))
                 self.update_binaries(temp_path, self.plan_binaries(temp_path))
                 self.update_indexes(self.plan_indexes(temp_path))
-            return True
+            return WorkRequestResults.SUCCESS
 
+    @override
     def get_label(self) -> str:
         """Return the task label."""
         return f"mirror {self.data.collection} from {self.data.url}"
