@@ -10,10 +10,12 @@
 """Base support for tasks that run on server-side Celery workers."""
 
 from abc import ABCMeta
+from collections.abc import Callable
 from pathlib import Path
-from typing import TypeVar
+from typing import override
 
 from debusine.artifacts import WorkRequestDebugLogs
+from debusine.artifacts.models import TaskTypes
 from debusine.db.context import context
 from debusine.db.models import (
     Artifact,
@@ -21,15 +23,22 @@ from debusine.db.models import (
     WorkRequest,
     Workspace,
 )
+from debusine.db.models.permissions import (
+    PermissionUser,
+    format_permission_check_error,
+)
 from debusine.tasks import BaseTask
-from debusine.tasks.models import BaseDynamicTaskData, BaseTaskData, TaskTypes
-from debusine.worker.system_information import host_architecture
-
-TD = TypeVar("TD", bound=BaseTaskData)
-DTD = TypeVar("DTD", bound=BaseDynamicTaskData)
+from debusine.tasks.models import BaseDynamicTaskData, BaseTaskData
+from debusine.worker.system_information import native_architecture
 
 
-class BaseServerTask(BaseTask[TD, DTD], metaclass=ABCMeta):
+class ServerTaskPermissionDenied(Exception):
+    """Permission predicate checks failed on server tasks."""
+
+
+class BaseServerTask[TD: BaseTaskData, DTD: BaseDynamicTaskData](
+    BaseTask[TD, DTD], metaclass=ABCMeta
+):
     """Base class for tasks that run on server-side Celery workers."""
 
     TASK_TYPE = TaskTypes.SERVER
@@ -43,18 +52,16 @@ class BaseServerTask(BaseTask[TD, DTD], metaclass=ABCMeta):
     workspace: Workspace | None = None
 
     def set_work_request(self, work_request: WorkRequest) -> None:
-        """Set this task's work request and workspace."""
+        """Set this task's work request and workspace information."""
+        super().set_work_request(work_request)
+
         self.work_request = work_request
         self.workspace = work_request.workspace
 
-        # BaseTask attributes; work_request_id and workspace_name are less
-        # useful for server tasks since we have the model instances, but we
-        # set them anyway for compatibility.
-        self.work_request_id = work_request.id
-        self.workspace_name = work_request.workspace.name
-        self.worker_host_architecture = host_architecture()
+        self.worker_native_architecture = native_architecture()
 
-    def execute(self) -> bool:
+    @override
+    def execute(self) -> WorkRequest.Results:
         """Execute task, setting up a suitable context."""
         assert self.work_request is not None
         assert self.workspace is not None
@@ -68,6 +75,7 @@ class BaseServerTask(BaseTask[TD, DTD], metaclass=ABCMeta):
         finally:
             context.reset()
 
+    @override
     def _upload_work_request_debug_logs(self) -> None:
         """
         Create a WorkRequestDebugLogs artifact and upload the logs.
@@ -101,3 +109,14 @@ class BaseServerTask(BaseTask[TD, DTD], metaclass=ABCMeta):
 
         self._debug_log_files_directory.cleanup()
         self._debug_log_files_directory = None
+
+    def enforce(self, predicate: Callable[[PermissionUser], bool]) -> None:
+        """Enforce a permission predicate."""
+        assert self.work_request is not None
+
+        if predicate(self.work_request.created_by):
+            return
+
+        raise ServerTaskPermissionDenied(
+            format_permission_check_error(predicate, context.user)
+        )
