@@ -215,7 +215,7 @@ class CopyCollectionItems(
                 )
 
     @override
-    def _execute(self) -> bool:
+    def _execute(self) -> WorkRequest.Results:
         """Execute the task."""
         assert self.work_request is not None
         assert self.workspace is not None
@@ -260,7 +260,7 @@ class CopyCollectionItems(
                     )
                     raise
 
-        return True
+        return WorkRequest.Results.SUCCESS
 
     @override
     def get_label(self) -> str:
