@@ -15,7 +15,7 @@ import tempfile
 from dataclasses import dataclass
 from functools import cache, cached_property
 from pathlib import Path, PurePath
-from typing import Any
+from typing import Any, override
 
 from debian.deb822 import Release
 from django.contrib.postgres.aggregates import StringAgg
@@ -41,7 +41,7 @@ from django.db.models.sql.datastructures import BaseTable
 from django_pglocks import advisory_lock
 
 from debusine.artifacts import RepositoryIndex
-from debusine.artifacts.models import ArtifactCategory
+from debusine.artifacts.models import ArtifactCategory, WorkRequestResults
 from debusine.db.locks import LockError, LockType
 from debusine.db.models import (
     Artifact,
@@ -169,7 +169,7 @@ class FunctionJoin(BaseTable):
     def as_sql(
         self,
         compiler: SQLCompiler,
-        connection: BaseDatabaseWrapper,  # noqa: U100
+        connection: BaseDatabaseWrapper,  # noqa: ARG002, U100
     ) -> tuple[str, list[str | int]]:
         """Generate an SQL fragment to be included in the current query."""
         alias_str = (
@@ -305,6 +305,7 @@ class GenerateSuiteIndexes(
         self.index_info: dict[PurePath, IndexInfo] = {}
         self.indexes: dict[PurePath, Artifact] = {}
 
+    @override
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> GenerateSuiteIndexesDynamicData:
@@ -315,6 +316,7 @@ class GenerateSuiteIndexes(
             ).id
         )
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of input artifact IDs used by this task."""
         # Our dynamic data includes a collection, but no artifacts.
@@ -740,7 +742,7 @@ class GenerateSuiteIndexes(
                     Value(f"\nFilename: pool/{component}/"),
                     Case(
                         When(
-                            data__package__startswith="lib",
+                            data__srcpkg_name__startswith="lib",
                             then=Left(KT("data__srcpkg_name"), 4),
                         ),
                         default=Left(KT("data__srcpkg_name"), 1),
@@ -811,6 +813,7 @@ class GenerateSuiteIndexes(
         release["Suite"] = release["Codename"] = self.suite.name
 
         release_fields = dict(self.suite.data.get("release_fields", {}))
+        release_fields.setdefault("Acquire-By-Hash", True)
 
         # Convert boolean fields.
         for field in (
@@ -925,7 +928,8 @@ class GenerateSuiteIndexes(
             .first()
         )
 
-    def _execute(self) -> bool:
+    @override
+    def _execute(self) -> WorkRequestResults:
         """Execute the task."""
         with advisory_lock(
             (
@@ -968,8 +972,9 @@ class GenerateSuiteIndexes(
                 self.generate_release(
                     temp_path=temp_path, newer_item=newer_item
                 )
-                return True
+                return WorkRequestResults.SUCCESS
 
+    @override
     def get_label(self) -> str:
         """Return the task label."""
         return (
