@@ -14,6 +14,7 @@ from typing import Annotated, Any, Self
 
 import pydantic
 
+from debusine.artifacts.models import WorkRequestResults
 from debusine.db.models.workspaces import workspace_name_regex
 from debusine.tasks.models import (
     BaseDynamicTaskData,
@@ -27,7 +28,7 @@ class ServerNoopData(BaseTaskData):
     """In-memory task data for the ServerNoop task."""
 
     exception: bool = False
-    result: bool = False
+    result: WorkRequestResults = WorkRequestResults.FAILURE
 
 
 class APTMirrorData(BaseTaskData):
