@@ -11,6 +11,7 @@
 
 from typing import override
 
+from debusine.artifacts.models import WorkRequestResults
 from debusine.server.tasks import BaseServerTask
 from debusine.server.tasks.models import ServerNoopData
 from debusine.tasks import DefaultDynamicData
@@ -26,7 +27,7 @@ class ServerNoop(
     TASK_VERSION = 1
 
     @override
-    def _execute(self) -> bool:
+    def _execute(self) -> WorkRequestResults:
         """Act as specified by the client."""
         if self.data.exception:
             raise RuntimeError("Client requested an exception")
