@@ -19,7 +19,7 @@ from typing import override
 import tenacity
 from fabric import Connection
 
-from debusine.artifacts.models import ArtifactCategory
+from debusine.artifacts.models import ArtifactCategory, WorkRequestResults
 from debusine.db.models import Artifact
 from debusine.server.tasks import BaseServerTask
 from debusine.server.tasks.models import (
@@ -181,7 +181,7 @@ class PackageUpload(
             raise
 
     @override
-    def _execute(self) -> bool:
+    def _execute(self) -> WorkRequestResults:
         """Execute the task."""
         with tempfile.TemporaryDirectory(
             prefix="debusine-package-upload-"
@@ -189,7 +189,7 @@ class PackageUpload(
             temp_path = Path(temp_dir)
             upload_paths = self.fetch_upload(temp_path)
             if upload_paths is None:
-                return False
+                return WorkRequestResults.FAILURE
             target = self._make_target()
 
             self.append_to_log_file(
@@ -205,7 +205,7 @@ class PackageUpload(
                         f"Unexpected URL scheme: {unreachable}"
                     )
             self.append_to_log_file("package-upload.log", ["Upload succeeded"])
-            return True
+            return WorkRequestResults.SUCCESS
 
     @override
     def get_label(self) -> str:
