@@ -12,18 +12,14 @@ A fake SFTP server for testing.
 
 Do not use this in production!  It has only the features required for the
 tests that currently use it, and no security.
-
-Parts of this file have no test coverage due to difficulties getting
-coverage.py to handle multiprocessing while also handling Django channels
-elsewhere.
 """
 
 import io
 import os
 import socket
-import time
-from multiprocessing import Process
-from typing import NoReturn, Self
+import time as tm
+from threading import Event, Thread
+from typing import Self
 
 from cryptography.hazmat.primitives import asymmetric, serialization
 from paramiko import (
@@ -45,7 +41,7 @@ from paramiko.common import (
 from paramiko.sftp import SFTP_FAILURE, SFTP_OK
 
 
-class FakeSSHServer(ServerInterface):  # pragma: no cover
+class FakeSSHServer(ServerInterface):
     """A fake SSH server for testing."""
 
     def __init__(self, user_key: Ed25519Key) -> None:
@@ -61,18 +57,23 @@ class FakeSSHServer(ServerInterface):  # pragma: no cover
             else OPEN_FAILED_ADMINISTRATIVELY_PROHIBITED
         )
 
-    def get_allowed_auths(self, username: str) -> str:  # noqa: U100
+    def get_allowed_auths(
+        self,
+        username: str,  # noqa: ARG002, U100
+    ) -> str:  # pragma: no cover
         """Return supported authentication methods."""
         return "publickey"
 
     def check_auth_publickey(
-        self, username: str, key: PKey  # noqa: U100
+        self,
+        username: str,  # noqa: ARG002, U100
+        key: PKey,
     ) -> int:
         """Determine if a client key is acceptable for authentication."""
         return AUTH_SUCCESSFUL if key == self.user_key else AUTH_FAILED
 
 
-class FakeSFTPServer(SFTPServerInterface):  # pragma: no cover
+class FakeSFTPServer(SFTPServerInterface):
     """A fake SFTP subsystem for testing."""
 
     def open(
@@ -105,7 +106,7 @@ class FakeSFTPServer(SFTPServerInterface):  # pragma: no cover
         return SFTP_OK
 
 
-class WrappedEd25519Key:  # pragma: no cover
+class WrappedEd25519Key:
     """A wrapper for the various formats of Ed25519 key that we need."""
 
     def __init__(
@@ -129,7 +130,7 @@ class WrappedEd25519Key:  # pragma: no cover
         ).decode()
 
     @property
-    def public_openssh(self) -> str:
+    def public_openssh(self) -> str:  # pragma: no cover
         """Return the OpenSSH public key representation of this key."""
         return (
             self.private_key.public_key()
@@ -146,8 +147,8 @@ class WrappedEd25519Key:  # pragma: no cover
         return Ed25519Key.from_private_key(io.StringIO(self.private_openssh))
 
 
-class FakeSFTPServerProcess(Process):
-    """Process that runs a fake SFTP server for testing."""
+class FakeSFTPServerThread(Thread):
+    """Thread that runs a fake SFTP server for testing."""
 
     def __init__(self) -> None:
         """Initialize the server and start listening."""
@@ -158,6 +159,7 @@ class FakeSFTPServerProcess(Process):
         self.socket.listen()
         self.host_key = WrappedEd25519Key.generate()
         self.user_key = WrappedEd25519Key.generate()
+        self.stop_event = Event()
 
     @property
     def address(self) -> tuple[str, int]:
@@ -167,25 +169,39 @@ class FakeSFTPServerProcess(Process):
         assert isinstance(port, int)
         return host, port
 
-    def run(self) -> NoReturn:  # pragma: no cover
+    def check_stop(self) -> None:
+        """Raise ``StopIteration`` if we have been asked to stop."""
+        if self.stop_event.is_set():
+            raise StopIteration
+
+    def run(self) -> None:
         """Run the server."""
         while True:
-            conn, _ = self.socket.accept()
-            transport = Transport(conn)
-            transport.add_server_key(self.host_key.public_paramiko)
-            transport.set_subsystem_handler("sftp", SFTPServer, FakeSFTPServer)
-            server = FakeSSHServer(self.user_key.public_paramiko)
-            transport.start_server(server=server)
-            channel = transport.accept()
-            if channel is not None:
-                try:
-                    while transport.is_active():
-                        time.sleep(0.1)
-                finally:
-                    channel.close()
+            try:
+                self.check_stop()
+                conn, _ = self.socket.accept()
+                transport = Transport(conn)
+                transport.add_server_key(self.host_key.public_paramiko)
+                transport.set_subsystem_handler(
+                    "sftp", SFTPServer, FakeSFTPServer
+                )
+                server = FakeSSHServer(self.user_key.public_paramiko)
+                transport.start_server(server=server)
+                self.check_stop()
+                channel = transport.accept()
+                if channel is not None:  # pragma: no cover
+                    try:
+                        while transport.is_active():
+                            self.check_stop()
+                            tm.sleep(0.1)
+                    finally:
+                        transport.close()
+                        channel.close()
+            except StopIteration:
+                break
 
     def stop(self) -> None:
         """Stop the server."""
-        self.terminate()
+        self.stop_event.set()
         self.join()
         self.socket.close()
