@@ -24,14 +24,17 @@ from textwrap import dedent
 from typing import Any, IO
 from unittest.mock import MagicMock, patch
 
-from debian.deb822 import Deb822, Packages, Release, Sources
+from debian.deb822 import Deb822, Dsc, Packages, Release, Sources
 from django_pglocks import advisory_lock
 
+from debusine.artifacts.local_artifact import deb822dict_to_dict
 from debusine.artifacts.models import (
     ArtifactCategory,
     CollectionCategory,
     DebianSourcePackage,
+    WorkRequestResults,
 )
+from debusine.artifacts.playground import ArtifactPlayground
 from debusine.db.locks import LockError, LockType
 from debusine.db.models import Artifact, ArtifactRelation, Collection, Workspace
 from debusine.db.tests.utils import _calculate_hash_from_data
@@ -50,10 +53,12 @@ from debusine.test.django import TestCase
 class APTMirrorTests(TestCase):
     """Test the :py:class:`APTMirror` task."""
 
-    def create_suite_collection(self, name: str) -> Collection:
+    def create_suite_collection(
+        self, name: str, workspace: Workspace | None = None
+    ) -> Collection:
         """Create a `debian:suite` collection."""
         return self.playground.create_collection(
-            name=name, category=CollectionCategory.SUITE
+            name=name, category=CollectionCategory.SUITE, workspace=workspace
         )
 
     def create_apt_mirror_task(
@@ -78,7 +83,10 @@ class APTMirrorTests(TestCase):
             task_data["components"] = components
         if signing_key is not None:
             task_data["signing_key"] = signing_key
-        return APTMirror(task_data)
+        task = APTMirror(task_data)
+        # Configured by the Celery worker
+        task.workspace = self.playground.get_default_workspace()
+        return task
 
     def create_source_package_artifact(
         self, name: str, version: str, paths: list[str]
@@ -135,22 +143,26 @@ class APTMirrorTests(TestCase):
         section: str = "devel",
     ) -> Sources:
         """Write a sample source package, returning its index entry."""
-        dsc_contents = dedent(
-            f"""\
-            Format: 3.0 (native)
-            Source: {name}
-            Binary: {name}
-            Architecture: any
-            Version: {version}
-            """
-        ).encode()
-        dsc_hash = hashlib.sha256(dsc_contents).hexdigest()
-        dsc_size = len(dsc_contents)
-        (temp_path / f"{name}_{version}.dsc").write_bytes(dsc_contents)
         tar_contents = b"tar"
         tar_hash = hashlib.sha256(tar_contents).hexdigest()
         tar_size = len(tar_contents)
-        (temp_path / f"{name}_{version}.tar.xz").write_bytes(tar_contents)
+        tar_path = temp_path / f"{name}_{version}.tar.xz"
+        tar_path.write_bytes(tar_contents)
+
+        dsc_path = temp_path / f"{name}_{version}.dsc"
+        ArtifactPlayground.write_deb822_file(
+            Dsc,
+            dsc_path,
+            [tar_path],
+            format_version="3.0 (native)",
+            source=name,
+            version=version,
+            section=section,
+        )
+        dsc_contents = dsc_path.read_bytes()
+        dsc_hash = hashlib.sha256(dsc_contents).hexdigest()
+        dsc_size = len(dsc_contents)
+
         return Sources(
             {
                 "Package": name,
@@ -378,7 +390,10 @@ class APTMirrorTests(TestCase):
         task = self.create_apt_mirror_task("nonexistent")
         with self.assertRaisesRegex(
             TaskConfigError,
-            "Collection 'nonexistent' with category 'debian:suite' not found",
+            (
+                "Collection 'nonexistent' in 'debusine/System' with category "
+                "'debian:suite' not found"
+            ),
         ):
             task.collection
 
@@ -390,7 +405,24 @@ class APTMirrorTests(TestCase):
         task = self.create_apt_mirror_task("bookworm")
         with self.assertRaisesRegex(
             TaskConfigError,
-            "Collection 'bookworm' with category 'debian:suite' not found",
+            (
+                "Collection 'bookworm' in 'debusine/System' with category "
+                "'debian:suite' not found"
+            ),
+        ):
+            task.collection
+
+    def test_collection_wrong_workspace(self) -> None:
+        """`collection` raises exception: wrong category."""
+        workspace = self.playground.create_workspace(name="other")
+        self.create_suite_collection(name="bookworm", workspace=workspace)
+        task = self.create_apt_mirror_task("bookworm")
+        with self.assertRaisesRegex(
+            TaskConfigError,
+            (
+                "Collection 'bookworm' in 'debusine/System' with category "
+                "'debian:suite' not found"
+            ),
         ):
             task.collection
 
@@ -618,13 +650,13 @@ class APTMirrorTests(TestCase):
 
         sources_path = temp_path / "Sources"
         with open(sources_path, "w") as sources:
-            for name, version in (("pkg1", "1.0"), ("pkg2", "2.0")):
-                sources.write(
-                    self.write_sample_source_package(
-                        temp_path, name, version
-                    ).dump()
-                    + "\n"
-                )
+            sources.writelines(
+                self.write_sample_source_package(
+                    temp_path, name, version
+                ).dump()
+                + "\n"
+                for name, version in (("pkg1", "1.0"), ("pkg2", "2.0"))
+            )
 
         targets = [
             {
@@ -858,13 +890,7 @@ class APTMirrorTests(TestCase):
                 "name": "hello",
                 "version": "1.0",
                 "type": "dpkg",
-                "dsc_fields": {
-                    "Format": "3.0 (native)",
-                    "Source": "hello",
-                    "Binary": "hello",
-                    "Architecture": "any",
-                    "Version": "1.0",
-                },
+                "dsc_fields": deb822dict_to_dict(Dsc(dsc_contents)),
             },
             {"hello_1.0.dsc": dsc_contents, "hello_1.0.tar.xz": tar_contents},
         )
@@ -1004,13 +1030,7 @@ class APTMirrorTests(TestCase):
                 "name": "hello",
                 "version": "1.0",
                 "type": "dpkg",
-                "dsc_fields": {
-                    "Format": "3.0 (native)",
-                    "Source": "hello",
-                    "Binary": "hello",
-                    "Architecture": "any",
-                    "Version": "1.0",
-                },
+                "dsc_fields": deb822dict_to_dict(Dsc(dsc_contents)),
             },
             {"hello_1.0.dsc": dsc_contents, "hello_1.0.tar.xz": tar_contents},
         )
@@ -1124,13 +1144,13 @@ class APTMirrorTests(TestCase):
 
         packages_path = temp_path / "Packages"
         with open(packages_path, "w") as packages:
-            for name, version in (("pkg1", "1.0"), ("pkg2", "2.0")):
-                packages.write(
-                    self.write_sample_binary_package(
-                        temp_path, name, version, "amd64"
-                    ).dump()
-                    + "\n"
-                )
+            packages.writelines(
+                self.write_sample_binary_package(
+                    temp_path, name, version, "amd64"
+                ).dump()
+                + "\n"
+                for name, version in (("pkg1", "1.0"), ("pkg2", "2.0"))
+            )
 
         targets = [
             {
@@ -2439,7 +2459,7 @@ class APTMirrorTests(TestCase):
             patch("subprocess.run", side_effect=fake_run),
         ):
             assert acquired
-            self.assertTrue(task.execute())
+            self.assertEqual(task.execute(), WorkRequestResults.SUCCESS)
 
         self.assertQuerySetEqual(
             collection.child_items.values_list("name", flat=True),
