@@ -21,10 +21,7 @@ from debusine.artifacts.models import (
     BareDataCategory,
     CollectionCategory,
 )
-from debusine.client.models import (
-    LookupChildType,
-    model_to_json_serializable_dict,
-)
+from debusine.client.models import LookupChildType
 from debusine.db.models import (
     Collection,
     CollectionItem,
@@ -143,24 +140,21 @@ class CopyCollectionItemsTests(TestCase):
         self, lookup: dict[str, Any]
     ) -> tuple[CopyCollectionItems, Sequence[LookupResult]]:
         """Set up a task and lookup results to test ``copy_item``."""
-        source_items = LookupMultiple.parse_obj(
+        source_items = LookupMultiple.model_validate(
             {
                 "collection": f"_@{CollectionCategory.PACKAGE_BUILD_LOGS}",
                 **lookup,
             }
         )
         task = CopyCollectionItems(
-            task_data=model_to_json_serializable_dict(
-                CopyCollectionItemsData(
-                    copies=[
-                        CopyCollectionItemsCopies(
-                            source_items=source_items,
-                            target_collection=self.target_build_logs.id,
-                        )
-                    ]
-                ),
-                exclude_unset=True,
-            )
+            task_data=CopyCollectionItemsData(
+                copies=[
+                    CopyCollectionItemsCopies(
+                        source_items=source_items,
+                        target_collection=self.target_build_logs.id,
+                    )
+                ]
+            ).model_dump(mode="json", exclude_unset=True)
         )
         self.addCleanup(cleanup_task, task)
         results = lookup_multiple(
@@ -626,7 +620,7 @@ class CopyCollectionItemsTests(TestCase):
             category=CollectionCategory.SUITE,
             workspace=self.target_workspace,
         )
-        binary_package_lookup = LookupMultiple.parse_obj(
+        binary_package_lookup = LookupMultiple.model_validate(
             {
                 "collection": "internal@collections",
                 "category": ArtifactCategory.BINARY_PACKAGE,
@@ -646,7 +640,7 @@ class CopyCollectionItemsTests(TestCase):
                         },
                     ),
                     CopyCollectionItemsCopies(
-                        source_items=LookupMultiple.parse_obj(
+                        source_items=LookupMultiple.model_validate(
                             {
                                 "collection": (
                                     f"_@{CollectionCategory.PACKAGE_BUILD_LOGS}"
@@ -675,7 +669,7 @@ class CopyCollectionItemsTests(TestCase):
             copy_collection_items.created_by,
             Workspace.Roles.CONTRIBUTOR,
         ):
-            self.assertTrue(task.execute())
+            self.assertEqual(task.execute(), WorkRequest.Results.SUCCESS)
 
         debug_logs_artifact = copy_collection_items.artifact_set.get(
             category=ArtifactCategory.WORK_REQUEST_DEBUG_LOGS
@@ -730,7 +724,7 @@ class CopyCollectionItemsTests(TestCase):
 
     def test_execute_copy_fails(self) -> None:
         self.create_build_log_placeholder()
-        source_items = LookupMultiple.parse_obj(
+        source_items = LookupMultiple.model_validate(
             {
                 "collection": self.source_build_logs.id,
                 "child_type": LookupChildType.BARE,
