@@ -881,7 +881,7 @@ class GenerateSuiteIndexesTests(TestCase):
             ) as acquired,
         ):
             assert acquired
-            self.assertTrue(task.execute())
+            self.assertEqual(task.execute(), WorkRequest.Results.SUCCESS)
 
         self.assertQuerySetEqual(
             scenario.suite.child_items.filter(
