@@ -11,6 +11,7 @@
 
 from unittest import TestCase
 
+from debusine.artifacts.models import WorkRequestResults
 from debusine.server.tasks import ServerNoop
 from debusine.tasks import TaskConfigError
 
@@ -19,14 +20,14 @@ class ServerNoopTests(TestCase):
     """Test the ServerNoop task."""
 
     def test_execute_result_true(self) -> None:
-        """If result=True, the task returns True."""
-        noop = ServerNoop({"result": True})
-        self.assertTrue(noop._execute())
+        """If result=SUCCESS, the task returns SUCCESS."""
+        noop = ServerNoop({"result": WorkRequestResults.SUCCESS})
+        self.assertEqual(noop._execute(), WorkRequestResults.SUCCESS)
 
     def test_execute_result_false(self) -> None:
-        """If result=False, the task returns False."""
-        noop = ServerNoop({"result": False})
-        self.assertFalse(noop._execute())
+        """If result=FAILURE, the task returns FAILURE."""
+        noop = ServerNoop({"result": WorkRequestResults.FAILURE})
+        self.assertEqual(noop._execute(), WorkRequestResults.FAILURE)
 
     def test_execute_exception(self) -> None:
         """If exception=True, the task raises an exception."""
@@ -37,11 +38,11 @@ class ServerNoopTests(TestCase):
 
     def test_no_additional_properties(self) -> None:
         """Assert no additional properties."""
-        error_msg = "extra fields not permitted"
+        error_msg = "Extra inputs are not permitted"
         with self.assertRaisesRegex(TaskConfigError, error_msg):
-            ServerNoop({"result": "True", "input": {}})
+            ServerNoop({"input": {}})
 
     def test_label(self) -> None:
         """Test get_label."""
-        task = ServerNoop({"result": True})
+        task = ServerNoop({"result": WorkRequestResults.SUCCESS})
         self.assertEqual(task.get_label(), "noop")
