@@ -11,16 +11,19 @@
 
 import logging
 import os
-from multiprocessing import current_process
 from pathlib import Path
-from unittest import SkipTest, mock
+from unittest import mock
 
-from debusine.artifacts.models import ArtifactCategory, DebianUpload
+from debusine.artifacts.models import (
+    ArtifactCategory,
+    DebianUpload,
+    WorkRequestResults,
+)
 from debusine.db.models import Artifact, File
 from debusine.server.tasks import PackageUpload
 from debusine.server.tasks.models import PackageUploadDynamicData
-from debusine.server.tasks.tests.ftp_server import FakeFTPServerProcess
-from debusine.server.tasks.tests.sftp_server import FakeSFTPServerProcess
+from debusine.server.tasks.tests.ftp_server import FakeFTPServerThread
+from debusine.server.tasks.tests.sftp_server import FakeSFTPServerThread
 from debusine.tasks.server import ArtifactInfo
 from debusine.tasks.tests.helper_mixin import FakeTaskDatabase, TaskHelperMixin
 from debusine.test.django import TestCase
@@ -50,19 +53,6 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
             self.task._debug_log_files_directory.cleanup()
         super().tearDown()
 
-    def skip_on_multiprocessing(self) -> None:
-        """
-        Mark a test as unable to run under multiprocessing parallel tests.
-
-        If we execute the test, we'll hit an assert in multiprocessing.
-        """
-        process = current_process()
-        if process._config.get('daemon'):  # type: ignore[attr-defined]
-            raise SkipTest(
-                "Cannot be run inside multiprocessing parallel tests. "
-                "multiprocessing doesn't support nesting."
-            )  # pragma: no cover
-
     def create_source_upload(self) -> Artifact:
         """Create a minimal source upload."""
         filenames = [
@@ -164,7 +154,7 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
         self.assertTrue(upload_paths[-1].name.endswith(".changes"))
 
     def test_execute_no_upload_paths(self) -> None:
-        """execute() returns False if fetch_upload returned no paths."""
+        """execute() returns FAILURE if fetch_upload returned no paths."""
         self.task.set_work_request(
             self.playground.create_worker_task(assign_contributor_role=True)
         )
@@ -175,15 +165,14 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
             input_upload_id=artifact.id
         )
 
-        self.assertFalse(self.task.execute())
+        self.assertEqual(self.task.execute(), WorkRequestResults.FAILURE)
 
     def test_execute_ftp(self) -> None:
         """execute() can make an upload using FTP."""
         username = "user"
         remote_home_directory = self.create_temporary_directory()
         (remote_home_directory / "queue").mkdir()
-        self.skip_on_multiprocessing()
-        server = FakeFTPServerProcess(username, remote_home_directory)
+        server = FakeFTPServerThread(username, remote_home_directory)
         server.start()
         self.addCleanup(server.stop)
         host, port = server.address
@@ -202,7 +191,7 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
         with mock.patch.object(
             self.task, "fetch_upload", return_value=[deb_path, changes_path]
         ):
-            self.assertTrue(self.task.execute())
+            self.assertEqual(self.task.execute(), WorkRequestResults.SUCCESS)
 
         for path in (deb_path, changes_path):
             self.assertEqual(
@@ -214,8 +203,7 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
         """execute() handles FTP URLs with no path."""
         username = "user"
         remote_home_directory = self.create_temporary_directory()
-        self.skip_on_multiprocessing()
-        server = FakeFTPServerProcess(username, remote_home_directory)
+        server = FakeFTPServerThread(username, remote_home_directory)
         server.start()
         self.addCleanup(server.stop)
         host, port = server.address
@@ -234,7 +222,7 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
         with mock.patch.object(
             self.task, "fetch_upload", return_value=[deb_path, changes_path]
         ):
-            self.assertTrue(self.task.execute())
+            self.assertEqual(self.task.execute(), WorkRequestResults.SUCCESS)
 
         for path in (deb_path, changes_path):
             self.assertEqual(
@@ -249,8 +237,7 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
         (remote_home_directory / "queue" / "DELAYED" / "3-day").mkdir(
             parents=True
         )
-        self.skip_on_multiprocessing()
-        server = FakeFTPServerProcess(username, remote_home_directory)
+        server = FakeFTPServerThread(username, remote_home_directory)
         server.start()
         self.addCleanup(server.stop)
         host, port = server.address
@@ -272,7 +259,7 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
         with mock.patch.object(
             self.task, "fetch_upload", return_value=[deb_path, changes_path]
         ):
-            self.assertTrue(self.task.execute())
+            self.assertEqual(self.task.execute(), WorkRequestResults.SUCCESS)
 
         for path in (deb_path, changes_path):
             self.assertEqual(
@@ -323,8 +310,7 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
     def test_execute_sftp(self) -> None:
         """execute() can make an upload using SFTP."""
         queue_directory = self.create_temporary_directory()
-        self.skip_on_multiprocessing()
-        server = FakeSFTPServerProcess()
+        server = FakeSFTPServerThread()
         home_directory = self.create_temporary_directory()
         (home_directory / ".ssh").mkdir()
         (id_ed25519 := home_directory / ".ssh" / "id_ed25519").write_text(
@@ -354,7 +340,7 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
             ),
             mock.patch.dict(os.environ, {"HOME": str(home_directory)}),
         ):
-            self.assertTrue(self.task.execute())
+            self.assertEqual(self.task.execute(), WorkRequestResults.SUCCESS)
 
         for path in (deb_path, changes_path):
             self.assertEqual(
@@ -365,8 +351,7 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
         """execute() can make a delayed upload using SFTP."""
         queue_directory = self.create_temporary_directory()
         (queue_directory / "DELAYED" / "3-day").mkdir(parents=True)
-        self.skip_on_multiprocessing()
-        server = FakeSFTPServerProcess()
+        server = FakeSFTPServerThread()
         home_directory = self.create_temporary_directory()
         (home_directory / ".ssh").mkdir()
         (id_ed25519 := home_directory / ".ssh" / "id_ed25519").write_text(
@@ -399,7 +384,7 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
             ),
             mock.patch.dict(os.environ, {"HOME": str(home_directory)}),
         ):
-            self.assertTrue(self.task.execute())
+            self.assertEqual(self.task.execute(), WorkRequestResults.SUCCESS)
 
         for path in (deb_path, changes_path):
             self.assertEqual(
@@ -451,8 +436,7 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
         username = "user"
         remote_home_directory = self.create_temporary_directory()
         (remote_home_directory / "queue").mkdir()
-        self.skip_on_multiprocessing()
-        server = FakeFTPServerProcess(username, remote_home_directory)
+        server = FakeFTPServerThread(username, remote_home_directory)
         server.start()
         self.addCleanup(server.stop)
         host, port = server.address
@@ -482,7 +466,7 @@ class PackageUploadTests(TaskHelperMixin[PackageUpload], TestCase):
         ]
         self.write_changes_file(changes_path, non_changes_paths)
 
-        self.assertTrue(self.task.execute())
+        self.assertEqual(self.task.execute(), WorkRequestResults.SUCCESS)
 
         debug_logs_artifact = Artifact.objects.get(
             category=ArtifactCategory.WORK_REQUEST_DEBUG_LOGS,
