@@ -22,15 +22,13 @@ class DelayTaskTests(TestCase):
 
     def test_missing_delay_until(self) -> None:
         """The `delay_until` field is required."""
-        error_msg = (
-            r"delay_until\s+field required \(type=value_error\.missing\)"
-        )
+        error_msg = r"delay_until\s+Field required.*type=missing"
         with self.assertRaisesRegex(TaskConfigError, error_msg):
             Delay({})
 
     def test_no_additional_properties(self) -> None:
         """Assert no additional properties."""
-        error_msg = "extra fields not permitted"
+        error_msg = "Extra inputs are not permitted"
         with self.assertRaisesRegex(TaskConfigError, error_msg):
             Delay({"delay_until": timezone.now().isoformat(), "input": {}})
 
