@@ -10,14 +10,14 @@
 """Unit tests for Celery integration."""
 
 import logging
-import threading
-from typing import Any
+from typing import Any, override
 from unittest import mock
 
 from django.db import connections, transaction
 
 from debusine.db.models import WorkRequest, Worker
 from debusine.db.models.work_requests import workflow_ancestors
+from debusine.db.tests.utils import RunInThreadAndCloseDBConnections
 from debusine.server.celery import (
     WorkRequestNotPending,
     run_server_task,
@@ -41,8 +41,13 @@ class SampleTaskNotManagingTransactions(
 
     TASK_VERSION = 1
 
-    def _execute(self) -> bool:
-        return connections["default"].in_atomic_block
+    @override
+    def _execute(self) -> WorkRequest.Results:
+        return (
+            WorkRequest.Results.SUCCESS
+            if connections["default"].in_atomic_block
+            else WorkRequest.Results.FAILURE
+        )
 
 
 class SampleTaskManagingTransactions(
@@ -53,8 +58,13 @@ class SampleTaskManagingTransactions(
     TASK_VERSION = 1
     TASK_MANAGES_TRANSACTIONS = True
 
-    def _execute(self) -> bool:
-        return not connections["default"].in_atomic_block
+    @override
+    def _execute(self) -> WorkRequest.Results:
+        return (
+            WorkRequest.Results.SUCCESS
+            if not connections["default"].in_atomic_block
+            else WorkRequest.Results.FAILURE
+        )
 
 
 class RunServerTaskTests(TestCase):
@@ -70,7 +80,7 @@ class RunServerTaskTests(TestCase):
     ) -> WorkRequest:
         """Create a work request and assign it to self.worker."""
         work_request = self.playground.create_server_task(
-            task_name=task_name, **kwargs
+            task_name=task_name, mark_pending=True, **kwargs
         )
         work_request.assign_worker(self.worker)
         return work_request
@@ -89,8 +99,9 @@ class RunServerTaskTests(TestCase):
 
     def test_not_pending(self) -> None:
         """The Celery task fails if the work request is not pending."""
-        work_request = self.create_assigned_work_request()
-        work_request.mark_completed(WorkRequest.Results.ERROR)
+        work_request = self.create_assigned_work_request(
+            result=WorkRequest.Results.ERROR
+        )
         with self.assertLogsContains(
             f"Work request {work_request.id} is in status completed, not "
             f"pending",
@@ -117,7 +128,7 @@ class RunServerTaskTests(TestCase):
             transaction.atomic(),
         ):
             result = run_server_task.apply(args=(work_request.id,))
-        self.assertFalse(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.ERROR)
         work_request.refresh_from_db()
         self.assertIsNotNone(work_request.started_at)
         self.assertIsNotNone(work_request.completed_at)
@@ -153,7 +164,7 @@ class RunServerTaskTests(TestCase):
             transaction.atomic(),
         ):
             result = run_server_task.apply(args=(work_request.id,))
-        self.assertFalse(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.ERROR)
         work_request.refresh_from_db()
         self.assertIsNotNone(work_request.started_at)
         self.assertIsNotNone(work_request.completed_at)
@@ -175,7 +186,10 @@ class RunServerTaskTests(TestCase):
     def test_external_task(self) -> None:
         """The Celery task logs but does not fail on an external task."""
         work_request = self.playground.create_worker_task(
-            task_name="noop", task_data={"result": True}, worker=self.worker
+            task_name="noop",
+            task_data={"result": WorkRequest.Results.SUCCESS},
+            mark_pending=True,
+            worker=self.worker,
         )
         expected_message = "Cannot run on a Celery worker"
         with (
@@ -188,7 +202,7 @@ class RunServerTaskTests(TestCase):
             transaction.atomic(),
         ):
             result = run_server_task.apply(args=(work_request.id,))
-        self.assertFalse(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.ERROR)
         work_request.refresh_from_db()
         self.assertIsNotNone(work_request.started_at)
         self.assertIsNotNone(work_request.completed_at)
@@ -221,7 +235,7 @@ class RunServerTaskTests(TestCase):
             transaction.atomic(),
         ):
             result = run_server_task.apply(args=(work_request.id,))
-        self.assertFalse(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.ERROR)
         work_request.refresh_from_db()
         self.assertIsNotNone(work_request.started_at)
         self.assertIsNotNone(work_request.completed_at)
@@ -254,7 +268,7 @@ class RunServerTaskTests(TestCase):
             transaction.atomic(),
         ):
             result = run_server_task.apply(args=(work_request.id,))
-        self.assertFalse(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.FAILURE)
         work_request.refresh_from_db()
         self.assertIsNotNone(work_request.started_at)
         self.assertIsNone(work_request.completed_at)
@@ -262,14 +276,14 @@ class RunServerTaskTests(TestCase):
         self.assertEqual(work_request.result, WorkRequest.Results.NONE)
         self.assertIsNone(work_request.output_data)
 
-    def test_task_returns_false(self) -> None:
-        """If the task returns False, the Celery task records that."""
+    def test_task_returns_failure(self) -> None:
+        """If the task returns FAILURE, the Celery task records that."""
         work_request = self.create_assigned_work_request(
-            task_data=ServerNoopData(result=False),
+            task_data=ServerNoopData(result=WorkRequest.Results.FAILURE),
         )
         with transaction.atomic():
             result = run_server_task.apply(args=(work_request.id,))
-        self.assertFalse(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.FAILURE)
         work_request.refresh_from_db()
         self.assertIsNotNone(work_request.started_at)
         self.assertIsNotNone(work_request.completed_at)
@@ -280,11 +294,11 @@ class RunServerTaskTests(TestCase):
     def test_task_returns_true(self) -> None:
         """If the task returns True, the Celery task records that."""
         work_request = self.create_assigned_work_request(
-            task_data=ServerNoopData(result=True),
+            task_data=ServerNoopData(result=WorkRequest.Results.SUCCESS),
         )
         with transaction.atomic():
             result = run_server_task.apply(args=(work_request.id,))
-        self.assertTrue(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.SUCCESS)
         work_request.refresh_from_db()
         self.assertIsNotNone(work_request.started_at)
         self.assertIsNotNone(work_request.completed_at)
@@ -302,10 +316,11 @@ class RunServerTaskTransactionTests(TransactionTestCase):
         work_request = self.playground.create_server_task(
             task_name="sampletasknotmanagingtransactions",
             task_data={},
+            mark_pending=True,
         )
         work_request.assign_worker(worker)
         result = run_server_task.apply(args=(work_request.id,))
-        self.assertTrue(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.SUCCESS)
 
     def test_task_managing_transactions(self) -> None:
         """An atomic block is not used for tasks that manage transactions."""
@@ -313,15 +328,17 @@ class RunServerTaskTransactionTests(TransactionTestCase):
         work_request = self.playground.create_server_task(
             task_name="sampletaskmanagingtransactions",
             task_data={},
+            mark_pending=True,
         )
         work_request.assign_worker(worker)
         result = run_server_task.apply(args=(work_request.id,))
-        self.assertTrue(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.SUCCESS)
 
     def test_locks_workflow_before_completion(self) -> None:
         workflow = self.playground.create_workflow()
         server_noop = workflow.create_child_server(
-            task_name="servernoop", task_data=ServerNoopData(result=True)
+            task_name="servernoop",
+            task_data=ServerNoopData(result=WorkRequest.Results.SUCCESS),
         )
         noop = workflow.create_child_worker(task_name="noop")
         self.playground.advance_work_request(server_noop, mark_pending=True)
@@ -339,7 +356,7 @@ class RunServerTaskTransactionTests(TransactionTestCase):
         ):
             result = run_server_task.apply(args=(server_noop.id,))
 
-        self.assertTrue(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.SUCCESS)
 
     def test_locks_workflow_before_completion_error(self) -> None:
         workflow = self.playground.create_workflow()
@@ -362,7 +379,7 @@ class RunServerTaskTransactionTests(TransactionTestCase):
         ):
             result = run_server_task.apply(args=(server_noop.id,))
 
-        self.assertFalse(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.ERROR)
 
 
 class UpdateWorkflowTransactionTests(TransactionTestCase):
@@ -381,10 +398,7 @@ class UpdateWorkflowTransactionTests(TransactionTestCase):
             self.assertTrue(work_request.workflows_need_update)
             unrelated = self.playground.create_worker_task()
 
-        with (
-            transaction.atomic(),
-            mock.patch("debusine.server.celery.set_transaction"),
-        ):
+        with transaction.atomic():
             result = update_workflows.apply()
             self.assertIsNone(result.get())
 
@@ -426,9 +440,10 @@ class UpdateWorkflowTransactionTests(TransactionTestCase):
         def create_workflow_needs_update_in_thread(
             *args: Any, **kwargs: Any
         ) -> Any:
-            thread = threading.Thread(target=create_workflow_needs_update)
-            thread.start()
-            thread.join()
+            thread = RunInThreadAndCloseDBConnections(
+                create_workflow_needs_update
+            )
+            thread.run_and_wait()
             return mock.DEFAULT
 
         with mock.patch(
