@@ -106,7 +106,7 @@ class WorkerConsumerMixin(BaseDjangoTestCase):
             headers=headers,
         )
 
-        connected, subprotocol = await communicator.connect()
+        connected, _ = await communicator.connect()
         self.assertTrue(connected)
 
         if wait_for_fully_connected:
@@ -332,7 +332,7 @@ class WorkerConsumerTransactionTests(WorkerConsumerMixin, TransactionTestCase):
         """Disconnect cancels the dynamic metadata refresher."""
         self.assertTaskNotExists('dynamic_metadata_refresher')
 
-        communicator, worker = await self.connect_to_new_worker()
+        communicator, _ = await self.connect_to_new_worker()
 
         self.assertTaskExists('dynamic_metadata_refresher')
 
@@ -504,7 +504,7 @@ class WorkerConsumerTransactionTests(WorkerConsumerMixin, TransactionTestCase):
     async def test_metrics(self) -> None:
         registry = save_registry()
 
-        communicator1, worker1 = await self.connect_to_new_worker(
+        communicator1, _ = await self.connect_to_new_worker(
             fqdn="worker1.example"
         )
         assert_metric_diff(
@@ -520,7 +520,7 @@ class WorkerConsumerTransactionTests(WorkerConsumerMixin, TransactionTestCase):
             view="ws-connect",
         )
 
-        communicator2, worker2 = await self.connect_to_new_worker(
+        communicator2, _ = await self.connect_to_new_worker(
             fqdn="worker2.example"
         )
         assert_metric_diff(
@@ -661,7 +661,7 @@ class WorkRequestCompletedConsumerTests(TransactionTestCase):
             headers=headers,
         )
 
-        connected, subprotocol = await communicator.connect()
+        connected, _ = await communicator.connect()
 
         self.assertTrue(connected)
 
