@@ -13,7 +13,7 @@ import datetime as dt
 import inspect
 import logging
 from collections.abc import Callable
-from typing import Any, TYPE_CHECKING
+from typing import Any, TYPE_CHECKING, override
 from unittest import mock
 
 from celery import states
@@ -435,7 +435,8 @@ class SchedulerTests(SchedulerTestCase, TestCase):
         class WaitNoop(SampleBaseWaitTask[BaseTaskData, BaseDynamicTaskData]):
             TASK_VERSION = 1
 
-            def _execute(self) -> bool:
+            @override
+            def _execute(self) -> WorkRequest.Results:
                 raise NotImplementedError()
 
         parent = self.playground.create_workflow(mark_running=True)
@@ -930,7 +931,8 @@ class ScheduleForWorkerTests(SchedulerTestCase, TestCase):
 
     @mock.patch("debusine.server.scheduler.run_server_task.apply_async")
     def test_schedule_for_worker_concurrency(
-        self, mock_apply_async: mock.MagicMock  # noqa: U100
+        self,
+        mock_apply_async: mock.MagicMock,  # noqa: ARG002, U100
     ) -> None:
         """Consider a Worker's concurrency when assigning a WorkRequest."""
         worker = Worker.objects.get_or_create_celery()
@@ -1128,7 +1130,7 @@ class ScheduleForWorkerTransactionTests(SchedulerTestCase, TransactionTestCase):
         )
         self.assertRegex(
             mock_apply_async.call_args.kwargs["task_id"],
-            fr"^{task_id_prefix}_{work_request.id}_"
+            rf"^{task_id_prefix}_{work_request.id}_"
             r"[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$",
         )
 
