@@ -266,10 +266,14 @@ class WorkerStatusTests(TestCase):
         for task_type in TaskTypes:
             self.assertEqual(status.tasks[task_type], TaskQueueSummary())
         for worker_type in WorkerType:
-            self.assertEqual(status.workers[worker_type], WorkerSummary())
-            self.assertEqual(
-                status.worker_tasks[worker_type], TaskQueueSummary()
-            )
+            if worker_type == WorkerType.SCHEDULER:
+                self.assertNotIn(worker_type, status.workers)
+                self.assertNotIn(worker_type, status.worker_tasks)
+            else:
+                self.assertEqual(status.workers[worker_type], WorkerSummary())
+                self.assertEqual(
+                    status.worker_tasks[worker_type], TaskQueueSummary()
+                )
 
     def test_disabled_workers_ignored(self) -> None:
         """Workers are not counted if they are disabled."""
@@ -516,6 +520,10 @@ class WorkerStatusTests(TestCase):
         self.playground.create_worker(
             worker_type=WorkerType.CELERY,
         ).mark_connected()
+        # And a scheduler worker, which should not appear in the status
+        self.playground.create_worker(
+            worker_type=WorkerType.SCHEDULER
+        ).mark_connected()
 
         # Create a running task
         self.playground.create_worker_task(
