@@ -82,7 +82,11 @@ class ArtifactView(GenericAPIViewBase[Artifact], BaseAPIView):
                 title=str(exc), status_code=status.HTTP_404_NOT_FOUND
             )
 
-    def get(self, request: Request, artifact_id: int) -> Response:  # noqa: U100
+    def get(
+        self,
+        request: Request,
+        artifact_id: int,  # noqa: ARG002, U100
+    ) -> Response:
         """Return information of artifact_id."""
         artifact = self.get_object()
         self.set_current_workspace(artifact.workspace)
@@ -224,7 +228,10 @@ class WorkspaceArtifactView(RetrieveAPIViewBase[Artifact], BaseAPIView):
             )
 
     def get(
-        self, request: Request, workspace: str, artifact_id: int  # noqa: U100
+        self,
+        request: Request,
+        workspace: str,
+        artifact_id: int,  # noqa: ARG002, U100
     ) -> Response:
         """Return information of artifact_id."""
         self.set_current_workspace(workspace)
@@ -421,6 +428,8 @@ class UploadFileView(BaseAPIView):
             )
         assert isinstance(artifact, Artifact)
 
+        self.enforce(artifact.workspace.can_create_artifacts)
+
         try:
             return FileInArtifact.objects.get(artifact=artifact, path=file_path)
         except FileInArtifact.DoesNotExist:
