@@ -126,7 +126,10 @@ class TaskConfigurationCollectionView(BaseAPIView):
         return collection
 
     def get(
-        self, request: Request, workspace: str, name: str  # noqa: U100
+        self,
+        request: Request,  # noqa: ARG002, U100
+        workspace: str,
+        name: str,
     ) -> Response:
         """Retrieve the contents of the collection."""
         collection = self._get_collection(workspace, name)
@@ -322,11 +325,16 @@ class CollectionViewSet(
 
     def get_queryset(self) -> CollectionQuerySet[Any]:
         """Filter accessible collections."""
-        return (
+        queryset = (
             Collection.objects.can_display(context.user)
             .filter(workspace=context.require_workspace())
-            .order_by("name")
+            .order_by("category", "name")
         )
+        if self.action == "list":
+            queryset = queryset.exclude(
+                category=CollectionCategory.WORKFLOW_INTERNAL
+            )
+        return queryset
 
     @override
     def get_serializer_context(self) -> dict[str, Any]:
@@ -341,8 +349,8 @@ class CollectionViewSet(
     )
     def lookup(
         self,
-        request: Request,  # noqa: U100
-        workspace: str,  # noqa: U100
+        request: Request,  # noqa: ARG002, U100
+        workspace: str,  # noqa: ARG002, U100
         category: str,
         name: str,
     ) -> Response:
