@@ -70,7 +70,7 @@ class LookupSingleView(BaseAPIView):
                 default_category=lookup_deserialized.validated_data.get(
                     "default_category"
                 ),
-                workflow_root=work_request.get_workflow_root(),
+                workflow_root=work_request.workflow_root,
                 expect_type=lookup_deserialized.validated_data["expect_type"],
             )
         except KeyError as e:
@@ -124,7 +124,7 @@ class LookupMultipleView(BaseAPIView):
             lookup_user = work_request.created_by
 
         try:
-            lookup = LookupMultiple.parse_obj(
+            lookup = LookupMultiple.model_validate(
                 lookup_deserialized.validated_data["lookup"]
             )
         except ValueError as e:
@@ -141,7 +141,7 @@ class LookupMultipleView(BaseAPIView):
                 default_category=lookup_deserialized.validated_data.get(
                     "default_category"
                 ),
-                workflow_root=work_request.get_workflow_root(),
+                workflow_root=work_request.workflow_root,
                 expect_type=lookup_deserialized.validated_data["expect_type"],
             )
         except KeyError as e:
@@ -160,7 +160,8 @@ class LookupMultipleView(BaseAPIView):
         return Response(
             # https://github.com/typeddjango/djangorestframework-stubs/issues/260
             LookupResponseSerializer(
-                result, many=True  # type: ignore[arg-type]
+                result,  # type: ignore[arg-type]
+                many=True,
             ).data,
             status=status.HTTP_200_OK,
         )
