@@ -9,13 +9,14 @@
 
 """Tests for the asset views."""
 
+import base64
 from typing import Any
 
 from django.urls import reverse
 from django.utils.dateparse import parse_datetime
 from rest_framework import status
 
-from debusine.artifacts.models import ArtifactCategory, CollectionCategory
+from debusine.artifacts.models import CollectionCategory
 from debusine.assets import AssetCategory, KeyPurpose, SigningKeyData
 from debusine.db.models import (
     Artifact,
@@ -119,9 +120,9 @@ class AssetViewTests(TestCase):
             "data": SigningKeyData(
                 purpose=purpose,
                 fingerprint=fingerprint,
-                public_key=public_key,
+                public_key=base64.b64encode(public_key.encode()).decode(),
                 description=description,
-            ).dict(),
+            ).model_dump(),
         }
 
     def test_create_asset(self) -> None:
@@ -146,7 +147,7 @@ class AssetViewTests(TestCase):
         data = asset.data_model
         assert isinstance(data, SigningKeyData)
         self.assertEqual(data.fingerprint, "ABC123")
-        self.assertEqual(data.public_key, "PUBLIC KEY")
+        self.assertEqual(data.public_key, b"PUBLIC KEY")
         self.assertEqual(asset.workspace, workspace)
         self.assertEqual(asset.created_by, user)
         self.assertIsNone(asset.created_by_work_request)
@@ -317,7 +318,7 @@ class AssetPermissionCheckViewTests(TestCase):
         )
         wr.dynamic_task_data = DebsignDynamicData(
             unsigned_id=upload_artifacts.upload.id
-        ).dict()
+        ).model_dump()
         wr.save()
         return wr
 
@@ -399,7 +400,7 @@ class AssetPermissionCheckViewTests(TestCase):
             task_name="sign",
             task_data=SignData(
                 purpose=KeyPurpose.UEFI,
-                unsigned=LookupMultiple.parse_obj(signing_input_ids),
+                unsigned=LookupMultiple.model_validate(signing_input_ids),
                 key=asset_model.fingerprint,
             ),
             mark_running=True,
@@ -407,7 +408,7 @@ class AssetPermissionCheckViewTests(TestCase):
         )
         wr.dynamic_task_data = SignDynamicData(
             unsigned_ids=signing_input_ids
-        ).dict()
+        ).model_dump()
         wr.save()
         return wr
 
@@ -467,7 +468,7 @@ class AssetPermissionCheckViewTests(TestCase):
         )
         wr.dynamic_task_data = SignRepositoryIndexDynamicData(
             signing_keys=[asset_model.fingerprint], unsigned_id=index.id
-        ).dict()
+        ).model_dump()
         wr.save()
         return wr
 
@@ -479,11 +480,8 @@ class AssetPermissionCheckViewTests(TestCase):
         suite = self.playground.create_collection(
             "suite", CollectionCategory.SUITE
         )
-        index, _ = self.playground.create_artifact(
-            category=ArtifactCategory.REPOSITORY_INDEX,
-            paths=["Release"],
-            create_files=True,
-            skip_add_files_in_store=True,
+        index = self.playground.create_repository_index(
+            "Release", skip_add_files_in_store=True
         )
         work_request = self.create_sign_repository_index_work_request(
             asset, suite, index
@@ -717,11 +715,7 @@ class AssetPermissionCheckViewTests(TestCase):
         self.assertEqual(body["title"], "Unknown permission 'unknown'")
 
     def test_describe_artifact_repository_index(self) -> None:
-        artifact, _ = self.playground.create_artifact(
-            paths=["Release"],
-            category=ArtifactCategory.REPOSITORY_INDEX,
-            create_files=True,
-        )
+        artifact = self.playground.create_repository_index("Release")
         result = AssetPermissionCheckView.describe_artifact(artifact)
         self.assertEqual(result, {"path": "Release"})
 
