@@ -340,7 +340,7 @@ class TaskConfigurationCollectionViewTests(TestCase):
         response = self.get()
         data = self.assertAPIResponseOk(response)
         items = data["items"]
-        self.assertEqual(items, [item.dict()])
+        self.assertEqual(items, [item.model_dump()])
 
     def test_post_matches_collection(self) -> None:
         self.playground.create_group_role(
@@ -386,7 +386,7 @@ class TaskConfigurationCollectionViewTests(TestCase):
                     "name": self.collection.name,
                     "data": self.collection.data,
                 },
-                "items": [item.dict()],
+                "items": [item.model_dump()],
             }
         )
         data = self.assertAPIResponseOk(response)
@@ -444,7 +444,7 @@ class TaskConfigurationCollectionViewTests(TestCase):
                     "name": self.collection.name,
                     "data": self.collection.data,
                 },
-                "items": [new.dict()],
+                "items": [new.model_dump()],
             }
         )
         data = self.assertAPIResponseOk(response)
@@ -474,7 +474,7 @@ class TaskConfigurationCollectionViewTests(TestCase):
                     "name": self.collection.name,
                     "data": self.collection.data,
                 },
-                "items": [new.dict()],
+                "items": [new.model_dump()],
                 "dry_run": True,
             }
         )
@@ -1069,6 +1069,27 @@ class CollectionViewSetTests(TestCase):
         )
         self.assertSidUnchanged()
 
+    @override_permission(Workspace, "can_create_collections", AllowAll)
+    def test_post_invalid_name(self) -> None:
+        response = self.post(
+            data={
+                "category": CollectionCategory.SUITE,
+                "name": "sid/test",
+                "full_history_retention_period": None,
+                "metadata_only_retention_period": None,
+                "data": {},
+            }
+        )
+        self.assertResponseProblem(
+            response,
+            "Cannot deserialize collection",
+            validation_errors_pattern=(
+                "'sid/test' is not a valid collection name"
+            ),
+            status_code=status.HTTP_400_BAD_REQUEST,
+        )
+        self.assertFalse(Collection.objects.filter(name="sid/test").exists())
+
     @override_permission(Collection, "can_configure", AllowAll)
     def test_patch_noop(self) -> None:
         response = self.patch(data={})
