@@ -447,9 +447,9 @@ class LookupMultipleViewTests(TestCase):
             for i, artifact in enumerate(artifacts)
         ]
 
-        lookup = LookupMultiple.parse_obj(
+        lookup = LookupMultiple.model_validate(
             {"collection": f"collection@{CollectionCategory.TEST}"}
-        ).dict()["__root__"]
+        ).model_dump()
         self.assertEqual(
             lookup,
             (
@@ -485,7 +485,8 @@ class LookupMultipleViewTests(TestCase):
     def test_deserialization_error(self) -> None:
         """The view returns an error if it cannot deserialize the lookup."""
         response = self.post_lookup(
-            "nonsense", LookupChildType.ARTIFACT  # type: ignore[arg-type]
+            "nonsense",  # type: ignore[arg-type]
+            LookupChildType.ARTIFACT,
         )
 
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
