@@ -37,7 +37,7 @@ class PenetrationTests(TestCase):
 
     scenario = scenarios.DefaultContextAPI()
 
-    create_experiment_workspace: ClassVar[WorkflowTemplate]
+    create_child_workspace: ClassVar[WorkflowTemplate]
     signing_key: ClassVar[Asset]
     signing_key_usage: ClassVar[AssetUsage]
 
@@ -45,11 +45,9 @@ class PenetrationTests(TestCase):
     def setUpTestData(cls) -> None:
         """Set up common test data."""
         super().setUpTestData()
-        # Allow creation of experiment workspaces
-        cls.create_experiment_workspace = (
-            cls.playground.create_workflow_template(
-                "create_experiment", "create_experiment_workspace"
-            )
+        # Allow creation of child workspaces
+        cls.create_child_workspace = cls.playground.create_workflow_template(
+            "create_child", "create_child_workspace"
         )
         cls.signing_key = cls.playground.create_signing_key_asset()
         cls.signing_key_usage = cls.playground.create_asset_usage(
@@ -106,11 +104,11 @@ class PenetrationTests(TestCase):
             scope=self.scenario.scope.name,
         )
 
-    def assertExperimentWorkspaceCreated(self, **kwargs: Any) -> Workspace:
-        """Create an experiment workspace and return its name."""
+    def assertChildWorkspaceCreated(self, **kwargs: Any) -> Workspace:
+        """Create a child workspace and return its name."""
         response = self.post_workflow(
             {
-                "template_name": "create_experiment",
+                "template_name": "create_child",
                 "task_data": kwargs,
             }
         )
@@ -122,6 +120,7 @@ class PenetrationTests(TestCase):
 
         # Run the server task
         server_task = workflow.children.get()
+        self.playground.assign_worker(server_task)
         run_server_task.apply(args=(server_task.pk,))
         server_task.refresh_from_db()
         self.assertEqual(server_task.status, WorkRequest.Statuses.COMPLETED)
@@ -132,16 +131,14 @@ class PenetrationTests(TestCase):
             name=f"{self.scenario.workspace.name}-test",
         )
 
-    def test_use_signing_key_from_experiment(self) -> None:
-        """Attempt to use a workflow signing key in an experiment workspace."""
+    def test_use_signing_key_from_child(self) -> None:
+        """Attempt to use a workflow signing key in a child workspace."""
         self.playground.create_group_role(
             self.scenario.workspace,
             Workspace.Roles.CONTRIBUTOR,
             users=[self.scenario.user],
         )
-        new_workspace = self.assertExperimentWorkspaceCreated(
-            experiment_name="test"
-        )
+        new_workspace = self.assertChildWorkspaceCreated(suffix="test")
         signing_input = self.playground.create_signing_input_artifact(
             workspace=new_workspace
         )
@@ -153,7 +150,7 @@ class PenetrationTests(TestCase):
             task_name="sign",
             task_data=SignData(
                 purpose=ArtifactKeyPurpose(signing_key_data.purpose),
-                unsigned=LookupMultiple.parse_obj([signing_input.id]),
+                unsigned=LookupMultiple((signing_input.id,)),
                 key=signing_key_data.fingerprint,
             ),
             created_by=self.scenario.user,
@@ -163,7 +160,7 @@ class PenetrationTests(TestCase):
             unsigned_binary_package_names=[
                 signing_input.data["binary_package_name"]
             ],
-        ).dict()
+        ).model_dump()
         signing_task.save()
         response = self.post_permission_check(
             asset_category=self.signing_key.category,
