@@ -35,6 +35,8 @@ class DummyWorkerPool(
     def terminate_worker(self, worker: "Worker") -> None:
         worker.instance_created_at = None
         worker.worker_pool_data = None
+        worker.token = None
+        worker.activation_token = None
         worker.save()
 
     @override
