@@ -11,7 +11,7 @@
 
 from base64 import b64decode
 from collections import UserList
-from typing import Any, TYPE_CHECKING, TypeVar, override
+from typing import Any, TYPE_CHECKING, override
 from unittest import TestCase as SimpleTestCase
 from unittest.mock import call, patch
 
@@ -39,10 +39,7 @@ else:
     DescribeInstancesResultTypeDef = dict[str, Any]
 
 
-LI = TypeVar("LI")
-
-
-class UnsortedList(UserList[LI]):
+class UnsortedList[LI](UserList[LI]):
     """List that compares values in any order."""
 
     @override
@@ -116,7 +113,7 @@ class TestAWSEC2WorkerPool(TestCase):
             "https://example.com/"
         )
         with context.disable_permission_checks():
-            self.provider_account.data = provider_account_data.dict(
+            self.provider_account.data = provider_account_data.model_dump(
                 exclude_unset=True
             )
             self.provider_account.save()
@@ -132,7 +129,7 @@ class TestAWSEC2WorkerPool(TestCase):
             ImageId="ec2-image",
             InstanceType="t3a.medium",
         )
-        return launch_template.copy(update=kwargs)
+        return launch_template.model_copy(update=kwargs)
 
     def test_terminate_existing_instances(self) -> None:
         worker_pool = self.get_worker_pool()
@@ -318,7 +315,7 @@ class TestAWSEC2WorkerPool(TestCase):
         assert launch_template.InstanceRequirements
         self.assertEqual(
             launch_template_data["InstanceRequirements"],
-            launch_template.InstanceRequirements.dict(exclude_unset=True),
+            launch_template.InstanceRequirements.model_dump(exclude_unset=True),
         )
 
     def test_launch_template_data_ssh_key(self) -> None:
