@@ -11,7 +11,7 @@
 
 import datetime as dt
 from functools import cached_property
-from typing import Any, TypeAlias
+from typing import Any, TypeAlias, override
 
 from django.utils import timezone
 
@@ -62,6 +62,7 @@ class AutopkgtestWorkflow(
 
     TASK_NAME = "autopkgtest"
 
+    @override
     def post_init(self) -> None:
         """Workflow initialization."""
         if self.data.backend == BackendType.AUTO:
@@ -94,6 +95,7 @@ class AutopkgtestWorkflow(
 
         return architectures
 
+    @override
     def validate_input(self) -> None:
         """Thorough validation of input data."""
         super().validate_input()
@@ -128,7 +130,7 @@ class AutopkgtestWorkflow(
             and (
                 self.qa_suite_changed is None
                 or dt.datetime.fromtimestamp(
-                    latest_result.data["timestamp"], tz=dt.timezone.utc
+                    latest_result.data["timestamp"], tz=dt.UTC
                 )
                 >= self.qa_suite_changed - dt.timedelta(days=30)
             )
@@ -264,6 +266,7 @@ class AutopkgtestWorkflow(
             regression_analysis.add_dependency(wr)
             self.orchestrate_child(regression_analysis)
 
+    @override
     def populate(self) -> None:
         """Create autopkgtest work requests for all architectures."""
         assert self.work_request is not None
@@ -387,8 +390,10 @@ class AutopkgtestWorkflow(
         self.work_request.save()
         return True
 
+    @override
     def build_dynamic_data(
-        self, task_database: TaskDatabaseInterface  # noqa: U100
+        self,
+        task_database: TaskDatabaseInterface,  # noqa: U100
     ) -> AutopkgtestWorkflowDynamicData:
         """
         Compute dynamic data for this workflow.
@@ -425,6 +430,7 @@ class AutopkgtestWorkflow(
             context_artifacts_ids=artifact_ids(context_artifacts_results),
         )
 
+    @override
     def get_input_artifacts(self) -> list[InputArtifact]:
         """Return input artifacts."""
         return [
