@@ -12,9 +12,12 @@ Base Workflow infrastructure.
 See :ref:`explanation-workflows` for a high level explanation of concepts used
 here.
 """
+
 import logging
 from abc import ABCMeta, abstractmethod
-from typing import Any, Literal, TypeVar, TypedDict, cast
+from collections.abc import Callable
+from functools import partial
+from typing import Any, Literal, TypedDict, cast, override
 
 from django.contrib.auth.models import AnonymousUser
 from django.db.models import Q
@@ -25,11 +28,7 @@ from debusine.artifacts.models import (
     CollectionCategory,
     TaskTypes,
 )
-from debusine.client.models import (
-    LookupChildType,
-    RuntimeParameter,
-    model_to_json_serializable_dict,
-)
+from debusine.client.models import LookupChildType, RuntimeParameter
 from debusine.db.models import (
     Collection,
     CollectionItem,
@@ -65,10 +64,6 @@ from debusine.tasks.server import TaskDatabaseInterface
 logger = logging.getLogger(__name__)
 
 
-WD = TypeVar("WD", bound=BaseWorkflowData)
-DTD = TypeVar("DTD", bound=BaseDynamicTaskData)
-
-
 class WorkflowValidationError(Exception):
     """Raised if a workflow fails to validate its inputs."""
 
@@ -85,7 +80,9 @@ class WorkflowRunError(Exception):
         self.code = code
 
 
-class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
+class Workflow[WD: BaseWorkflowData, DTD: BaseDynamicTaskData](
+    BaseServerTask[WD, DTD], metaclass=ABCMeta
+):
     """
     Base class for workflow orchestrators.
 
@@ -97,6 +94,7 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
     work_request: WorkRequest
     workspace: Workspace
 
+    @override
     def __init__(
         self,
         *,
@@ -133,7 +131,7 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
             return
         assert isinstance(data, dict)
         for key, value in data.items():
-            if key not in cls.task_data_type.__fields__:
+            if key not in cls.task_data_type.model_fields:
                 raise WorkflowValidationError(
                     f"{key} is not a task_data parameter for {cls.__name__}"
                 )
@@ -166,10 +164,8 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
         """Ensure that this workflow's dynamic task data has been computed."""
         if self.work_request.dynamic_task_data is None:
             dynamic_task_data = self.compute_dynamic_data(task_database)
-            self.work_request.dynamic_task_data = (
-                model_to_json_serializable_dict(
-                    dynamic_task_data, exclude_unset=True
-                )
+            self.work_request.dynamic_task_data = dynamic_task_data.model_dump(
+                mode="json", exclude_unset=True
             )
             self.work_request.save()
             self.dynamic_data = self.dynamic_task_data_type(
@@ -395,7 +391,7 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
         try:
             return self.work_request.children.get(
                 task_name=task_name,
-                workflow_data_json=workflow_data.dict(exclude_unset=True),
+                workflow_data_json=workflow_data.model_dump(exclude_unset=True),
                 task_type=TaskTypes.WORKER,
             )
         except WorkRequest.DoesNotExist:
@@ -428,15 +424,15 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
         """
         if task_data_filter is None:
             task_data_filter = Q(
-                task_data=model_to_json_serializable_dict(
-                    task_data or BaseTaskData(), exclude_unset=True
+                task_data=(task_data or BaseTaskData()).model_dump(
+                    mode="json", exclude_unset=True
                 )
             )
         try:
             return self.work_request.children.get(
                 task_data_filter,
                 task_name=task_name,
-                workflow_data_json=workflow_data.dict(exclude_unset=True),
+                workflow_data_json=workflow_data.model_dump(exclude_unset=True),
                 task_type=TaskTypes.SERVER,
             )
         except WorkRequest.DoesNotExist:
@@ -467,7 +463,7 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
         try:
             return self.work_request.children.get(
                 task_name=task_name,
-                workflow_data_json=workflow_data.dict(exclude_unset=True),
+                workflow_data_json=workflow_data.model_dump(exclude_unset=True),
                 task_type=TaskTypes.INTERNAL,
             )
         except WorkRequest.DoesNotExist:
@@ -503,7 +499,7 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
             return self.work_request.children.get(
                 task_data_filter or Q(),
                 task_name=task_name,
-                workflow_data_json=workflow_data.dict(exclude_unset=True),
+                workflow_data_json=workflow_data.model_dump(exclude_unset=True),
                 task_type=TaskTypes.WORKFLOW,
             )
         except WorkRequest.DoesNotExist:
@@ -535,7 +531,7 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
         try:
             return self.work_request.children.get(
                 task_name=task_name,
-                workflow_data_json=workflow_data.dict(exclude_unset=True),
+                workflow_data_json=workflow_data.model_dump(exclude_unset=True),
                 task_type=TaskTypes.SIGNING,
             )
         except WorkRequest.DoesNotExist:
@@ -563,7 +559,7 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
         try:
             return self.work_request.children.get(
                 task_name=task_name,
-                workflow_data_json=workflow_data.dict(exclude_unset=True),
+                workflow_data_json=workflow_data.model_dump(exclude_unset=True),
                 task_type=TaskTypes.WAIT,
             )
         except WorkRequest.DoesNotExist:
@@ -592,6 +588,7 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
         """Return the list of input artifacts used by this workflow."""
         return []
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """
         Return the list of artifact ids used by this workflow.
@@ -605,7 +602,8 @@ class Workflow(BaseServerTask[WD, DTD], metaclass=ABCMeta):
             for artifact_id in input_artifact.resolved_ids()
         ]
 
-    def _execute(self) -> bool:
+    @override
+    def _execute(self) -> WorkRequest.Results:
         """Unused abstract method from BaseTask: populate() is used instead."""
         raise NotImplementedError()
 
@@ -629,15 +627,24 @@ def orchestrate_workflow(work_request: WorkRequest) -> bool:
 
     Return False if any errors were logged, otherwise True.
     """
-    try:
+
+    def run_or_raise_workflow_run_error[R: Any](
+        func: Callable[[], R], message_template: str, code: str
+    ) -> R:
         try:
-            work_request.mark_running()
-        except StatusChangeError:
+            return func()
+        except Exception as exc:
+            message = describe_exc(exc)
             raise WorkflowRunError(
-                work_request,
-                "Failed to mark work request as running",
-                "status-change-failed",
-            )
+                work_request, message_template.format(message=message), code
+            ) from exc
+
+    try:
+        run_or_raise_workflow_run_error(
+            work_request.mark_running,
+            "Failed to mark work request as running",
+            "status-change-failed",
+        )
 
         match (work_request.task_type, work_request.task_name):
             case (TaskTypes.INTERNAL, "workflow") | (TaskTypes.WORKFLOW, _):
@@ -666,30 +673,25 @@ def orchestrate_workflow(work_request: WorkRequest) -> bool:
         match (work_request.task_type, work_request.task_name):
             case (TaskTypes.INTERNAL, "workflow"):
                 parent = orchestrator.work_request
-                try:
-                    orchestrator.ensure_dynamic_data(TaskDatabase(parent))
-                except Exception as exc:
-                    # Workflow callbacks compute dynamic data for their
-                    # parent workflow.  If this fails, it's probably least
-                    # confusing to log information about both the workflow
-                    # callback and the workflow.
-                    raise WorkflowRunError(
-                        work_request,
-                        f"Failed to compute dynamic data for "
-                        f"{parent.task_type}/{parent.task_name} ({parent.id}): "
-                        f"{exc}",
-                        "dynamic-data-failed",
-                    ) from exc
+                # Workflow callbacks compute dynamic data for their parent
+                # workflow.  If this fails, it's probably least confusing to
+                # log information about both the workflow callback and the
+                # workflow.
+                run_or_raise_workflow_run_error(
+                    partial(
+                        orchestrator.ensure_dynamic_data, TaskDatabase(parent)
+                    ),
+                    f"Failed to compute dynamic data for "
+                    f"{parent.task_type}/{parent.task_name} ({parent.id}): "
+                    f"{{message}}",
+                    "dynamic-data-failed",
+                )
 
-                try:
-                    succeeded = orchestrator.callback(work_request)
-                except Exception as exc:
-                    message = describe_exc(exc)
-                    raise WorkflowRunError(
-                        work_request,
-                        f"Orchestrator failed: {message}",
-                        "orchestrator-failed",
-                    ) from exc
+                succeeded = run_or_raise_workflow_run_error(
+                    partial(orchestrator.callback, work_request),
+                    "Orchestrator failed: {message}",
+                    "orchestrator-failed",
+                )
 
                 work_request.mark_completed(
                     WorkRequest.Results.SUCCESS
@@ -699,27 +701,20 @@ def orchestrate_workflow(work_request: WorkRequest) -> bool:
 
             case (TaskTypes.WORKFLOW, _):
                 with work_request.running_workflow_orchestrator():
-                    try:
-                        orchestrator.ensure_dynamic_data(
-                            TaskDatabase(orchestrator.work_request)
-                        )
-                    except Exception as exc:
-                        message = describe_exc(exc)
-                        raise WorkflowRunError(
-                            work_request,
-                            f"Failed to compute dynamic data: {message}",
-                            "dynamic-data-failed",
-                        ) from exc
+                    run_or_raise_workflow_run_error(
+                        partial(
+                            orchestrator.ensure_dynamic_data,
+                            TaskDatabase(orchestrator.work_request),
+                        ),
+                        "Failed to compute dynamic data: {message}",
+                        "dynamic-data-failed",
+                    )
 
-                    try:
-                        orchestrator.populate()
-                    except Exception as exc:
-                        message = describe_exc(exc)
-                        raise WorkflowRunError(
-                            work_request,
-                            f"Orchestrator failed: {message}",
-                            "orchestrator-failed",
-                        ) from exc
+                    run_or_raise_workflow_run_error(
+                        orchestrator.populate,
+                        "Orchestrator failed: {message}",
+                        "orchestrator-failed",
+                    )
 
                     if work_request.children.exists():
                         orchestrator.work_request.unblock_workflow_children()
