@@ -221,7 +221,15 @@ class DebDiffWorkflow(
         )
         new_binaries_arch_lookup = self._get_new_packages_by_name_arch()
 
-        for arch in sorted(self._get_architectures(new_binaries_arch_lookup)):
+        archs = self._get_architectures(new_binaries_arch_lookup)
+        concrete_archs = {a for a in archs if a != Architecture("all")}
+
+        if concrete_archs:
+            archs_to_compare = concrete_archs
+        else:
+            archs_to_compare = {Architecture("all")}
+
+        for arch in sorted(archs_to_compare):
             self._populate_binary_for_arch(
                 architecture=arch,
                 orig_map=original_binaries_arch_lookup,
@@ -239,23 +247,30 @@ class DebDiffWorkflow(
         environment: LookupSingle,
         extra_flags: list[DebDiffFlags],
     ) -> None:
+        arch_all = Architecture("all")
         new_relevants = set()
         for arch_lookup in new_map.values():
-            for arch in (architecture, Architecture("all")):
+            for arch in (architecture, arch_all):
                 if arch in arch_lookup:
                     new_relevants.add(arch_lookup[arch])
 
         original_relevants: list[LookupSingle] = []
         for old_pkg_name, old_arch_map in orig_map.items():
-            # Architectures are considered compatible when they are equal,
-            # or when one is "all" and the other is a concrete architecture
-            # (to account for changes in a binary package's declared
-            # architecture across versions).
+            # Architectures are considered compatible in two cases:
+            # - if comparing a concrete architecture: include the architecture
+            #   and "all" packages
+            # - if comparing "all": include only "all" packages
             original_relevants += [
                 old_lookup
                 for old_arch, old_lookup in old_arch_map.items()
                 if old_pkg_name in new_map
-                and (architecture == "all" or old_arch in ("all", architecture))
+                and (
+                    (architecture == arch_all and old_arch == arch_all)
+                    or (
+                        architecture != arch_all
+                        and old_arch in (arch_all, architecture)
+                    )
+                )
             ]
 
         if original_relevants and new_relevants:
