@@ -10,22 +10,17 @@
 """debian_pipeline workflow."""
 
 from functools import partial
-from typing import assert_never
+from typing import assert_never, override
 
 from django.contrib.auth.models import AnonymousUser
 from django.db.models import Q
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic  # type: ignore
-
+from debusine.artifacts import SourcePackage
 from debusine.artifacts.models import ArtifactCategory, DebianSourcePackage
 from debusine.assets import KeyPurpose
 from debusine.client.models import LookupChildType
 from debusine.db.models import WorkRequest
 from debusine.server.collections.lookup import lookup_single
-from debusine.server.tasks.models import PackageUploadTarget
 from debusine.server.tasks.wait.models import ConfirmData
 from debusine.server.workflows import (
     Workflow,
@@ -34,6 +29,7 @@ from debusine.server.workflows import (
 )
 from debusine.server.workflows.models import (
     DebianPipelineWorkflowData,
+    DebianPipelineWorkflowDynamicData,
     MakeSignedSourceWorkflowData,
     PackagePublishWorkflowData,
     PackageUploadWorkflowData,
@@ -45,7 +41,6 @@ from debusine.server.workflows.models import (
 )
 from debusine.tasks.models import (
     BackendType,
-    DebianPipelineWorkflowDynamicData,
     ExtraDebusineRepository,
     ExtraRepository,
     InputArtifact,
@@ -65,6 +60,7 @@ class DebianPipelineWorkflow(
 
     TASK_NAME = "debian_pipeline"
 
+    @override
     def validate_input(self) -> None:
         """Thorough validation of input data."""
         if self.data.qa_suite is not None:
@@ -79,30 +75,27 @@ class DebianPipelineWorkflow(
             except LookupError as e:
                 raise WorkflowValidationError(str(e)) from e
 
+    @override
     def build_dynamic_data(
-        self, task_database: TaskDatabaseInterface  # noqa: U100
+        self,
+        task_database: TaskDatabaseInterface,  # noqa: U100
     ) -> DebianPipelineWorkflowDynamicData:
         """
         Compute dynamic data for this workflow.
 
         :subject: package name of ``source_artifact``
+        :source_artifact_id: id of the source artifact
         """
-        source_data = workflow_utils.source_package_data(self)
-
-        source_artifact_id = lookup_single(
-            self.data.source_artifact,
-            self.workspace,
-            user=self.work_request.created_by,
-            workflow_root=self.work_request.workflow_root,
-            expect_type=LookupChildType.ARTIFACT,
-        ).artifact.id
+        source_artifact = workflow_utils.source_package(self)
+        source_data = SourcePackage.create_data(source_artifact.data)
 
         return DebianPipelineWorkflowDynamicData(
             subject=source_data.name,
             parameter_summary=f"{source_data.name}_{source_data.version}",
-            input_source_artifact_id=source_artifact_id,
+            input_source_artifact_id=source_artifact.id,
         )
 
+    @override
     def get_input_artifacts(self) -> list[InputArtifact]:
         """Return workflow input artifacts (the source package)."""
         return [
@@ -110,9 +103,9 @@ class DebianPipelineWorkflow(
                 lookup=self.data.source_artifact,
                 label="source_artifact",
                 artifact_id=(
-                    None
-                    if self.dynamic_data is None
-                    else self.dynamic_data.input_source_artifact_id
+                    self.dynamic_data.input_source_artifact_id
+                    if self.dynamic_data is not None
+                    else None
                 ),
             )
         ]
@@ -152,6 +145,7 @@ class DebianPipelineWorkflow(
             )
         return extra_repositories
 
+    @override
     def populate(self) -> None:  # noqa: C901
         """Create work requests."""
         assert self.dynamic_data is not None
@@ -193,7 +187,7 @@ class DebianPipelineWorkflow(
         )
 
         # sbuild workflow promises the build-{arch} artifacts
-        binary_artifacts = LookupMultiple.parse_obj(
+        binary_artifacts = LookupMultiple.model_validate(
             {
                 "collection": "internal@collections",
                 "child_type": LookupChildType.ARTIFACT_OR_PROMISE,
@@ -202,7 +196,7 @@ class DebianPipelineWorkflow(
         )
 
         # sbuild workflow promises the buildlog-{arch} artifacts
-        package_build_logs = LookupMultiple.parse_obj(
+        package_build_logs = LookupMultiple.model_validate(
             {
                 "collection": "internal@collections",
                 "child_type": LookupChildType.ARTIFACT_OR_PROMISE,
@@ -285,7 +279,7 @@ class DebianPipelineWorkflow(
                     populate_qa(
                         prefix="reference-qa-result|",
                         source_artifact=reference_source.id,
-                        binary_artifacts=LookupMultiple.parse_obj(
+                        binary_artifacts=LookupMultiple.model_validate(
                             {
                                 "collection": self.data.qa_suite,
                                 "category": ArtifactCategory.BINARY_PACKAGE,
@@ -600,7 +594,7 @@ class DebianPipelineWorkflow(
                     (
                         f"internal@collections/name:"
                         f"signed-source-{arch}-{name}",
-                        LookupMultiple.parse_obj(
+                        LookupMultiple.model_validate(
                             {
                                 "collection": "internal@collections",
                                 "child_type": (
@@ -615,7 +609,9 @@ class DebianPipelineWorkflow(
                     )
                 )
 
-        signing_template_artifacts = LookupMultiple.parse_obj(signing_artifacts)
+        signing_template_artifacts = LookupMultiple.model_validate(
+            signing_artifacts
+        )
         wr = self.work_request_ensure_child_workflow(
             task_name="make_signed_source",
             task_data=MakeSignedSourceWorkflowData(
@@ -676,9 +672,7 @@ class DebianPipelineWorkflow(
                     source_artifact if include_source or signed_source else None
                 ),
                 binary_artifacts=(
-                    binary_artifacts
-                    if include_binaries
-                    else LookupMultiple.parse_obj(())
+                    binary_artifacts if include_binaries else LookupMultiple(())
                 ),
                 merge_uploads=merge_uploads,
                 since_version=since_version,
@@ -686,7 +680,7 @@ class DebianPipelineWorkflow(
                 key=key,
                 binary_key=binary_key,
                 require_signature=require_signature,
-                target=pydantic.parse_obj_as(PackageUploadTarget, target),
+                target=target,
                 delayed_days=delayed_days,
                 vendor=vendor,
                 codename=codename,
