@@ -222,6 +222,14 @@ class LintianWorkflow(
             # failures never cause the parent workflow or dependent tasks to
             # fail.
             workflow_data_kwargs["allow_failure"] = True
+
+        display_name = f"Lintian for {architecture}"
+        if architecture != "all" and output.binary_all_analysis:
+            display_name += "+all"
+
+        if output.source_analysis:
+            display_name += "+source"
+
         wr = self.work_request_ensure_child_worker(
             task_name="lintian",
             task_data=LintianData(
@@ -239,7 +247,7 @@ class LintianWorkflow(
                 target_distribution=target_distribution,
             ),
             workflow_data=WorkRequestWorkflowData(
-                display_name=f"Lintian for {architecture}",
+                display_name=display_name,
                 step=f"lintian-{architecture}",
                 **workflow_data_kwargs,
             ),
