@@ -10,17 +10,13 @@
 """Pydantic models used by debusine workflows."""
 
 import datetime as dt
-import re
 from enum import StrEnum
-from typing import Any
+from functools import partial
+from typing import Annotated, Any, Self
+
+import pydantic
 
 from debusine.assets import KeyPurpose
-
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 from debusine.db.models.workspaces import workspace_name_regex
 from debusine.server.tasks.models import PackageUploadTarget
 from debusine.tasks.models import (
@@ -40,7 +36,7 @@ from debusine.tasks.models import (
     LookupSingle,
     SbuildBinNMU,
     SbuildInput,
-    empty_lookup_multiple,
+    require_unique,
 )
 
 
@@ -80,39 +76,31 @@ class WorkRequestManualUnblockData(pydantic.BaseModel):
 class WorkRequestWorkflowData(pydantic.BaseModel):
     """Data structure for WorkRequest.workflow_data."""
 
-    class Config:
-        """Set up stricter pydantic Config."""
-
-        validate_assignment = True
-        extra = "forbid"
+    model_config = pydantic.ConfigDict(validate_assignment=True, extra="forbid")
 
     #: Whether the parent workflow and reverse-dependencies should continue
     #: if this work request fails.  If False, they are aborted instead.
-    allow_failure: bool = pydantic.Field(default=False, allow_mutation=False)
+    allow_failure: bool = pydantic.Field(default=False, frozen=True)
 
     #: Whether this work request should continue if any of its child work
     #: requests or dependencies fails.  If False, it is aborted instead.
-    allow_dependency_failures: bool = pydantic.Field(
-        default=False, allow_mutation=False
-    )
+    allow_dependency_failures: bool = pydantic.Field(default=False, frozen=True)
 
     #: name of the step in the visual representation of the workflow
-    display_name: str | None = pydantic.Field(
-        default=None, allow_mutation=False
-    )
+    display_name: str | None = pydantic.Field(default=None, frozen=True)
 
     #: internal identifier used to differentiate multiple workflow callbacks
     #: inside a single workflow. It allows the orchestrator to encode the plan
     #: about what it is supposed to do at this point in the workflow.
-    step: str | None = pydantic.Field(default=None, allow_mutation=False)
+    step: str | None = pydantic.Field(default=None, frozen=True)
 
     #: Name of the group within this workflow containing this work request.
-    group: str | None = pydantic.Field(default=None, allow_mutation=False)
+    group: str | None = pydantic.Field(default=None, frozen=True)
 
     #: For workflows created from a workflow template, the name of that
     #: template, cached here for convenience.
     workflow_template_name: str | None = pydantic.Field(
-        default=None, allow_mutation=False
+        default=None, frozen=True
     )
 
     #: Data stored for manual unblock requests.
@@ -126,11 +114,11 @@ class WorkRequestWorkflowData(pydantic.BaseModel):
 
     #: Whether this task should be shown in the visual representation of the
     #: workflow.
-    visible: bool = pydantic.Field(default=True, allow_mutation=False)
+    visible: bool = pydantic.Field(default=True, frozen=True)
 
     #: Whether this task's descendants should be expanded by default in the
     #: visual representation of the workflow.
-    expanded: bool = pydantic.Field(default=True, allow_mutation=False)
+    expanded: bool = pydantic.Field(default=True, frozen=True)
 
 
 class SbuildWorkflowData(BaseWorkflowData):
@@ -141,32 +129,27 @@ class SbuildWorkflowData(BaseWorkflowData):
     target_distribution: str
     # If AUTO is used, default to BackendType.UNSHARE
     backend: BackendType = BackendType.AUTO
-    architectures: list[str] = pydantic.Field(
-        min_items=1,
-        unique_items=True,
-    )
+    architectures: Annotated[
+        list[str],
+        pydantic.Field(min_length=1),
+        pydantic.AfterValidator(require_unique),
+    ]
     arch_all_build_architecture: str = "amd64"
     environment_variant: str | None = None
     extra_repositories: list[ExtraRepository] | None = None
     binnmu: SbuildBinNMU | None = None
     build_profiles: list[str] | None = None
-    retry_delays: list[str] | None = pydantic.Field(default=None, min_items=1)
+    retry_delays: Annotated[
+        list[
+            Annotated[
+                str, pydantic.Field(pattern=ActionRetryWithDelays._delay_re)
+            ]
+        ]
+        | None,
+        pydantic.Field(min_length=1),
+    ] = None
     signing_template_names: dict[str, list[str]] = {}
 
-    @pydantic.validator("retry_delays")
-    @classmethod
-    def validate_retry_delays(
-        cls, values: list[str] | None
-    ) -> list[str] | None:
-        """Check items in `retry_delays` field."""
-        for v in values or []:
-            if ActionRetryWithDelays._delay_re.match(v) is None:
-                raise ValueError(
-                    f"Item in retry_delays must be an integer followed by "
-                    f"m, h, d, or w; got {v!r}"
-                )
-        return values
-
 
 class SbuildWorkflowDynamicData(BaseDynamicTaskData):
     """Dynamic data for the Sbuild workflow."""
@@ -182,10 +165,18 @@ class UpdateEnvironmentsWorkflowTarget(BaseWorkflowData):
         default_factory=dict
     )
     variants: str | None | list[str | None] = pydantic.Field(
-        default_factory=list
+        # TODO: Why is mypy confused about what type default_factory should be?
+        default_factory=list  # type: ignore[arg-type]
     )
-    backends: str | list[str] = pydantic.Field(default_factory=list)
-    architectures: list[str] = pydantic.Field(min_items=1, unique_items=True)
+    backends: str | list[str] = pydantic.Field(
+        # TODO: Why is mypy confused about what type default_factory should be?
+        default_factory=list  # type: ignore[arg-type]
+    )
+    architectures: Annotated[
+        list[str],
+        pydantic.Field(min_length=1),
+        pydantic.AfterValidator(require_unique),
+    ]
     mmdebstrap_template: dict[str, Any] | None = None
     simplesystemimagebuild_template: dict[str, Any] | None = None
 
@@ -194,9 +185,9 @@ class UpdateEnvironmentsWorkflowData(BaseWorkflowData):
     """update_environments workflow data."""
 
     vendor: str
-    targets: list[UpdateEnvironmentsWorkflowTarget] = pydantic.Field(
-        min_items=1
-    )
+    targets: Annotated[
+        list[UpdateEnvironmentsWorkflowTarget], pydantic.Field(min_length=1)
+    ]
 
 
 class PackageUploadWorkflowData(BaseWorkflowData):
@@ -204,9 +195,9 @@ class PackageUploadWorkflowData(BaseWorkflowData):
 
     prefix: str = ""
 
-    source_artifact: LookupSingle | None
+    source_artifact: LookupSingle | None = None
     binary_artifacts: LookupMultiple = pydantic.Field(
-        default_factory=empty_lookup_multiple
+        default_factory=partial(LookupMultiple, ())
     )
     merge_uploads: bool = False
     since_version: str | None = None
@@ -221,6 +212,13 @@ class PackageUploadWorkflowData(BaseWorkflowData):
     arch_all_build_architecture: str = "amd64"
 
 
+class PackageUploadWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for PackageUpload workflow."""
+
+    source_artifact_id: int | None = None
+    binary_artifacts_ids: list[int] | None = None
+
+
 class MakeSignedSourceWorkflowData(BaseWorkflowData):
     """`make_signed_source` workflow data."""
 
@@ -237,6 +235,13 @@ class MakeSignedSourceWorkflowData(BaseWorkflowData):
     sbuild_backend: BackendType = BackendType.AUTO
 
 
+class MakeSignedSourceWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for the MakeSignedSource workflow."""
+
+    binary_artifacts_ids: list[int] | None = None
+    signing_template_artifacts_ids: list[int] | None = None
+
+
 class RegressionTrackingWorkflowData(BaseWorkflowData):
     """Common data for workflows that handle regression tracking."""
 
@@ -248,33 +253,26 @@ class RegressionTrackingWorkflowData(BaseWorkflowData):
     enable_regression_tracking: bool = False
     update_qa_results: bool = False
 
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def check_qa_results_consistency(
-        cls, values: dict[str, Any]
-    ) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def check_qa_results_consistency(self) -> Self:
         """Check consistency of regression-tracking options."""
-        if values.get("enable_regression_tracking") or values.get(
-            "update_qa_results"
-        ):
-            if values.get("qa_suite") is None:
+        if self.enable_regression_tracking or self.update_qa_results:
+            if self.qa_suite is None:
                 raise ValueError(
                     '"qa_suite" is required if "enable_regression_tracking" or '
                     '"update_qa_results" is set'
                 )
-            if values.get("reference_qa_results") is None:
+            if self.reference_qa_results is None:
                 raise ValueError(
                     '"reference_qa_results" is required if '
                     '"enable_regression_tracking" or "update_qa_results" is set'
                 )
-        if values.get("enable_regression_tracking") and not values.get(
-            "reference_prefix"
-        ):
+        if self.enable_regression_tracking and not self.reference_prefix:
             raise ValueError(
                 '"reference_prefix" is required if '
                 '"enable_regression_tracking" is set'
             )
-        return values
+        return self
 
 
 class PiupartsWorkflowData(RegressionTrackingWorkflowData):
@@ -292,13 +290,20 @@ class PiupartsWorkflowData(RegressionTrackingWorkflowData):
     extra_repositories: list[ExtraRepository] | None = None
 
 
+class PiupartsWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for Piuparts workflow."""
+
+    source_artifact_id: int | None = None
+    binary_artifacts_ids: list[int] | None = None
+
+
 class AutopkgtestWorkflowData(RegressionTrackingWorkflowData):
     """`autopkgtest` workflow data."""
 
     source_artifact: LookupSingle
     binary_artifacts: LookupMultiple
     context_artifacts: LookupMultiple = pydantic.Field(
-        default_factory=empty_lookup_multiple
+        default_factory=partial(LookupMultiple, ())
     )
 
     vendor: str
@@ -319,6 +324,14 @@ class AutopkgtestWorkflowData(RegressionTrackingWorkflowData):
     timeout: AutopkgtestTimeout | None = None
 
 
+class AutopkgtestWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for the Autopkgtest workflow."""
+
+    source_artifact_id: int | None = None
+    binary_artifacts_ids: list[int] | None = None
+    context_artifacts_ids: list[int] | None = None
+
+
 class ReverseDependenciesAutopkgtestWorkflowData(
     RegressionTrackingWorkflowData
 ):
@@ -327,7 +340,7 @@ class ReverseDependenciesAutopkgtestWorkflowData(
     source_artifact: LookupSingle
     binary_artifacts: LookupMultiple
     context_artifacts: LookupMultiple = pydantic.Field(
-        default_factory=empty_lookup_multiple
+        default_factory=partial(LookupMultiple, ())
     )
 
     # RegressionTrackingWorkflowData declares this as optional, but it's
@@ -346,6 +359,16 @@ class ReverseDependenciesAutopkgtestWorkflowData(
     debug_level: int = pydantic.Field(default=0, ge=0, le=3)
 
 
+class ReverseDependenciesAutopkgtestWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for the ReverseDependenciesAutopkgtest workflow."""
+
+    source_artifact_id: int | None = None
+    binary_artifacts_ids: list[int] | None = None
+    context_artifacts_ids: list[int] | None = None
+
+    qa_suite_id: int | None = None
+
+
 class LintianWorkflowData(RegressionTrackingWorkflowData):
     """`lintian` workflow data."""
 
@@ -366,7 +389,7 @@ class LintianWorkflowData(RegressionTrackingWorkflowData):
 
 
 class LintianWorkflowDynamicData(BaseDynamicTaskData):
-    """`lintian` workflow dynamic data."""
+    """Dynamic data for the Lintian workflow."""
 
     source_artifact_id: int | None = None
     binary_artifacts_ids: list[int] | None = None
@@ -387,6 +410,15 @@ class DebDiffWorkflowData(BaseWorkflowData):
     arch_all_build_architecture: str = "amd64"
 
 
+class DebDiffWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for the DebDiff workflow."""
+
+    source_artifact_id: int | None = None
+    binary_artifacts_ids: list[int] | None = None
+
+    original_id: int | None = None
+
+
 class BlhcWorkflowData(RegressionTrackingWorkflowData):
     """`blhc` workflow data."""
 
@@ -399,19 +431,22 @@ class BlhcWorkflowData(RegressionTrackingWorkflowData):
 
     arch_all_build_architecture: str = "amd64"
 
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def check_source_artifact(cls, values: dict[str, Any]) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def check_source_artifact(self) -> Self:
         """``source_artifact`` is required for regression tracking."""
-        if (
-            values.get("enable_regression_tracking")
-            and values.get("source_artifact") is None
-        ):
+        if self.enable_regression_tracking and self.source_artifact is None:
             raise ValueError(
                 '"source_artifact" is required if '
                 '"enable_regression_tracking" is set'
             )
-        return values
+        return self
+
+
+class BlhcWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for Blhc workflow."""
+
+    source_artifact_id: int | None = None
+    package_build_logs_ids: list[int] | None = None
 
 
 class QAFailOn(StrEnum):
@@ -461,64 +496,46 @@ class QAWorkflowData(RegressionTrackingWorkflowData):
     enable_debdiff: bool = False
     enable_blhc: bool = False
 
-    # This fake default is just to avoid too much mypy fallout.  The real
-    # default is set by `default_fail_on` below.
-    fail_on: QAFailOn = QAFailOn.FAILURE
+    @staticmethod
+    def _fail_on_default_factory(data: dict[str, Any]) -> QAFailOn:
+        return (
+            QAFailOn.REGRESSION
+            if data.get("enable_regression_tracking")
+            else QAFailOn.FAILURE
+        )
 
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def check_reverse_dependencies_autopkgtest_consistency(
-        cls, values: dict[str, Any]
-    ) -> dict[str, Any]:
+    fail_on: QAFailOn = pydantic.Field(default_factory=_fail_on_default_factory)
+
+    @pydantic.model_validator(mode="after")
+    def check_reverse_dependencies_autopkgtest_consistency(self) -> Self:
         """Check consistency of reverse-dependencies-autopkgtest options."""
         if (
-            values.get("enable_reverse_dependencies_autopkgtest")
-            and values.get("qa_suite") is None
+            self.enable_reverse_dependencies_autopkgtest
+            and self.qa_suite is None
         ):
             raise ValueError(
                 '"qa_suite" is required if '
                 '"enable_reverse_dependencies_autopkgtest" is set'
             )
-        return values
+        return self
 
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def enable_debdiff_consistency(
-        cls, values: dict[str, Any]
-    ) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def enable_debdiff_consistency(self) -> Self:
         """Check consistency of enable_debdiff options."""
-        if values.get("enable_debdiff") and values.get("qa_suite") is None:
+        if self.enable_debdiff and self.qa_suite is None:
             raise ValueError(
                 '"qa_suite" is required if "enable_debdiff" is set'
             )
-        return values
+        return self
 
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def enable_blhc_consistency(cls, values: dict[str, Any]) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def enable_blhc_consistency(self) -> Self:
         """Check consistency of enable_blhc options."""
-        if (
-            values.get("enable_blhc")
-            and values.get("package_build_logs") is None
-        ):
+        if self.enable_blhc and self.package_build_logs is None:
             raise ValueError(
                 '"package_build_logs" is required if "enable_blhc" is set'
             )
-        return values
-
-    # TODO: Once we require pydantic v2, this dynamic default can be handled
-    # using default_factory instead of a validator.
-    @pydantic.root_validator(pre=True, allow_reuse=True)
-    @classmethod
-    def default_fail_on(cls, values: dict[str, Any]) -> dict[str, Any]:
-        """Set default for ``fail_on``."""
-        if "fail_on" not in values:
-            values["fail_on"] = (
-                QAFailOn.REGRESSION
-                if values.get("enable_regression_tracking")
-                else QAFailOn.FAILURE
-            )
-        return values
+        return self
 
 
 class QAWorkflowDynamicData(BaseDynamicTaskData):
@@ -606,52 +623,49 @@ class DebianPipelineWorkflowData(BaseWorkflowData):
 
     publish_replace: bool = False
 
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def check_reverse_dependencies_autopkgtest_consistency(
-        cls, values: dict[str, Any]
-    ) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def check_reverse_dependencies_autopkgtest_consistency(self) -> Self:
         """Check consistency of reverse-dependencies-autopkgtest options."""
         if (
-            values.get("enable_reverse_dependencies_autopkgtest")
-            and values.get("qa_suite") is None
+            self.enable_reverse_dependencies_autopkgtest
+            and self.qa_suite is None
         ):
             raise ValueError(
                 '"qa_suite" is required if '
                 '"enable_reverse_dependencies_autopkgtest" is set'
             )
-        return values
+        return self
 
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def enable_debdiff_consistency(
-        cls, values: dict[str, Any]
-    ) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def enable_debdiff_consistency(self) -> Self:
         """Check consistency of enable_debdiff options."""
-        if values.get("enable_debdiff") and values.get("qa_suite") is None:
+        if self.enable_debdiff and self.qa_suite is None:
             raise ValueError(
                 '"qa_suite" is required if "enable_debdiff" is set'
             )
-        return values
+        return self
 
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def check_regression_tracking_consistency(
-        cls, values: dict[str, Any]
-    ) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def check_regression_tracking_consistency(self) -> Self:
         """Check consistency of regression-tracking options."""
-        if values.get("enable_regression_tracking"):
-            if values.get("qa_suite") is None:
+        if self.enable_regression_tracking:
+            if self.qa_suite is None:
                 raise ValueError(
                     '"qa_suite" is required if '
                     '"enable_regression_tracking" is set'
                 )
-            if values.get("regression_tracking_qa_results") is None:
+            if self.regression_tracking_qa_results is None:
                 raise ValueError(
                     '"regression_tracking_qa_results" is required if '
                     '"enable_regression_tracking" is set'
                 )
-        return values
+        return self
+
+
+class DebianPipelineWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for the DebianPipeline workflow."""
+
+    input_source_artifact_id: int | None = None
 
 
 class PackagePublishWorkflowData(BaseWorkflowData):
@@ -659,7 +673,7 @@ class PackagePublishWorkflowData(BaseWorkflowData):
 
     source_artifact: LookupSingle | None = None
     binary_artifacts: LookupMultiple = pydantic.Field(
-        default_factory=empty_lookup_multiple
+        default_factory=partial(LookupMultiple, ())
     )
     target_suite: LookupSingle
     unembargo: bool = False
@@ -667,60 +681,36 @@ class PackagePublishWorkflowData(BaseWorkflowData):
     suite_variables: dict[str, Any] = {}
     update_indexes: bool = True
 
-    @pydantic.root_validator(allow_reuse=True)
-    @classmethod
-    def check_one_of_source_or_binary(
-        cls, values: dict[str, Any]
-    ) -> dict[str, Any]:
+    @pydantic.model_validator(mode="after")
+    def check_one_of_source_or_binary(self) -> Self:
         """Ensure a source or binary artifact is present."""
-        if (
-            values.get("source_artifact") is None
-            and values.get("binary_artifacts") == empty_lookup_multiple()
-        ):
+        if self.source_artifact is None and not self.binary_artifacts:
             raise ValueError(
                 '"source_artifact" or "binary_artifacts" must be set'
             )
-        return values
+        return self
+
+
+class PackagePublishWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for PackagePublish workflow."""
+
+    source_artifact_id: int | None = None
+    binary_artifacts_ids: list[int] | None = None
+    target_suite_id: int | None = None
 
 
 class ChildWorkspaceData(BaseWorkflowData):
     """``create_child_workspace`` workflow data."""
 
-    prefix: str | None = None
-    suffix: str
+    prefix: str | None = pydantic.Field(
+        default=None, pattern=workspace_name_regex
+    )
+    suffix: str = pydantic.Field(pattern=workspace_name_regex)
     public: bool = True
     owner_group: str | None = None
     workflow_template_names: list[str] = []
     expiration_delay: int | None = 60
 
-    @pydantic.validator("prefix")
-    @classmethod
-    def validate_prefix(cls, data: str | None) -> str | None:
-        """
-        Validate the prefix.
-
-        Valid characters are the same as workspace/group names.
-        """
-        # In pydantic 1.10 this could be done with constr, but mypy currently
-        # complains about their syntax
-        if data is not None and not re.match(workspace_name_regex, data):
-            raise ValueError("prefix contains invalid characters")
-        return data
-
-    @pydantic.validator("suffix")
-    @classmethod
-    def validate_suffix(cls, data: str) -> str:
-        """
-        Validate the suffix.
-
-        Valid characters are the same as workspace/group names.
-        """
-        # In pydantic 1.10 this could be done with constr, but mypy currently
-        # complains about their syntax
-        if not re.match(workspace_name_regex, data):
-            raise ValueError("suffix contains invalid characters")
-        return data
-
 
 class UpdateSuiteData(BaseWorkflowData):
     """``update_suite`` workflow data."""
