@@ -10,25 +10,18 @@
 """Package upload workflow."""
 
 from functools import cached_property
-
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic  # type: ignore
+from typing import override
 
 from debusine.artifacts.models import ArtifactCategory
 from debusine.client.models import LookupChildType
 from debusine.db.models import WorkRequest
 from debusine.server.collections.lookup import (
+    artifact_ids,
     lookup_multiple,
     lookup_single,
     reconstruct_lookup,
 )
-from debusine.server.tasks.models import (
-    PackageUploadData,
-    PackageUploadInput,
-    PackageUploadTarget,
-)
+from debusine.server.tasks.models import PackageUploadData, PackageUploadInput
 from debusine.server.tasks.wait.models import ExternalDebsignData
 from debusine.server.workflows import (
     Workflow,
@@ -37,30 +30,33 @@ from debusine.server.workflows import (
 )
 from debusine.server.workflows.models import (
     PackageUploadWorkflowData,
+    PackageUploadWorkflowDynamicData,
     WorkRequestWorkflowData,
 )
 from debusine.signing.tasks.models import DebsignData
 from debusine.tasks.models import (
-    BaseDynamicTaskData,
+    InputArtifact,
+    InputArtifactMultiple,
+    InputArtifactSingle,
     LookupMultiple,
     LookupSingle,
     MakeSourcePackageUploadData,
     MakeSourcePackageUploadInput,
     MergeUploadsData,
     MergeUploadsInput,
-    empty_lookup_multiple,
 )
 from debusine.tasks.server import TaskDatabaseInterface
 
 
 class PackageUploadWorkflow(
-    Workflow[PackageUploadWorkflowData, BaseDynamicTaskData]
+    Workflow[PackageUploadWorkflowData, PackageUploadWorkflowDynamicData]
 ):
     """Run package uploads for a set of architectures."""
 
     TASK_NAME = "package_upload"
     _artifacts_pending_upload: list[tuple[LookupSingle, bool]]
 
+    @override
     def post_init(self) -> None:
         """Initialize."""
         self._artifacts_pending_upload: list[tuple[LookupSingle, bool]] = []
@@ -76,16 +72,17 @@ class PackageUploadWorkflow(
                 self.data.source_artifact,
                 self.workspace,
                 user=self.work_request.created_by,
-                workflow_root=self.work_request.get_workflow_root(),
+                workflow_root=self.work_request.workflow_root,
                 expect_type=LookupChildType.ARTIFACT_OR_PROMISE,
             )
         )
 
+    @override
     def validate_input(self) -> None:
         """Raise WorkflowValidationError if needed."""
         if (
             self.data.source_artifact is None
-            and self.data.binary_artifacts == empty_lookup_multiple()
+            and self.data.binary_artifacts == LookupMultiple(())
         ):
             raise WorkflowValidationError(
                 '"source_artifact" or "binary_artifacts" must be set'
@@ -101,9 +98,9 @@ class PackageUploadWorkflow(
                 f'artifact category is {ArtifactCategory.SOURCE_PACKAGE}'
             )
 
+    @override
     def populate(self) -> None:
         """Create package upload work requests."""
-        workflow_root = self.work_request.get_workflow_root()
         artifacts_pending_upload: list[tuple[LookupSingle, bool]] = []
 
         if (source_artifact := self.data.source_artifact) is not None:
@@ -128,12 +125,17 @@ class PackageUploadWorkflow(
             self.data.binary_artifacts,
             self.workspace,
             user=self.work_request.created_by,
-            workflow_root=workflow_root,
+            workflow_root=self.work_request.workflow_root,
             expect_type=LookupChildType.ARTIFACT_OR_PROMISE,
         )
 
         artifacts_pending_upload += sorted(
-            (reconstruct_lookup(result, workflow_root=workflow_root), True)
+            (
+                reconstruct_lookup(
+                    result, workflow_root=self.work_request.workflow_root
+                ),
+                True,
+            )
             for result in results
         )
 
@@ -141,19 +143,23 @@ class PackageUploadWorkflow(
 
         self._populate_package_uploads()
 
+    @override
     def build_dynamic_data(
-        self, task_database: TaskDatabaseInterface  # noqa: U100
-    ) -> BaseDynamicTaskData:
+        self,
+        task_database: TaskDatabaseInterface,  # noqa: U100
+    ) -> PackageUploadWorkflowDynamicData:
         """
         Compute dynamic data for this workflow.
 
         :subject: source package names (separated by spaces) of
           ``binary_artifacts`` and ``source_artifact``
         :parameter_summary: package names (same as subject) -> target
+        :source_artifact_id: id of source_artifact or None
+        :binary_artifacts_ids: ids of the binary_artifacts
         """
         binaries = lookup_multiple(
             self.data.binary_artifacts,
-            workflow_root=self.work_request.get_workflow_root(),
+            workflow_root=self.work_request.workflow_root,
             workspace=self.workspace,
             user=self.work_request.created_by,
             expect_type=LookupChildType.ARTIFACT_OR_PROMISE,
@@ -163,20 +169,23 @@ class PackageUploadWorkflow(
             configuration_key="binary_artifacts",
             artifact_expected_categories=(
                 ArtifactCategory.BINARY_PACKAGE,
-                ArtifactCategory.BINARY_PACKAGES,
                 ArtifactCategory.UPLOAD,
             ),
         )
 
+        source_artifact_id = None
         if self.data.source_artifact is not None:
             source_artifact = lookup_single(
                 self.data.source_artifact,
-                workflow_root=self.work_request.get_workflow_root(),
+                workflow_root=self.work_request.workflow_root,
                 workspace=self.workspace,
                 user=self.work_request.created_by,
                 expect_type=LookupChildType.ARTIFACT_OR_PROMISE,
             )
 
+            if source_artifact.artifact is not None:
+                source_artifact_id = source_artifact.artifact.id
+
             source_artifact_names = workflow_utils.get_source_package_names(
                 [source_artifact],
                 configuration_key="source_artifact",
@@ -191,11 +200,45 @@ class PackageUploadWorkflow(
 
         package_names = " ".join(source_package_names)
 
-        return BaseDynamicTaskData(
+        return PackageUploadWorkflowDynamicData(
             subject=package_names,
             parameter_summary=f"{package_names} → {self.data.target}",
+            source_artifact_id=source_artifact_id,
+            binary_artifacts_ids=artifact_ids(binaries),
         )
 
+    @override
+    def get_input_artifacts(self) -> list[InputArtifact]:
+        """Return input artifacts."""
+        artifacts: list[InputArtifact] = []
+
+        if self.data.source_artifact is not None:
+            artifacts.append(
+                InputArtifactSingle(
+                    lookup=self.data.source_artifact,
+                    label="source_artifact",
+                    artifact_id=(
+                        self.dynamic_data.source_artifact_id
+                        if self.dynamic_data is not None
+                        else None
+                    ),
+                )
+            )
+
+        artifacts.append(
+            InputArtifactMultiple(
+                lookup=self.data.binary_artifacts,
+                label="binary_artifacts",
+                artifact_ids=(
+                    self.dynamic_data.binary_artifacts_ids
+                    if self.dynamic_data is not None
+                    else None
+                ),
+            )
+        )
+
+        return artifacts
+
     def _populate_make_source_package_upload(
         self,
         lookup: LookupSingle,
@@ -215,10 +258,9 @@ class PackageUploadWorkflow(
                 target_distribution=target_distribution,
                 since_version=since_version,
                 environment=(
-                    f"{self.data.vendor}/match:"
-                    f"codename={self.data.codename}"
+                    f"{self.data.vendor}/match:codename={self.data.codename}"
                 ),
-                host_architecture=self.data.arch_all_host_architecture,
+                build_architecture=self.data.arch_all_build_architecture,
             ),
             workflow_data=WorkRequestWorkflowData(
                 display_name="Make .changes file",
@@ -266,8 +308,7 @@ class PackageUploadWorkflow(
                 task_data=ExternalDebsignData(unsigned=unsigned_artifact),
                 workflow_data=WorkRequestWorkflowData(
                     display_name=(
-                        "Wait for signature on "
-                        f"upload for {signer_identifier}"
+                        f"Wait for signature on upload for {signer_identifier}"
                     ),
                     step=f"external-debsign-{signer_identifier}",
                     needs_input=True,
@@ -305,7 +346,7 @@ class PackageUploadWorkflow(
                 task_name="mergeuploads",
                 task_data=MergeUploadsData(
                     input=MergeUploadsInput(
-                        uploads=LookupMultiple.parse_obj(
+                        uploads=LookupMultiple.model_validate(
                             [
                                 upload
                                 for upload, _ in self._artifacts_pending_upload
@@ -368,9 +409,7 @@ class PackageUploadWorkflow(
                 task_name="packageupload",
                 task_data=PackageUploadData(
                     input=PackageUploadInput(upload=upload),
-                    target=pydantic.parse_obj_as(
-                        PackageUploadTarget, self.data.target
-                    ),
+                    target=self.data.target,
                     delayed_days=self.data.delayed_days,
                 ),
                 workflow_data=WorkRequestWorkflowData(
