@@ -9,10 +9,18 @@
 
 """qa workflow."""
 
+from typing import override
+
 from django.db.models import Q, QuerySet
 
+from debusine.artifacts import SourcePackage
 from debusine.artifacts.models import TaskTypes
-from debusine.db.models import WorkRequest
+from debusine.client.models import LookupChildType
+from debusine.db.models import Artifact, WorkRequest
+from debusine.server.collections.lookup import (
+    artifact_ids,
+    lookup_multiple,
+)
 from debusine.server.workflows import workflow_utils
 from debusine.server.workflows.models import (
     AutopkgtestWorkflowData,
@@ -22,6 +30,7 @@ from debusine.server.workflows.models import (
     PiupartsWorkflowData,
     QAFailOn,
     QAWorkflowData,
+    QAWorkflowDynamicData,
     ReverseDependenciesAutopkgtestWorkflowData,
     WorkRequestWorkflowData,
 )
@@ -30,37 +39,137 @@ from debusine.server.workflows.regression_tracking import (
 )
 from debusine.tasks.models import (
     BackendType,
-    BaseDynamicTaskData,
+    InputArtifact,
+    InputArtifactMultiple,
+    InputArtifactSingle,
     LintianFailOnSeverity,
     LookupMultiple,
     LookupSingle,
     OutputData,
+    RegressionAnalysis,
     RegressionAnalysisStatus,
 )
 from debusine.tasks.server import TaskDatabaseInterface
 
 
 class QAWorkflow(
-    RegressionTrackingWorkflow[QAWorkflowData, BaseDynamicTaskData]
+    RegressionTrackingWorkflow[QAWorkflowData, QAWorkflowDynamicData]
 ):
     """QA workflow."""
 
     TASK_NAME = "qa"
 
+    @override
     def build_dynamic_data(
-        self, task_database: TaskDatabaseInterface  # noqa: U100
-    ) -> BaseDynamicTaskData:
+        self,
+        task_database: TaskDatabaseInterface,  # noqa: U100
+    ) -> QAWorkflowDynamicData:
         """
         Compute dynamic data for this workflow.
 
         :subject: package name of ``source_artifact``
+        :parameter_summary: package name_version
+        :source_artifact_id: id of the source artifact
+        :binary_artifacts_ids: ids of the binary artifacts or None
+        :reference_source_artifact_id: id of the reference artifact or None
+        :package_build_logs_ids: ids of the package build logs or None
         """
-        source_data = workflow_utils.source_package_data(self)
-        return BaseDynamicTaskData(
-            subject=source_data.name,
-            parameter_summary=f"{source_data.name}_{source_data.version}",
+        source_artifact = workflow_utils.source_package(self)
+        source_data = SourcePackage.create_data(source_artifact.data)
+
+        if self.data.reference_source_artifact is not None:
+            reference_source_artifact = workflow_utils.source_package(
+                self, configuration_key="reference_source_artifact"
+            )
+        else:
+            reference_source_artifact = None
+
+        binary_artifacts_results = lookup_multiple(
+            self.data.binary_artifacts,
+            self.workspace,
+            user=self.work_request.created_by,
+            workflow_root=self.work_request.workflow_root,
+            expect_type=LookupChildType.ARTIFACT_OR_PROMISE,
         )
 
+        if self.data.package_build_logs is not None:
+            build_logs_results = lookup_multiple(
+                self.data.package_build_logs,
+                self.workspace,
+                user=self.work_request.created_by,
+                workflow_root=self.work_request.workflow_root,
+                expect_type=LookupChildType.ARTIFACT_OR_PROMISE,
+            )
+            build_logs_artifacts_ids = artifact_ids(build_logs_results)
+        else:
+            build_logs_artifacts_ids = None
+
+        return QAWorkflowDynamicData(
+            subject=source_data.name,
+            parameter_summary=f"{source_data.name}_{source_data.version}",
+            source_artifact_id=source_artifact.id,
+            binary_artifacts_ids=artifact_ids(binary_artifacts_results),
+            reference_source_artifact_id=(
+                reference_source_artifact.id
+                if reference_source_artifact is not None
+                else None
+            ),
+            package_build_logs_ids=build_logs_artifacts_ids,
+        )
+
+    @override
+    def get_input_artifacts(self) -> list[InputArtifact]:
+        """Return the list of input artifacts."""
+        artifacts: list[InputArtifact] = [
+            InputArtifactSingle(
+                lookup=self.data.source_artifact,
+                label="source_artifact",
+                artifact_id=(
+                    self.dynamic_data.source_artifact_id
+                    if self.dynamic_data is not None
+                    else None
+                ),
+            ),
+            InputArtifactMultiple(
+                lookup=self.data.binary_artifacts,
+                label="binary_artifacts",
+                artifact_ids=(
+                    self.dynamic_data.binary_artifacts_ids
+                    if self.dynamic_data is not None
+                    else None
+                ),
+            ),
+        ]
+
+        if self.data.reference_source_artifact is not None:
+            artifacts.append(
+                InputArtifactSingle(
+                    lookup=self.data.reference_source_artifact,
+                    label="reference_source_artifact",
+                    artifact_id=(
+                        None
+                        if self.dynamic_data is None
+                        else self.dynamic_data.reference_source_artifact_id
+                    ),
+                )
+            )
+
+        if self.data.package_build_logs is not None:
+            artifacts.append(
+                InputArtifactMultiple(
+                    lookup=self.data.package_build_logs,
+                    label="package_build_logs",
+                    artifact_ids=(
+                        None
+                        if self.dynamic_data is None
+                        else self.dynamic_data.package_build_logs_ids
+                    ),
+                )
+            )
+
+        return artifacts
+
+    @override
     def populate(self) -> None:
         """Create work requests."""
         if (data_archs := self.data.architectures) is not None:
@@ -84,7 +193,7 @@ class QAWorkflow(
 
         filtered_binary_artifacts = (
             workflow_utils.filter_artifact_lookup_by_arch(
-                self, self.data.binary_artifacts, architectures
+                self, self.data.binary_artifacts, architectures | {"all"}
             )
         )
 
@@ -184,7 +293,7 @@ class QAWorkflow(
             assert self.data.qa_suite is not None
             self._populate_debdiff(
                 source_artifact=self.data.source_artifact,
-                binary_artifacts=self.data.binary_artifacts,
+                binary_artifacts=filtered_binary_artifacts,
                 vendor=self.data.vendor,
                 codename=self.data.codename,
                 original=self.data.qa_suite,
@@ -529,11 +638,31 @@ class QAWorkflow(
             # workflow as the final callback.
             wr.add_dependency(callback, skip_same_workflow_check=True)
 
+    @staticmethod
+    def _summarize_status(
+        statuses: set[RegressionAnalysisStatus],
+    ) -> RegressionAnalysisStatus:
+        if RegressionAnalysisStatus.REGRESSION in statuses:
+            return RegressionAnalysisStatus.REGRESSION
+        elif RegressionAnalysisStatus.ERROR in statuses:
+            # Prefer REGRESSION if both exist, since it's probably more
+            # informative: ERROR might be a temporary problem with a single
+            # task.
+            return RegressionAnalysisStatus.ERROR
+        elif RegressionAnalysisStatus.IMPROVEMENT in statuses:
+            return RegressionAnalysisStatus.IMPROVEMENT
+        elif RegressionAnalysisStatus.STABLE in statuses:
+            return RegressionAnalysisStatus.STABLE
+        else:
+            return RegressionAnalysisStatus.NO_RESULT
+
     def callback_regression_analysis(self) -> bool:
         """Collate regression analysis results."""
+        assert self.dynamic_data is not None
+
         output_data = self.work_request.output_data or OutputData()
         output_data.regression_analysis = {}
-        overall_result = True
+        statuses: set[RegressionAnalysisStatus] = set()
         for (
             task_name,
             subject,
@@ -549,12 +678,36 @@ class QAWorkflow(
                 assert subject is not None
                 output_data.regression_analysis[
                     f"{task_name}:{subject}:{key}"
-                ] = analysis
-                if analysis["status"] in {
-                    RegressionAnalysisStatus.ERROR,
-                    RegressionAnalysisStatus.REGRESSION,
-                }:
-                    overall_result = False
+                ] = RegressionAnalysis.model_validate(analysis)
+                statuses.add(analysis["status"])
+
+        # Top-level summary.
+        overall_status = self._summarize_status(statuses)
+        output_data.regression_analysis[""] = RegressionAnalysis(
+            original_source_version=(
+                SourcePackage.create_data(
+                    Artifact.objects.get(
+                        id=self.dynamic_data.reference_source_artifact_id
+                    ).data
+                ).version
+                if self.dynamic_data.reference_source_artifact_id is not None
+                else None
+            ),
+            new_source_version=(
+                SourcePackage.create_data(
+                    Artifact.objects.get(
+                        id=self.dynamic_data.source_artifact_id
+                    ).data
+                ).version
+                if self.dynamic_data.source_artifact_id is not None
+                else None
+            ),
+            status=overall_status,
+        )
+
         self.work_request.output_data = output_data
         self.work_request.save()
-        return overall_result
+        return overall_status not in {
+            RegressionAnalysisStatus.REGRESSION,
+            RegressionAnalysisStatus.ERROR,
+        }
