@@ -15,7 +15,7 @@ from collections.abc import Iterable
 from dataclasses import dataclass
 from functools import cached_property, partial
 from itertools import chain
-from typing import Any, Self
+from typing import Any, Self, override
 
 from debian.deb822 import PkgRelation
 from django.contrib.postgres.expressions import ArraySubquery
@@ -30,6 +30,7 @@ from django.db.models import (
 )
 from django.db.models.fields.json import KT
 
+from debusine.artifacts import SourcePackage
 from debusine.artifacts.models import (
     ArtifactCategory,
     DebianBinaryPackage,
@@ -38,11 +39,16 @@ from debusine.artifacts.models import (
 )
 from debusine.client.models import LookupChildType
 from debusine.db.models import Collection, CollectionItem
-from debusine.server.collections.lookup import lookup_multiple, lookup_single
+from debusine.server.collections.lookup import (
+    artifact_ids,
+    lookup_multiple,
+    lookup_single,
+)
 from debusine.server.workflows import workflow_utils
 from debusine.server.workflows.models import (
     AutopkgtestWorkflowData,
     ReverseDependenciesAutopkgtestWorkflowData,
+    ReverseDependenciesAutopkgtestWorkflowDynamicData,
     WorkRequestWorkflowData,
 )
 from debusine.server.workflows.regression_tracking import (
@@ -50,7 +56,9 @@ from debusine.server.workflows.regression_tracking import (
 )
 from debusine.tasks.models import (
     BackendType,
-    BaseDynamicTaskData,
+    InputArtifact,
+    InputArtifactMultiple,
+    InputArtifactSingle,
     LookupMultiple,
     LookupSingle,
 )
@@ -154,13 +162,15 @@ def _lookup_multiple_to_list(
 
 class ReverseDependenciesAutopkgtestWorkflow(
     RegressionTrackingWorkflow[
-        ReverseDependenciesAutopkgtestWorkflowData, BaseDynamicTaskData
+        ReverseDependenciesAutopkgtestWorkflowData,
+        ReverseDependenciesAutopkgtestWorkflowDynamicData,
     ]
 ):
     """Run autopkgtest for all the reverse-deps of a package in a suite."""
 
     TASK_NAME = "reverse_dependencies_autopkgtest"
 
+    @override
     def post_init(self) -> None:
         """Initialize."""
         if self.data.backend == BackendType.AUTO:
@@ -237,9 +247,9 @@ class ReverseDependenciesAutopkgtestWorkflow(
         # See:
         # https://www.postgresql.org/docs/current/functions-matching.html#FUNCTIONS-POSIX-REGEXP
         depends_pattern = (
-            fr"(?:^|\W)"
-            fr"(?:{'|'.join(re.escape(name) for name in binary_names)})"
-            fr"(?:\W|$)"
+            rf"(?:^|\W)"
+            rf"(?:{'|'.join(re.escape(name) for name in binary_names)})"
+            rf"(?:\W|$)"
         )
         depends_pattern_json = json.dumps(depends_pattern)
 
@@ -387,7 +397,7 @@ class ReverseDependenciesAutopkgtestWorkflow(
         """Create an autopkgtest sub-workflow for a single source package."""
         assert self.work_request is not None
 
-        context_lookup = LookupMultiple.parse_obj(
+        context_lookup = LookupMultiple.model_validate(
             _lookup_multiple_to_list(self.data.binary_artifacts)
             + _lookup_multiple_to_list(self.data.context_artifacts)
         )
@@ -401,7 +411,7 @@ class ReverseDependenciesAutopkgtestWorkflow(
                     f"{source.name}_{source.version}|"
                 ),
                 source_artifact=source.to_lookup(),
-                binary_artifacts=LookupMultiple.parse_obj(
+                binary_artifacts=LookupMultiple.model_validate(
                     sorted([binary.to_lookup() for binary in binaries])
                 ),
                 context_artifacts=context_lookup,
@@ -431,22 +441,90 @@ class ReverseDependenciesAutopkgtestWorkflow(
         # results in the internal collection.
         self.orchestrate_child(wr)
 
+    @override
     def populate(self) -> None:
         """Create autopkgtest sub-workflows for all reverse-dependencies."""
         for source, binaries in self.get_reverse_dependencies():
             self._populate_single(source, binaries)
 
+    @override
     def build_dynamic_data(
-        self, task_database: TaskDatabaseInterface  # noqa: U100
-    ) -> BaseDynamicTaskData:
+        self,
+        task_database: TaskDatabaseInterface,  # noqa: U100
+    ) -> ReverseDependenciesAutopkgtestWorkflowDynamicData:
         r"""
         Compute dynamic data for this workflow.
 
         :subject: package name of ``source_artifact``
         :parameter_summary: package name of ``source_artifact``\_"version"
+        :source_artifact_id: id of the ``source_artifact``
+        :binary_artifacts_ids: ids of the ``binary_artifacts``
+        :context_artifacts_ids: ids of the ``context_artifacts``
+        :qa_suite_id: id of the ``qa_suite``
         """
-        source_data = workflow_utils.source_package_data(self)
-        return BaseDynamicTaskData(
+        source_artifact = workflow_utils.source_package(self)
+        source_data = SourcePackage.create_data(source_artifact.data)
+
+        binary_artifacts_result = lookup_multiple(
+            self.data.binary_artifacts,
+            self.workspace,
+            user=self.work_request.created_by,
+            workflow_root=self.work_request.workflow_root,
+            expect_type=LookupChildType.ARTIFACT_OR_PROMISE,
+        )
+        context_artifacts_result = lookup_multiple(
+            self.data.context_artifacts,
+            self.workspace,
+            user=self.work_request.created_by,
+            workflow_root=self.work_request.workflow_root,
+            expect_type=LookupChildType.ARTIFACT_OR_PROMISE,
+        )
+        qa_suite_id = lookup_single(
+            self.data.qa_suite,
+            self.workspace,
+            user=self.work_request.created_by,
+            workflow_root=self.work_request.workflow_root,
+            expect_type=LookupChildType.COLLECTION,
+        ).collection.id
+
+        return ReverseDependenciesAutopkgtestWorkflowDynamicData(
             subject=source_data.name,
             parameter_summary=f"{source_data.name}_{source_data.version}",
+            source_artifact_id=source_artifact.id,
+            binary_artifacts_ids=artifact_ids(binary_artifacts_result),
+            context_artifacts_ids=artifact_ids(context_artifacts_result),
+            qa_suite_id=qa_suite_id,
         )
+
+    @override
+    def get_input_artifacts(self) -> list[InputArtifact]:
+        """Return input artifacts."""
+        return [
+            InputArtifactSingle(
+                lookup=self.data.source_artifact,
+                label="source_artifact",
+                artifact_id=(
+                    self.dynamic_data.source_artifact_id
+                    if self.dynamic_data is not None
+                    else None
+                ),
+            ),
+            InputArtifactMultiple(
+                lookup=self.data.binary_artifacts,
+                label="binary_artifacts",
+                artifact_ids=(
+                    self.dynamic_data.binary_artifacts_ids
+                    if self.dynamic_data is not None
+                    else None
+                ),
+            ),
+            InputArtifactMultiple(
+                lookup=self.data.context_artifacts,
+                label="context_artifacts",
+                artifact_ids=(
+                    self.dynamic_data.context_artifacts_ids
+                    if self.dynamic_data is not None
+                    else None
+                ),
+            ),
+        ]
