@@ -9,14 +9,20 @@
 
 """Unit tests for workflow Celery integration."""
 
+import datetime as dt
 import logging
+from itertools import chain, repeat
 from typing import Any
 from unittest import mock
 
 from django.db import connections, transaction
+from django.utils import timezone
+from django_prometheus.testutils import assert_metric_diff, save_registry
 
 from debusine.db.models import WorkRequest
-from debusine.server.workflows.celery import run_workflow_task
+from debusine.server.workflows.celery import (
+    run_workflow_task,
+)
 from debusine.tasks.models import OutputData, OutputDataError
 from debusine.test.django import TestCase, TransactionTestCase
 
@@ -50,7 +56,7 @@ class RunWorkflowTaskTests(TestCase):
         ):
             result = run_workflow_task.apply(args=(wr.id,))
 
-        self.assertFalse(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.ERROR)
         wr.refresh_from_db()
         self.assertIsNotNone(wr.completed_at)
         self.assertEqual(wr.status, WorkRequest.Statuses.COMPLETED)
@@ -89,7 +95,7 @@ class RunWorkflowTaskTests(TestCase):
         ):
             result = run_workflow_task.apply(args=(wr.id,))
 
-        self.assertFalse(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.ERROR)
         wr.refresh_from_db()
         self.assertIsNotNone(wr.completed_at)
         self.assertEqual(wr.status, WorkRequest.Statuses.COMPLETED)
@@ -121,7 +127,7 @@ class RunWorkflowTaskTests(TestCase):
         ):
             result = run_workflow_task.apply(args=(sub_wr.id,))
 
-        self.assertFalse(result.get())
+        self.assertEqual(result.get(), WorkRequest.Results.ERROR)
         sub_wr.refresh_from_db()
         self.assertIsNotNone(sub_wr.started_at)
         self.assertIsNotNone(sub_wr.completed_at)
@@ -200,6 +206,46 @@ class RunWorkflowTaskTests(TestCase):
         self.assertEqual(wr.status, WorkRequest.Statuses.COMPLETED)
         self.assertEqual(wr.result, WorkRequest.Results.SUCCESS)
 
+    def test_emits_metric(self) -> None:
+        registry = save_registry()
+        wr = self.playground.create_workflow(
+            task_name="noop", mark_running=True
+        )
+        now = timezone.now()
+
+        with (
+            mock.patch(
+                "django.utils.timezone.now",
+                side_effect=chain([now], repeat(now + dt.timedelta(minutes=4))),
+            ),
+            mock.patch("debusine.server.workflows.noop.NoopWorkflow.populate"),
+        ):
+            result = run_workflow_task.apply(args=(wr.id,))
+
+        self.assertTrue(result.get())
+        labels = {"task_name": wr.task_name}
+        assert_metric_diff(
+            registry,
+            0,
+            "debusine_workflow_orchestrator_duration_bucket",
+            **labels,
+            le="60.0",
+        )
+        assert_metric_diff(
+            registry,
+            1,
+            "debusine_workflow_orchestrator_duration_bucket",
+            **labels,
+            le="300.0",
+        )
+        assert_metric_diff(
+            registry,
+            1,
+            "debusine_workflow_orchestrator_duration_bucket",
+            **labels,
+            le="+Inf",
+        )
+
 
 class RunWorkflowTaskTransactionTests(TransactionTestCase):
     """Test transactional behaviour of :py;func:`run_workflow_task`."""
