@@ -432,7 +432,7 @@ class DebDiffWorkflowTests(WorkflowTestBase[DebDiffWorkflow]):
             debdiff_work_requests.filter(
                 workflow_data_json__step__startswith="debdiff-binaries"
             ).count(),
-            3,
+            2,
         )
 
         amd64_work_request = debdiff_work_requests.get(
@@ -593,78 +593,6 @@ class DebDiffWorkflowTests(WorkflowTestBase[DebDiffWorkflow]):
                 "environment": "debian/match:codename=bookworm",
                 "build_architecture": "arm64",
                 "extra_flags": [],
-                "input": {
-                    "binary_artifacts": [
-                        [
-                            f"{bookworm_lookup}/name:hello_1.0.0_all",
-                            f"{bookworm_lookup}/name:hello_1.0.0_amd64",
-                            f"{bookworm_lookup}/name:hello_1.0.0_arm64",
-                        ],
-                        [
-                            self.new_binary_artifact_lookup("all"),
-                        ],
-                    ]
-                },
-            },
-        )
-
-    @preserve_task_registry()
-    def test_populate_origin_binary_artifacts_only_all_arch(self) -> None:
-        # Add coverage for an "all" architecture binary package in the
-        # debian_collection but not in the new artifacts
-        self.debian_collection.manager.add_artifact(
-            self.playground.create_minimal_binary_package_artifact(
-                package="bye", version="1.0.0", architecture="all"
-            ),
-            user=self.playground.get_default_user(),
-            variables={
-                "component": "main",
-                "section": "devel",
-                "priority": "optional",
-            },
-        )
-
-        # Add coverage for a not "all" architecture binary package in the
-        # debian_collection but not in the new artifacts
-        self.debian_collection.manager.add_artifact(
-            self.playground.create_minimal_binary_package_artifact(
-                package="greeting", version="1.0.0", architecture="amd64"
-            ),
-            user=self.playground.get_default_user(),
-            variables={
-                "component": "main",
-                "section": "devel",
-                "priority": "optional",
-            },
-        )
-
-        work_request = self.create_debdiff_workflow(
-            add_origin_binary_artifacts_archs=["all"]
-        )
-
-        debdiff_work_requests = work_request.children.all()
-
-        # Check work requests to compare the binary packages
-        self.assertEqual(
-            debdiff_work_requests.filter(
-                workflow_data_json__step__startswith="debdiff-binaries"
-            ).count(),
-            3,
-        )
-
-        all_work_request = debdiff_work_requests.get(
-            workflow_data_json__step="debdiff-binaries-all"
-        )
-
-        bookworm = Collection.objects.get(name="bookworm")
-        bookworm_lookup = f"{bookworm.name}@{bookworm.category}"
-
-        self.assertEqual(
-            all_work_request.task_data,
-            {
-                "environment": "debian/match:codename=bookworm",
-                "build_architecture": "amd64",
-                "extra_flags": [],
                 "input": {
                     "binary_artifacts": [
                         [
@@ -691,7 +619,7 @@ class DebDiffWorkflowTests(WorkflowTestBase[DebDiffWorkflow]):
             debdiff_work_requests.filter(
                 workflow_data_json__step__startswith="debdiff-binaries"
             ).count(),
-            3,
+            2,
         )
 
         amd64_work_request = debdiff_work_requests.get(
@@ -768,7 +696,7 @@ class DebDiffWorkflowTests(WorkflowTestBase[DebDiffWorkflow]):
             debdiff_work_requests.filter(
                 workflow_data_json__step__startswith="debdiff-binaries"
             ).count(),
-            3,
+            2,
         )
 
         # The version 0.1.0 is not used, only 1.0.0 versions
@@ -801,6 +729,76 @@ class DebDiffWorkflowTests(WorkflowTestBase[DebDiffWorkflow]):
             new_source_artifact, f"{upload_artifact.source.id}@artifacts"
         )
 
+    @preserve_task_registry()
+    def test_populate_one_debdiff_per_concrete_arch_includes_all_binaries(
+        self,
+    ) -> None:
+        work_request = self.create_debdiff_workflow()
+
+        debdiff_work_requests = work_request.children.all()
+
+        expected_archs = {"amd64", "arm64"}
+
+        binary_wrs = debdiff_work_requests.filter(
+            workflow_data_json__step__startswith="debdiff-binaries"
+        )
+
+        # One per expected concrete arch (without "all")
+        steps = binary_wrs.values_list("workflow_data_json__step", flat=True)
+        self.assertCountEqual(
+            steps,
+            {f"debdiff-binaries-{arch}" for arch in expected_archs},
+        )
+
+        bookworm = Collection.objects.get(name="bookworm")
+        bookworm_lookup = f"{bookworm.name}@{bookworm.category}"
+
+        for arch in expected_archs:
+            wr = binary_wrs.get(
+                workflow_data_json__step=f"debdiff-binaries-{arch}"
+            )
+            originals, news = wr.task_data["input"]["binary_artifacts"]
+
+            # Originals: "all" + specific architecture packages
+            self.assertEqual(
+                set(originals),
+                {
+                    f"{bookworm_lookup}/name:hello_1.0.0_all",
+                    f"{bookworm_lookup}/name:hello_1.0.0_{arch}",
+                },
+            )
+
+            # news: "all" + specific architecture packages
+            self.assertEqual(
+                set(news),
+                {
+                    self.new_binary_artifact_lookup("all"),
+                    self.new_binary_artifact_lookup(arch),
+                },
+            )
+
+    @preserve_task_registry()
+    def test_populate_binary_for_all_does_not_include_arch_specific_originals(
+        self,
+    ) -> None:
+        work_request = self.create_debdiff_workflow(
+            add_new_binary_artifacts_archs=["all"],
+        )
+
+        debdiff_work_requests = work_request.children.all()
+        all_work_request = debdiff_work_requests.get(
+            workflow_data_json__step="debdiff-binaries-all"
+        )
+
+        originals, _ = all_work_request.task_data["input"]["binary_artifacts"]
+        debian_collection_lookup = (
+            f"{self.debian_collection.name}@{self.debian_collection.category}"
+        )
+
+        self.assertEqual(
+            originals, [f"{debian_collection_lookup}/name:hello_1.0.0_all"]
+        )
+
     @preserve_task_registry()
     def test_compute_dynamic_data_from_source(self) -> None:
         work_request = self.create_debdiff_workflow()
