@@ -120,6 +120,24 @@ class LintianWorkflowTests(
 
         return self.get_workflow(wr)
 
+    def _expected_task_display_name(
+        self, architecture: str, lintian: WorkRequest
+    ) -> str:
+        """Return the expected display name for a lintian task."""
+        display_name = f"Lintian for {architecture}"
+        output = lintian.task_data["output"]
+
+        binary_all_analysis = output.get("binary_all_analysis", True)
+        source_analysis = output.get("source_analysis", True)
+
+        if architecture != "all" and binary_all_analysis:
+            display_name += "+all"
+
+        if source_analysis:
+            display_name += "+source"
+
+        return display_name
+
     def orchestrate(
         self,
         task_data: LintianWorkflowData,
@@ -549,7 +567,9 @@ class LintianWorkflowTests(
             self.assertEqual(
                 lintian.workflow_data_json,
                 {
-                    "display_name": f"Lintian for {architecture}",
+                    "display_name": self._expected_task_display_name(
+                        architecture, lintian
+                    ),
                     "step": f"lintian-{architecture}",
                 },
             )
@@ -980,7 +1000,9 @@ class LintianWorkflowTests(
             self.assertEqual(
                 lintian.workflow_data_json,
                 {
-                    "display_name": f"Lintian for {architecture}",
+                    "display_name": self._expected_task_display_name(
+                        architecture, lintian
+                    ),
                     "step": f"lintian-{architecture}",
                 },
             )
@@ -1177,7 +1199,9 @@ class LintianWorkflowTests(
                 lintian.workflow_data_json,
                 {
                     "allow_failure": True,
-                    "display_name": f"Lintian for {architecture}",
+                    "display_name": self._expected_task_display_name(
+                        architecture, lintian
+                    ),
                     "step": f"lintian-{architecture}",
                 },
             )
