@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Unit tests for the make_signed_source workflow."""
+
 from collections.abc import Sequence
 from typing import ClassVar
 
@@ -169,13 +170,13 @@ class MakeSignedSourceWorkflowTests(WorkflowTestBase[MakeSignedSourceWorkflow]):
         wr = self.playground.create_workflow(
             task_name="make_signed_source",
             task_data=MakeSignedSourceWorkflowData(
-                binary_artifacts=LookupMultiple.parse_obj(
-                    [binary_artifact.id, upload_artifact.id]
+                binary_artifacts=LookupMultiple(
+                    (binary_artifact.id, upload_artifact.id)
                 ),
                 vendor="debian",
                 codename="trixie",
-                signing_template_artifacts=LookupMultiple.parse_obj(
-                    [signing_artifact.id]
+                signing_template_artifacts=LookupMultiple(
+                    (signing_artifact.id,)
                 ),
                 architectures=["amd64"],
                 purpose=KeyPurpose("uefi"),
@@ -205,11 +206,11 @@ class MakeSignedSourceWorkflowTests(WorkflowTestBase[MakeSignedSourceWorkflow]):
         wr = self.playground.create_workflow(
             task_name="make_signed_source",
             task_data=MakeSignedSourceWorkflowData(
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="trixie",
-                signing_template_artifacts=LookupMultiple.parse_obj(
-                    [signing_artifact.id]
+                signing_template_artifacts=LookupMultiple(
+                    (signing_artifact.id,)
                 ),
                 architectures=["amd64"],
                 purpose=KeyPurpose("uefi"),
@@ -246,13 +247,13 @@ class MakeSignedSourceWorkflowTests(WorkflowTestBase[MakeSignedSourceWorkflow]):
         root = self.orchestrate(
             task_data=MakeSignedSourceWorkflowData(
                 architectures=architectures,
-                binary_artifacts=LookupMultiple.parse_obj(
+                binary_artifacts=LookupMultiple.model_validate(
                     [
                         f"internal@collections/name:build-{arch}"
                         for arch in (*architectures, "arm64")
                     ]
                 ),
-                signing_template_artifacts=LookupMultiple.parse_obj(
+                signing_template_artifacts=LookupMultiple.model_validate(
                     [
                         {
                             "collection": "internal@collections",
@@ -348,7 +349,7 @@ class MakeSignedSourceWorkflowTests(WorkflowTestBase[MakeSignedSourceWorkflow]):
                 ],
             )
 
-            unsigned = LookupMultiple.parse_obj(
+            unsigned = LookupMultiple.model_validate(
                 {
                     "collection": "internal@collections",
                     "child_type": LookupChildType.ARTIFACT,
@@ -358,9 +359,7 @@ class MakeSignedSourceWorkflowTests(WorkflowTestBase[MakeSignedSourceWorkflow]):
                 }
             )
             sign = signs.get(
-                task_data__unsigned=unsigned.dict(exclude_unset=True)[
-                    "__root__"
-                ]
+                task_data__unsigned=unsigned.model_dump(exclude_unset=True)
             )
             self.assertEqual(
                 {
@@ -399,7 +398,7 @@ class MakeSignedSourceWorkflowTests(WorkflowTestBase[MakeSignedSourceWorkflow]):
                 ],
             )
 
-            signed = LookupMultiple.parse_obj(
+            signed = LookupMultiple.model_validate(
                 {
                     "collection": "internal@collections",
                     "child_type": LookupChildType.ARTIFACT,
@@ -409,7 +408,7 @@ class MakeSignedSourceWorkflowTests(WorkflowTestBase[MakeSignedSourceWorkflow]):
                 }
             )
             assemble_signed_source = assemble_signed_sources.get(
-                task_data__signed=signed.dict(exclude_unset=True)["__root__"]
+                task_data__signed=signed.model_dump(exclude_unset=True)
             )
 
             self.assertEqual(
@@ -528,7 +527,7 @@ class MakeSignedSourceWorkflowTests(WorkflowTestBase[MakeSignedSourceWorkflow]):
                 [
                     result.artifact
                     for result in lookup_multiple(
-                        LookupMultiple.parse_obj(
+                        LookupMultiple.model_validate(
                             assemble_signed_source.task_data["signed"]
                         ),
                         assemble_signed_source.workspace,
@@ -604,11 +603,11 @@ class MakeSignedSourceWorkflowTests(WorkflowTestBase[MakeSignedSourceWorkflow]):
 
         root = self.orchestrate(
             task_data=MakeSignedSourceWorkflowData(
-                binary_artifacts=LookupMultiple.parse_obj(
-                    [binary_artifact.id, upload_artifact.id]
+                binary_artifacts=LookupMultiple(
+                    (binary_artifact.id, upload_artifact.id)
                 ),
-                signing_template_artifacts=LookupMultiple.parse_obj(
-                    [signing_artifact.id]
+                signing_template_artifacts=LookupMultiple(
+                    (signing_artifact.id,)
                 ),
                 vendor="debian",
                 codename="bookworm",
