@@ -32,6 +32,7 @@ from debusine.server.workflows.base import orchestrate_workflow
 from debusine.server.workflows.models import (
     BaseWorkflowData,
     ReverseDependenciesAutopkgtestWorkflowData,
+    ReverseDependenciesAutopkgtestWorkflowDynamicData,
     SbuildWorkflowData,
 )
 from debusine.server.workflows.reverse_dependencies_autopkgtest import (
@@ -51,6 +52,8 @@ from debusine.tasks.models import (
     BackendType,
     BaseDynamicTaskData,
     ExtraExternalRepository,
+    InputArtifactMultiple,
+    InputArtifactSingle,
     LookupMultiple,
     LookupSingle,
     SbuildData,
@@ -66,6 +69,7 @@ class ReverseDependenciesAutopkgtestWorkflowTests(
 
     sid: ClassVar[Collection]
     source_artifact: ClassVar[Artifact]
+    binary_artifact: ClassVar[Artifact]
 
     @classmethod
     def setUpTestData(cls) -> None:
@@ -77,28 +81,43 @@ class ReverseDependenciesAutopkgtestWorkflowTests(
         cls.source_artifact = cls.playground.create_source_artifact(
             name="hello"
         )
+        cls.binary_artifact = (
+            cls.playground.create_minimal_binary_package_artifact(
+                srcpkg_name="hello", package="hello"
+            )
+        )
 
     def create_rdep_autopkgtest_workflow(
         self,
         extra_task_data: dict[str, Any] | None = None,
         parent: WorkRequest | None = None,
         validate: bool = True,
+        internal_collection_artifacts: (
+            list[tuple[Artifact, dict[str, Any]]] | None
+        ) = None,
     ) -> ReverseDependenciesAutopkgtestWorkflow:
         """Create a reverse_dependencies_autopkgtest workflow."""
         task_data = {
             "source_artifact": self.source_artifact.pk,
-            "binary_artifacts": ["internal@collections/name:build-amd64"],
+            "binary_artifacts": ("internal@collections/name:build-amd64",),
             "qa_suite": "sid@debian:suite",
             "vendor": "debian",
             "codename": "sid",
         }
         if extra_task_data is not None:
             task_data.update(extra_task_data)
+
+        if internal_collection_artifacts is None:
+            internal_collection_artifacts = [
+                (self.binary_artifact, {"name": "build-amd64"})
+            ]
+
         wr = self.playground.create_workflow(
             task_name="reverse_dependencies_autopkgtest",
             task_data=task_data,
             parent=parent,
             validate=validate,
+            internal_collection_artifacts=internal_collection_artifacts,
         )
         return self.get_workflow(wr)
 
@@ -181,7 +200,7 @@ class ReverseDependenciesAutopkgtestWorkflowTests(
             name="trixie", category=CollectionCategory.SUITE
         )
         source_artifact = self.source_artifact.pk
-        binary_artifacts = ["internal@collections/name:build-arm64"]
+        binary_artifacts = ("internal@collections/name:build-arm64",)
         qa_suite = "trixie@debian:suite"
         vendor = "debian"
         codename = "trixie"
@@ -192,13 +211,15 @@ class ReverseDependenciesAutopkgtestWorkflowTests(
                 "qa_suite": qa_suite,
                 "vendor": vendor,
                 "codename": codename,
-            }
+            },
+            internal_collection_artifacts=[
+                (self.binary_artifact, {"name": "build-arm64"}),
+            ],
         )
 
         self.assertEqual(workflow.data.source_artifact, source_artifact)
         self.assertEqual(
-            workflow.data.binary_artifacts,
-            LookupMultiple.parse_obj(binary_artifacts),
+            workflow.data.binary_artifacts, LookupMultiple(binary_artifacts)
         )
         self.assertEqual(workflow.data.qa_suite, qa_suite)
         self.assertEqual(workflow.data.vendor, vendor)
@@ -235,7 +256,12 @@ class ReverseDependenciesAutopkgtestWorkflowTests(
     def test_get_binary_names_promise(self) -> None:
         """Get binary names from a promise."""
         workflow = self.create_rdep_autopkgtest_workflow()
+
+        # Delete the automatically-added artifact from the collection,
+        # to exercise the promise code
         assert workflow.work_request.internal_collection is not None
+        workflow.work_request.internal_collection.child_artifacts.clear()
+
         self.playground.create_bare_data_item(
             workflow.work_request.internal_collection,
             "build-amd64",
@@ -623,7 +649,7 @@ class ReverseDependenciesAutopkgtestWorkflowTests(
                     task_name="reverse_dependencies_autopkgtest",
                     task_data=ReverseDependenciesAutopkgtestWorkflowData(
                         source_artifact=source_artifact.id,
-                        binary_artifacts=LookupMultiple.parse_obj(
+                        binary_artifacts=LookupMultiple.model_validate(
                             [
                                 f"internal@collections/"
                                 f"name:build-{architecture}"
@@ -689,12 +715,10 @@ class ReverseDependenciesAutopkgtestWorkflowTests(
             architectures,
             extra_data={
                 "extra_repositories": [
-                    ExtraExternalRepository.parse_obj(
-                        {
-                            "url": "http://example.com/",
-                            "suite": "bookworm",
-                            "components": ["main"],
-                        }
+                    ExtraExternalRepository(
+                        url="http://example.com/",
+                        suite="bookworm",
+                        components=["main"],
                     )
                 ]
             },
@@ -763,8 +787,7 @@ class ReverseDependenciesAutopkgtestWorkflowTests(
                             f"sid@{CollectionCategory.SUITE}/name:{source}_all"
                         ],
                         "context_artifacts": [
-                            f"internal@collections/"
-                            f"name:build-{architecture}"
+                            f"internal@collections/name:build-{architecture}"
                             for architecture in ("all", "amd64")
                         ],
                     },
@@ -1102,11 +1125,15 @@ class ReverseDependenciesAutopkgtestWorkflowTests(
         binary_artifact = (
             self.playground.create_minimal_binary_package_artifact()
         )
+        context_artifact = (
+            self.playground.create_minimal_binary_package_artifact()
+        )
         wr = self.playground.create_workflow(
             task_name="reverse_dependencies_autopkgtest",
             task_data=ReverseDependenciesAutopkgtestWorkflowData(
                 source_artifact=source_artifact.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
+                context_artifacts=LookupMultiple((context_artifact.id,)),
                 vendor="debian",
                 codename="trixie",
                 qa_suite="sid@debian:suite",
@@ -1116,7 +1143,76 @@ class ReverseDependenciesAutopkgtestWorkflowTests(
 
         self.assertEqual(
             workflow.compute_dynamic_data(TaskDatabase(wr)),
-            BaseDynamicTaskData(
-                subject="hello", parameter_summary="hello_1.0-1"
+            ReverseDependenciesAutopkgtestWorkflowDynamicData(
+                subject="hello",
+                parameter_summary="hello_1.0-1",
+                source_artifact_id=source_artifact.id,
+                binary_artifacts_ids=[binary_artifact.id],
+                context_artifacts_ids=[context_artifact.id],
+                qa_suite_id=self.sid.id,
             ),
         )
+
+    def test_get_input_artifacts(self) -> None:
+        source_artifact = self.playground.create_source_artifact(
+            name="hello", version="1.0-1"
+        )
+        binary_artifact_1 = (
+            self.playground.create_minimal_binary_package_artifact(
+                package="hello"
+            )
+        )
+        binary_artifact_2 = (
+            self.playground.create_minimal_binary_package_artifact(
+                package="bye"
+            )
+        )
+        context_artifact_1 = (
+            self.playground.create_minimal_binary_package_artifact(
+                package="python3"
+            )
+        )
+        context_artifact_2 = (
+            self.playground.create_minimal_binary_package_artifact(
+                package="python3-django"
+            )
+        )
+        wr = self.playground.create_workflow(
+            task_name="reverse_dependencies_autopkgtest",
+            task_data=ReverseDependenciesAutopkgtestWorkflowData(
+                source_artifact=source_artifact.id,
+                binary_artifacts=LookupMultiple(
+                    (binary_artifact_1.id, binary_artifact_2.id)
+                ),
+                context_artifacts=LookupMultiple(
+                    (context_artifact_1.id, context_artifact_2.id)
+                ),
+                vendor="debian",
+                codename="trixie",
+                qa_suite="sid@debian:suite",
+            ),
+        )
+        workflow = self.get_workflow(wr)
+
+        workflow.dynamic_data = workflow.build_dynamic_data(TaskDatabase(wr))
+
+        self.assertEqual(
+            workflow.get_input_artifacts(),
+            [
+                InputArtifactSingle(
+                    lookup=workflow.data.source_artifact,
+                    label="source_artifact",
+                    artifact_id=source_artifact.id,
+                ),
+                InputArtifactMultiple(
+                    lookup=workflow.data.binary_artifacts,
+                    label="binary_artifacts",
+                    artifact_ids=[binary_artifact_1.id, binary_artifact_2.id],
+                ),
+                InputArtifactMultiple(
+                    lookup=workflow.data.context_artifacts,
+                    label="context_artifacts",
+                    artifact_ids=[context_artifact_1.id, context_artifact_2.id],
+                ),
+            ],
+        )
