@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Unit tests for the base Workflow classes."""
+
 import abc
 from unittest import mock
 
@@ -366,7 +367,7 @@ class WorkflowTests(TestCase):
 
         workflow_root_task.requires_artifact(
             child_requires,
-            LookupMultiple.parse_obj(
+            LookupMultiple.model_validate(
                 {
                     "collection": "internal@collections",
                     "child_type": LookupChildType.BARE,
@@ -490,14 +491,14 @@ class WorkflowTests(TestCase):
             ),
             InputArtifactMultiple(
                 artifact_ids=None,
-                lookup=LookupMultiple.parse_obj(
-                    ["internal@collections/name:buildlog-amd64"]
+                lookup=LookupMultiple(
+                    ("internal@collections/name:buildlog-amd64",)
                 ),
                 label="package_log",
             ),
             InputArtifactMultiple(
                 artifact_ids=[5, 6],
-                lookup=LookupMultiple.parse_obj([5, 6]),
+                lookup=LookupMultiple((5, 6)),
                 label="binary_artifacts",
             ),
         ]
