@@ -8,12 +8,8 @@
 # contained in the LICENSE file.
 
 """Unit tests for the workflow_utils functions."""
-import re
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
+import re
 
 from debusine.artifacts.models import (
     ArtifactCategory,
@@ -103,7 +99,7 @@ class WorkflowUtilsTests(TestCase):
             "lintian",
             LintianWorkflowData(
                 source_artifact=source_package.id,
-                binary_artifacts=LookupMultiple.parse_obj([binary_artifact.id]),
+                binary_artifacts=LookupMultiple((binary_artifact.id,)),
                 vendor="debian",
                 codename="trixie",
             ),
@@ -200,8 +196,10 @@ class WorkflowUtilsTests(TestCase):
         ):
             workflow_utils.lookup_result_artifact_category(result)
 
-    def test_lookup_result_architecture_promise_with_architecture(self) -> None:
-        """lookup_result_architecture with a binary promise."""
+    def test_lookup_result_architectures_promise_with_architecture(
+        self,
+    ) -> None:
+        """lookup_result_architectures with a binary promise."""
         collection = self.playground.create_collection(
             "test", CollectionCategory.TEST
         )
@@ -221,11 +219,11 @@ class WorkflowUtilsTests(TestCase):
         )
 
         self.assertEqual(
-            workflow_utils.lookup_result_architecture(result), "amd64"
+            workflow_utils.lookup_result_architectures(result), {"amd64"}
         )
 
-    def test_lookup_result_architecture_promise_no_architecture(self) -> None:
-        """lookup_result_architecture rejects promise without architecture."""
+    def test_lookup_result_architectures_promise_no_architecture(self) -> None:
+        """lookup_result_architectures rejects promise without architecture."""
         collection = self.playground.create_collection(
             "test", CollectionCategory.TEST
         )
@@ -249,10 +247,10 @@ class WorkflowUtilsTests(TestCase):
                 f"Cannot determine architecture for lookup result: {result}"
             ),
         ):
-            workflow_utils.lookup_result_architecture(result)
+            workflow_utils.lookup_result_architectures(result)
 
-    def test_lookup_result_architecture_binary_packages_artifact(self) -> None:
-        """lookup_result_architecture with a binary-packages artifact."""
+    def test_lookup_result_architectures_binary_packages_artifact(self) -> None:
+        """lookup_result_architectures with a binary-packages artifact."""
         artifact = self.playground.create_minimal_binary_package_artifact(
             architecture="i386",
         )
@@ -261,13 +259,13 @@ class WorkflowUtilsTests(TestCase):
         )
 
         self.assertEqual(
-            workflow_utils.lookup_result_architecture(result), "i386"
+            workflow_utils.lookup_result_architectures(result), {"i386"}
         )
 
-    def test_lookup_result_architecture_binary_packages_artifact_item(
+    def test_lookup_result_architectures_binary_packages_artifact_item(
         self,
     ) -> None:
-        """lookup_result_architecture with a binary-packages artifact item."""
+        """lookup_result_architectures with a binary-packages artifact item."""
         collection = self.playground.create_collection(
             "test", CollectionCategory.TEST
         )
@@ -288,11 +286,11 @@ class WorkflowUtilsTests(TestCase):
         )
 
         self.assertEqual(
-            workflow_utils.lookup_result_architecture(result), "i386"
+            workflow_utils.lookup_result_architectures(result), {"i386"}
         )
 
-    def test_lookup_result_architecture_debian_binary_package(self) -> None:
-        """lookup_result_architecture return arch from a binary package."""
+    def test_lookup_result_architectures_debian_binary_package(self) -> None:
+        """lookup_result_architectures return arch from a binary package."""
         artifact, _ = self.playground.create_artifact(
             category=ArtifactCategory.BINARY_PACKAGE,
             data={
@@ -308,14 +306,14 @@ class WorkflowUtilsTests(TestCase):
         )
 
         self.assertEqual(
-            workflow_utils.lookup_result_architecture(result),
-            "amd64",
+            workflow_utils.lookup_result_architectures(result),
+            {"amd64"},
         )
 
-    def test_lookup_result_architecture_debian_binary_package_item(
+    def test_lookup_result_architectures_debian_binary_package_item(
         self,
     ) -> None:
-        """lookup_result_architecture return arch from a binary package item."""
+        """lookup_result_architectures returns arch from a binpkg item."""
         collection = self.playground.create_collection(
             "test", CollectionCategory.TEST
         )
@@ -342,12 +340,12 @@ class WorkflowUtilsTests(TestCase):
         )
 
         self.assertEqual(
-            workflow_utils.lookup_result_architecture(result),
-            "amd64",
+            workflow_utils.lookup_result_architectures(result),
+            {"amd64"},
         )
 
-    def test_lookup_result_architecture_debian_upload(self) -> None:
-        """lookup_result_architecture return arch from an upload artifact."""
+    def test_lookup_result_architectures_debian_upload(self) -> None:
+        """lookup_result_architectures return arch from an upload artifact."""
         artifact, _ = self.playground.create_artifact(
             category=ArtifactCategory.UPLOAD,
             data={
@@ -364,12 +362,38 @@ class WorkflowUtilsTests(TestCase):
         )
 
         self.assertEqual(
-            workflow_utils.lookup_result_architecture(result),
-            "amd64",
+            workflow_utils.lookup_result_architectures(result),
+            {"amd64"},
         )
 
-    def test_lookup_result_architecture_debian_package_build_log(self) -> None:
-        """lookup_result_architecture return arch from a build log."""
+    def test_lookup_result_architectures_mixed_upload(self) -> None:
+        """lookup_result_architectures return arch from a mixed upload."""
+        artifact, _ = self.playground.create_artifact(
+            category=ArtifactCategory.UPLOAD,
+            data={
+                "type": "dpkg",
+                "changes_fields": {
+                    "Architecture": "amd64 i386 source",
+                    "Files": [
+                        {"name": "test.dsc"},
+                        {"name": "test_amd64.deb"},
+                        {"name": "test_i386.deb"},
+                    ],
+                },
+            },
+        )
+
+        result = LookupResult(
+            result_type=CollectionItem.Types.ARTIFACT, artifact=artifact
+        )
+
+        self.assertEqual(
+            workflow_utils.lookup_result_architectures(result),
+            {"amd64", "i386"},
+        )
+
+    def test_lookup_result_architectures_debian_package_build_log(self) -> None:
+        """lookup_result_architectures return arch from a build log."""
         artifact, _ = self.playground.create_artifact(
             category=ArtifactCategory.PACKAGE_BUILD_LOG,
             data={
@@ -385,12 +409,12 @@ class WorkflowUtilsTests(TestCase):
         )
 
         self.assertEqual(
-            workflow_utils.lookup_result_architecture(result),
-            "amd64",
+            workflow_utils.lookup_result_architectures(result),
+            {"amd64"},
         )
 
-    def test_lookup_result_architecture_debian_upload_item(self) -> None:
-        """lookup_result_architecture return arch from an upload item."""
+    def test_lookup_result_architectures_debian_upload_item(self) -> None:
+        """lookup_result_architectures return arch from an upload item."""
         collection = self.playground.create_collection(
             "test", CollectionCategory.TEST
         )
@@ -418,12 +442,12 @@ class WorkflowUtilsTests(TestCase):
         )
 
         self.assertEqual(
-            workflow_utils.lookup_result_architecture(result),
-            "amd64",
+            workflow_utils.lookup_result_architectures(result),
+            {"amd64"},
         )
 
-    def test_lookup_result_architecture_other_artifacts(self) -> None:
-        """lookup_result_architecture with source package artifact."""
+    def test_lookup_result_architectures_other_artifacts(self) -> None:
+        """lookup_result_architectures with source package artifact."""
         artifact, _ = self.playground.create_artifact(
             category=ArtifactCategory.SOURCE_PACKAGE,
             data={
@@ -440,10 +464,10 @@ class WorkflowUtilsTests(TestCase):
         with self.assertRaisesRegex(
             ValueError, f"Unexpected type: {DebianSourcePackage.__name__}"
         ):
-            workflow_utils.lookup_result_architecture(result)
+            workflow_utils.lookup_result_architectures(result)
 
-    def test_lookup_result_architecture_collection(self) -> None:
-        """lookup_result_architecture with a collection."""
+    def test_lookup_result_architectures_collection(self) -> None:
+        """lookup_result_architectures with a collection."""
         collection = self.playground.create_collection(
             "test", CollectionCategory.TEST
         )
@@ -457,10 +481,10 @@ class WorkflowUtilsTests(TestCase):
                 "Unexpected result: must have collection_item or artifact"
             ),
         ):
-            workflow_utils.lookup_result_architecture(result)
+            workflow_utils.lookup_result_architectures(result)
 
-    def test_lookup_result_architecture_collection_item_invalid(self) -> None:
-        """lookup_result_architecture raise error: invalid architecture type."""
+    def test_lookup_result_architectures_collection_item_invalid(self) -> None:
+        """lookup_result_architectures raises invalid architecture type."""
         collection = self.playground.create_collection(
             "test", CollectionCategory.TEST
         )
@@ -483,14 +507,14 @@ class WorkflowUtilsTests(TestCase):
             ValueError,
             "Cannot determine architecture for lookup result:",
         ):
-            workflow_utils.lookup_result_architecture(result)
+            workflow_utils.lookup_result_architectures(result)
 
-    def test_lookup_result_architecture_unexpected_result(self) -> None:
-        """lookup_result_architecture raise error: unexpected result."""
+    def test_lookup_result_architectures_unexpected_result(self) -> None:
+        """lookup_result_architectures raise error: unexpected result."""
         result = LookupResult(result_type=CollectionItem.Types.BARE)
 
         with self.assertRaisesRegex(ValueError, "^Unexpected result: .*"):
-            workflow_utils.lookup_result_architecture(result)
+            workflow_utils.lookup_result_architectures(result)
 
     def test_lookup_result_binary_package_name_promise_with_bpn(self) -> None:
         """lookup_result_binary_package_name with a binary promise."""
@@ -709,7 +733,7 @@ class WorkflowUtilsTests(TestCase):
         self.assertEqual(
             workflow_utils.filter_artifact_lookup_by_arch(
                 wf,
-                LookupMultiple.parse_obj(
+                LookupMultiple.model_validate(
                     [
                         {
                             "collection": "internal@collections",
@@ -718,17 +742,60 @@ class WorkflowUtilsTests(TestCase):
                         }
                     ]
                 ),
-                ("amd64", "armel", "ppc64el"),
+                {"amd64", "armel", "ppc64el"},
             ),
-            LookupMultiple.parse_obj(
-                [
+            LookupMultiple(
+                (
                     "internal@collections/name:hello-amd64",
                     "internal@collections/name:hello-armel",
+                )
+            ),
+        )
+
+    def test_filter_artifact_lookup_by_arch_with_upload(self) -> None:
+        wf = self.get_noop_workflow(
+            self.playground.create_workflow(task_name="noop")
+        )
+        artifacts = self.playground.create_upload_artifacts()
+        architectures = {"amd64", "all"}
+        self.assertEqual(
+            workflow_utils.filter_artifact_lookup_by_arch(
+                wf,
+                LookupMultiple((f"{artifacts.upload.id}@artifacts",)),
+                architectures,
+            ),
+            LookupMultiple((f"{artifacts.upload.id}@artifacts",)),
+        )
+
+    def test_filter_artifact_lookup_by_arch_with_mixed_upload(self) -> None:
+        wf = self.get_noop_workflow(
+            self.playground.create_workflow(task_name="noop")
+        )
+        artifacts = self.playground.create_upload_artifacts(
+            binaries=[
+                ("hello", "amd64"),
+                ("hello", "i386"),
+                ("hello-doc", "all"),
+            ]
+        )
+        architectures = {"amd64", "all"}
+        self.assertEqual(
+            workflow_utils.filter_artifact_lookup_by_arch(
+                wf,
+                LookupMultiple((f"{artifacts.upload.id}@artifacts",)),
+                architectures,
+            ),
+            LookupMultiple.model_validate(
+                [
+                    f"{artifact.id}@artifacts"
+                    for artifact in artifacts.binaries
+                    if artifact.data["deb_fields"]["Architecture"]
+                    in architectures
                 ]
             ),
         )
 
-    def test_get_architectures(self) -> None:
+    def test_get_lookup_architectures(self) -> None:
         wf = self.get_noop_workflow(
             self.playground.create_workflow(task_name="noop")
         )
@@ -759,9 +826,9 @@ class WorkflowUtilsTests(TestCase):
             user=self.playground.get_default_user(),
         )
         self.assertEqual(
-            workflow_utils.get_architectures(
+            workflow_utils.get_lookup_architectures(
                 wf,
-                LookupMultiple.parse_obj(
+                LookupMultiple.model_validate(
                     [
                         {
                             "collection": "internal@collections",
@@ -774,6 +841,24 @@ class WorkflowUtilsTests(TestCase):
             {"amd64", "i386"},
         )
 
+    def test_get_lookup_architectures_mixed_upload(self) -> None:
+        wf = self.get_noop_workflow(
+            self.playground.create_workflow(task_name="noop")
+        )
+        artifacts = self.playground.create_upload_artifacts(
+            binaries=[
+                ("hello", "amd64"),
+                ("hello", "i386"),
+                ("hello-doc", "all"),
+            ],
+        )
+        self.assertEqual(
+            workflow_utils.get_lookup_architectures(
+                wf, LookupMultiple((f"{artifacts.upload.id}@artifacts",))
+            ),
+            {"amd64", "i386", "all"},
+        )
+
     def test_locate_debian_source_package_with_srcpkg(self) -> None:
         """Test with a debian:source-package."""
         source_artifact = self.playground.create_source_artifact()
@@ -857,7 +942,7 @@ class WorkflowUtilsTests(TestCase):
     def test_locate_debian_binary_packages_with_upload(self) -> None:
         """Test with a debian:upload artifact."""
         upload_artifacts = self.playground.create_upload_artifacts(
-            binaries=["foo", "bar"]
+            binaries=[("foo", "amd64"), ("foo-common", "all")]
         )
         result = workflow_utils.locate_debian_binary_packages(
             "source_artifact", [upload_artifacts.upload]
@@ -1144,10 +1229,7 @@ class WorkflowUtilsTests(TestCase):
                     result,
                     [
                         ExtraExternalRepository(
-                            url=pydantic.parse_obj_as(
-                                pydantic.AnyUrl,
-                                "http://ftp.uk.debian.org/debian",
-                            ),
+                            url="http://ftp.uk.debian.org/debian",
                             suite="experimental",
                             components=["main", "contrib"],
                         ),
@@ -1159,9 +1241,7 @@ class WorkflowUtilsTests(TestCase):
         workflow = self.get_noop_workflow(work_request)
         extra_repositories = [
             ExtraExternalRepository(
-                url=pydantic.parse_obj_as(
-                    pydantic.AnyUrl, "http://deb.debian.org/debian"
-                ),
+                url="http://deb.debian.org/debian",
                 suite="foo-backports",
                 components=["main"],
             ),
