@@ -60,7 +60,7 @@ class Command(DebusineBaseCommand):
                 fingerprint=fingerprint,
                 private_key=ProtectedKeyPKCS11Static.create(
                     pkcs11_uri=pkcs11_uri
-                ).dict(),
+                ).model_dump(),
                 public_key=public_key,
             )
             key.full_clean()
