@@ -14,7 +14,7 @@ from typing import override
 
 from django.db import close_old_connections, transaction
 
-from debusine.artifacts.models import TaskTypes
+from debusine.artifacts.models import TaskTypes, WorkRequestResults
 from debusine.tasks import BaseExternalTask
 from debusine.tasks.models import BaseDynamicTaskData, BaseTaskData
 
@@ -27,7 +27,7 @@ class BaseSigningTask[TD: BaseTaskData, DTD: BaseDynamicTaskData](
     TASK_TYPE = TaskTypes.SIGNING
 
     @override
-    def execute(self) -> bool:
+    def execute(self) -> WorkRequestResults:
         """
         Execute task in a transaction.
 
