@@ -23,7 +23,7 @@ from typing import Any, override
 
 from debusine import utils
 from debusine.artifacts import Upload
-from debusine.artifacts.models import ArtifactCategory
+from debusine.artifacts.models import ArtifactCategory, WorkRequestResults
 from debusine.assets import AssetCategory, KeyPurpose
 from debusine.client.models import (
     AssetPermissionCheckResponse,
@@ -178,7 +178,7 @@ class Debsign(BaseSigningTask[DebsignData, DebsignDynamicData]):
         )
 
     @override
-    def run(self, execute_directory: Path) -> bool:
+    def run(self, execute_directory: Path) -> WorkRequestResults:
         """Sign all the requested files."""
         assert self.work_request_id is not None
         assert self._files is not None
@@ -212,20 +212,23 @@ class Debsign(BaseSigningTask[DebsignData, DebsignDynamicData]):
             else:
                 self._signed_changes_path = signature_path
 
-        return True
+        return WorkRequestResults.SUCCESS
 
     @override
     def upload_artifacts(
-        self, execute_directory: Path, *, execution_success: bool
+        self,
+        execute_directory: Path,
+        *,
+        execution_result: WorkRequestResults,
     ) -> None:
         """Upload artifacts for the task."""
         assert self.dynamic_data is not None
         assert self.work_request_id is not None
         assert self.debusine is not None
         assert self._signed_changes_path is not None
-        # run() always either returns True or raises an exception; in the
+        # run() always either returns SUCCESS or raises an exception; in the
         # latter case we won't get here.
-        assert execution_success
+        assert execution_result == WorkRequestResults.SUCCESS
 
         upload_artifact = Upload.create(changes_file=self._signed_changes_path)
         uploaded_upload_artifact = self.debusine.upload_artifact(
