@@ -10,22 +10,30 @@
 """Signing-side no-operation task."""
 
 from pathlib import Path
+from typing import override
 
+from debusine.artifacts.models import WorkRequestResults
 from debusine.signing.tasks import BaseSigningTask
 from debusine.signing.tasks.models import SigningNoopData
+from debusine.tasks import DefaultDynamicData
 from debusine.tasks.models import BaseDynamicTaskData
 
 
-class SigningNoop(BaseSigningTask[SigningNoopData, BaseDynamicTaskData]):
+class SigningNoop(
+    BaseSigningTask[SigningNoopData, BaseDynamicTaskData],
+    DefaultDynamicData[SigningNoopData],
+):
     """Task that runs on server-side Celery workers and returns a boolean."""
 
     TASK_NAME = "noop"
     TASK_VERSION = 1
 
-    def run(self, execute_directory: Path) -> bool:  # noqa: U100
+    @override
+    def run(self, execute_directory: Path) -> WorkRequestResults:  # noqa: U100
         """Do nothing."""
         return self.data.result
 
+    @override
     def get_label(self) -> str:
         """Return the task label."""
         return "noop"
