@@ -13,13 +13,13 @@ import shutil
 from collections import defaultdict
 from itertools import zip_longest
 from pathlib import Path
-from typing import Any, assert_never
+from typing import Any, assert_never, override
 
 from django.conf import settings
 
 from debusine import utils
 from debusine.artifacts import SigningOutputArtifact
-from debusine.artifacts.models import SigningResult
+from debusine.artifacts.models import SigningResult, WorkRequestResults
 from debusine.assets import AssetCategory, KeyPurpose
 from debusine.client.models import (
     AssetPermissionCheckResponse,
@@ -38,6 +38,7 @@ class Sign(BaseSigningTask[SignData, SignDynamicData]):
 
     TASK_VERSION = 1
 
+    @override
     def __init__(
         self,
         task_data: dict[str, Any],
@@ -51,6 +52,7 @@ class Sign(BaseSigningTask[SignData, SignDynamicData]):
         self._permission_checks: dict[int, AssetPermissionCheckResponse] = {}
         self._results: dict[int, list[SigningResult]] = defaultdict(list)
 
+    @override
     @classmethod
     def analyze_worker(cls) -> dict[str, Any]:
         """Report metadata for this task on this worker."""
@@ -62,6 +64,7 @@ class Sign(BaseSigningTask[SignData, SignDynamicData]):
 
         return metadata
 
+    @override
     def can_run_on(self, worker_metadata: dict[str, Any]) -> bool:
         """Check if the specified worker can run the task."""
         if not super().can_run_on(worker_metadata):
@@ -69,7 +72,7 @@ class Sign(BaseSigningTask[SignData, SignDynamicData]):
 
         # OpenPGP support is implemented in Python and is always available.
         # Other key purposes require external tools.
-        if self.data.purpose != KeyPurpose.OPENPGP:
+        if self.data.purpose != KeyPurpose.OPENPGP_UPLOAD:
             available_key = self.prefix_with_task_name(
                 f"available:{self.data.purpose}"
             )
@@ -78,6 +81,7 @@ class Sign(BaseSigningTask[SignData, SignDynamicData]):
 
         return True
 
+    @override
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> SignDynamicData:
@@ -91,12 +95,14 @@ class Sign(BaseSigningTask[SignData, SignDynamicData]):
             ],
         )
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of input artifact IDs used by this task."""
         if not self.dynamic_data:
             return []
         return self.dynamic_data.unsigned_ids
 
+    @override
     def fetch_input(self, destination: Path) -> bool:
         """Fetch artifacts and database objects needed by the task."""
         assert self.debusine is not None
@@ -155,20 +161,24 @@ class Sign(BaseSigningTask[SignData, SignDynamicData]):
 
         return True
 
+    @override
     def configure_for_execution(
-        self, download_directory: Path  # noqa: U100
+        self,
+        download_directory: Path,  # noqa: U100
     ) -> bool:
         """Configure task variables."""
         # Nothing to do here; fetch_input does it all.
         return True
 
+    @override
     def prepare_to_run(
         self, download_directory: Path, execute_directory: Path
     ) -> None:
         """Copy downloaded files into the execution directory."""
         shutil.copytree(download_directory, execute_directory / "input")
 
-    def run(self, execute_directory: Path) -> bool:
+    @override
+    def run(self, execute_directory: Path) -> WorkRequestResults:
         """Sign all the requested files."""
         assert self.work_request_id is not None
         assert self._files is not None
@@ -201,8 +211,13 @@ class Sign(BaseSigningTask[SignData, SignDynamicData]):
                     match self.data.purpose:
                         case KeyPurpose.UEFI:
                             mode = SigningMode.DETACHED
-                        case KeyPurpose.OPENPGP:
+                        case KeyPurpose.OPENPGP_UPLOAD:
                             mode = SigningMode.CLEAR
+                        case KeyPurpose.OPENPGP_REPOSITORY:  # pragma: no cover
+                            raise AssertionError(
+                                f"Sign task does not support "
+                                f"{KeyPurpose.OPENPGP_REPOSITORY} keys"
+                            )
                         case _ as unreachable:
                             assert_never(unreachable)
                     permission_check = self._permission_checks[unsigned_id]
@@ -231,10 +246,16 @@ class Sign(BaseSigningTask[SignData, SignDynamicData]):
                             )
                         )
 
-        return signed_any and not failed
+        if signed_any and not failed:
+            return WorkRequestResults.SUCCESS
+        return WorkRequestResults.FAILURE
 
+    @override
     def upload_artifacts(
-        self, execute_directory: Path, *, execution_success: bool  # noqa: U100
+        self,
+        execute_directory: Path,
+        *,
+        execution_result: WorkRequestResults,  # noqa: U100
     ) -> None:
         """Upload artifacts for the task."""
         assert self.dynamic_data is not None
@@ -269,6 +290,7 @@ class Sign(BaseSigningTask[SignData, SignDynamicData]):
                 RelationType.RELATES_TO,
             )
 
+    @override
     def get_label(self) -> str:
         """Return the task label."""
         return f"sign data for {self.data.purpose}"
