@@ -14,7 +14,11 @@ from pathlib import Path
 from typing import Any, override
 
 from debusine.artifacts import RepositoryIndex
-from debusine.artifacts.models import ArtifactCategory, CollectionCategory
+from debusine.artifacts.models import (
+    ArtifactCategory,
+    CollectionCategory,
+    WorkRequestResults,
+)
 from debusine.assets import AssetCategory, KeyPurpose
 from debusine.client.models import AssetPermissionCheckResponse, RelationType
 from debusine.signing.db.models import Key, sign
@@ -185,7 +189,7 @@ class SignRepositoryIndex(
         shutil.copytree(download_directory, execute_directory / "input")
 
     @override
-    def run(self, execute_directory: Path) -> bool:
+    def run(self, execute_directory: Path) -> WorkRequestResults:
         """Sign the requested file."""
         assert self.work_request_id is not None
         assert self._file_path is not None
@@ -213,20 +217,23 @@ class SignRepositoryIndex(
             else:
                 self._signed_path = signed_path
 
-        return True
+        return WorkRequestResults.SUCCESS
 
     @override
     def upload_artifacts(
-        self, execute_directory: Path, *, execution_success: bool
+        self,
+        execute_directory: Path,
+        *,
+        execution_result: WorkRequestResults,
     ) -> None:
         """Upload artifacts for the task."""
         assert self.dynamic_data is not None
         assert self.work_request_id is not None
         assert self.debusine is not None
         assert self._signed_path is not None
-        # run() always either returns True or raises an exception; in the
+        # run() always either returns SUCCESS or raises an exception; in the
         # latter case we won't get here.
-        assert execution_success
+        assert execution_result == WorkRequestResults.SUCCESS
 
         content_type: str | None
         match self.data.mode:
