@@ -31,6 +31,7 @@ from debusine.artifacts.models import (
     ArtifactCategory,
     DebianUpload,
     EmptyArtifactData,
+    WorkRequestResults,
 )
 from debusine.assets.models import AssetCategory
 from debusine.client.models import (
@@ -57,20 +58,20 @@ class DebsignTests(SignTestMixin, TestCase, DjangoTestCase):
     def test_analyze_worker(self) -> None:
         """Test the analyze_worker() method."""
         self.mock_is_command_available({"debsign": True})
-        task = Debsign(task_data={"unsigned": 2, "key": 1})
+        task = Debsign(task_data={"unsigned": 2, "key": "ABC123"})
         metadata = task.analyze_worker()
         self.assertEqual(metadata["signing:debsign:available"], True)
 
     def test_analyze_worker_debsign_not_available(self) -> None:
         """analyze_worker() handles debsign not being available."""
         self.mock_is_command_available({"debsign": False})
-        task = Debsign(task_data={"unsigned": 2, "key": 1})
+        task = Debsign(task_data={"unsigned": 2, "key": "ABC123"})
         metadata = task.analyze_worker()
         self.assertEqual(metadata["signing:debsign:available"], False)
 
     def test_can_run_on(self) -> None:
         """can_run_on returns True if debsign is available."""
-        task = Debsign(task_data={"unsigned": 2, "key": 1})
+        task = Debsign(task_data={"unsigned": 2, "key": "ABC123"})
         self.assertTrue(
             task.can_run_on(
                 {
@@ -83,7 +84,7 @@ class DebsignTests(SignTestMixin, TestCase, DjangoTestCase):
 
     def test_can_run_on_mismatched_task_version(self) -> None:
         """can_run_on returns False for mismatched task versions."""
-        task = Debsign(task_data={"unsigned": 2, "key": 1})
+        task = Debsign(task_data={"unsigned": 2, "key": "ABC123"})
         self.assertFalse(
             task.can_run_on(
                 {
@@ -96,7 +97,7 @@ class DebsignTests(SignTestMixin, TestCase, DjangoTestCase):
 
     def test_can_run_on_missing_tool(self) -> None:
         """can_run_on returns False if debsign is not available."""
-        task = Debsign(task_data={"unsigned": 2, "key": 1})
+        task = Debsign(task_data={"unsigned": 2, "key": "ABC123"})
         self.assertFalse(
             task.can_run_on(
                 {
@@ -325,7 +326,9 @@ class DebsignTests(SignTestMixin, TestCase, DjangoTestCase):
         task.prepare_to_run(download_directory, execute_directory)
 
         with mock.patch("debusine.signing.tasks.debsign.sign") as mock_sign:
-            self.assertTrue(task.run(execute_directory))
+            self.assertEqual(
+                task.run(execute_directory), WorkRequestResults.SUCCESS
+            )
 
         self.assertEqual(
             task._signed_changes_path,
@@ -386,7 +389,7 @@ class DebsignIntegrationTests(SignTestMixin, TestCase, TransactionTestCase):
         }
 
         def download_artifact(
-            artifact_id: int, destination: Path, **kwargs: Any  # noqa: U100
+            artifact_id: int, destination: Path, **kwargs: Any
         ) -> ArtifactResponse:
             assert artifact_id == upload_id
             shutil.copy(dsc_path, destination)
@@ -438,7 +441,7 @@ class DebsignIntegrationTests(SignTestMixin, TestCase, TransactionTestCase):
         with override_settings(
             DEBUSINE_SIGNING_PRIVATE_KEYS=[service_private_key]
         ):
-            self.assertTrue(task.execute())
+            self.assertEqual(task.execute(), WorkRequestResults.SUCCESS)
 
         debusine_mock.asset_permission_check.assert_called_once_with(
             asset_category=AssetCategory.SIGNING_KEY,
@@ -507,7 +510,7 @@ class DebsignIntegrationTests(SignTestMixin, TestCase, TransactionTestCase):
         upload_response = self.make_artifact_response(upload, upload_id)
 
         def download_artifact(
-            artifact_id: int, destination: Path, **kwargs: Any  # noqa: U100
+            artifact_id: int, destination: Path, **kwargs: Any
         ) -> ArtifactResponse:
             assert artifact_id == upload_id
             shutil.copy(dsc_path, destination)
@@ -535,7 +538,7 @@ class DebsignIntegrationTests(SignTestMixin, TestCase, TransactionTestCase):
             "debusine.signing.tasks.debsign.sign",
             side_effect=Exception("Signing failed"),
         ):
-            self.assertFalse(task.execute())
+            self.assertEqual(task.execute(), WorkRequestResults.FAILURE)
 
         # Only a debug logs artifact was uploaded, not any signing output
         debusine_mock.upload_artifact.assert_called_once_with(
@@ -565,5 +568,5 @@ class DebsignIntegrationTests(SignTestMixin, TestCase, TransactionTestCase):
 
     def test_label(self) -> None:
         """Test get_label."""
-        task = Debsign(task_data={"unsigned": 2, "key": 1})
+        task = Debsign(task_data={"unsigned": 2, "key": "ABC123"})
         self.assertEqual(task.get_label(), "sign upload")
