@@ -24,19 +24,21 @@ class SignDataTests(TestCase):
         """``purpose=KeyPurpose.UEFI`` is accepted."""
         data = SignData(
             purpose=KeyPurpose.UEFI,
-            unsigned=LookupMultiple.parse_obj([1]),
+            unsigned=LookupMultiple((1,)),
             key="ABC123",
         )
-        self.assertEqual(data.dict()["purpose"], KeyPurpose.UEFI)
+        self.assertEqual(data.model_dump()["purpose"], KeyPurpose.UEFI)
 
     def test_purpose_openpgp_upload(self) -> None:
         """``purpose=KeyPurpose.OPENPGP_UPLOAD`` is accepted."""
         data = SignData(
             purpose=KeyPurpose.OPENPGP_UPLOAD,
-            unsigned=LookupMultiple.parse_obj([1]),
+            unsigned=LookupMultiple((1,)),
             key="ABC123",
         )
-        self.assertEqual(data.dict()["purpose"], KeyPurpose.OPENPGP_UPLOAD)
+        self.assertEqual(
+            data.model_dump()["purpose"], KeyPurpose.OPENPGP_UPLOAD
+        )
 
     def test_purpose_openpgp_repository(self) -> None:
         """``purpose=KeyPurpose.OPENPGP_REPOSITORY`` is rejected."""
@@ -47,7 +49,7 @@ class SignDataTests(TestCase):
         ):
             SignData(
                 purpose=KeyPurpose.OPENPGP_REPOSITORY,
-                unsigned=LookupMultiple.parse_obj([1]),
+                unsigned=LookupMultiple((1,)),
                 key="ABC123",
             )
 
@@ -63,7 +65,7 @@ class SignRepositoryIndexDataTests(TestCase):
             mode=SigningMode.DETACHED,
             signed_name="Release.gpg",
         )
-        self.assertEqual(data.dict()["mode"], SigningMode.DETACHED)
+        self.assertEqual(data.model_dump()["mode"], SigningMode.DETACHED)
 
     def test_mode_clear(self) -> None:
         """``mode=SigningMode.CLEAR`` is accepted."""
@@ -73,7 +75,7 @@ class SignRepositoryIndexDataTests(TestCase):
             mode=SigningMode.CLEAR,
             signed_name="InRelease",
         )
-        self.assertEqual(data.dict()["mode"], SigningMode.CLEAR)
+        self.assertEqual(data.model_dump()["mode"], SigningMode.CLEAR)
 
     def test_mode_not_detached_or_clear(self) -> None:
         """``mode`` must be either ``DETACHED`` or ``CLEAR``."""
@@ -91,8 +93,7 @@ class SignRepositoryIndexDataTests(TestCase):
     def test_signed_name_not_single_path_segment(self) -> None:
         """``signed_name`` must be a single path segment."""
         with self.assertRaisesRegex(
-            ValueError,
-            "Signed name must be a single path segment; got '../naughty'",
+            ValueError, "String should match pattern.*input_value='../naughty'"
         ):
             SignRepositoryIndexData(
                 suite_collection=1,
