@@ -30,6 +30,7 @@ from debusine.artifacts.models import (
     ArtifactCategory,
     CollectionCategory,
     EmptyArtifactData,
+    WorkRequestResults,
 )
 from debusine.assets.models import AssetCategory
 from debusine.client.models import (
@@ -120,9 +121,9 @@ class SignRepositoryIndexTests(SignTestMixin, TestCase, DjangoTestCase):
         )
         with self.assertRaisesRegex(
             TaskConfigError,
-            fr"^suite_collection: unexpected collection category: "
-            fr"'{CollectionCategory.TEST}'\. "
-            fr"Expected: '{CollectionCategory.SUITE}'$",
+            rf"^suite_collection: unexpected collection category: "
+            rf"'{CollectionCategory.TEST}'\. "
+            rf"Expected: '{CollectionCategory.SUITE}'$",
         ):
             task.compute_dynamic_data(task_db)
 
@@ -495,7 +496,9 @@ class SignRepositoryIndexTests(SignTestMixin, TestCase, DjangoTestCase):
         with mock.patch(
             "debusine.signing.tasks.sign_repository_index.sign"
         ) as mock_sign:
-            self.assertTrue(task.run(execute_directory))
+            self.assertEqual(
+                task.run(execute_directory), WorkRequestResults.SUCCESS
+            )
 
         self.assertEqual(
             task._signed_path, execute_directory / "output" / "InRelease"
@@ -559,7 +562,7 @@ class SignRepositoryIndexIntegrationTests(
         }
 
         def download_artifact(
-            artifact_id: int, destination: Path, **kwargs: Any  # noqa: U100
+            artifact_id: int, destination: Path, **kwargs: Any
         ) -> ArtifactResponse:
             assert artifact_id == unsigned_id
             shutil.copy(release_path, destination)
@@ -618,7 +621,7 @@ class SignRepositoryIndexIntegrationTests(
         with override_settings(
             DEBUSINE_SIGNING_PRIVATE_KEYS=[service_private_key]
         ):
-            self.assertTrue(task.execute())
+            self.assertEqual(task.execute(), WorkRequestResults.SUCCESS)
 
         self.assertEqual(
             debusine_mock.asset_permission_check.call_count, len(keys)
@@ -709,7 +712,7 @@ class SignRepositoryIndexIntegrationTests(
         }
 
         def download_artifact(
-            artifact_id: int, destination: Path, **kwargs: Any  # noqa: U100
+            artifact_id: int, destination: Path, **kwargs: Any
         ) -> ArtifactResponse:
             assert artifact_id == unsigned_id
             shutil.copy(release_path, destination)
@@ -768,7 +771,7 @@ class SignRepositoryIndexIntegrationTests(
         with override_settings(
             DEBUSINE_SIGNING_PRIVATE_KEYS=[service_private_key]
         ):
-            self.assertTrue(task.execute())
+            self.assertEqual(task.execute(), WorkRequestResults.SUCCESS)
 
         self.assertEqual(
             debusine_mock.asset_permission_check.call_count, len(keys)
@@ -848,7 +851,7 @@ class SignRepositoryIndexIntegrationTests(
         unsigned_response = self.make_artifact_response(unsigned, unsigned_id)
 
         def download_artifact(
-            artifact_id: int, destination: Path, **kwargs: Any  # noqa: U100
+            artifact_id: int, destination: Path, **kwargs: Any
         ) -> ArtifactResponse:
             assert artifact_id == unsigned_id
             shutil.copy(release_path, destination)
@@ -878,7 +881,7 @@ class SignRepositoryIndexIntegrationTests(
             "debusine.signing.tasks.sign_repository_index.sign",
             side_effect=Exception("Signing failed"),
         ):
-            self.assertFalse(task.execute())
+            self.assertEqual(task.execute(), WorkRequestResults.FAILURE)
 
         # Only a debug logs artifact was uploaded, not any signing output
         debusine_mock.upload_artifact.assert_called_once_with(
