@@ -21,6 +21,7 @@ name of the class must be unique among all child classes.
 A child class must, at the very least, override the :py:meth:`BaseTask.execute`
 method.
 """
+
 import datetime as dt
 import inspect
 import logging
@@ -34,25 +35,27 @@ from abc import ABCMeta, abstractmethod
 from collections import defaultdict
 from collections.abc import Collection, Generator
 from contextlib import contextmanager
+from functools import cache
 from pathlib import Path
 from typing import (
     Any,
     AnyStr,
     BinaryIO,
     ClassVar,
-    Generic,
     IO,
     Literal,
     Self,
     TYPE_CHECKING,
     TextIO,
-    TypeVar,
     Union,
+    assert_never,
     overload,
+    override,
 )
 
 if TYPE_CHECKING:
     from _typeshed import OpenBinaryModeWriting, OpenTextModeWriting
+
     from debusine.db.models import WorkRequest
 
 from debian.debian_support import Version
@@ -62,6 +65,7 @@ from debusine.artifacts.models import (
     ArtifactCategory,
     CollectionCategory,
     TaskTypes,
+    WorkRequestResults,
 )
 from debusine.client.debusine import Debusine
 from debusine.client.models import ArtifactResponse, RelationType
@@ -76,10 +80,14 @@ from debusine.tasks.models import (
     BackendType,
     BaseDynamicTaskData,
     BaseDynamicTaskDataWithExecutor,
+    BaseDynamicTaskDataWithExtraRepositories,
     BaseTaskData,
     BaseTaskDataWithExecutor,
     BaseTaskDataWithExtraRepositories,
     EventReaction,
+    ExtraDebusineRepository,
+    ExtraExternalRepository,
+    ExtraRepository,
     LookupSingle,
     WorkerType,
     build_key_value_lookup_segment,
@@ -94,6 +102,7 @@ from debusine.utils import extract_generic_type_arguments
 class TaskConfigError(Exception):
     """Exception raised when there is an issue with a task configuration."""
 
+    @override
     def __init__(
         self, message: str | None, original_exception: Exception | None = None
     ):
@@ -133,11 +142,7 @@ class TaskConfigError(Exception):
             return str(self.args[0])
 
 
-TD = TypeVar("TD", bound=BaseTaskData)
-DTD = TypeVar("DTD", bound=BaseDynamicTaskData)
-
-
-class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
+class BaseTask[TD: BaseTaskData, DTD: BaseDynamicTaskData](metaclass=ABCMeta):
     """
     Base class for tasks.
 
@@ -243,16 +248,15 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
 
         self.work_request_id: int | None = None
 
-        # Workspace is used when uploading artifacts.
-        # If it's None: the artifacts are created in the default workspace.
+        # Workspace is used when downloading and uploading artifacts.
         # When the worker instantiates the task it should set
         # self.workspace_name (see issue #186).
         self.workspace_name: str | None = None
 
-        # The worker's host architecture.  If set, this is used as a
+        # The worker's native architecture.  If set, this is used as a
         # fallback for tasks that do not specify their own host
         # architecture.
-        self.worker_host_architecture: str | None = None
+        self.worker_native_architecture: str | None = None
 
         # fetch_input() add the downloaded artifacts. Used by
         # `BaseTask._upload_work_request_debug_logs()` and maybe by
@@ -262,8 +266,8 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
         # extract IDs from dynamic_data for use by UI views
         self._source_artifacts_ids: list[int] = []
 
-        self._debug_log_files_directory: None | (
-            tempfile.TemporaryDirectory[str]
+        self._debug_log_files_directory: (
+            None | (tempfile.TemporaryDirectory[str])
         ) = None
 
     def set_work_request(self, work_request: "WorkRequest") -> None:
@@ -280,7 +284,7 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
         new_task = self.__class__(task_data, dynamic_task_data)
         new_task.work_request_id = self.work_request_id
         new_task.workspace_name = self.workspace_name
-        new_task.worker_host_architecture = self.worker_host_architecture
+        new_task.worker_native_architecture = self.worker_native_architecture
         return new_task
 
     def append_to_log_file(self, filename: str, lines: list[str]) -> None:
@@ -423,18 +427,18 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
 
         return metadata
 
-    def host_architecture(self) -> str | None:
+    def build_architecture(self) -> str | None:
         """
-        Return host_architecture.
+        Return the architecture to run this task on.
 
-        Tasks where host_architecture is not determined by
-        self.data.host_architecture should re-implement this method.
+        Tasks where build_architecture is not determined by
+        self.data.build_architecture should re-implement this method.
         """
-        task_architecture = getattr(self.data, "host_architecture", None)
+        task_architecture = getattr(self.data, "build_architecture", None)
         if task_architecture is not None:
             assert isinstance(task_architecture, str)
             return task_architecture
-        return self.worker_host_architecture
+        return self.worker_native_architecture
 
     def can_run_on(self, worker_metadata: dict[str, Any]) -> bool:
         """
@@ -478,8 +482,8 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
         if worker_metadata.get(version_key_name) != self.TASK_VERSION:
             return False
 
-        # Some tasks might not have "host_architecture"
-        task_architecture = self.host_architecture()
+        # Some tasks might not have "build_architecture"
+        task_architecture = self.build_architecture()
 
         if (
             task_architecture is not None
@@ -499,9 +503,7 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
         :returns: the newly created dynamic task data
         """
 
-    def compute_dynamic_data(
-        self, task_database: TaskDatabaseInterface  # noqa: U100
-    ) -> DTD:
+    def compute_dynamic_data(self, task_database: TaskDatabaseInterface) -> DTD:
         """
         Compute dynamic data for this task.
 
@@ -535,15 +537,15 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
         except ValueError as exc:
             raise TaskConfigError(None, original_exception=exc)
 
-    def execute_logging_exceptions(self) -> bool:
+    def execute_logging_exceptions(self) -> WorkRequestResults:
         """Execute self.execute() logging any raised exceptions."""
         try:
             return self.execute()
         except Exception as exc:
-            self.logger.exception("Exception in Task %s", self.name)
+            self.logger.info("Exception in Task %s", self.name, exc_info=True)
             raise exc
 
-    def execute(self) -> bool:
+    def execute(self) -> WorkRequestResults:
         """
         Call the _execute() method, upload debug artifacts.
 
@@ -558,7 +560,7 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
         return result
 
     @abstractmethod
-    def _execute(self) -> bool:
+    def _execute(self) -> WorkRequestResults:
         """
         Execute the requested task.
 
@@ -570,8 +572,8 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
         the parameters of the task let you anticipate that it has no chance of
         completing successfully.
 
-        :return: True to indicate success, False for a failure.
-        :rtype: bool.
+        :return: SUCCESS to indicate success, FAILURE for a failure, ERROR for
+            an internal error, SKIPPED if the task turned out to be a noop.
         :raises TaskConfigError: if the parameters of the work request are
             incompatible with the worker.
         """
@@ -675,7 +677,7 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
 
     def get_event_reactions(
         self,
-        event_name: Literal[  # noqa: U100
+        event_name: Literal[
             "on_creation",
             "on_unblock",
             "on_assignment",
@@ -695,7 +697,9 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
         return event_reactions
 
 
-class BaseExternalTask(BaseTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta):
+class BaseExternalTask[TD: BaseTaskData, DTD: BaseDynamicTaskData](
+    BaseTask[TD, DTD], metaclass=ABCMeta
+):
     r"""
     A :py:class:`BaseTask` that runs on an external worker.
 
@@ -743,7 +747,7 @@ class BaseExternalTask(BaseTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta):
 
     @staticmethod
     @contextmanager
-    def _temporary_directory() -> Generator[Path, None, None]:
+    def _temporary_directory() -> Generator[Path]:
         with tempfile.TemporaryDirectory(
             prefix="debusine-fetch-exec-upload-"
         ) as directory:
@@ -774,13 +778,19 @@ class BaseExternalTask(BaseTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta):
         if not self.debusine:
             raise AssertionError("self.debusine not set")
 
+        if not self.workspace_name:  # Required for cross-scope artifacts
+            raise AssertionError("self.workspace_name not set")
+
         artifact_response = self.debusine.download_artifact(
-            artifact_id, destination, tarball=False
+            artifact_id,
+            destination,
+            tarball=False,
+            workspace=self.workspace_name,
         )
         self._source_artifacts_ids.append(artifact_id)
         return artifact_response
 
-    def fetch_input(self, destination: Path) -> bool:  # noqa: U100
+    def fetch_input(self, destination: Path) -> bool:  # noqa: ARG002, U100
         """
         Download artifacts needed by the task, update self.source_artifacts_ids.
 
@@ -793,7 +803,8 @@ class BaseExternalTask(BaseTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta):
         return True
 
     def configure_for_execution(
-        self, download_directory: Path  # noqa: U100
+        self,
+        download_directory: Path,  # noqa: ARG002, U100
     ) -> bool:
         """
         Configure task: set variables needed for the self._cmdline().
@@ -803,23 +814,32 @@ class BaseExternalTask(BaseTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta):
         return True
 
     def prepare_to_run(
-        self, download_directory: Path, execute_directory: Path  # noqa: U100
+        self,
+        download_directory: Path,  # noqa: ARG002, U100
+        execute_directory: Path,  # noqa: ARG002, U100
     ) -> None:
         """Prepare the execution environment to do the main work of the task."""
         # Do nothing by default.
 
     @abstractmethod
-    def run(self, execute_directory: Path) -> bool:  # noqa: U100
+    def run(
+        self,
+        execute_directory: Path,  # noqa: ARG002, U100
+    ) -> WorkRequestResults:
         """Do the main work of the task."""
 
     def check_directory_for_consistency_errors(
-        self, build_directory: Path  # noqa: U100
+        self,
+        build_directory: Path,  # noqa: ARG002, U100
     ) -> list[str]:
         """Return list of errors after doing the main work of the task."""
         return []
 
     def upload_artifacts(
-        self, execute_directory: Path, *, execution_success: bool  # noqa: U100
+        self,
+        execute_directory: Path,
+        *,
+        execution_result: WorkRequestResults,  # noqa: U100
     ) -> None:
         """Upload the artifacts for the task."""
         # Do nothing by default.
@@ -828,7 +848,8 @@ class BaseExternalTask(BaseTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta):
         """Clean up after running the task."""
         # Do nothing by default.
 
-    def _execute(self) -> bool:  # noqa: C901
+    @override
+    def _execute(self) -> WorkRequestResults:  # noqa: C901
         """
         Fetch the required input, execute the command and upload artifacts.
 
@@ -843,8 +864,7 @@ class BaseExternalTask(BaseTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta):
         - Call ``self.check_directory_for_consistency_errors()``. If any
           errors are returned save them into consistency.log.
         - Call ``self.upload_artifacts(exec_dir, execution_success=succeeded)``.
-        - Return ``execution_succeeded`` (the Worker will set the result as
-          "Success" or "Failure")
+        - Return ``execution_result``  (the Worker will set the result)
         """
         with (
             self._temporary_directory() as execute_directory,
@@ -858,25 +878,25 @@ class BaseExternalTask(BaseTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta):
                     "Work request %s: %s", self.work_request_id, message
                 )
                 print(
-                    f"{dt.datetime.now(dt.timezone.utc).isoformat()} {message}",
+                    f"{dt.datetime.now(dt.UTC).isoformat()} {message}",
                     file=stages_log,
                 )
 
             try:
                 log_stage("Fetching input")
                 if not self.fetch_input(download_directory):
-                    return False
+                    return WorkRequestResults.FAILURE
             except Exception as exc:
                 self._log_exception(exc, stage="fetch_input")
-                return False
+                return WorkRequestResults.FAILURE
 
             try:
                 log_stage("Configuring for execution")
                 if not self.configure_for_execution(download_directory):
-                    return False
+                    return WorkRequestResults.FAILURE
             except Exception as exc:
                 self._log_exception(exc, stage="configure_for_execution")
-                return False
+                return WorkRequestResults.FAILURE
 
             try:
                 try:
@@ -885,10 +905,10 @@ class BaseExternalTask(BaseTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta):
 
                     log_stage("Running")
 
-                    execution_succeeded = self.run(execute_directory)
+                    execution_result = self.run(execute_directory)
                 except Exception as exc:
                     self._log_exception(exc, stage="execution")
-                    return False
+                    return WorkRequestResults.FAILURE
 
                 try:
                     log_stage("Checking output")
@@ -898,30 +918,30 @@ class BaseExternalTask(BaseTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta):
                         self.append_to_log_file(
                             "consistency.log", sorted(errors)
                         )
-                        return False
+                        return WorkRequestResults.FAILURE
 
                     log_stage("Uploading artifacts")
                     self.upload_artifacts(
-                        execute_directory, execution_success=execution_succeeded
+                        execute_directory, execution_result=execution_result
                     )
                 except Exception as exc:
                     self._log_exception(exc, stage="post_execution")
-                    return False
+                    return WorkRequestResults.FAILURE
             finally:
                 try:
                     log_stage("Cleaning up")
                     self.cleanup()
                 except Exception as exc:
                     self._log_exception(exc, stage="post_execution")
-                    return False
+                    execution_result = WorkRequestResults.FAILURE
 
-        if execution_succeeded:
+        if execution_result == WorkRequestResults.SUCCESS:
             # We mainly care about stages.log for failures.  It's rather
             # boring for successes.
             assert self._debug_log_files_directory is not None
             (Path(self._debug_log_files_directory.name) / "stages.log").unlink()
 
-        return execution_succeeded
+        return execution_result
 
     def _upload_work_request_debug_logs(self) -> None:
         """
@@ -976,7 +996,7 @@ def get_environment(
     :param task_database: the :py:class:`TaskDatabaseInterface` used to
       perform the lookup
     :param lookup: the base lookup provided by the task data
-    :param architecture: the task's host architecture, if available
+    :param architecture: the task's build architecture, if available
     :param backend: the task's backend, or None if the environment lookup
       does not need to be constrained to a particular backend
     :param default_category: the default category to use for the first
@@ -1058,12 +1078,11 @@ def get_environment(
     )
 
 
-TDE = TypeVar("TDE", bound=BaseTaskDataWithExecutor)
-DTDE = TypeVar("DTDE", bound=BaseDynamicTaskDataWithExecutor)
-
-
 # TODO: This should be an ABC.
-class BaseTaskWithExecutor(BaseExternalTask[TDE, DTDE], Generic[TDE, DTDE]):
+class BaseTaskWithExecutor[
+    TDE: BaseTaskDataWithExecutor,
+    DTDE: BaseDynamicTaskDataWithExecutor,
+](BaseExternalTask[TDE, DTDE]):
     r"""
     Base for tasks with executor capabilities.
 
@@ -1108,7 +1127,7 @@ class BaseTaskWithExecutor(BaseExternalTask[TDE, DTDE], Generic[TDE, DTDE]):
         return get_environment(
             task_database=task_database,
             lookup=lookup,
-            architecture=self.host_architecture(),
+            architecture=self.build_architecture(),
             backend=self.backend if set_backend else None,
             default_category=default_category,
             image_category=image_category,
@@ -1127,8 +1146,11 @@ class BaseTaskWithExecutor(BaseExternalTask[TDE, DTDE], Generic[TDE, DTDE]):
         assert self.debusine
         assert self.dynamic_data
         assert self.dynamic_data.environment_id
+        assert self.workspace_name
         self.executor = executor_class(self.backend)(
-            self.debusine, self.dynamic_data.environment_id
+            self.debusine,
+            self.dynamic_data.environment_id,
+            workspace=self.workspace_name,
         )
         self.executor.download_image()
 
@@ -1235,8 +1257,8 @@ class BaseTaskWithExecutor(BaseExternalTask[TDE, DTDE], Generic[TDE, DTDE]):
             self.executor_instance.stop()
 
 
-class RunCommandTask(
-    BaseExternalTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta
+class RunCommandTask[TD: BaseTaskData, DTD: BaseDynamicTaskData](
+    BaseExternalTask[TD, DTD], metaclass=ABCMeta
 ):
     r"""
     A :py:class:`BaseTask` that can execute commands and upload artifacts.
@@ -1244,8 +1266,8 @@ class RunCommandTask(
     Concrete subclasses must implement:
 
     * ``_cmdline(self) -> list[str]``
-    * ``task_succeeded(self, returncode: Optional[int], execute_directory: Path)
-      -> bool`` (defaults to True)
+    * ``task_result(self, returncode: Optional[int], execute_directory: Path)
+      -> WorkRequestResults`` (defaults to SUCCESS)
 
     They must also implement ``configure_for_execution()``,
     ``fetch_input()``, ``check_directory_for_consistency_errors()``, and
@@ -1276,7 +1298,8 @@ class RunCommandTask(
     CMD_LOG_SEPARATOR = "--------------------"
     CMD_LOG_FILENAME = "cmd-output.log"
 
-    def run(self, execute_directory: Path) -> bool:
+    @override
+    def run(self, execute_directory: Path) -> WorkRequestResults:
         """
         Run a single command via the executor.
 
@@ -1299,13 +1322,13 @@ class RunCommandTask(
 
         self.logger.info("%s exited with code %s", cmd[0], returncode)
 
-        return self.task_succeeded(returncode, execute_directory)
+        return self.task_result(returncode, execute_directory)
 
-    def task_succeeded(
+    def task_result(
         self,
-        returncode: int | None,  # noqa: U100
-        execute_directory: Path,  # noqa: U100
-    ) -> bool:
+        returncode: int | None,
+        execute_directory: Path,  # noqa: ARG002, U100
+    ) -> WorkRequestResults:
         """
         Sub-tasks can evaluate if the task was a success or failure.
 
@@ -1313,9 +1336,11 @@ class RunCommandTask(
 
         :param returncode: return code of the command, or None if aborted
         :param execute_directory: directory with the output of the task
-        :return: True (if success) or False (if failure).
+        :return: WorkRequestResults.
         """
-        return returncode == 0
+        if returncode == 0:
+            return WorkRequestResults.SUCCESS
+        return WorkRequestResults.FAILURE
 
     @abstractmethod
     def _cmdline(self) -> list[str]:
@@ -1564,12 +1589,10 @@ class RunCommandTask(
             pass
 
 
-TDER = TypeVar("TDER", bound=BaseTaskDataWithExtraRepositories)
-
-
-class ExtraRepositoryMixin(
-    BaseExternalTask[TDER, DTD], Generic[TDER, DTD], metaclass=ABCMeta
-):
+class ExtraRepositoryMixin[
+    TDER: BaseTaskDataWithExtraRepositories,
+    DTDER: BaseDynamicTaskDataWithExtraRepositories,
+](BaseExternalTask[TDER, DTDER], metaclass=ABCMeta):
     """Methods for configuring external APT repositories."""
 
     data: TDER
@@ -1588,19 +1611,69 @@ class ExtraRepositoryMixin(
         self.extra_repository_lists = []
         self.extra_repository_keys = []
 
-    def supports_deb822_sources(self, codename: str) -> bool:
-        """Determine if codename supports deb822 sources."""
-        return codename not in ("jessie", "trusty")
+    @cache
+    def _get_archive_fqdn(self, task_database: TaskDatabaseInterface) -> str:
+        """Return the primary Debusine archive FQDN."""
+        return task_database.get_server_setting(
+            "DEBUSINE_DEBIAN_ARCHIVE_PRIMARY_FQDN"
+        )
+
+    def _resolve_extra_repository(
+        self,
+        task_database: TaskDatabaseInterface,
+        extra_repository: ExtraRepository,
+    ) -> ExtraExternalRepository:
+        """Resolve a single extra repository into the external form."""
+        match extra_repository:
+            case ExtraDebusineRepository():
+                suite = task_database.lookup_single_collection(
+                    extra_repository.suite
+                )
+                components = extra_repository.components
+                if components is None:
+                    if "components" not in suite.data:
+                        raise TaskConfigError(
+                            f"'components' not set for {extra_repository.suite}"
+                        )
+                    components = suite.data["components"]
+                return ExtraExternalRepository(
+                    # Ideally we'd use HTTPS, but that might require
+                    # certificate setup within environments, and we know that
+                    # our own repositories are signed, so HTTP should be good
+                    # enough to use from workers for now.
+                    url=(
+                        f"http://{self._get_archive_fqdn(task_database)}"
+                        f"/{suite.scope_name}/{suite.workspace_name}"
+                    ),
+                    suite=suite.name,
+                    components=components,
+                    signing_key=task_database.export_suite_signing_keys(
+                        suite.id
+                    ),
+                )
+            case ExtraExternalRepository():
+                return extra_repository
+            case _ as unreachable:
+                assert_never(unreachable)
+
+    def resolve_extra_repositories(
+        self, task_database: TaskDatabaseInterface
+    ) -> list[ExtraExternalRepository] | None:
+        """Resolve Debusine repositories so that the worker can handle them."""
+        if self.data.extra_repositories is None:
+            return None
+        return [
+            self._resolve_extra_repository(task_database, extra_repository)
+            for extra_repository in self.data.extra_repositories
+        ]
 
     def supports_inline_signed_by(self, codename: str) -> bool:
         """Determine if codename supports inline signatures."""
         # apt < 2.3.10 has no support for keys inline in Signed-By
         return codename not in (
-            "jessie",
             "stretch",
             "buster",
             "bullseye",
-            "trusty",
             "xenial",
             "bionic",
             "focal",
@@ -1615,12 +1688,15 @@ class ExtraRepositoryMixin(
         ``extra_repository_keys`` will be populated with keys to install
         into /etc/apt/keyrings, if needed.
 
-        If deb822 sources files are supported, ``extra_repository_sources``
-        will be populated with them; otherwise, ``extra_repository_lists``
-        will be populated with one-line sources.
+        ``extra_repository_sources`` will be populated with deb822 sources
+        files.
         """
+        assert self.dynamic_data is not None
+
         inline_signed_by = self.supports_inline_signed_by(codename)
-        for i, extra_repo in enumerate(self.data.extra_repositories or []):
+        for i, extra_repo in enumerate(
+            self.dynamic_data.extra_repositories or []
+        ):
             signed_by = None
             if not inline_signed_by:
                 if extra_repo.signing_key:
@@ -1629,44 +1705,27 @@ class ExtraRepositoryMixin(
                     self.extra_repository_keys.append(path)
                     signed_by = f"/etc/apt/keyrings/{path.name}"
 
-            # apt < 1.1 has no support for deb822 sources
-            if self.supports_deb822_sources(codename):
-                path = destination / f"extra_repository_{i}.sources"
-                path.write_text(
-                    extra_repo.as_deb822_source(signed_by_filename=signed_by)
-                )
-                self.extra_repository_sources.append(path)
-            else:
-                path = destination / f"extra_repository_{i}.list"
-                path.write_text(
-                    extra_repo.as_oneline_source(signed_by_filename=signed_by)
-                    + "\n"
-                )
-                self.extra_repository_lists.append(path)
-
-    def iter_oneline_sources(self) -> Generator[str]:
-        """
-        Generate apt one-line sources.list entries.
-
-        Use this for releases that don't supports_deb822_sources.
-        """
-        for i, extra_repository in enumerate(
-            self.data.extra_repositories or []
-        ):
-            yield extra_repository.as_oneline_source(
-                signed_by_filename=f"/etc/apt/keyrings/extra_apt_key_{i}.asc"
+            path = destination / f"extra_repository_{i}.sources"
+            path.write_text(
+                extra_repo.as_deb822_source(signed_by_filename=signed_by)
             )
+            self.extra_repository_sources.append(path)
 
 
-class DefaultDynamicData(BaseTask[TD, BaseDynamicTaskData], metaclass=ABCMeta):
+class DefaultDynamicData[TD: BaseTaskData](
+    BaseTask[TD, BaseDynamicTaskData], metaclass=ABCMeta
+):
     """Base class for tasks that do not add to dynamic task data."""
 
+    @override
     def build_dynamic_data(
-        self, task_database: TaskDatabaseInterface  # noqa: U100
+        self,
+        task_database: TaskDatabaseInterface,  # noqa: U100
     ) -> BaseDynamicTaskData:
         """Return default dynamic data."""
         return BaseDynamicTaskData()
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of source artifact IDs used by this task."""
         return []
