@@ -17,7 +17,7 @@ import subprocess
 import tempfile
 from collections.abc import Generator
 from pathlib import Path, PurePath
-from typing import Any
+from typing import Any, override
 
 from debian.changelog import Changelog
 from debian.deb822 import Changes
@@ -32,6 +32,7 @@ from debusine.artifacts.models import (
     ArtifactCategory,
     CollectionCategory,
     DebianBinaryPackage,
+    WorkRequestResults,
     get_architectures,
     get_binary_package_name,
     get_binary_package_version,
@@ -63,6 +64,7 @@ class AssembleSignedSource(
 
     TASK_VERSION = 1
 
+    @override
     def __init__(
         self,
         task_data: dict[str, Any],
@@ -83,10 +85,12 @@ class AssembleSignedSource(
         self._source_package_artifact: SourcePackage | None = None
         self._upload_artifact: Upload | None = None
 
+    @override
     def _cmdline(self) -> list[str]:
         """Unused abstract method from RunCommandTask."""
         raise NotImplementedError()
 
+    @override
     def can_run_on(self, worker_metadata: dict[str, Any]) -> bool:
         """Check if the specified worker can run the task."""
         if not super().can_run_on(worker_metadata):
@@ -95,6 +99,7 @@ class AssembleSignedSource(
         executor_available_key = f"executor:{self.backend}:available"
         return bool(worker_metadata.get(executor_available_key, False))
 
+    @override
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> AssembleSignedSourceDynamicData:
@@ -133,6 +138,7 @@ class AssembleSignedSource(
             f"({package_architectures})",
         )
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of input artifact IDs used by this task."""
         if not self.dynamic_data:
@@ -173,6 +179,7 @@ class AssembleSignedSource(
                 if artifact.category == target_category:
                     yield relation.target
 
+    @override
     def fetch_input(self, destination: Path) -> bool:
         """Download the required artifacts."""
         assert self.dynamic_data
@@ -231,8 +238,10 @@ class AssembleSignedSource(
 
         return True
 
+    @override
     def configure_for_execution(
-        self, download_directory: Path  # noqa: U100
+        self,
+        download_directory: Path,  # noqa: U100
     ) -> bool:
         """Configure task: ensure that the executor has dpkg-dev installed."""
         self._prepare_executor_instance()
@@ -444,7 +453,8 @@ class AssembleSignedSource(
         )
         self._upload_artifact = Upload.create(changes_file=local_changes_path)
 
-    def run(self, execute_directory: Path) -> bool:
+    @override
+    def run(self, execute_directory: Path) -> WorkRequestResults:
         """Do the main assembly work."""
         assert self._template_deb_name is not None
         assert self._template_deb_file is not None
@@ -477,16 +487,20 @@ class AssembleSignedSource(
         changes_path = self._build_source_package(local_source_path)
         self._create_artifacts(changes_path)
 
-        return True
+        return WorkRequestResults.SUCCESS
 
+    @override
     def upload_artifacts(
-        self, execute_directory: Path, *, execution_success: bool  # noqa: U100
+        self,
+        execute_directory: Path,
+        *,
+        execution_result: WorkRequestResults,
     ) -> None:
         """Upload artifacts for the task."""
         assert self.work_request_id is not None
         assert self.debusine is not None
 
-        if execution_success:
+        if execution_result == WorkRequestResults.SUCCESS:
             assert self._built_using_ids is not None
             assert self._source_package_artifact is not None
             assert self._upload_artifact is not None
@@ -513,6 +527,7 @@ class AssembleSignedSource(
                 RelationType.EXTENDS,
             )
 
+    @override
     def cleanup(self) -> None:
         """Clean up after running the task."""
         if self._local_execute_directory is not None:
