@@ -30,6 +30,7 @@ from debusine.artifacts.models import (
     DebianSystemImage,
     DebianSystemTarball,
     DebianUpload,
+    WorkRequestResults,
     get_source_package_name,
     get_source_package_version,
 )
@@ -416,9 +417,9 @@ class Autopkgtest(
         return True
 
     @override
-    def task_succeeded(
+    def task_result(
         self, returncode: int | None, execute_directory: Path
-    ) -> bool:
+    ) -> WorkRequestResults:
         """
         Parse the summary file and return success.
 
@@ -436,29 +437,36 @@ class Autopkgtest(
                 or (result.status == "FLAKY" and fail_on.flaky_test)
                 or (result.status == "SKIP" and fail_on.skipped_test)
             ):
-                return False
+                return WorkRequestResults.FAILURE
 
         if returncode == 4 and not fail_on.failed_test:
-            return True
+            return WorkRequestResults.SUCCESS
 
         if returncode == 2 and fail_on.flaky_test:
-            return False
+            return WorkRequestResults.FAILURE
 
         if returncode == 8 and fail_on.skipped_test:
-            return False
+            return WorkRequestResults.FAILURE
+
+        if returncode == 8 and all(
+            result.status == "SKIP" for result in self._parsed.values()
+        ):
+            return WorkRequestResults.SKIPPED
 
         # Return True if autopkgtest has run successfully.
         # 0 all tests passed
         # 2 at least one test was skipped (or at least one flaky test failed)
         # 8 no tests in this package, or all non-superficial tests were skipped
-        return returncode in {0, 2, 8}
+        if returncode in {0, 2, 8}:
+            return WorkRequestResults.SUCCESS
+        return WorkRequestResults.FAILURE
 
     @override
     def upload_artifacts(
         self,
         execute_directory: Path,
         *,
-        execution_success: bool,  # noqa: U100
+        execution_result: WorkRequestResults,  # noqa: U100
     ) -> None:
         """Upload AutopkgtestArtifact with the files, data and relationships."""
         if not self.debusine:
