@@ -10,7 +10,7 @@
 """Task to use blhc in debusine."""
 
 from pathlib import Path
-from typing import Any
+from typing import Any, override
 
 from debian.debian_support import Version
 
@@ -20,6 +20,7 @@ from debusine.artifacts.models import (
     ArtifactCategory,
     CollectionCategory,
     DebianPackageBuildLog,
+    WorkRequestResults,
     get_architectures,
     get_source_package_name,
     get_source_package_version,
@@ -40,6 +41,7 @@ class Blhc(
 
     CAPTURE_OUTPUT_FILENAME = "blhc.txt"
 
+    @override
     def __init__(
         self,
         task_data: dict[str, Any],
@@ -51,6 +53,7 @@ class Blhc(
         # list of build logs to be checked
         self._blhc_target: Path | None = None
 
+    @override
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> BlhcDynamicData:
@@ -83,7 +86,7 @@ class Blhc(
             input_artifact_id=input_artifact.id,
             # We don't need the dose-distcheck analysis, and it's
             # potentially complex.
-            input_artifact_data=input_artifact.data.copy(
+            input_artifact_data=input_artifact.data.model_copy(
                 update={"bd_uninstallable": None}
             ),
             subject=package_name,
@@ -91,6 +94,7 @@ class Blhc(
             f"({architectures})",
         )
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of input artifact IDs used by this task."""
         if not self.dynamic_data:
@@ -112,6 +116,7 @@ class Blhc(
             "0.07+20170817+gita232d32"
         )
 
+    @override
     def _cmdline(self) -> list[str]:
         """
         Build the blhc command line.
@@ -131,6 +136,7 @@ class Blhc(
 
         return cmd
 
+    @override
     def fetch_input(self, destination: Path) -> bool:
         """Download the required artifacts."""
         assert self.dynamic_data
@@ -139,6 +145,7 @@ class Blhc(
 
         return True
 
+    @override
     def configure_for_execution(self, download_directory: Path) -> bool:
         """
         Find .build files in the input artifacts.
@@ -168,10 +175,7 @@ class Blhc(
             list_of_files = sorted(map(str, download_directory.iterdir()))
             self.append_to_log_file(
                 "configure_for_execution.log",
-                [
-                    f"No *.build files to be analyzed. "
-                    f"Files: {list_of_files}"
-                ],
+                [f"No *.build files to be analyzed. Files: {list_of_files}"],
             )
             return False
 
@@ -179,8 +183,12 @@ class Blhc(
 
         return True
 
+    @override
     def upload_artifacts(
-        self, exec_directory: Path, *, execution_success: bool  # noqa: U100
+        self,
+        exec_directory: Path,
+        *,
+        execution_result: WorkRequestResults,  # noqa: U100
     ) -> None:
         """Upload the BlhcArtifact with the files and relationships."""
         assert self.dynamic_data
@@ -205,15 +213,18 @@ class Blhc(
                 uploaded.id, source_artifact_id, RelationType.RELATES_TO
             )
 
-    def task_succeeded(
-        self, returncode: int | None, execute_directory: Path  # noqa: U100
-    ) -> bool:
+    @override
+    def task_result(
+        self,
+        returncode: int | None,
+        execute_directory: Path,  # noqa: U100
+    ) -> WorkRequestResults:
         """
         Evaluate task output and return success.
 
         We don't actually check the output, but use the return code of
         blhc.
-
-        :return: True for success, False failure.
         """
-        return returncode in [0, 1]
+        if returncode in [0, 1]:
+            return WorkRequestResults.SUCCESS
+        return WorkRequestResults.FAILURE
