@@ -1,4 +1,4 @@
-# Copyright 2023 The Debusine Developers
+# Copyright © The Debusine Developers
 # See the AUTHORS file at the top-level directory of this distribution
 #
 # This file is part of Debusine. It is subject to the license terms
@@ -16,8 +16,10 @@ Provides containment for tasks using a variety of backends.
 from debusine.tasks.executors.base import (
     ExecutorImageCategory,
     ExecutorInterface,
+    ExecutorStatistics,
     InstanceInterface,
     analyze_worker_all_executors,
+    executor_backends,
     executor_class,
 )
 from debusine.tasks.executors.incus import (
@@ -31,6 +33,7 @@ from debusine.tasks.executors.unshare import UnshareExecutor, UnshareInstance
 __all__ = [
     "ExecutorImageCategory",
     "ExecutorInterface",
+    "ExecutorStatistics",
     "IncusInstance",
     "IncusLXCExecutor",
     "IncusVMExecutor",
@@ -39,5 +42,6 @@ __all__ = [
     "UnshareExecutor",
     "UnshareInstance",
     "analyze_worker_all_executors",
+    "executor_backends",
     "executor_class",
 ]
