@@ -96,7 +96,9 @@ class ExecutorInterface(ABC):
         _backends[backend_name] = cls
 
     @abstractmethod
-    def __init__(self, debusine_api: Debusine, system_image_id: int) -> None:
+    def __init__(
+        self, debusine_api: Debusine, system_image_id: int, workspace: str
+    ) -> None:
         """
         Instantiate an ExecutorInterface.
 
