@@ -9,8 +9,8 @@
 
 """Image handling for executor backends."""
 
+import datetime as dt
 import logging
-from datetime import datetime, timezone
 from pathlib import Path
 from shutil import rmtree
 
@@ -19,12 +19,18 @@ from fasteners import InterProcessLock  # type: ignore
 from debusine.client.debusine import Debusine
 from debusine.client.models import ArtifactResponse
 from debusine.tasks.executors.base import ExecutorImageCategory, _backends
-from debusine.tasks.models import ImageCacheUsageLog, ImageCacheUsageLogEntry
+from debusine.tasks.models import (
+    BackendType,
+    ImageCacheUsageLog,
+    ImageCacheUsageLogEntry,
+)
 
 CACHE_SIZE = 10
 USAGE_LOG = "usage.json"
 
 log = logging.getLogger(__name__)
+# Alias datetime.now to make it easier to mock
+now = dt.datetime.now
 
 
 class ImageCache:
@@ -36,11 +42,15 @@ class ImageCache:
 
     image_cache_path: Path = Path.home() / "system-images"
     image_category: ExecutorImageCategory
-    backend: str | None = None
+    backend: BackendType | None = None
+    workspace: str
 
     def __init__(
-        self, debusine_api: Debusine, image_category: ExecutorImageCategory
-    ):
+        self,
+        debusine_api: Debusine,
+        image_category: ExecutorImageCategory,
+        workspace: str,
+    ) -> None:
         """
         Instantiate an ImageCache.
 
@@ -49,13 +59,17 @@ class ImageCache:
         """
         self.debusine_api = debusine_api
         self.image_category = image_category
+        self.workspace = workspace
 
     def cache_artifact_path(self, artifact_id: int) -> Path:
         """Return the path to the image cache pool for artifact_id."""
         return self.image_cache_path / str(artifact_id)
 
     def cache_artifact_image_path(
-        self, artifact_id: int, filename: str, backend: str | None = None
+        self,
+        artifact_id: int,
+        filename: str,
+        backend: BackendType | None = None,
     ) -> Path:
         """Return the path to the cached image for filename, for backend."""
         cache_path = self.cache_artifact_path(artifact_id)
@@ -65,7 +79,9 @@ class ImageCache:
 
     def image_artifact(self, artifact_id: int) -> ArtifactResponse:
         """Retrieve an Artifact."""
-        r = self.debusine_api.artifact_get(artifact_id)
+        r = self.debusine_api.artifact_get(
+            artifact_id, workspace=self.workspace
+        )
         if r.category != self.image_category.value:
             raise ValueError(
                 f"Unexpected artifact type {r.category}; expected "
@@ -103,7 +119,10 @@ class ImageCache:
         temp_path = destination.parent / (".download.tmp." + destination.name)
         temp_path.unlink(missing_ok=True)
         self.debusine_api.download_artifact_file(
-            artifact_id, path_in_artifact=filename, destination=temp_path
+            artifact_id,
+            path_in_artifact=filename,
+            destination=temp_path,
+            workspace=self.workspace,
         )
         temp_path.rename(destination)
 
@@ -144,7 +163,7 @@ class ImageCache:
         record_file = self.cache_artifact_image_path(artifact.id, USAGE_LOG)
         if record_file.exists():
             with record_file.open("r") as f:
-                record = ImageCacheUsageLog.parse_raw(f.read())
+                record = ImageCacheUsageLog.model_validate_json(f.read())
         else:
             record = ImageCacheUsageLog()
 
@@ -156,7 +175,7 @@ class ImageCache:
             ImageCacheUsageLogEntry(
                 filename=artifact.data["filename"],
                 backend=self.backend,
-                timestamp=datetime.now(timezone.utc),
+                timestamp=now(dt.UTC),
             )
         )
 
@@ -164,7 +183,7 @@ class ImageCache:
             artifact.id, f".tmp.{USAGE_LOG}"
         )
         with tmp_file.open("w") as f:
-            f.write(record.json())
+            f.write(record.model_dump_json())
         tmp_file.replace(record_file)
 
     def clean_up_old_images(self) -> None:
@@ -193,14 +212,14 @@ class ImageCache:
                         )
                 rmtree(self.cache_artifact_path(artifact_id))
 
-    def _find_least_used_images(self) -> list[tuple[int, set[str]]]:
+    def _find_least_used_images(self) -> list[tuple[int, set[BackendType]]]:
         """
         Find the least recently used images in the cache.
 
         Return a list of (artifact_id, [backends]) tuples.
         """
-        last_used: dict[int, datetime] = {}
-        backends: dict[int, set[str]] = {}
+        last_used: dict[int, dt.datetime] = {}
+        backends: dict[int, set[BackendType]] = {}
         unknown: list[int] = []
 
         for path in self.image_cache_path.iterdir():
@@ -215,7 +234,9 @@ class ImageCache:
                     continue
                 try:
                     with record_file.open("r") as f:
-                        record = ImageCacheUsageLog.parse_raw(f.read())
+                        record = ImageCacheUsageLog.model_validate_json(
+                            f.read()
+                        )
                 except Exception:
                     log.warning(
                         "Failed to parse log for artifact %i", artifact_id
