@@ -182,10 +182,10 @@ class ImageCacheTests(ImageCacheTest):
         """Test that _download_image_artifact does a 2-stage download."""
 
         def download_tarball(
-            artifact_id: int,  # noqa: U100
-            path_in_artifact: str,  # noqa: U100
+            artifact_id: int,  # noqa: ARG001, U100
+            path_in_artifact: str,  # noqa: ARG001, U100
             destination: Path,
-            workspace: str,  # noqa: U100
+            workspace: str,  # noqa: ARG001, U100
         ) -> None:
             destination.write_bytes(b"downloaded!")
 
@@ -212,7 +212,7 @@ class ImageCacheTests(ImageCacheTest):
         (dir_ := self.image_cache.cache_artifact_path(42)).mkdir()
         record_path = dir_ / "usage.json"
         now_mock.return_value = dt.datetime(
-            2024, 1, 1, 0, 0, 0, 0, tzinfo=dt.timezone.utc
+            2024, 1, 1, 0, 0, 0, 0, tzinfo=dt.UTC
         )
 
         self.image_cache.record_image_use(self.artifact)
@@ -228,7 +228,7 @@ class ImageCacheTests(ImageCacheTest):
                 "usage": [
                     {
                         "filename": "system.tar.xz",
-                        "timestamp": "2024-01-01T00:00:00+00:00",
+                        "timestamp": "2024-01-01T00:00:00Z",
                         "backend": None,
                     }
                 ],
@@ -246,7 +246,7 @@ class ImageCacheTests(ImageCacheTest):
             "usage": [
                 {
                     "filename": "system.tar.xz",
-                    "timestamp": "2024-01-01T00:00:00+00:00",
+                    "timestamp": "2024-01-01T00:00:00Z",
                     "backend": None,
                 }
             ]
@@ -256,7 +256,7 @@ class ImageCacheTests(ImageCacheTest):
             json.dump(existing, f)
 
         now_mock.return_value = dt.datetime(
-            2024, 1, 2, 0, 0, 0, 0, tzinfo=dt.timezone.utc
+            2024, 1, 2, 0, 0, 0, 0, tzinfo=dt.UTC
         )
 
         self.image_cache.record_image_use(self.artifact)
@@ -269,7 +269,7 @@ class ImageCacheTests(ImageCacheTest):
             record["usage"][-1],
             {
                 "filename": "system.tar.xz",
-                "timestamp": "2024-01-02T00:00:00+00:00",
+                "timestamp": "2024-01-02T00:00:00Z",
                 "backend": None,
             },
         )
@@ -315,9 +315,7 @@ class ImageCacheTests(ImageCacheTest):
     ) -> None:
         """Create an image usage log for artifact_id, with timestamp."""
         if timestamp is None:
-            timestamp = dt.datetime(
-                2024, 1, 1, 0, 0, 0, 0, tzinfo=dt.timezone.utc
-            )
+            timestamp = dt.datetime(2024, 1, 1, 0, 0, 0, 0, tzinfo=dt.UTC)
         if backends is None:
             backends = set()
         (dir_ := self.image_cache.cache_artifact_path(artifact_id)).mkdir()
@@ -349,7 +347,7 @@ class ImageCacheTests(ImageCacheTest):
             self.write_image_usage_log(i)
         self.write_image_usage_log(
             99,
-            dt.datetime(2023, 12, 1, 0, 0, 0, 0, tzinfo=dt.timezone.utc),
+            dt.datetime(2023, 12, 1, 0, 0, 0, 0, tzinfo=dt.UTC),
             {BackendType.UNSHARE},
         )
         self.assertEqual(
