@@ -16,7 +16,7 @@ import shutil
 import subprocess
 import tempfile
 from pathlib import Path, PurePath
-from typing import Any
+from typing import Any, override
 
 from debusine.artifacts import SigningInputArtifact
 from debusine.artifacts.models import (
@@ -24,6 +24,7 @@ from debusine.artifacts.models import (
     CollectionCategory,
     DebianBinaryPackage,
     DebianUpload,
+    WorkRequestResults,
     get_architectures,
     get_binary_package_name,
     get_binary_package_version,
@@ -52,6 +53,7 @@ class ExtractForSigning(
 
     TASK_VERSION = 1
 
+    @override
     def __init__(
         self,
         task_data: dict[str, Any],
@@ -73,10 +75,12 @@ class ExtractForSigning(
             dict[str, SigningInputArtifact] | None
         ) = None
 
+    @override
     def _cmdline(self) -> list[str]:
         """Unused abstract method from RunCommandTask."""
         raise NotImplementedError()
 
+    @override
     def can_run_on(self, worker_metadata: dict[str, Any]) -> bool:
         """Check if the specified worker can run the task."""
         if not super().can_run_on(worker_metadata):
@@ -85,6 +89,7 @@ class ExtractForSigning(
         executor_available_key = f"executor:{self.backend}:available"
         return bool(worker_metadata.get(executor_available_key, False))
 
+    @override
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> ExtractForSigningDynamicData:
@@ -163,6 +168,7 @@ class ExtractForSigning(
             f"({architectures_str})",
         )
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of input artifact IDs used by this task."""
         if not self.dynamic_data:
@@ -173,6 +179,7 @@ class ExtractForSigning(
             *self.dynamic_data.input_binary_artifacts_ids,
         ]
 
+    @override
     def fetch_input(self, destination: Path) -> bool:
         """Download the required artifacts."""
         assert self.dynamic_data is not None
@@ -224,8 +231,10 @@ class ExtractForSigning(
 
         return True
 
+    @override
     def configure_for_execution(
-        self, download_directory: Path  # noqa: U100
+        self,
+        download_directory: Path,  # noqa: U100
     ) -> bool:
         """Configure task: create and start an executor instance."""
         self._prepare_executor_instance()
@@ -353,7 +362,8 @@ class ExtractForSigning(
             binary_package_name=package,
         )
 
-    def run(self, execute_directory: Path) -> bool:
+    @override
+    def run(self, execute_directory: Path) -> WorkRequestResults:
         """Do the main extraction work."""
         assert self.executor_instance is not None
         assert self._binary_paths is not None
@@ -369,16 +379,20 @@ class ExtractForSigning(
             for package, metadata in manifest["packages"].items()
         }
 
-        return True
+        return WorkRequestResults.SUCCESS
 
+    @override
     def upload_artifacts(
-        self, execute_directory: Path, *, execution_success: bool  # noqa: U100
+        self,
+        execute_directory: Path,
+        *,
+        execution_result: WorkRequestResults,
     ) -> None:
         """Upload artifacts for the task."""
         assert self.work_request_id is not None
         assert self.debusine is not None
 
-        if execution_success:
+        if execution_result == WorkRequestResults.SUCCESS:
             assert self.dynamic_data is not None
             assert self._binary_artifacts is not None
             assert self._signing_input_artifacts is not None
@@ -399,6 +413,7 @@ class ExtractForSigning(
                         RelationType.RELATES_TO,
                     )
 
+    @override
     def cleanup(self) -> None:
         """Clean up after running the task."""
         if self._local_execute_directory is not None:
