@@ -8,11 +8,12 @@
 # contained in the LICENSE file.
 
 """Task to use lintian in debusine."""
+
 import json
 import re
 from collections import defaultdict
 from pathlib import Path
-from typing import Any
+from typing import Any, override
 
 from debian import debfile
 from debusine import utils
@@ -23,8 +24,10 @@ from debusine.artifacts.models import (
     DebianBinaryPackage,
     DebianLintianSummary,
     DebianSourcePackage,
+    DebianSystemImage,
     DebianSystemTarball,
     DebianUpload,
+    WorkRequestResults,
     get_source_package_name,
     get_source_package_version,
 )
@@ -59,6 +62,7 @@ class Lintian(
 
     CAPTURE_OUTPUT_FILENAME = "lintian.txt"
 
+    @override
     def __init__(
         self,
         task_data: dict[str, Any],
@@ -87,6 +91,7 @@ class Lintian(
         ):
             self._severities_to_level[severity] = ranking
 
+    @override
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> LintianDynamicData:
@@ -169,9 +174,14 @@ class Lintian(
             self.ensure_artifact_categories(
                 configuration_key="environment",
                 category=environment.category,
-                expected=(ArtifactCategory.SYSTEM_TARBALL,),
+                expected=(
+                    ArtifactCategory.SYSTEM_TARBALL,
+                    ArtifactCategory.SYSTEM_IMAGE,
+                ),
+            )
+            assert isinstance(
+                environment.data, (DebianSystemTarball, DebianSystemImage)
             )
-            assert isinstance(environment.data, DebianSystemTarball)
 
             runtime_context = f"{what_str}:{environment.data.codename}"
             configuration_context = environment.data.codename
@@ -190,6 +200,7 @@ class Lintian(
             configuration_context=configuration_context,
         )
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of input artifact IDs used by this task."""
         if not self.dynamic_data:
@@ -291,8 +302,8 @@ class Lintian(
         severities = "".join(cls._SEVERITY_SHORT_TO_LONG)
 
         m = re.match(
-            fr"(?P<severity>[{severities}M]):\s(?P<package>\S+"
-            fr"(?: source)?):\s(?P<tag>\S+) ?(?P<note>[^[]*)?",
+            rf"(?P<severity>[{severities}M]):\s(?P<package>\S+"
+            rf"(?: source)?):\s(?P<tag>\S+) ?(?P<note>[^[]*)?",
             line,
         )
         # severity, package and tags are always there. Information might
@@ -300,7 +311,7 @@ class Lintian(
         # with [ (if it starts with [ it's a file, dealt below)
 
         if m is None:
-            m = re.match(fr"(?P<severity>[{severities}M]):\s(?P<tag>\S+)", line)
+            m = re.match(rf"(?P<severity>[{severities}M]):\s(?P<tag>\S+)", line)
             if m:
                 # Bullseye's lintian have a duplicated tag line after each
                 # real (full information). Ignore it.
@@ -400,22 +411,18 @@ class Lintian(
 
         return tags
 
+    @override
     def _cmdline(self) -> list[str]:
         """
         Build the lintian command line.
 
         Use configuration of self.data and self._lintian_targets.
         """
-        if self.data.target_distribution == "jessie":
-            display_level = "pedantic"
-        else:
-            display_level = "classification"
-
         cmd = [
             "lintian",
             "--no-cfg",
             "--display-level",
-            f">={display_level}",
+            ">=classification",
             "--display-experimental",
             "--info",
             "--show-overrides",
@@ -471,6 +478,7 @@ class Lintian(
 
         return package_name, architecture
 
+    @override
     def fetch_input(self, destination: Path) -> bool:
         """Download the required artifacts."""
         assert self.dynamic_data
@@ -485,6 +493,7 @@ class Lintian(
 
         return True
 
+    @override
     def configure_for_execution(self, download_directory: Path) -> bool:
         """
         Find a .dsc, .deb and .udeb files in download_directory.
@@ -544,8 +553,9 @@ class Lintian(
 
         return True
 
-    def execution_consistency_errors(
-        self, build_directory: Path  # noqa: U100
+    @override
+    def check_directory_for_consistency_errors(
+        self, build_directory: Path
     ) -> list[str]:
         """Return list of errors."""
         files_in_directory: set[Path] = set(build_directory.iterdir())
@@ -558,8 +568,12 @@ class Lintian(
 
         return []
 
+    @override
     def upload_artifacts(
-        self, exec_directory: Path, *, execution_success: bool  # noqa: U100
+        self,
+        exec_directory: Path,
+        *,
+        execution_result: WorkRequestResults,  # noqa: U100
     ) -> None:
         """Upload the LintianArtifact with the files and relationships."""
         if not self.debusine:
@@ -637,9 +651,10 @@ class Lintian(
 
         return architecture_to_analysis
 
-    def task_succeeded(
-        self, returncode: int | None, execute_directory: Path  # noqa: U100
-    ) -> bool:
+    @override
+    def task_result(
+        self, returncode: int | None, execute_directory: Path
+    ) -> WorkRequestResults:
         """
         Evaluate task output and return success.
 
@@ -647,12 +662,12 @@ class Lintian(
         -lintian must have generated the output file
         -no tags of severity self.data["fail_on"] or higher
 
-        :return: True for success, False failure.
+        :return: SUCCESS for success, False failure.
         """
         fail_on_severity = self.data.fail_on_severity
 
         if fail_on_severity == "none":
-            return True
+            return WorkRequestResults.SUCCESS
 
         fail_on_severity_level = self._severities_to_level[fail_on_severity]
         lintian_file = execute_directory / self.CAPTURE_OUTPUT_FILENAME
@@ -663,9 +678,9 @@ class Lintian(
                 self._severities_to_level[tag["severity"]]
                 >= fail_on_severity_level
             ):
-                return False
+                return WorkRequestResults.FAILURE
 
-        return True
+        return WorkRequestResults.SUCCESS
 
     def _get_lintian_version(self) -> str:
         if not self.executor_instance:
