@@ -18,6 +18,7 @@ from debusine.artifacts.models import (
     ArtifactCategory,
     CollectionCategory,
     DebianSourcePackage,
+    WorkRequestResults,
     get_source_package_name,
     get_source_package_version,
 )
@@ -207,7 +208,7 @@ ls -lh "$2"
         self,
         execute_directory: Path,
         *,
-        execution_success: bool,  # noqa: U100
+        execution_result: WorkRequestResults,  # noqa: U100
     ) -> None:
         """Create DebianUpload artifact and relationships."""
         if not self.debusine:
