@@ -15,6 +15,7 @@ from typing import Any, override
 
 from debusine import utils
 from debusine.artifacts.local_artifact import DebianSystemTarballArtifact
+from debusine.artifacts.models import WorkRequestResults
 from debusine.tasks.models import MmDebstrapData
 from debusine.tasks.systembootstrap import SystemBootstrap
 
@@ -180,13 +181,13 @@ class MmDebstrap(SystemBootstrap[MmDebstrapData]):
 
     @override
     def upload_artifacts(
-        self, execute_dir: Path, *, execution_success: bool
+        self, execute_dir: Path, *, execution_result: WorkRequestResults
     ) -> None:
         """Upload generated artifacts."""
         if not self.debusine:
             raise AssertionError("self.debusine not set")
 
-        if not execution_success:
+        if execution_result != WorkRequestResults.SUCCESS:
             return
         system_file = execute_dir / self._OUTPUT_SYSTEM_FILE
 
