@@ -27,6 +27,7 @@ from debusine.artifacts.models import (
     BareDataCategory,
     DebianPackageBuildLog,
     RuntimeStatistics,
+    WorkRequestResults,
 )
 from debusine.client.models import LookupChildType
 from debusine.utils import DjangoChoicesEnum
@@ -710,7 +711,7 @@ class OutputData(BaseTaskDataModel):
 class NoopData(BaseTaskDataWithExecutor):
     """In memory task data for the Noop task."""
 
-    result: bool = True
+    result: WorkRequestResults = WorkRequestResults.SUCCESS
 
 
 class AutopkgtestInput(BaseTaskDataModel):
