@@ -12,6 +12,7 @@
 from pathlib import Path
 from typing import override
 
+from debusine.artifacts.models import WorkRequestResults
 from debusine.tasks import BaseExternalTask, DefaultDynamicData
 from debusine.tasks.models import BaseDynamicTaskData, NoopData
 
@@ -29,6 +30,6 @@ class Noop(
     TASK_VERSION = 1
 
     @override
-    def run(self, execute_directory: Path) -> bool:  # noqa: U100
+    def run(self, execute_directory: Path) -> WorkRequestResults:  # noqa: U100
         """Return self.data.result (was sent by the client)."""
         return self.data.result
