@@ -15,7 +15,6 @@ https://freexian-team.pages.debian.net/debusine/reference/tasks.html#piuparts-ta
 """
 
 import gzip
-import os
 import re
 import shlex
 import shutil
@@ -23,7 +22,8 @@ import tarfile
 from collections.abc import Collection
 from io import BytesIO
 from pathlib import Path
-from typing import Any
+from tempfile import TemporaryDirectory
+from typing import Any, override
 
 from debian.debian_support import Version
 
@@ -34,11 +34,12 @@ from debusine.artifacts.models import (
     ArtifactCategory,
     CollectionCategory,
     DebianBinaryPackage,
-    DebianBinaryPackages,
     DebianPiuparts,
     DebianSystemTarball,
     DebianUpload,
+    WorkRequestResults,
     get_source_package_name,
+    get_source_package_version,
 )
 from debusine.client.models import RelationType
 from debusine.tasks import (
@@ -63,6 +64,7 @@ class Piuparts(
 
     CAPTURE_OUTPUT_FILENAME = "piuparts.txt"
 
+    @override
     def __init__(
         self,
         task_data: dict[str, Any],
@@ -84,6 +86,7 @@ class Piuparts(
         self._base_tar_data: DebianSystemTarball | None = None
         self._scripts_dir: Path | None = None
 
+    @override
     def build_dynamic_data(
         self, task_database: TaskDatabaseInterface
     ) -> PiupartsDynamicData:
@@ -92,7 +95,8 @@ class Piuparts(
 
         :subject: space-separated list of source package names from
           ``input.binary_artifact``
-        :runtime_context: ``codename:host_architecture`` where ``codename``
+        :parameter_summary: same as subject with the version (if one package)
+        :runtime_context: ``codename:build_architecture`` where ``codename``
           is from ``base_tgz``
         :configuration_context: ``codename`` from ``base_tgz``
         """
@@ -116,24 +120,40 @@ class Piuparts(
         assert isinstance(base_tgz.data, DebianSystemTarball)
 
         package_names = []
+        source_versions = set()
         for i, binary_artifact in enumerate(input_binary_artifacts):
             self.ensure_artifact_categories(
                 configuration_key=f"input.binary_artifacts[{i}]",
                 category=binary_artifact.category,
                 expected=(
                     ArtifactCategory.BINARY_PACKAGE,
-                    ArtifactCategory.BINARY_PACKAGES,
                     ArtifactCategory.UPLOAD,
                 ),
             )
             assert isinstance(
                 binary_artifact.data,
-                (DebianBinaryPackage, DebianBinaryPackages, DebianUpload),
+                (DebianBinaryPackage, DebianUpload),
             )
             package_names.append(get_source_package_name(binary_artifact.data))
+            source_versions.add(
+                get_source_package_version(binary_artifact.data)
+            )
 
-        runtime_context = f"{base_tgz.data.codename}:{self.host_architecture()}"
+        runtime_context = (
+            f"{base_tgz.data.codename}:{self.build_architecture()}"
+        )
         configuration_context = base_tgz.data.codename
+        package_names_sorted = sorted(package_names)
+
+        if len(package_names_sorted) == 1 and len(source_versions) == 1:
+            source_version = next(iter(source_versions))
+            parameter_summary = f"{package_names_sorted[0]}_{source_version}"
+        else:
+            parameter_summary = " ".join(package_names_sorted)
+
+        # TODO: It would probably be better to get the architecture of the
+        # input binary artifacts and use that.
+        parameter_summary += f" ({self.build_architecture()})"
 
         return PiupartsDynamicData(
             environment_id=self.get_environment(
@@ -141,13 +161,16 @@ class Piuparts(
                 self.data.environment,
                 default_category=CollectionCategory.ENVIRONMENTS,
             ).id,
+            extra_repositories=self.resolve_extra_repositories(task_database),
             input_binary_artifacts_ids=input_binary_artifacts.get_ids(),
             base_tgz_id=base_tgz.id,
-            subject=" ".join(sorted(package_names)),
+            subject=" ".join(package_names_sorted),
+            parameter_summary=parameter_summary,
             runtime_context=runtime_context,
             configuration_context=configuration_context,
         )
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of input artifact IDs used by this task."""
         if not self.dynamic_data:
@@ -158,6 +181,7 @@ class Piuparts(
             *self.dynamic_data.input_binary_artifacts_ids,
         ]
 
+    @override
     def fetch_input(self, destination: Path) -> bool:
         """Populate work directory with user-specified binary artifact(s)."""
         assert self.dynamic_data
@@ -166,6 +190,7 @@ class Piuparts(
             self.fetch_artifact(artifact_id, destination)
         return True
 
+    @override
     def configure_for_execution(self, download_directory: Path) -> bool:
         r"""
         Find the .deb files for piuparts.
@@ -272,7 +297,7 @@ class Piuparts(
         base_tgz_response = self.fetch_artifact(
             self.dynamic_data.base_tgz_id, base_tar_dir
         )
-        self._base_tar_data = DebianSystemTarball.parse_obj(
+        self._base_tar_data = DebianSystemTarball.model_validate(
             base_tgz_response.data
         )
         self._base_tar = base_tar_dir / self._base_tar_data.filename
@@ -405,54 +430,68 @@ class Piuparts(
 
     def _prepare_scripts(self, script_directory: Path) -> None:
         """Prepare scripts for piuparts."""
-        if not self.data.extra_repositories:
-            return
         if not self._base_tar_data:
             raise AssertionError(
                 "self._base_tar_data not set, call _prepare_base_tgz first."
             )
+
+        bad_permissions_script = (
+            script_directory / "pre_remove_50_find_bad_permissions"
+        )
+        bad_permissions_script.write_text(
+            "#!/bin/sh\n"
+            "echo 'Skipping to avoid https://bugs.debian.org/1125784'\n"
+        )
+        bad_permissions_script.chmod(0o755)
+
+        install_passwd_script = script_directory / "post_setup_00_passwd"
+        install_passwd_script.write_text(
+            "#!/bin/sh\n"
+            "echo 'Installing passwd for https://bugs.debian.org/1125789'\n"
+            "if [ ! -e /usr/sbin/useradd ]; then\n"
+            "    apt-get -y install passwd\n"
+            "fi\n"
+        )
+        install_passwd_script.chmod(0o755)
+
         codename = self._base_tar_data.codename
-        supports_deb822_sources = self.supports_deb822_sources(codename)
-        inline_signed_by = self.supports_inline_signed_by(codename)
-        post_unpack_script = script_directory / "post_chroot_unpack_debusine"
-        with post_unpack_script.open("w") as f:
-            f.write("#!/bin/sh\nset -eux\n")
-            if not inline_signed_by:
-                f.write("mkdir -p /etc/apt/keyrings\n")
-            for i, repo in enumerate(self.data.extra_repositories):
-                signed_by = None
-                if not inline_signed_by and repo.signing_key:
-                    signed_by = f"/etc/apt/keyrings/extra_apt_key_{i}.asc"
-                    signing_key = shlex.quote(repo.signing_key + "\n")
-                    f.write(f"printf %s {signing_key} > {signed_by}\n")
+        if self.data.extra_repositories:
+            extra_repo_script = (
+                script_directory / "post_chroot_unpack_debusine_extra_repos"
+            )
+            with (
+                TemporaryDirectory(
+                    prefix="debusine-piuparts-"
+                ) as extra_repositories_dir,
+                extra_repo_script.open("w") as f,
+            ):
+                extra_repositories_path = Path(extra_repositories_dir)
+                self.write_extra_repository_config(
+                    codename=codename, destination=extra_repositories_path
+                )
 
-                if supports_deb822_sources:
-                    source = repo.as_deb822_source(signed_by_filename=signed_by)
-                    source_file = (
-                        f"/etc/apt/sources.list.d/extra_repository_{i}.sources"
+                f.write("#!/bin/sh\nset -eux\n")
+                if self.extra_repository_keys:
+                    f.write("mkdir -p /etc/apt/keyrings\n")
+                for key in self.extra_repository_keys:
+                    f.write(
+                        f"printf %s {shlex.quote(key.read_text())}"
+                        f" > /etc/apt/keyrings/{key.name}\n"
                     )
-                else:
-                    source = (
-                        repo.as_oneline_source(signed_by_filename=signed_by)
-                        + "\n"
+                for source in (
+                    self.extra_repository_sources + self.extra_repository_lists
+                ):
+                    f.write(
+                        f"printf %s {shlex.quote(source.read_text())}"
+                        f" > /etc/apt/sources.list.d/{source.name}\n"
                     )
-                    source_file = (
-                        f"/etc/apt/sources.list.d/extra_repository_{i}.list"
-                    )
-                f.write(f"printf %s {shlex.quote(source)} > {source_file}\n")
-
-            f.write("echo DONE\n")
-        post_unpack_script.chmod(0o755)
+                f.write("echo DONE\n")
+            extra_repo_script.chmod(0o755)
 
+    @override
     def _cmdline(self) -> list[str]:
         """Build full piuparts command line."""
-        cmdline = []
-
-        path_env = os.environ["PATH"].split(":")
-        if "/usr/sbin" not in path_env:
-            path_env.insert(0, "/usr/sbin")
-
-        cmdline.extend(["env", f"PATH={':'.join(path_env)}", "piuparts"])
+        cmdline = ["piuparts"]
 
         # Use --keep-sources-list (not --distribution=dist-variant /
         # --mirror / --extra-repo): we feed pre-generated tarballs and
@@ -471,6 +510,8 @@ class Piuparts(
         # Use pre-generated tarballs (don't debootstrap on the fly)
         cmdline.append(f"--basetgz={self._base_tar}")
 
+        cmdline.append("--scriptsdir=/etc/piuparts/scripts")
+
         # Configure APT sources, etc.
         cmdline.append(f"--scriptsdir={self._scripts_dir}")
 
@@ -479,13 +520,15 @@ class Piuparts(
 
         return cmdline
 
+    @override
     @staticmethod
     def _cmdline_as_root() -> bool:
         """Piuparts must run as root."""
         return True
 
-    def execution_consistency_errors(
-        self, build_directory: Path  # noqa: U100
+    @override
+    def check_directory_for_consistency_errors(
+        self, build_directory: Path
     ) -> list[str]:
         """Return list of errors."""
         if build_directory / self.CAPTURE_OUTPUT_FILENAME not in set(
@@ -495,8 +538,12 @@ class Piuparts(
 
         return []
 
+    @override
     def upload_artifacts(
-        self, execute_directory: Path, *, execution_success: bool  # noqa: U100
+        self,
+        execute_directory: Path,
+        *,
+        execution_result: WorkRequestResults,  # noqa: U100
     ) -> None:
         """Upload a PiupartsArtifact with the files, data, and relationships."""
         assert self.debusine is not None
@@ -510,7 +557,11 @@ class Piuparts(
             data=DebianPiuparts(
                 piuparts_version=str(self._piuparts_version),
                 binary_packages=self._deb_versions,
-                architecture=self.data.host_architecture,
+                # TODO: Should this be the architecture of the binary
+                # packages instead?  If we're testing `Architecture: all`
+                # binary packages on amd64, "all" seems like a better value
+                # here.
+                architecture=self.data.build_architecture,
                 distribution=f"{base_tar_data.vendor}:{base_tar_data.codename}",
             ),
         )
@@ -527,11 +578,3 @@ class Piuparts(
                 source_artifact_id,
                 RelationType.RELATES_TO,
             )
-
-    def get_label(self) -> str:
-        """Return the task label."""
-        return (
-            f"piuparts {subject}"
-            if (subject := self.get_subject())
-            else "piuparts"
-        )
