@@ -36,6 +36,7 @@ from debusine.artifacts.models import (
     DebianSystemImage,
     DebianSystemTarball,
     DoseDistCheck,
+    WorkRequestResults,
 )
 from debusine.client.models import RelationType, RemoteArtifact
 from debusine.tasks import (
@@ -428,23 +429,24 @@ class Sbuild(
         return None
 
     @override
-    def task_succeeded(
+    def task_result(
         self, returncode: int | None, execute_directory: Path
-    ) -> bool:
+    ) -> WorkRequestResults:
         """
         Check whether the task succeeded.
 
         `sbuild` returns 0 for "Status: skipped" (i.e. host architecture not
         supported by source package); we consider that a failure.
         """
-        if not super().task_succeeded(returncode, execute_directory):
-            return False
+        super_result = super().task_result(returncode, execute_directory)
+        if super_result != WorkRequestResults.SUCCESS:
+            return super_result
 
         build_log_path = debusine.utils.find_file_suffixes(
             execute_directory, [".build"]
         )
         if build_log_path is None:
-            return False
+            return WorkRequestResults.ERROR
 
         status = ""
         # Reading the whole build log is inefficient, but shouldn't usually
@@ -453,7 +455,9 @@ class Sbuild(
             for line in f:
                 if line.startswith("Status: "):
                     status = line[len("Status: ") :].rstrip("\n")
-        return status == "successful"
+        if status == "successful":
+            return WorkRequestResults.SUCCESS
+        return WorkRequestResults.FAILURE
 
     @staticmethod
     def _extract_dose3_explanation(
@@ -494,7 +498,7 @@ class Sbuild(
         source: str,
         version: str,
         architecture: str,
-        execution_success: bool,
+        execution_result: WorkRequestResults,
     ) -> RemoteArtifact | None:
         if not self.debusine:
             raise AssertionError("self.debusine not set")
@@ -506,7 +510,7 @@ class Sbuild(
             return None
 
         explanation = None
-        if not execution_success:
+        if execution_result != WorkRequestResults.SUCCESS:
             # BD-Uninstallable: look for the dose3 output
             explanation = self._extract_dose3_explanation(build_log_path)
 
@@ -690,7 +694,7 @@ class Sbuild(
 
     @override
     def upload_artifacts(
-        self, directory: Path, *, execution_success: bool
+        self, directory: Path, *, execution_result: WorkRequestResults
     ) -> None:
         """
         Upload the artifacts from directory.
@@ -712,7 +716,7 @@ class Sbuild(
                 dsc["source"],
                 dsc["version"],
                 self._host_architecture,
-                execution_success,
+                execution_result,
             )
 
             if remote_build_log is not None:
@@ -723,7 +727,7 @@ class Sbuild(
                         RelationType.RELATES_TO,
                     )
 
-            if execution_success:
+            if execution_result == WorkRequestResults.SUCCESS:
                 # Upload the *.deb/*.udeb files (BinaryPackages)
                 remote_binary_packages = self._upload_binary_packages(directory)
 
