@@ -17,6 +17,7 @@ from typing import Any, override
 
 from debusine import utils
 from debusine.artifacts.local_artifact import DebianSystemImageArtifact
+from debusine.artifacts.models import WorkRequestResults
 from debusine.tasks.models import DiskImageFormat, SystemImageBuildData
 from debusine.tasks.systembootstrap import SystemBootstrap
 
@@ -206,13 +207,13 @@ class SimpleSystemImageBuild(SystemBootstrap[SystemImageBuildData]):
 
     @override
     def upload_artifacts(
-        self, execute_dir: Path, *, execution_success: bool
+        self, execute_dir: Path, *, execution_result: WorkRequestResults
     ) -> None:
         """Upload generated artifacts."""
         if not self.debusine:
             raise AssertionError("self.debusine not set")
 
-        if not execution_success:
+        if execution_result != WorkRequestResults.SUCCESS:
             return
 
         if self.data.disk_image.format == DiskImageFormat.QCOW2:
