@@ -8,7 +8,9 @@
 # contained in the LICENSE file.
 
 """Ontology definition of SystemImageBuild."""
+
 import abc
+from typing import override
 
 from debusine.tasks import DefaultDynamicData, RunCommandTask
 from debusine.tasks.models import BaseDynamicTaskData, SystemImageBuildData
@@ -24,8 +26,10 @@ class SystemImageBuild(
 
     TASK_VERSION = 1
 
+    @override
     def build_dynamic_data(
-        self, task_database: TaskDatabaseInterface  # noqa: U100
+        self,
+        task_database: TaskDatabaseInterface,  # noqa: U100
     ) -> BaseDynamicTaskData:
         """Compute dynamic data."""
         suite_name = self.data.bootstrap_repositories[0].suite
