@@ -8,7 +8,8 @@
 # contained in the LICENSE file.
 
 """Common test-helper code involving Tasks."""
-import datetime
+
+import datetime as dt
 import hashlib
 import shlex
 import tarfile
@@ -18,15 +19,10 @@ from io import BytesIO
 from pathlib import Path
 from shutil import rmtree
 from tempfile import mkdtemp
-from typing import Any, Generic, Protocol, TypeVar, cast, overload
+from typing import Any, Protocol, cast, overload, override
 from unittest import mock
 from unittest.mock import MagicMock
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 from debusine.artifacts.models import ArtifactCategory, CollectionCategory
 from debusine.client.debusine import Debusine
 from debusine.client.models import (
@@ -34,7 +30,6 @@ from debusine.client.models import (
     FileResponse,
     FilesResponseType,
     RelationType,
-    StrMaxLength255,
 )
 from debusine.tasks import BaseExternalTask, BaseTask, BaseTaskWithExecutor
 from debusine.tasks.executors import ExecutorInterface, UnshareInstance
@@ -56,13 +51,8 @@ from debusine.test.base import TestCase
 from debusine.test.test_utils import create_artifact_response
 from debusine.utils import extract_generic_type_arguments
 
-TaskClass = TypeVar("TaskClass", bound=BaseTask[Any, Any])
-ExternalTaskClass = TypeVar(
-    "ExternalTaskClass", bound=BaseExternalTask[Any, Any]
-)
 
-
-class TaskTestProtocol(Protocol, Generic[TaskClass]):
+class TaskTestProtocol[TaskClass: BaseTask[Any, Any]](Protocol):
     """Attributes that tests using :py:class:`TaskHelperMixin` must provide."""
 
     SAMPLE_TASK_DATA: dict[str, Any]
@@ -105,13 +95,15 @@ class FakeTaskDatabaseBase(TaskDatabaseInterface):
             | None
         ) = None,
         settings: dict[str, str] | None = None,
+        suite_signing_keys: dict[int, str] | None = None,
     ) -> None:
         """Construct a :py:class:`FakeTaskDatabase`."""
-        self.single_lookups = single_lookups or {}
-        self.multiple_lookups = multiple_lookups or {}
-        self.relations = relations or {}
-        self.single_collection_lookups = single_collection_lookups or {}
-        self.settings = settings or {}
+        self.single_lookups = dict(single_lookups or {})
+        self.multiple_lookups = dict(multiple_lookups or {})
+        self.relations = dict(relations or {})
+        self.single_collection_lookups = dict(single_collection_lookups or {})
+        self.settings = dict(settings or {})
+        self.suite_signing_keys = dict(suite_signing_keys or {})
 
     @overload
     def lookup_single_artifact(
@@ -190,6 +182,10 @@ class FakeTaskDatabaseBase(TaskDatabaseInterface):
         """Look up a Django setting (strings only)."""
         return self.settings[setting]
 
+    def export_suite_signing_keys(self, suite_id: int) -> str:
+        """Export signing keys for a suite as an ASCII-armored keyring."""
+        return self.suite_signing_keys[suite_id]
+
 
 class FakeTaskDatabase(FakeTaskDatabaseBase):
     """
@@ -203,11 +199,12 @@ class FakeTaskDatabase(FakeTaskDatabaseBase):
         raise NotImplementedError()
 
 
-class TaskHelperMixin(Generic[TaskClass]):
+class TaskHelperMixin[TaskClass: BaseTask[Any, Any]]:
     """Helper mixin for Task tests."""
 
     task_class: type[TaskClass]
     task: TaskClass
+    task_db: FakeTaskDatabase
 
     def __init_subclass__(cls, **kwargs: Any) -> None:
         """Compute cls.task_class."""
@@ -246,6 +243,16 @@ class TaskHelperMixin(Generic[TaskClass]):
 
         self.task = self.task_class(task_data)
 
+    def set_dynamic_data(self) -> None:
+        """
+        Compute and store the task's dynamic data.
+
+        ``task_db`` must be set up in advance with enough information to
+        allow computing dynamic data.
+        """
+        assert self.task_db is not None
+        self.task.dynamic_data = self.task.compute_dynamic_data(self.task_db)
+
     def write_os_release(
         self, filename: Path, codename: str = "bookworm", version: int = 12
     ) -> dict[str, str]:
@@ -263,8 +270,6 @@ class TaskHelperMixin(Generic[TaskClass]):
             "VERSION_ID": str(version),
         }
 
-        if codename == "jessie":
-            del data["VERSION_CODENAME"]
         if version >= 13:
             del data["VERSION"]
             del data["VERSION_ID"]
@@ -275,8 +280,8 @@ class TaskHelperMixin(Generic[TaskClass]):
         return data
 
 
-class ExternalTaskHelperMixin(
-    TaskHelperMixin[ExternalTaskClass], Generic[ExternalTaskClass]
+class ExternalTaskHelperMixin[ExternalTaskClass: BaseExternalTask[Any, Any]](
+    TaskHelperMixin[ExternalTaskClass]
 ):
     """Helper mixin for testing Tasks that run on external workers."""
 
@@ -313,8 +318,8 @@ class ExternalTaskHelperMixin(
         debusine_mock.artifact_get.return_value = artifact_response
 
         def download_tarball(
-            artifact_id: int,  # noqa: U100
-            filename: str,  # noqa: U100
+            artifact_id: int,  # noqa: ARG001, U100
+            filename: str,  # noqa: ARG001, U100
             destination: Path,
         ) -> None:
             with tarfile.open(destination, "w:xz") as f:
@@ -329,8 +334,8 @@ class ExternalTaskHelperMixin(
                 f.addfile(tarinfo, BytesIO(b"123"))
 
         def download_image(
-            artifact_id: int,  # noqa: U100
-            filename: str,  # noqa: U100
+            artifact_id: int,  # noqa: ARG001, U100
+            filename: str,  # noqa: ARG001, U100
             destination: Path,
         ) -> None:
             with destination.open("wb") as f:
@@ -390,9 +395,7 @@ class ExternalTaskHelperMixin(
             id=42,
             workspace="Testing",
             category=ArtifactCategory.SYSTEM_TARBALL,
-            created_at=datetime.datetime(
-                2024, 1, 1, 0, 0, 0, tzinfo=datetime.UTC
-            ),
+            created_at=dt.datetime(2024, 1, 1, 0, 0, 0, tzinfo=dt.UTC),
             data={
                 "architecture": "amd64",
                 "codename": "bookworm",
@@ -400,23 +403,14 @@ class ExternalTaskHelperMixin(
                 "vendor": "debian",
                 "pkglist": {},
             },
-            download_tar_gz_url=pydantic.parse_obj_as(
-                pydantic.AnyUrl, "https://example.com/download-42/"
-            ),
+            download_tar_gz_url="https://example.com/download-42/",
             files=FilesResponseType(
                 {
                     "system.tar.xz": FileResponse(
                         size=4001,
-                        checksums={
-                            "sha256": pydantic.parse_obj_as(
-                                StrMaxLength255, "abc123"
-                            )
-                        },
+                        checksums={"sha256": "abc123"},
                         type="file",
-                        url=pydantic.parse_obj_as(
-                            pydantic.AnyUrl,
-                            "https://example.com/download-system.tar.xz",
-                        ),
+                        url="https://example.com/download-system.tar.xz",
                     ),
                 }
             ),
@@ -429,9 +423,7 @@ class ExternalTaskHelperMixin(
             id=42,
             workspace="Testing",
             category=ArtifactCategory.SYSTEM_IMAGE,
-            created_at=datetime.datetime(
-                2024, 1, 1, 0, 0, 0, tzinfo=datetime.UTC
-            ),
+            created_at=dt.datetime(2024, 1, 1, 0, 0, 0, tzinfo=dt.UTC),
             data={
                 "architecture": "amd64",
                 "codename": "bookworm",
@@ -443,23 +435,14 @@ class ExternalTaskHelperMixin(
                 "boot_mechanism": "efi",
                 "pkglist": {},
             },
-            download_tar_gz_url=pydantic.parse_obj_as(
-                pydantic.AnyUrl, "https://example.com/download-42/"
-            ),
+            download_tar_gz_url="https://example.com/download-42/",
             files=FilesResponseType(
                 {
                     "image.qcow2": FileResponse(
                         size=4001,
-                        checksums={
-                            "sha256": pydantic.parse_obj_as(
-                                StrMaxLength255, "abc123"
-                            )
-                        },
+                        checksums={"sha256": "abc123"},
                         type="file",
-                        url=pydantic.parse_obj_as(
-                            pydantic.AnyUrl,
-                            "https://example.com/download-image.qcow2",
-                        ),
+                        url="https://example.com/download-image.qcow2",
                     ),
                 }
             ),
@@ -472,32 +455,21 @@ class ExternalTaskHelperMixin(
             id=6,
             workspace="Testing",
             category=ArtifactCategory.SOURCE_PACKAGE,
-            created_at=datetime.datetime(
-                2024, 1, 1, 0, 0, 0, tzinfo=datetime.UTC
-            ),
+            created_at=dt.datetime(2024, 1, 1, 0, 0, 0, tzinfo=dt.UTC),
             data={
                 "name": "foo",
                 "version": "1.0-1",
                 "type": "dpkg",
                 "dsc_fields": {},
             },
-            download_tar_gz_url=pydantic.parse_obj_as(
-                pydantic.AnyUrl, "https://example.com/download-6/"
-            ),
+            download_tar_gz_url="https://example.com/download-6/",
             files=FilesResponseType(
                 {
                     "foo_1.0-1.dsc": FileResponse(
                         size=10,
-                        checksums={
-                            "sha256": pydantic.parse_obj_as(
-                                StrMaxLength255, "abc123"
-                            )
-                        },
+                        checksums={"sha256": "abc123"},
                         type="file",
-                        url=pydantic.parse_obj_as(
-                            pydantic.AnyUrl,
-                            "https://example.com/foo_1.0-1.dsc",
-                        ),
+                        url="https://example.com/foo_1.0-1.dsc",
                     ),
                 }
             ),
@@ -510,9 +482,7 @@ class ExternalTaskHelperMixin(
             id=7,
             workspace="Testing",
             category=ArtifactCategory.BINARY_PACKAGE,
-            created_at=datetime.datetime(
-                2024, 1, 1, 0, 0, 0, tzinfo=datetime.UTC
-            ),
+            created_at=dt.datetime(2024, 1, 1, 0, 0, 0, tzinfo=dt.UTC),
             data={
                 "srcpkg_name": "foo",
                 "srcpkg_version": "1.0-1",
@@ -520,23 +490,14 @@ class ExternalTaskHelperMixin(
                 "dsc_fields": {},
                 "dsc_control_files": [],
             },
-            download_tar_gz_url=pydantic.parse_obj_as(
-                pydantic.AnyUrl, "https://example.com/download-7/"
-            ),
+            download_tar_gz_url="https://example.com/download-7/",
             files=FilesResponseType(
                 {
                     "foo_1.0-1_all.deb": FileResponse(
                         size=10,
-                        checksums={
-                            "sha256": pydantic.parse_obj_as(
-                                StrMaxLength255, "abc123"
-                            )
-                        },
+                        checksums={"sha256": "abc123"},
                         type="file",
-                        url=pydantic.parse_obj_as(
-                            pydantic.AnyUrl,
-                            "https://example.com/foo_1.0-1_all.deb",
-                        ),
+                        url="https://example.com/foo_1.0-1_all.deb",
                     ),
                 }
             ),
@@ -560,9 +521,7 @@ class ExternalTaskHelperMixin(
             id=8,
             workspace="Testing",
             category=ArtifactCategory.UPLOAD,
-            created_at=datetime.datetime(
-                2024, 1, 1, 0, 0, 0, tzinfo=datetime.UTC
-            ),
+            created_at=dt.datetime(2024, 1, 1, 0, 0, 0, tzinfo=dt.UTC),
             data={
                 "type": "dpkg",
                 "changes_fields": {
@@ -570,23 +529,16 @@ class ExternalTaskHelperMixin(
                     "Files": [{"name": name} for name in names],
                 },
             },
-            download_tar_gz_url=pydantic.parse_obj_as(
-                pydantic.AnyUrl, "https://example.com/download-8/"
-            ),
+            download_tar_gz_url="https://example.com/download-8/",
             files=FilesResponseType(
                 {
                     name: FileResponse(
                         size=len(name),
                         checksums={
-                            "sha256": pydantic.parse_obj_as(
-                                StrMaxLength255,
-                                hashlib.sha256(name.encode()).hexdigest(),
-                            )
+                            "sha256": hashlib.sha256(name.encode()).hexdigest()
                         },
                         type="file",
-                        url=pydantic.parse_obj_as(
-                            pydantic.AnyUrl, f"https://example.com/{name}"
-                        ),
+                        url=f"https://example.com/{name}",
                     )
                     for name in [
                         f"{source_package_name}_1.0-1_{architecture}.changes",
@@ -598,13 +550,12 @@ class ExternalTaskHelperMixin(
         )
 
 
-TD = TypeVar("TD", bound=BaseTaskData)
-DTD = TypeVar("DTD", bound=BaseDynamicTaskData)
-
-
-class SampleBaseTask(BaseTask[TD, DTD]):
+class SampleBaseTask[TD: BaseTaskData, DTD: BaseDynamicTaskData](
+    BaseTask[TD, DTD]
+):
     """Common test implementation of abstract task methods."""
 
+    @override
     def build_dynamic_data(
         self,
         task_database: TaskDatabaseInterface,  # noqa: U100
@@ -612,22 +563,20 @@ class SampleBaseTask(BaseTask[TD, DTD]):
         """Resolve artifact lookups for this task."""
         return self.dynamic_task_data_type()
 
+    @override
     def get_input_artifacts_ids(self) -> list[int]:
         """Return the list of input artifact IDs used by this task."""
         return []
 
 
-class SampleBaseExternalTask(
+class SampleBaseExternalTask[TD: BaseTaskData, DTD: BaseDynamicTaskData](
     SampleBaseTask[TD, DTD], BaseExternalTask[TD, DTD]
 ):
     """Common test implementation of BaseExternalTask methods."""
 
 
-TDE = TypeVar("TDE", bound=BaseTaskDataWithExecutor)
-DTDE = TypeVar("DTDE", bound=BaseDynamicTaskDataWithExecutor)
-
-
-class SampleBaseTaskWithExecutor(
-    SampleBaseTask[TDE, DTDE], BaseTaskWithExecutor[TDE, DTDE]
-):
+class SampleBaseTaskWithExecutor[
+    TDE: BaseTaskDataWithExecutor,
+    DTDE: BaseDynamicTaskDataWithExecutor,
+](SampleBaseTask[TDE, DTDE], BaseTaskWithExecutor[TDE, DTDE]):
     """Common test implementation of BaseExternalTask methods."""
