@@ -29,6 +29,7 @@ from debusine.artifacts.models import (
     DebianBinaryPackage,
     DebusineSigningOutput,
     EmptyArtifactData,
+    WorkRequestResults,
 )
 from debusine.artifacts.playground import ArtifactPlayground
 from debusine.assets import KeyPurpose
@@ -944,7 +945,9 @@ class AssembleSignedSourceTests(
         debusine_mock = self.mock_debusine()
         execute_directory = self.create_temporary_directory()
 
-        self.task.upload_artifacts(execute_directory, execution_success=False)
+        self.task.upload_artifacts(
+            execute_directory, execution_result=WorkRequestResults.FAILURE
+        )
 
         debusine_mock.upload_artifact.assert_not_called()
         debusine_mock.relation_create.assert_not_called()
@@ -978,7 +981,9 @@ class AssembleSignedSourceTests(
         ]
         execute_directory = self.create_temporary_directory()
 
-        self.task.upload_artifacts(execute_directory, execution_success=True)
+        self.task.upload_artifacts(
+            execute_directory, execution_result=WorkRequestResults.SUCCESS
+        )
 
         debusine_mock.upload_artifact.assert_has_calls(
             [
@@ -1177,7 +1182,7 @@ class AssembleSignedSourceTests(
             mock_executor_instance.file_pull.side_effect = shutil.copy2
             mock_executor_instance.file_push.side_effect = shutil.copy2
             mock_executor_instance.run.side_effect = run
-            self.assertTrue(self.task.execute())
+            self.assertEqual(self.task.execute(), WorkRequestResults.SUCCESS)
 
         self.assertEqual(debusine_mock.upload_artifact.call_count, 3)
         with tarfile.open(signed_tarball_path) as tar:
