@@ -29,6 +29,7 @@ from debusine.artifacts.models import (
     DebianBinaryPackage,
     DebianSourcePackage,
     DebianUpload,
+    WorkRequestResults,
 )
 from debusine.artifacts.models import DebianAutopkgtestResultStatus as rs
 from debusine.client.debusine import Debusine
@@ -1143,7 +1144,7 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
             log_file_contents, "hello.dsc is not a valid .dsc file\n"
         )
 
-    def setup_task_succeeded(
+    def setup_task_result(
         self, test_result: str, fail_on_config: dict[str, bool]
     ) -> Path:
         """
@@ -1162,78 +1163,105 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
 
         return directory
 
-    def test_task_succeeded_failed_test_fail_on_failed(self) -> None:
+    def test_task_result_failed_test_fail_on_failed(self) -> None:
         """Test failed, fail on failed_test=True. Failure."""
-        directory = self.setup_task_succeeded(
+        directory = self.setup_task_result(
             "test_name\tFAIL", {"failed_test": True}
         )
-        self.assertFalse(self.task.task_succeeded(0, directory))
+        self.assertEqual(
+            self.task.task_result(0, directory), WorkRequestResults.FAILURE
+        )
 
-    def test_task_succeeded_failed_test_do_not_fail_on_failed(self) -> None:
+    def test_task_result_failed_test_do_not_fail_on_failed(self) -> None:
         """Test failed, fail on failed_test=False. Success."""
-        directory = self.setup_task_succeeded(
+        directory = self.setup_task_result(
             "test_name\tFAIL", {"failed_test": False}
         )
-        self.assertTrue(self.task.task_succeeded(0, directory))
+        self.assertEqual(
+            self.task.task_result(0, directory), WorkRequestResults.SUCCESS
+        )
 
-    def test_task_succeed_flaky_test_fail_on_flaky_failure(self) -> None:
+    def test_task_result_flaky_test_fail_on_flaky_failure(self) -> None:
         """Test is flaky, fail on flaky_test=True. Failure."""
-        directory = self.setup_task_succeeded(
+        directory = self.setup_task_result(
             "test_name\tFLAKY", {"flaky_test": True}
         )
-        self.assertFalse(self.task.task_succeeded(0, directory))
+        self.assertEqual(
+            self.task.task_result(0, directory), WorkRequestResults.FAILURE
+        )
 
-    def test_task_succeed_flaky_test_do_not_fail_on_flaky_success(self) -> None:
+    def test_task_result_flaky_test_do_not_fail_on_flaky_success(self) -> None:
         """Test is flaky, fail on flaky_test=False. Success."""
-        directory = self.setup_task_succeeded(
+        directory = self.setup_task_result(
             "test_name\tFLAKY", {"flaky_test": False}
         )
-        self.assertTrue(self.task.task_succeeded(0, directory))
+        self.assertEqual(
+            self.task.task_result(0, directory), WorkRequestResults.SUCCESS
+        )
 
-    def test_task_succeeded_skipped_test_fail_on_skipped_success(self) -> None:
+    def test_task_result_skipped_test_fail_on_skipped_success(self) -> None:
         """Test is skipped, fail on skipped_test=True. Failure."""
-        directory = self.setup_task_succeeded(
+        directory = self.setup_task_result(
             "test_name\tSKIP", {"skipped_test": True}
         )
-        self.assertFalse(self.task.task_succeeded(0, directory))
+        self.assertEqual(
+            self.task.task_result(8, directory), WorkRequestResults.FAILURE
+        )
 
-    def test_task_succeeded_skipped_test_do_not_fail_on_skipped_failure(
-        self,
-    ) -> None:
-        """Test is skipped, fail on skipped_test=False. Success."""
-        directory = self.setup_task_succeeded(
+    def test_task_result_all_skipped(self) -> None:
+        """Tests are skipped. Skipped."""
+        directory = self.setup_task_result(
             "test_name\tSKIP", {"skipped_test": False}
         )
-        self.assertTrue(self.task.task_succeeded(0, directory))
+        self.assertEqual(
+            self.task.task_result(8, directory), WorkRequestResults.SKIPPED
+        )
 
-    def test_task_succeeded_ignore_return_code(self) -> None:
+    def test_task_result_skipped_test_do_not_fail_on_skipped_failure(
+        self,
+    ) -> None:
+        """A test is skipped, fail on skipped_test=False. Success."""
+        directory = self.setup_task_result(
+            "test_name\tSKIP\ntest_2\tPASS", {"skipped_test": False}
+        )
+        self.assertEqual(
+            self.task.task_result(0, directory), WorkRequestResults.SUCCESS
+        )
+
+    def test_task_result_ignore_return_code(self) -> None:
         """Summary file is inconclusive and ignore return value."""
-        directory = self.setup_task_succeeded(
+        directory = self.setup_task_result(
             "foo: nothing", {"failed_test": False}
         )
-        self.assertTrue(self.task.task_succeeded(4, directory))
-
-    def test_task_succeeded_flaky_return_code(self) -> None:
-        """Summary file is inconclusive and return value 2."""
-        directory = self.setup_task_succeeded(
-            "foo: nothing", {"flaky_test": True}
+        self.assertEqual(
+            self.task.task_result(4, directory), WorkRequestResults.SUCCESS
         )
-        self.assertFalse(self.task.task_succeeded(2, directory))
 
-    def test_task_succeeded_skip_return_code(self) -> None:
+    def test_task_result_flaky_return_code(self) -> None:
+        """Summary file is inconclusive and return value 2."""
+        directory = self.setup_task_result("foo: nothing", {"flaky_test": True})
+        self.assertEqual(
+            self.task.task_result(2, directory), WorkRequestResults.FAILURE
+        )
+
+    def test_task_result_skip_return_code(self) -> None:
         """Summary file is inconclusive and return value 8."""
-        directory = self.setup_task_succeeded(
+        directory = self.setup_task_result(
             "foo: nothing", {"skipped_test": True}
         )
-        self.assertFalse(self.task.task_succeeded(8, directory))
+        self.assertEqual(
+            self.task.task_result(8, directory), WorkRequestResults.FAILURE
+        )
 
-    def test_task_succeeded_fail_on_return_code(self) -> None:
+    def test_task_result_fail_on_return_code(self) -> None:
         """Summary file is inconclusive fail on return value."""
-        directory = self.setup_task_succeeded(
+        directory = self.setup_task_result(
             "erroneous package: Test dependencies are unsatisfiable.",
             {"failed_test": True},
         )
-        self.assertFalse(self.task.task_succeeded(12, directory))
+        self.assertEqual(
+            self.task.task_result(12, directory), WorkRequestResults.FAILURE
+        )
 
     def test_upload_artifacts(self) -> None:
         """Upload the AutopkgtestArtifact."""
@@ -1258,7 +1286,9 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
             "https://some-url.com/test"
         )
 
-        self.task.upload_artifacts(exec_dir, execution_success=True)
+        self.task.upload_artifacts(
+            exec_dir, execution_result=WorkRequestResults.SUCCESS
+        )
 
         calls = []
 
@@ -1294,7 +1324,7 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
             r"^self\.debusine not set",
             self.task.upload_artifacts,
             self.create_temporary_directory(),
-            execution_success=True,
+            execution_result=WorkRequestResults.SUCCESS,
         )
 
     def test_upload_artifacts_without_executor(self) -> None:
@@ -1310,7 +1340,7 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
             msg,
             self.task.upload_artifacts,
             self.create_temporary_directory(),
-            execution_success=True,
+            execution_result=WorkRequestResults.SUCCESS,
         )
 
     def test_check_directory_for_consistency_missing_summary(self) -> None:
