@@ -22,6 +22,7 @@ from debusine.artifacts.models import (
     CollectionCategory,
     DebianPackageBuildLog,
     EmptyArtifactData,
+    WorkRequestResults,
 )
 from debusine.client.models import LookupResultType, LookupSingleResponse
 from debusine.tasks import Blhc, TaskConfigError
@@ -127,7 +128,7 @@ class BlhcTests(ExternalTaskHelperMixin[Blhc], TestCase):
 
     def test_configure_additional_properties_in_input(self) -> None:
         """Assert no additional properties in task_data input."""
-        error_msg = "extra fields not permitted"
+        error_msg = "Extra inputs are not permitted"
         with self.assertRaisesRegex(TaskConfigError, error_msg):
             self.configure_task(
                 task_data={
@@ -166,7 +167,7 @@ class BlhcTests(ExternalTaskHelperMixin[Blhc], TestCase):
             r"'debian:source-package'. "
             r"Valid categories: \['debian:package-build-log'\]$",
         ):
-            self.task.compute_dynamic_data(self.task_db),
+            self.task.compute_dynamic_data(self.task_db)
 
     def test_get_input_artifacts_ids(self) -> None:
         """Test get_input_artifacts_ids."""
@@ -260,13 +261,25 @@ class BlhcTests(ExternalTaskHelperMixin[Blhc], TestCase):
         self.assertIn(extra_flags[0], cmdline)
         self.assertEqual(cmdline[-1], str(self.task._blhc_target))
 
-    def test_task_succeeded_empty_file_return_true(self) -> None:
-        """task_succeeded() for an empty file return True."""
+    def test_task_result_empty_file_success(self) -> None:
+        """task_result() for an empty file return SUCCESS."""
         directory = self.create_temporary_directory()
         (directory / Blhc.CAPTURE_OUTPUT_FILENAME).write_text("")
 
         self.configure_task()
-        self.assertTrue(self.task.task_succeeded(0, directory))
+        self.assertEqual(
+            self.task.task_result(0, directory), WorkRequestResults.SUCCESS
+        )
+
+    def test_task_result_failure_exit_code(self) -> None:
+        """task_result() for an exit code of 8 return FAILURE."""
+        directory = self.create_temporary_directory()
+        (directory / Blhc.CAPTURE_OUTPUT_FILENAME).write_text("")
+
+        self.configure_task()
+        self.assertEqual(
+            self.task.task_result(8, directory), WorkRequestResults.FAILURE
+        )
 
     def test_upload_artifacts(self) -> None:
         """upload_artifact() and relation_create() is called."""
@@ -304,7 +317,9 @@ class BlhcTests(ExternalTaskHelperMixin[Blhc], TestCase):
         work_request_id = 147
         self.task.work_request_id = work_request_id
 
-        self.task.upload_artifacts(exec_dir, execution_success=True)
+        self.task.upload_artifacts(
+            exec_dir, execution_result=WorkRequestResults.SUCCESS
+        )
 
         # Debusine Mock upload_artifact expected calls
         upload_artifact_calls = []
@@ -393,7 +408,9 @@ class BlhcTests(ExternalTaskHelperMixin[Blhc], TestCase):
             "NONVERBOSE BUILD:    Compiling gkrust v0.1.0 (/build/rust)\n"
         )
 
-        self.task.upload_artifacts(download_directory, execution_success=True)
+        self.task.upload_artifacts(
+            download_directory, execution_result=WorkRequestResults.SUCCESS
+        )
 
         debusine_mock.upload_artifact.assert_called_once_with(
             BlhcArtifact.create(
