@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Unit tests for the debdiff task support on the worker."""
+
 import itertools
 import re
 from typing import Any
@@ -21,6 +22,7 @@ from debusine.artifacts.models import (
     DebianSourcePackage,
     DebianUpload,
     EmptyArtifactData,
+    WorkRequestResults,
 )
 from debusine.client.models import LookupResultType, LookupSingleResponse
 from debusine.tasks import DebDiff, TaskConfigError
@@ -112,7 +114,7 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
 
     def test_configure_additional_properties_in_input(self) -> None:
         """Assert no additional properties in task_data input."""
-        error_msg = "extra fields not permitted"
+        error_msg = "Extra inputs are not permitted"
         with self.assertRaisesRegex(TaskConfigError, error_msg):
             self.configure_task(
                 task_data={
@@ -142,7 +144,7 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
         )
         self.task_db.multiple_lookups = {
             # binary artifacts
-            (LookupMultiple.parse_obj([500]), None): [
+            (LookupMultiple((500,)), None): [
                 ArtifactInfo(
                     id=500,
                     category=ArtifactCategory.UPLOAD,
@@ -157,7 +159,7 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
                     ),
                 ),
             ],
-            (LookupMultiple.parse_obj([501]), None): [
+            (LookupMultiple((501,)), None): [
                 ArtifactInfo(
                     id=501,
                     category=ArtifactCategory.UPLOAD,
@@ -197,7 +199,7 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
         )
         self.task_db.multiple_lookups = {
             # binary artifacts
-            (LookupMultiple.parse_obj([500]), None): [
+            (LookupMultiple((500,)), None): [
                 ArtifactInfo(
                     id=500,
                     category=ArtifactCategory.UPLOAD,
@@ -212,7 +214,7 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
                     ),
                 ),
             ],
-            (LookupMultiple.parse_obj([501]), None): [
+            (LookupMultiple((501,)), None): [
                 ArtifactInfo(
                     id=501,
                     category=ArtifactCategory.UPLOAD,
@@ -262,14 +264,14 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
         )
         self.task_db.multiple_lookups = {
             # binary artifacts
-            (LookupMultiple.parse_obj([500]), None): [
+            (LookupMultiple((500,)), None): [
                 ArtifactInfo(
                     id=500,
                     category=ArtifactCategory.SOURCE_PACKAGE,
                     data=EmptyArtifactData(),
                 ),
             ],
-            (LookupMultiple.parse_obj([501]), None): [
+            (LookupMultiple((501,)), None): [
                 ArtifactInfo(
                     id=501,
                     category=ArtifactCategory.BINARY_PACKAGE,
@@ -289,7 +291,7 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
             r"'debian:source-package'. Valid categories: "
             r"\['debian:binary-package', 'debian:upload'\]$",
         ):
-            self.task.compute_dynamic_data(self.task_db),
+            self.task.compute_dynamic_data(self.task_db)
 
     def test_compute_dynamic_data_raise_task_config_error_categories(
         self,
@@ -300,7 +302,7 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
         )
         self.task_db.multiple_lookups = {
             # binary artifacts
-            (LookupMultiple.parse_obj([500]), None): [
+            (LookupMultiple((500,)), None): [
                 ArtifactInfo(
                     id=500,
                     category=ArtifactCategory.UPLOAD,
@@ -314,7 +316,7 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
                     ),
                 ),
             ],
-            (LookupMultiple.parse_obj([501]), None): [
+            (LookupMultiple((501,)), None): [
                 ArtifactInfo(
                     id=501,
                     category=ArtifactCategory.BINARY_PACKAGE,
@@ -333,7 +335,7 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
             r'^All binary artifacts must have the same category. '
             r'Found "debian:upload" and "debian:binary-package"$',
         ):
-            self.task.compute_dynamic_data(self.task_db),
+            self.task.compute_dynamic_data(self.task_db)
 
     def test_compute_dynamic_data_raise_invalid_category(self) -> None:
         """Raise TaskConfigError: invalid categories binary artifacts."""
@@ -342,7 +344,7 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
         )
         self.task_db.multiple_lookups = {
             # binary artifacts
-            (LookupMultiple.parse_obj([500, 501]), None): [
+            (LookupMultiple((500, 501)), None): [
                 ArtifactInfo(
                     id=500,
                     category=ArtifactCategory.UPLOAD,
@@ -368,7 +370,7 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
                     ),
                 ),
             ],
-            (LookupMultiple.parse_obj([502, 503]), None): [
+            (LookupMultiple((502, 503)), None): [
                 ArtifactInfo(
                     id=502,
                     category=ArtifactCategory.UPLOAD,
@@ -402,14 +404,13 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
             r"than one artifact all must be of category debian:binary-package. "
             r"Found: debian:upload$",
         ):
-            self.task.compute_dynamic_data(self.task_db),
+            self.task.compute_dynamic_data(self.task_db)
 
     def test_compute_dynamic_data_raise_binary_cannot_be_zero(self) -> None:
         self.configure_task(override={"input": {"binary_artifacts": [[], []]}})
         self.task_db.multiple_lookups = {
             # binary artifacts
-            (LookupMultiple.parse_obj([]), None): [],
-            (LookupMultiple.parse_obj([]), None): [],
+            (LookupMultiple(()), None): [],
         }
 
         with self.assertRaisesRegex(
@@ -419,7 +420,7 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
                 "cannot have zero artifacts (got 0 and 0)"
             ),
         ):
-            self.task.compute_dynamic_data(self.task_db),
+            self.task.compute_dynamic_data(self.task_db)
 
     def test_get_input_artifacts_ids_dynamic_dynamic_data_none(self) -> None:
         self.task.dynamic_data = None
@@ -441,14 +442,6 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
         )
         self.assertEqual(self.task.get_input_artifacts_ids(), [1, 2, 3, 4])
 
-    def test_get_input_artifacts_ids_source_binary_artifacts(self) -> None:
-        self.task.dynamic_data = DebDiffDynamicData(
-            environment_id=1,
-            input_source_artifacts_ids=[1, 2],
-            input_binary_artifacts_ids=[[3, 4]],
-        )
-        self.assertEqual(self.task.get_input_artifacts_ids(), [1, 2, 3, 4])
-
     def test_fetch_input_source(self) -> None:
         """Test fetching different source inputs."""
         self.configure_task(override={"input": {'source_artifacts': [1, 2]}})
@@ -591,13 +584,25 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
             ],
         )
 
-    def test_task_succeeded_empty_file_return_true(self) -> None:
-        """task_succeeded() for an empty file return True."""
+    def test_task_result_empty_file_success(self) -> None:
+        """task_result() for an empty file return SUCCESS."""
         directory = self.create_temporary_directory()
         (directory / DebDiff.CAPTURE_OUTPUT_FILENAME).write_text("")
 
         self.configure_task()
-        self.assertTrue(self.task.task_succeeded(0, directory))
+        self.assertEqual(
+            self.task.task_result(0, directory), WorkRequestResults.SUCCESS
+        )
+
+    def test_task_result_failure_exit_code(self) -> None:
+        """task_result() for an exit code of 255 return FAILURE."""
+        directory = self.create_temporary_directory()
+        (directory / DebDiff.CAPTURE_OUTPUT_FILENAME).write_text("")
+
+        self.configure_task()
+        self.assertEqual(
+            self.task.task_result(255, directory), WorkRequestResults.FAILURE
+        )
 
     def test_upload_artifacts(self) -> None:
         """upload_artifact() and relation_create() is called."""
@@ -639,7 +644,9 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
         work_request_id = 147
         self.task.work_request_id = work_request_id
 
-        self.task.upload_artifacts(exec_dir, execution_success=True)
+        self.task.upload_artifacts(
+            exec_dir, execution_result=WorkRequestResults.SUCCESS
+        )
 
         # Debusine Mock upload_artifact expected calls
         upload_artifact_calls = []
@@ -729,7 +736,9 @@ class DebDiffTests(ExternalTaskHelperMixin[DebDiff], TestCase):
         debdiff_output = download_directory / self.task.CAPTURE_OUTPUT_FILENAME
         debdiff_output.write_text("1c1\n< Source: foo\n---\n> Source: bar\n")
 
-        self.task.upload_artifacts(download_directory, execution_success=True)
+        self.task.upload_artifacts(
+            download_directory, execution_result=WorkRequestResults.SUCCESS
+        )
 
         debusine_mock.upload_artifact.assert_called_once_with(
             DebDiffArtifact.create(
