@@ -26,6 +26,7 @@ from debusine.artifacts.models import (
     DebianBinaryPackages,
     DebianUpload,
     EmptyArtifactData,
+    WorkRequestResults,
 )
 from debusine.artifacts.playground import ArtifactPlayground
 from debusine.client.models import (
@@ -55,7 +56,9 @@ from debusine.test.test_utils import (
 
 
 def _mock_run(
-    args: list[str], run_as_root: bool = False, **kwargs: Any  # noqa: U100
+    args: list[str],
+    run_as_root: bool = False,  # noqa: ARG001, U100
+    **kwargs: Any,
 ) -> subprocess.CompletedProcess[AnyStr]:
     """Mock InstanceInterface.run using subprocess.run."""
     kwargs.setdefault("stdout", subprocess.PIPE)
@@ -124,7 +127,7 @@ class ExtractForSigningTests(
             },
             multiple_lookups={
                 # input.binary_artifacts
-                (LookupMultiple.parse_obj([3, 4]), None): [
+                (LookupMultiple((3, 4)), None): [
                     ArtifactInfo(
                         id=3,
                         category=ArtifactCategory.BINARY_PACKAGE,
@@ -210,7 +213,7 @@ class ExtractForSigningTests(
         """compute_dynamic_data follows relations from upload artifacts."""
         self.task_db.multiple_lookups = {
             # input.binary_artifacts
-            (LookupMultiple.parse_obj([3, 4]), None): [
+            (LookupMultiple((3, 4)), None): [
                 ArtifactInfo(
                     id=3,
                     category=ArtifactCategory.UPLOAD,
@@ -298,7 +301,7 @@ class ExtractForSigningTests(
     ) -> None:
         self.task_db.multiple_lookups = {
             # input.binary_artifacts
-            (LookupMultiple.parse_obj([3, 4]), None): [
+            (LookupMultiple((3, 4)), None): [
                 ArtifactInfo(
                     id=3,
                     category=ArtifactCategory.BINARY_PACKAGES,
@@ -755,7 +758,9 @@ class ExtractForSigningTests(
         debusine_mock = self.mock_debusine()
         execute_directory = self.create_temporary_directory()
 
-        self.task.upload_artifacts(execute_directory, execution_success=False)
+        self.task.upload_artifacts(
+            execute_directory, execution_result=WorkRequestResults.FAILURE
+        )
 
         debusine_mock.upload_artifact.assert_not_called()
         debusine_mock.relation_create.assert_not_called()
@@ -782,7 +787,9 @@ class ExtractForSigningTests(
         )
         execute_directory = self.create_temporary_directory()
 
-        self.task.upload_artifacts(execute_directory, execution_success=True)
+        self.task.upload_artifacts(
+            execute_directory, execution_result=WorkRequestResults.SUCCESS
+        )
 
         debusine_mock.upload_artifact.assert_called_once_with(
             self.task._signing_input_artifacts["hello"],
@@ -881,7 +888,7 @@ class ExtractForSigningTests(
             artifact_id: int,
             destination: Path,
             tarball: bool = False,
-            workspace: str | None = None,  # noqa: U100
+            workspace: str | None = None,  # noqa: ARG001, U100
         ) -> ArtifactResponse:
             assert not tarball
             for file_name in artifacts[artifact_id].files:
@@ -919,7 +926,7 @@ class ExtractForSigningTests(
         ):
             mock_executor_instance.file_pull.side_effect = shutil.copy2
             mock_executor_instance.run.side_effect = _mock_run
-            self.assertTrue(self.task.execute())
+            self.assertEqual(self.task.execute(), WorkRequestResults.SUCCESS)
 
         self.assertEqual(debusine_mock.upload_artifact.call_count, 3)
         self.assertEqual(
