@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Unit tests for the Lintian class."""
+
 import datetime as dt
 import itertools
 import json
@@ -18,11 +19,6 @@ from typing import Any, cast
 from unittest import mock
 from unittest.mock import MagicMock, call
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 from debusine.artifacts import LintianArtifact
 from debusine.artifacts.models import (
     ArtifactCategory,
@@ -32,12 +28,9 @@ from debusine.artifacts.models import (
     DebianSourcePackage,
     DebianUpload,
     EmptyArtifactData,
+    WorkRequestResults,
 )
-from debusine.client.models import (
-    FileResponse,
-    FilesResponseType,
-    StrMaxLength255,
-)
+from debusine.client.models import FileResponse, FilesResponseType
 from debusine.tasks import Lintian, TaskConfigError
 from debusine.tasks.executors import InstanceInterface
 from debusine.tasks.models import (
@@ -506,18 +499,20 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
                 self.create_temporary_file(contents=line.encode("utf-8"))
             )
 
-    def test_task_succeeded_empty_file_return_true(self) -> None:
-        """task_succeeded() for an empty file return True."""
+    def test_task_result_empty_file_success(self) -> None:
+        """task_result() for an empty file return SUCCESS."""
         directory = self.create_temporary_directory()
         (directory / Lintian.CAPTURE_OUTPUT_FILENAME).write_text("")
 
         self.configure_task(
             override={"fail_on_severity": LintianFailOnSeverity.WARNING}
         )
-        self.assertTrue(self.task.task_succeeded(0, directory))
+        self.assertEqual(
+            self.task.task_result(0, directory), WorkRequestResults.SUCCESS
+        )
 
-    def test_task_succeed_severity_less_than_fail_on_return_true(self) -> None:
-        """task_succeeded() severity < than fail_on_severity: return True."""
+    def test_task_result_severity_less_than_fail_on_success(self) -> None:
+        """task_result() severity < than fail_on_severity: return SUCCESS."""
         directory = self.create_temporary_directory()
         (directory / Lintian.CAPTURE_OUTPUT_FILENAME).write_text(
             "W: cynthiune.app: vcs-obsolete"
@@ -532,12 +527,12 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
             override={"fail_on_severity": LintianFailOnSeverity.ERROR}
         )
 
-        self.assertTrue(self.task.task_succeeded(0, directory))
+        self.assertEqual(
+            self.task.task_result(0, directory), WorkRequestResults.SUCCESS
+        )
 
-    def test_task_succeeded_severity_equal_as_fail_on_return_false(
-        self,
-    ) -> None:
-        """task_succeeded() severity == fail_on_severity: return False."""
+    def test_task_result_severity_equal_as_fail_on_failure(self) -> None:
+        """task_result() severity == fail_on_severity: return FAILURE."""
         directory = self.create_temporary_directory()
         (directory / Lintian.CAPTURE_OUTPUT_FILENAME).write_text(
             "W: cynthiune.app: vcs-obsolete"
@@ -552,10 +547,12 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
         }
         self.task._architecture_to_packages["all"] = {"cynthiune.app"}
 
-        self.assertFalse(self.task.task_succeeded(0, directory))
+        self.assertEqual(
+            self.task.task_result(0, directory), WorkRequestResults.FAILURE
+        )
 
-    def test_task_succeeded_fail_on_none(self) -> None:
-        """task_succeeded() fail_on_severity == "none": return True."""
+    def test_task_result_fail_on_none(self) -> None:
+        """task_result() fail_on_severity == "none": return SUCCESS."""
         directory = self.create_temporary_directory()
         (directory / Lintian.CAPTURE_OUTPUT_FILENAME).write_text(
             "E: cynthiune.app: vcs-obsolete\nW: hello: invalid-something\n"
@@ -573,7 +570,9 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
         self.task._architecture_to_packages["amd64"] = {"hello"}
 
         # Succeeded (fail_on_severity: none)
-        self.assertTrue(self.task.task_succeeded(0, directory))
+        self.assertEqual(
+            self.task.task_result(0, directory), WorkRequestResults.SUCCESS
+        )
 
     @staticmethod
     def get_analysis_no_tags() -> dict[str, Any]:
@@ -714,7 +713,7 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
         """Configuration does not include "output". Check defaults."""
         self.configure_task()
         self.assertEqual(
-            self.task.data.output,
+            self.task.data.output.model_dump(),
             {
                 "source_analysis": True,
                 "binary_all_analysis": True,
@@ -835,7 +834,7 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
         )
         self.task_db.multiple_lookups = {
             # input.binary_artifacts
-            (LookupMultiple.parse_obj([6]), None): [
+            (LookupMultiple((6,)), None): [
                 ArtifactInfo(
                     id=6,
                     category=ArtifactCategory.BINARY_PACKAGE,
@@ -895,7 +894,7 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
         self.configure_task(override={"input": {"binary_artifacts": [6]}})
         self.task_db.multiple_lookups = {
             # input.binary_artifacts
-            (LookupMultiple.parse_obj([6]), None): [
+            (LookupMultiple((6,)), None): [
                 ArtifactInfo(
                     id=6,
                     category=ArtifactCategory.BINARY_PACKAGE,
@@ -941,7 +940,7 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
             TaskConfigError,
             "^environment: unexpected artifact category: "
             "'debian:source-package'. Valid categories: "
-            r"\['debian:system-tarball'\]$",
+            r"\['debian:system-image', 'debian:system-tarball'\]$",
         ):
             self.task.compute_dynamic_data(self.task_db)
 
@@ -981,7 +980,7 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
         )
         self.task_db.multiple_lookups = {
             # input.binary_artifacts
-            (LookupMultiple.parse_obj([6]), None): [
+            (LookupMultiple((6,)), None): [
                 ArtifactInfo(
                     id=6,
                     category=ArtifactCategory.SOURCE_PACKAGE,
@@ -1034,21 +1033,6 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
         self.task._lintian_targets = [self.create_temporary_file()]
         self.assertEqual(self.task._cmdline()[: len(minimum_cmd)], minimum_cmd)
 
-    def test_cmdline_minimum_options_jessie(self) -> None:
-        """
-        Test Lintian._cmdline minimum options for Jessie.
-
-        Jessie's lintian does not have display-level classification. It uses
-        pedantic instead.
-        """
-        self.configure_task(override={"target_distribution": "jessie"})
-        self.task._lintian_targets = [self.create_temporary_file()]
-        cmdline = self.task._cmdline()
-
-        display_level_position = cmdline.index("--display-level")
-
-        self.assertEqual(cmdline[display_level_position + 1], ">=pedantic")
-
     def test_cmdline_with_tags(self) -> None:
         """Cmdline add --tags."""
         tags = ["wish-script-but-no-wish-dep", "zero-byte-executable-in-path"]
@@ -1230,7 +1214,7 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
 
     def test_configure_additional_properties_in_input(self) -> None:
         """Assert no additional properties in task_data input."""
-        error_msg = "extra fields not permitted"
+        error_msg = "Extra inputs are not permitted"
         with self.assertRaisesRegex(TaskConfigError, error_msg):
             self.configure_task(
                 override={
@@ -1247,16 +1231,18 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
         build_directory = self.create_temporary_directory()
         (build_directory / Lintian.CAPTURE_OUTPUT_FILENAME).write_text("")
         self.assertEqual(
-            self.task.execution_consistency_errors(build_directory), []
+            self.task.check_directory_for_consistency_errors(build_directory),
+            [],
         )
 
-    def test_execution_consistency_errors(self) -> None:
+    def test_check_directory_for_consistency_errors(self) -> None:
         """There is one consistency error: no lintian.txt."""
         build_directory = self.create_temporary_directory()
 
         expected = f"{Lintian.CAPTURE_OUTPUT_FILENAME} not in {build_directory}"
         self.assertEqual(
-            self.task.execution_consistency_errors(build_directory), [expected]
+            self.task.check_directory_for_consistency_errors(build_directory),
+            [expected],
         )
 
     def test_upload_artifacts(self) -> None:
@@ -1333,7 +1319,9 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
         work_request_id = 147
         self.task.work_request_id = work_request_id
 
-        self.task.upload_artifacts(exec_dir, execution_success=True)
+        self.task.upload_artifacts(
+            exec_dir, execution_result=WorkRequestResults.SUCCESS
+        )
 
         # Debusine Mock upload_artifact expected calls
         upload_artifact_calls = []
@@ -1345,7 +1333,9 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
                 analysis=analysis_file,
                 lintian_output=lintian_output,
                 architecture=architecture,
-                summary=DebianLintianSummary.parse_obj(analysis["summary"]),
+                summary=DebianLintianSummary.model_validate(
+                    analysis["summary"]
+                ),
             )
 
             upload_artifact_calls.append(
@@ -1511,11 +1501,9 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
             file_in_artifact = self.create_temporary_file()
             file_model = FileResponse(
                 size=file_in_artifact.stat().st_size,
-                checksums={
-                    "sha256": pydantic.parse_obj_as(StrMaxLength255, "not-used")
-                },
+                checksums={"sha256": "not-used"},
                 type="file",
-                url=pydantic.parse_obj_as(pydantic.AnyUrl, "https://not-used"),
+                url="https://not-used",
             )
 
             filename = f"pkg-{artifact_id}_amd64.deb"
@@ -1527,9 +1515,7 @@ class LintianTests(ExternalTaskHelperMixin[Lintian], TestCase):
                     category="Test",
                     created_at=dt.datetime.now(),
                     data={},
-                    download_tar_gz_url=pydantic.parse_obj_as(
-                        pydantic.AnyUrl, "https://example.com/not-used"
-                    ),
+                    download_tar_gz_url="https://example.com/not-used",
                     files=FilesResponseType({filename: file_model}),
                     files_to_upload=[],
                 )
