@@ -19,6 +19,7 @@ from debusine.artifacts.models import (
     ArtifactCategory,
     CollectionCategory,
     DebianSourcePackage,
+    WorkRequestResults,
 )
 from debusine.client.models import LookupResultType, LookupSingleResponse
 from debusine.tasks import MakeSourcePackageUpload, TaskConfigError
@@ -256,7 +257,9 @@ class MakeSourcePackageUploadTests(
             ],
         )
 
-        self.task.upload_artifacts(download_directory, execution_success=True)
+        self.task.upload_artifacts(
+            download_directory, execution_result=WorkRequestResults.SUCCESS
+        )
 
         debusine_mock.upload_artifact.assert_called_once_with(
             Upload.create(changes_file=f_out),
@@ -340,7 +343,7 @@ class MakeSourcePackageUploadTests(
 
         with mock.patch.object(self.task, "executor_instance", autospec=True):
             self.task.upload_artifacts(
-                download_directory, execution_success=True
+                download_directory, execution_result=WorkRequestResults.SUCCESS
             )
 
         # Debusine Mock upload_artifact expected calls
