@@ -22,6 +22,7 @@ from debusine.artifacts.models import (
     ArtifactCategory,
     DebianUpload,
     EmptyArtifactData,
+    WorkRequestResults,
 )
 from debusine.artifacts.playground import ArtifactPlayground
 from debusine.client.models import LookupResultType, LookupSingleResponse
@@ -67,7 +68,7 @@ class MergeUploadsTests(ExternalTaskHelperMixin[MergeUploads], TestCase):
         self.task_db = FakeTaskDatabase(
             multiple_lookups={
                 # input.uploads
-                (LookupMultiple.parse_obj([421, 666]), None): [
+                (LookupMultiple((421, 666)), None): [
                     ArtifactInfo(
                         id=421,
                         category=ArtifactCategory.UPLOAD,
@@ -139,7 +140,7 @@ class MergeUploadsTests(ExternalTaskHelperMixin[MergeUploads], TestCase):
 
     def test_compute_dynamic_data_multiple_packages(self) -> None:
         """Dynamic data receives relevant artifact IDs."""
-        binary_artifacts_lookup = LookupMultiple.parse_obj([421, 666])
+        binary_artifacts_lookup = LookupMultiple((421, 666))
         self.task_db.multiple_lookups[(binary_artifacts_lookup, None)][1] = (
             ArtifactInfo(
                 id=666,
@@ -165,7 +166,7 @@ class MergeUploadsTests(ExternalTaskHelperMixin[MergeUploads], TestCase):
         )
 
     def test_compute_dynamic_raise_task_error_wrong_category(self) -> None:
-        binary_artifacts_lookup = LookupMultiple.parse_obj([421, 666])
+        binary_artifacts_lookup = LookupMultiple((421, 666))
         self.task_db.multiple_lookups[(binary_artifacts_lookup, None)][0] = (
             ArtifactInfo(
                 id=421,
@@ -297,8 +298,8 @@ class MergeUploadsTests(ExternalTaskHelperMixin[MergeUploads], TestCase):
                 all_changes[1][field] = "mismatch"
                 with self.assertRaisesRegex(
                     MergeUploadsError,
-                    fr"{field} fields do not match: "
-                    fr"\[{all_changes[0][field]!r}, 'mismatch'\]",
+                    rf"{field} fields do not match: "
+                    rf"\[{all_changes[0][field]!r}, 'mismatch'\]",
                 ):
                     self.task.merge_changes(execute_directory, all_changes)
 
@@ -396,12 +397,12 @@ class MergeUploadsTests(ExternalTaskHelperMixin[MergeUploads], TestCase):
                 execute_directory = self.create_temporary_directory()
                 with self.assertRaisesRegex(
                     MergeUploadsError,
-                    fr"Entries in {field} for mismatch_1\.0_all.deb do not "
-                    fr"match: "
-                    fr"\{{'{checksum}': '0002', 'size': '24', "
-                    fr"'name': 'mismatch_1\.0_all.deb'\}} != "
-                    fr"\{{'{checksum}': '0003', 'size': '32', "
-                    fr"'name': 'mismatch_1\.0_all.deb'\}}",
+                    rf"Entries in {field} for mismatch_1\.0_all.deb do not "
+                    rf"match: "
+                    rf"\{{'{checksum}': '0002', 'size': '24', "
+                    rf"'name': 'mismatch_1\.0_all.deb'\}} != "
+                    rf"\{{'{checksum}': '0003', 'size': '32', "
+                    rf"'name': 'mismatch_1\.0_all.deb'\}}",
                 ):
                     self.task.merge_changes(
                         execute_directory,
@@ -625,9 +626,13 @@ class MergeUploadsTests(ExternalTaskHelperMixin[MergeUploads], TestCase):
         )
 
         execute_directory = self.create_temporary_directory()
-        self.assertTrue(self.task.run(execute_directory))
+        self.assertEqual(
+            self.task.run(execute_directory), WorkRequestResults.SUCCESS
+        )
         assert self.task._upload_artifact is not None
-        self.task.upload_artifacts(execute_directory, execution_success=True)
+        self.task.upload_artifacts(
+            execute_directory, execution_result=WorkRequestResults.SUCCESS
+        )
 
         self.assertEqual(
             self.task._upload_artifact.data,
@@ -729,7 +734,9 @@ class MergeUploadsTests(ExternalTaskHelperMixin[MergeUploads], TestCase):
         self.task.work_request_id = work_request_id
 
         execute_directory = self.create_temporary_directory()
-        self.task.upload_artifacts(execute_directory, execution_success=True)
+        self.task.upload_artifacts(
+            execute_directory, execution_result=WorkRequestResults.SUCCESS
+        )
 
         # Assert that the artifacts were uploaded and relations created
         debusine_mock.upload_artifact.assert_called_once_with(
