@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Unit tests for MmDebstrap class."""
+
 import copy
 import shlex
 from pathlib import Path
@@ -16,6 +17,7 @@ from unittest import mock
 from unittest.mock import call
 
 from debusine.artifacts.local_artifact import DebianSystemTarballArtifact
+from debusine.artifacts.models import WorkRequestResults
 from debusine.tasks import MmDebstrap
 from debusine.tasks.models import (
     BaseDynamicTaskData,
@@ -215,7 +217,6 @@ class MmDebstrapTests(ExternalTaskHelperMixin[MmDebstrap], TestCase):
             "--format=tar",
             "--architectures=amd64",
             "--verbose",
-            "--hook-dir=/usr/share/mmdebstrap/hooks/maybe-jessie-or-older",
             (
                 '--customize-hook=cd "$1" && '
                 "find etc/apt/sources.list.d -type f -delete"
@@ -228,11 +229,16 @@ class MmDebstrapTests(ExternalTaskHelperMixin[MmDebstrap], TestCase):
             f"--customize-hook=download /etc/os-release {os_release_file}",
             f"--customize-hook=copy-out /var/lib/dpkg {var_lib_dpkg}",
             '--customize-hook=rm -f "$1/etc/hostname"',
-            '--customize-hook='
-            'test -h "$1/etc/resolv.conf" || rm -f "$1/etc/resolv.conf"',
-            '--customize-hook='
-            '(test -x "$1/sbin/init" || test -h "$1/sbin/init") ; '
-            'echo $? > "$1/test_sbin_init"',
+            (
+                '--customize-hook='
+                'test -h "$1/etc/resolv.conf" || rm -f "$1/etc/resolv.conf"'
+            ),
+            '--skip=chroot/start-stop-daemon',
+            (
+                '--customize-hook='
+                '(test -x "$1/sbin/init" || test -h "$1/sbin/init") ; '
+                'echo $? > "$1/test_sbin_init"'
+            ),
             f'--customize-hook=download test_sbin_init {test_sbin_init}',
             '--customize-hook=rm "$1/test_sbin_init"',
             "--include=hello,python3",
@@ -345,15 +351,17 @@ class MmDebstrapTests(ExternalTaskHelperMixin[MmDebstrap], TestCase):
         packages = self.patch_subprocess_run_pkglist()
 
         mirror = (
-            MmDebstrapData.parse_obj(self.SAMPLE_TASK_DATA)
+            MmDebstrapData.model_validate(self.SAMPLE_TASK_DATA)
             .bootstrap_repositories[0]
             .mirror
         )
-        bootstrap_options = MmDebstrapBootstrapOptions.parse_obj(
+        bootstrap_options = MmDebstrapBootstrapOptions.model_validate(
             self.SAMPLE_TASK_DATA["bootstrap_options"]
         )
 
-        self.task.upload_artifacts(directory, execution_success=True)
+        self.task.upload_artifacts(
+            directory, execution_result=WorkRequestResults.SUCCESS
+        )
 
         calls = []
 
@@ -382,62 +390,6 @@ class MmDebstrapTests(ExternalTaskHelperMixin[MmDebstrap], TestCase):
 
         debusine_mock.upload_artifact.assert_has_calls(calls)
 
-    def test_upload_artifacts_jessie(self) -> None:
-        """Test upload_artifacts() for a jessie tarball."""
-        directory = self.create_temporary_directory()
-
-        system_tarball = directory / MmDebstrap._OUTPUT_SYSTEM_FILE
-        system_tarball.write_bytes(b"Generated tarball")
-
-        # Debusine.upload_artifact is mocked to verify the call only
-        debusine_mock = self.mock_debusine()
-
-        os_release_data = self.write_os_release(
-            directory / self.task._OS_RELEASE_FILE, codename="jessie", version=8
-        )
-        (directory / self.task._TEST_SBIN_INIT_RETURN_CODE_FILE).write_text("0")
-
-        packages = self.patch_subprocess_run_pkglist()
-
-        mirror = (
-            MmDebstrapData.parse_obj(self.SAMPLE_TASK_DATA)
-            .bootstrap_repositories[0]
-            .mirror
-        )
-        bootstrap_options = MmDebstrapBootstrapOptions.parse_obj(
-            self.SAMPLE_TASK_DATA["bootstrap_options"]
-        )
-        self.task.data.bootstrap_repositories[0].suite = "jessie"
-
-        self.task.upload_artifacts(directory, execution_success=True)
-
-        calls = []
-
-        expected_system_artifact = DebianSystemTarballArtifact.create(
-            system_tarball,
-            data={
-                "variant": None,
-                "architecture": bootstrap_options.architecture,
-                "vendor": os_release_data["ID"],
-                "codename": "jessie",
-                "components": ["main", "contrib"],
-                "pkglist": packages,
-                "with_dev": True,
-                "with_init": True,
-                "mirror": mirror,
-            },
-        )
-
-        calls.append(
-            call(
-                expected_system_artifact,
-                workspace=self.task.workspace_name,
-                work_request=self.task.work_request_id,
-            )
-        )
-
-        debusine_mock.upload_artifact.assert_has_calls(calls)
-
     def test_upload_artifacts_sid(self) -> None:
         """Test upload_artifacts() for a sid tarball."""
         directory = self.create_temporary_directory()
@@ -458,16 +410,18 @@ class MmDebstrapTests(ExternalTaskHelperMixin[MmDebstrap], TestCase):
         packages = self.patch_subprocess_run_pkglist()
 
         mirror = (
-            MmDebstrapData.parse_obj(self.SAMPLE_TASK_DATA)
+            MmDebstrapData.model_validate(self.SAMPLE_TASK_DATA)
             .bootstrap_repositories[0]
             .mirror
         )
-        bootstrap_options = MmDebstrapBootstrapOptions.parse_obj(
+        bootstrap_options = MmDebstrapBootstrapOptions.model_validate(
             self.SAMPLE_TASK_DATA["bootstrap_options"]
         )
         self.task.data.bootstrap_repositories[0].suite = "unstable"
 
-        self.task.upload_artifacts(directory, execution_success=True)
+        self.task.upload_artifacts(
+            directory, execution_result=WorkRequestResults.SUCCESS
+        )
 
         calls = []
 
@@ -497,9 +451,11 @@ class MmDebstrapTests(ExternalTaskHelperMixin[MmDebstrap], TestCase):
         debusine_mock.upload_artifact.assert_has_calls(calls)
 
     def test_upload_artifacts_do_nothing(self) -> None:
-        """Test upload_artifacts() doing nothing: execution_success=False."""
+        """Test upload_artifacts() doing nothing: execution_result=FAILURE."""
         self.mock_debusine()
-        self.task.upload_artifacts(Path(), execution_success=False)
+        self.task.upload_artifacts(
+            Path(), execution_result=WorkRequestResults.FAILURE
+        )
 
     def test_upload_no_components_specified(self) -> None:
         """Test upload_artifacts() falls back to sources_file's components."""
@@ -535,11 +491,13 @@ class MmDebstrapTests(ExternalTaskHelperMixin[MmDebstrap], TestCase):
 
         packages = self.patch_subprocess_run_pkglist()
 
-        self.task.upload_artifacts(directory, execution_success=True)
+        self.task.upload_artifacts(
+            directory, execution_result=WorkRequestResults.SUCCESS
+        )
 
         calls = []
 
-        bootstrap_options = MmDebstrapBootstrapOptions.parse_obj(
+        bootstrap_options = MmDebstrapBootstrapOptions.model_validate(
             self.SAMPLE_TASK_DATA["bootstrap_options"]
         )
         expected_system_artifact = DebianSystemTarballArtifact.create(
