@@ -30,6 +30,7 @@ from debusine.artifacts.models import (
     DebianSystemTarball,
     DebianUpload,
     EmptyArtifactData,
+    WorkRequestResults,
 )
 from debusine.client.models import (
     ArtifactResponse,
@@ -925,7 +926,9 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
         self.task.workspace_name = workspace_name
         self.task.work_request_id = work_request_id = 147
 
-        self.task.upload_artifacts(execute_directory, execution_success=True)
+        self.task.upload_artifacts(
+            execute_directory, execution_result=WorkRequestResults.SUCCESS
+        )
 
         debusine_mock.upload_artifact.assert_called_once_with(
             PiupartsArtifact.create(
@@ -1018,4 +1021,6 @@ class PiupartsTests(ExternalTaskHelperMixin[Piuparts], TestCase):
         assert self.task.executor is not None
         self.task.executor.system_image = self.fake_system_tarball_artifact()
 
-        self.task.upload_artifacts(download_directory, execution_success=True)
+        self.task.upload_artifacts(
+            download_directory, execution_result=WorkRequestResults.SUCCESS
+        )
