@@ -10,23 +10,26 @@
 """Unit tests for the SbuildValidatorMixin class."""
 
 from pathlib import Path
+from typing import override
 
-from debusine.tasks import BaseExternalTask
+from debusine.artifacts.models import WorkRequestResults
+from debusine.tasks import DefaultDynamicData
 from debusine.tasks.models import BaseDynamicTaskData, BaseTaskData
 from debusine.tasks.sbuild_validator_mixin import SbuildValidatorMixin
-from debusine.tasks.tests.helper_mixin import TestTaskMixin
+from debusine.tasks.tests.helper_mixin import SampleBaseExternalTask
 from debusine.test import TestCase
 from debusine.utils import calculate_hash
 
 
 class TaskWithSbuildValidatorMixin(
-    TestTaskMixin,
     SbuildValidatorMixin,
-    BaseExternalTask[BaseTaskData, BaseDynamicTaskData],
+    SampleBaseExternalTask[BaseTaskData, BaseDynamicTaskData],
+    DefaultDynamicData[BaseTaskData],
 ):
     """Minimum class to test SbuildValidatorMixin."""
 
-    def run(self, execute_directory: Path) -> bool:
+    @override
+    def run(self, execute_directory: Path) -> WorkRequestResults:
         """Unused abstract method from BaseExternalTask."""
         raise NotImplementedError()
 
@@ -36,6 +39,7 @@ class SbuildValidatorMixinTests(TestCase):
 
     def setUp(self) -> None:
         """Set up test."""
+        super().setUp()
         self.sbuild_validator_mixin = TaskWithSbuildValidatorMixin({})
 
     def test_check_directory_for_consistency_errors_no_errors(self) -> None:
@@ -223,6 +227,6 @@ class SbuildValidatorMixinTests(TestCase):
             ),
             [
                 "Files in directory not referenced in "
-                f".changes or .dsc: [\'{str(file2)}\']"
+                f".changes or .dsc: ['{str(file2)}']"
             ],
         )
