@@ -8,13 +8,17 @@
 # contained in the LICENSE file.
 
 """Unit tests for SimpleSystemImageBuild class."""
+
 import shlex
 from copy import deepcopy
 from pathlib import Path
 from typing import Any, cast
 from unittest.mock import call, patch
 
+import pydantic
+
 from debusine.artifacts.local_artifact import DebianSystemImageArtifact
+from debusine.artifacts.models import WorkRequestResults
 from debusine.tasks import SimpleSystemImageBuild
 from debusine.tasks.models import (
     BaseDynamicTaskData,
@@ -117,6 +121,16 @@ class SimpleSystemImageBuildTests(
         super().setUp()
         self.configure_task()
 
+    def configure_task(
+        self,
+        task_data: dict[str, Any] | None = None,
+        override: dict[str, Any] | None = None,
+        remove: list[str] | None = None,
+    ) -> None:
+        """Perform further setup."""
+        super().configure_task(task_data, override, remove)
+        self.task_db = FakeTaskDatabase()
+
     def tearDown(self) -> None:
         """Delete objects."""
         if self.task._debug_log_files_directory:
@@ -138,7 +152,7 @@ class SimpleSystemImageBuildTests(
         self.configure_task(override={"bootstrap_options": bootstrap_options})
 
         self.assertEqual(
-            self.task.data.dict(exclude_unset=True),
+            self.task.data.model_dump(exclude_unset=True),
             {
                 'bootstrap_options': {
                     'architecture': 'amd64',
@@ -160,7 +174,9 @@ class SimpleSystemImageBuildTests(
                         ),
                         'components': ['main'],
                         'keyring': {
-                            'url': 'https://example.com/keyring.gpg',
+                            'url': pydantic.AnyUrl(
+                                'https://example.com/keyring.gpg'
+                            ),
                         },
                         'mirror': 'https://example.com',
                         'suite': 'bullseye',
@@ -175,11 +191,11 @@ class SimpleSystemImageBuildTests(
         )
 
     def test_compute_dynamic_data(self) -> None:
-        task_database = FakeTaskDatabase()
         self.assertEqual(
-            self.task.compute_dynamic_data(task_database),
+            self.task.compute_dynamic_data(self.task_db),
             BaseDynamicTaskData(
                 subject="stable",
+                parameter_summary="stable (amd64)",
                 runtime_context="amd64:None:hello",
                 configuration_context="amd64",
             ),
@@ -488,7 +504,9 @@ class SimpleSystemImageBuildTests(
             return 0
 
         with patch('subprocess.check_call', mock_tar):
-            self.task.upload_artifacts(directory, execution_success=True)
+            self.task.upload_artifacts(
+                directory, execution_result=WorkRequestResults.SUCCESS
+            )
 
         calls = []
 
@@ -553,7 +571,9 @@ class SimpleSystemImageBuildTests(
             return 0
 
         with patch('subprocess.check_call', mock_qemu_img):
-            self.task.upload_artifacts(directory, execution_success=True)
+            self.task.upload_artifacts(
+                directory, execution_result=WorkRequestResults.SUCCESS
+            )
 
         calls = []
 
@@ -632,7 +652,9 @@ class SimpleSystemImageBuildTests(
             return 0
 
         with patch('subprocess.check_call', mock_tar):
-            self.task.upload_artifacts(directory, execution_success=True)
+            self.task.upload_artifacts(
+                directory, execution_result=WorkRequestResults.SUCCESS
+            )
 
         calls = []
 
@@ -672,12 +694,10 @@ class SimpleSystemImageBuildTests(
     def test_upload_artifacts_do_nothing(self) -> None:
         """Test upload_artifacts() doing nothing: execution_success=False."""
         self.mock_debusine()
-        self.task.upload_artifacts(Path(), execution_success=False)
+        self.task.upload_artifacts(
+            Path(), execution_result=WorkRequestResults.FAILURE
+        )
 
     def test_get_input_artifacts_ids(self) -> None:
         """Test get_input_artifacts_ids."""
         self.assertEqual(self.task.get_input_artifacts_ids(), [])
-
-    def test_get_label(self) -> None:
-        """Test get_label."""
-        self.assertEqual(self.task.get_label(), "bootstrap a system image")
