@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Unit tests for SystemBootstrap class."""
+
 import copy
 import hashlib
 import io
@@ -18,11 +19,6 @@ from typing import Any, cast
 from unittest import mock
 from unittest.mock import call
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 import requests
 import responses
 from debian.deb822 import Deb822
@@ -91,6 +87,16 @@ class SystemBootstrapTests(
             self.task._debug_log_files_directory.cleanup()
         super().tearDown()
 
+    def configure_task(
+        self,
+        task_data: dict[str, Any] | None = None,
+        override: dict[str, Any] | None = None,
+        remove: list[str] | None = None,
+    ) -> None:
+        """Perform further setup."""
+        super().configure_task(task_data, override, remove)
+        self.task_db = FakeTaskDatabase()
+
     def test_configure_task(self) -> None:
         """Ensure self.SAMPLE_TASK_DATA is valid."""
         self.configure_task(self.SAMPLE_TASK_DATA)
@@ -136,12 +142,11 @@ class SystemBootstrapTests(
             self.configure_task(task_data)
 
     def test_compute_dynamic_data(self) -> None:
-        task_database = FakeTaskDatabase()
-
         self.assertEqual(
-            self.task.compute_dynamic_data(task_database),
+            self.task.compute_dynamic_data(self.task_db),
             BaseDynamicTaskData(
                 subject="bookworm",
+                parameter_summary="bookworm (amd64-buildd)",
                 runtime_context="amd64:buildd:hello,python3",
                 configuration_context="amd64",
             ),
@@ -158,10 +163,7 @@ class SystemBootstrapTests(
         keyring: SystemBootstrapRepositoryKeyring | None = None
         if keyring_url is not None:
             keyring = SystemBootstrapRepositoryKeyring(
-                url=pydantic.parse_obj_as(
-                    pydantic.AnyUrl | pydantic.FileUrl, keyring_url
-                ),
-                sha256sum=keyring_sha256sum,
+                url=keyring_url, sha256sum=keyring_sha256sum
             )
         repository = SystemBootstrapRepository(
             types=[SystemBootstrapRepositoryType.DEB],
@@ -248,7 +250,7 @@ class SystemBootstrapTests(
         self.assertIsNotNone(repository.keyring)
         assert repository.keyring
         responses.add(
-            responses.GET, repository.keyring.url, body=keyring_contents
+            responses.GET, str(repository.keyring.url), body=keyring_contents
         )
 
         actual = self.task._deb822_source(
@@ -277,7 +279,7 @@ class SystemBootstrapTests(
         self.assertIsNotNone(repository.keyring)
         assert repository.keyring
         responses.add(
-            responses.GET, repository.keyring.url, body=keyring_contents
+            responses.GET, str(repository.keyring.url), body=keyring_contents
         )
 
         actual = self.task._deb822_source(
@@ -310,7 +312,7 @@ class SystemBootstrapTests(
         assert repository.keyring
 
         responses.add(
-            responses.GET, repository.keyring.url, body=keyring_contents
+            responses.GET, str(repository.keyring.url), body=keyring_contents
         )
 
         actual_sha256 = hashlib.sha256(keyring_contents).hexdigest()
@@ -346,7 +348,7 @@ class SystemBootstrapTests(
         assert repository.keyring
 
         responses.add(
-            responses.GET, repository.keyring.url, body=keyring_contents
+            responses.GET, str(repository.keyring.url), body=keyring_contents
         )
 
         self.task._deb822_source(
@@ -400,9 +402,7 @@ class SystemBootstrapTests(
             check_signature_with=(
                 SystemBootstrapRepositoryCheckSignatureWith.EXTERNAL
             ),
-            keyring=SystemBootstrapRepositoryKeyring(
-                url=pydantic.parse_obj_as(pydantic.AnyUrl, keyring_url)
-            ),
+            keyring=SystemBootstrapRepositoryKeyring(url=keyring_url),
         )
 
         for use_signed_by in [True, False]:
@@ -552,10 +552,6 @@ class SystemBootstrapTests(
         with self.assertRaisesRegex(ValueError, msg):
             SystemBootstrap._list_components_for_suite(mirror_url, suite)
 
-    def test_get_label(self) -> None:
-        """Test get_label."""
-        self.assertEqual(self.task.get_label(), "bootstrap a system tarball")
-
     def test_get_source_components_reads_first_source(self) -> None:
         sources = self.create_temporary_file(
             contents=dedent(
