@@ -19,11 +19,6 @@ from itertools import count
 from typing import Any
 from urllib.parse import quote, urljoin
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic as pydantic  # type: ignore
-
 from debusine.artifacts.models import DebianSystemTarball
 from debusine.client.models import (
     ArtifactResponse,
@@ -57,12 +52,12 @@ def data_generator(size: int) -> Iterator[bytes]:
 
 def yesterday() -> dt.datetime:
     """Return datetime of yesterday."""
-    return dt.datetime.now(dt.timezone.utc) - dt.timedelta(days=1)
+    return dt.datetime.now(dt.UTC) - dt.timedelta(days=1)
 
 
 def tomorrow() -> dt.datetime:
     """Return datetime of tomorrow."""
-    return dt.datetime.now(dt.timezone.utc) + dt.timedelta(days=1)
+    return dt.datetime.now(dt.UTC) + dt.timedelta(days=1)
 
 
 def date_time_to_isoformat_rest_framework(value: dt.datetime) -> str:
@@ -105,7 +100,7 @@ def create_artifact_response(
         "category": "Testing",
         "data": {},
         "files_to_upload": [],
-        "created_at": dt.datetime.now(dt.timezone.utc),
+        "created_at": dt.datetime.now(dt.UTC),
         "scope": scope,
         "workspace": "Testing",
         "download_tar_gz_url": "https://example.com/some-path",
@@ -151,7 +146,7 @@ def create_work_request_response(
     """Return a WorkRequestResponse. Use defaults for certain fields."""
     defaults: dict[str, Any] = {
         "id": 11,
-        "created_at": dt.datetime.now(dt.timezone.utc),
+        "created_at": dt.datetime.now(dt.UTC),
         "status": "pending",
         "result": "",
         "task_type": "Worker",
@@ -164,15 +159,17 @@ def create_work_request_response(
         "workspace": "Testing",
     }
     defaults.update(kwargs)
-    defaults.setdefault(
-        "url",
-        urljoin(
-            base_url,
-            f"{quote(scope)}/{quote(defaults['workspace'])}/"
-            f"work-request/{defaults['id']}/",
-        ),
+    api_url = urljoin(
+        base_url,
+        f"{quote(scope)}/{quote(defaults['workspace'])}/"
+        f"work-request/{defaults['id']}/",
+    )
+    defaults.setdefault("url", api_url)
+    defaults.setdefault("links", {})
+    defaults["links"].setdefault("self", api_url)
+    defaults["links"].setdefault(
+        "webui_self", f"{quote(scope)}/{quote(defaults['workspace'])}/"
     )
-
     return WorkRequestResponse(**defaults)
 
 
@@ -182,13 +179,9 @@ def create_listing_response(
     """Return a single page of PaginatedResponse, containing args."""
     return PaginatedResponse(
         count=None,
-        next=(
-            pydantic.parse_obj_as(pydantic.AnyUrl, next_url)
-            if next_url is not None
-            else None
-        ),
+        next=next_url,
         previous=None,
-        results=[arg.dict() for arg in args],
+        results=[arg.model_dump() for arg in args],
     )
 
 
@@ -203,9 +196,7 @@ def create_system_tarball_data(
         vendor="debian",
         codename=codename,
         components=["main"],
-        mirror=pydantic.parse_obj_as(
-            pydantic.AnyUrl, "https://deb.debian.org/debian"
-        ),
+        mirror="https://deb.debian.org/debian",
         variant=variant,
         pkglist={},
         architecture=architecture,
