@@ -10,12 +10,11 @@
 """Tests for debusine.tests.base.TestCase."""
 
 import contextlib
+import datetime as dt
 import io
 import logging
-import os
 import re
 from configparser import ConfigParser
-from datetime import datetime, timezone
 from unittest import mock
 
 import lxml
@@ -40,7 +39,7 @@ class TestCaseTests(TestCase):
         directory = self.create_temp_config_directory(config)
 
         actual_config = ConfigParser()
-        actual_config.read(os.path.join(directory, 'config.ini'))
+        actual_config.read(directory / 'config.ini')
 
         expected_config = ConfigParser()
         expected_config.read_dict(config)
@@ -67,19 +66,23 @@ class TestCaseTests(TestCase):
     def test_assert_dict_contains_subset_arg1_not_a_dictionary(self) -> None:
         """Raise exception because of wrong type argument 1."""
         expected_message = (
-            "'a' is not an instance of <class 'dict'> : "
-            "First argument is not a dictionary"
+            "'a' is not an instance of <class 'collections.abc.Mapping'> : "
+            "First argument is not a mapping"
         )
-        with self.assertRaisesRegex(self.failureException, expected_message):
+        with self.assertRaisesRegex(
+            self.failureException, re.escape(expected_message)
+        ):
             self.assertDictContainsAll('a', {})  # type: ignore[arg-type]
 
     def test_assert_dict_contains_subset_arg2_not_a_dictionary(self) -> None:
         """Raise exception because of wrong type argument 2."""
         expected_message = (
-            "'b' is not an instance of <class 'dict'> : "
-            "Second argument is not a dictionary"
+            "'b' is not an instance of <class 'collections.abc.Mapping'> : "
+            "Second argument is not a mapping"
         )
-        with self.assertRaisesRegex(self.failureException, expected_message):
+        with self.assertRaisesRegex(
+            self.failureException, re.escape(expected_message)
+        ):
             self.assertDictContainsAll({}, 'b')  # type: ignore[arg-type]
 
     def test_assert_raises_system_exit_no_system_exit(self) -> None:
@@ -406,7 +409,7 @@ class TestCaseTests(TestCase):
         )
         self.assertDatetimeContentEqual(
             tree.xpath("//b")[0],
-            datetime(2025, 1, 1, 12, 30, tzinfo=timezone.utc),
+            dt.datetime(2025, 1, 1, 12, 30, tzinfo=dt.UTC),
         )
 
     def test_assertDatetimeContentEqual_anywhere(self) -> None:
@@ -416,7 +419,7 @@ class TestCaseTests(TestCase):
         )
         self.assertDatetimeContentEqual(
             tree.xpath("//p")[0],
-            datetime(2025, 1, 1, 12, 30, tzinfo=timezone.utc),
+            dt.datetime(2025, 1, 1, 12, 30, tzinfo=dt.UTC),
             anywhere=True,
         )
 
@@ -430,7 +433,7 @@ class TestCaseTests(TestCase):
         ):
             self.assertDatetimeContentEqual(
                 tree.xpath("//ul")[0],
-                datetime(2025, 1, 1, 12, 30, tzinfo=timezone.utc),
+                dt.datetime(2025, 1, 1, 12, 30, tzinfo=dt.UTC),
             )
 
     def test_assertDatetimeContentEqualDifferentDatetime(self) -> None:
@@ -443,17 +446,17 @@ class TestCaseTests(TestCase):
         ):
             self.assertDatetimeContentEqual(
                 tree.xpath("//ul")[0],
-                datetime(2025, 1, 1, 12, 30, tzinfo=timezone.utc),
+                dt.datetime(2025, 1, 1, 12, 30, tzinfo=dt.UTC),
             )
 
     def test_assertDatetimeContentEqualIgnoreSeconds(self) -> None:
         """:py:meth:`assertDatetimeContentEqual` ignores seconds."""
         tree = self.assertHTMLValid("<ul><li>2025-01-01 12:30</li></ul>")
         for expected in (
-            datetime(2025, 1, 1, 12, 30, 0, tzinfo=timezone.utc),
-            datetime(2025, 1, 1, 12, 30, 1, tzinfo=timezone.utc),
-            datetime(2025, 1, 1, 12, 30, 1, 12345, tzinfo=timezone.utc),
-            datetime(2025, 1, 1, 12, 30, 0, 12345, tzinfo=timezone.utc),
+            dt.datetime(2025, 1, 1, 12, 30, 0, tzinfo=dt.UTC),
+            dt.datetime(2025, 1, 1, 12, 30, 1, tzinfo=dt.UTC),
+            dt.datetime(2025, 1, 1, 12, 30, 1, 12345, tzinfo=dt.UTC),
+            dt.datetime(2025, 1, 1, 12, 30, 0, 12345, tzinfo=dt.UTC),
         ):
             with self.subTest(expected=expected.isoformat()):
                 self.assertDatetimeContentEqual(tree.xpath("//ul")[0], expected)
