@@ -10,29 +10,40 @@
 """utils module contain utilities used by different components of debusine."""
 
 import hashlib
+import os
 import re
 import shutil
+import tempfile
 from collections.abc import Callable, Generator, Mapping, Sequence
+from contextlib import contextmanager
 from enum import StrEnum
+from enum import property as enum_property
+from importlib.metadata import PackageNotFoundError, version
 from pathlib import Path
 from types import GenericAlias
 from typing import (
+    Annotated,
     Any,
-    Generic,
+    BinaryIO,
+    IO,
     Literal,
     TYPE_CHECKING,
-    TypeVar,
+    TextIO,
     TypedDict,
     Union,
-    get_args,
-    get_origin,
+    overload,
 )
 
+import pydantic
+
+# https://github.com/pydantic/pydantic/issues/12720
+from pydantic._internal._generics import get_args, get_origin
 from requests.structures import CaseInsensitiveDict
 
 from debian import deb822
 
 if TYPE_CHECKING:
+    from _typeshed import OpenBinaryModeWriting, OpenTextModeWriting
     from django.http.request import HttpHeaders
 
 CALCULATE_HASH_CHUNK_SIZE = 1 * 1024 * 1024
@@ -49,11 +60,8 @@ def calculate_hash(file_path: Path, hash_name: str) -> bytes:
     return hasher.digest()
 
 
-_Get = TypeVar("_Get", covariant=True)
-
-
 # taken from functional.py in python3-django 3:4.2.11-1 to avoid the dependency
-class classproperty(Generic[_Get]):
+class classproperty[Get]:
     """
     classproperty definition.
 
@@ -61,13 +69,15 @@ class classproperty(Generic[_Get]):
     that can be accessed directly from the class.
     """
 
-    def __init__(self, method: Callable[[Any], _Get]) -> None:
+    def __init__(self, method: Callable[[Any], Get]) -> None:
         """Define __init__."""
         self.fget = method
 
     def __get__(
-        self, instance: Any | None, cls: type[Any] | None = None  # noqa: U100
-    ) -> _Get:
+        self,
+        instance: Any | None,  # noqa: U100
+        cls: type[Any] | None = None,
+    ) -> Get:
         """Define __get__."""
         return self.fget(cls)
 
@@ -76,8 +86,10 @@ def _error_message_invalid_header(header_name: str, header_value: str) -> str:
     return f'Invalid {header_name} header: "{header_value}"'
 
 
+# TODO: RFC 7233 allows multiple byte-ranges separated by commas, but this
+# currently raises an error for those.
 def parse_range_header(
-    headers: Union[CaseInsensitiveDict[str], "HttpHeaders"],
+    headers: Union[CaseInsensitiveDict[str], "HttpHeaders"], file_size: int
 ) -> dict[str, int] | None:
     """Parse headers["Range"]. Return dictionary with information."""
     header_name = "Range"
@@ -86,8 +98,21 @@ def parse_range_header(
     if header_value is None:
         return None
 
-    if m := re.match("bytes=([0-9]+)-([0-9]+)", header_value):
-        return {"start": int(m.group(1)), "end": int(m.group(2))}
+    if m := re.match("^bytes=([0-9]*)-([0-9]*)$", header_value):
+        start, end = m.groups()
+        if start or end:
+            if not start:
+                # This is a suffix-byte-range-spec
+                # (https://www.rfc-editor.org/rfc/rfc7233#section-2.1), and
+                # requests the last ``end`` bytes of the representation (not
+                # from the start of the representation to the byte with
+                # offset ``end``, as one might expect).
+                start = file_size - int(end)
+                end = file_size - 1
+            elif not end:
+                # Request from ``start`` to the end of the file.
+                end = file_size - 1
+            return {"start": int(start), "end": int(end)}
 
     raise ValueError(_error_message_invalid_header(header_name, header_value))
 
@@ -245,7 +270,11 @@ def _get_specialization(cls: type, base: type) -> Any:
       means of multiple inheritance.
     """
     specializations: set[GenericAlias] = set()
-    for cls_base in getattr(cls, "__orig_bases__", []):
+    if hasattr(cls, "__pydantic_generic_metadata__"):
+        orig_bases = [get_origin(cls)[get_args(cls)]]
+    else:
+        orig_bases = getattr(cls, "__orig_bases__", [])
+    for cls_base in orig_bases:
         origin = get_origin(cls_base)
         if origin == base:
             specializations.add(cls_base)
@@ -256,7 +285,8 @@ def _get_specialization(cls: type, base: type) -> Any:
     if len(specializations) != 1:
         raise AssertionError(
             f"{cls.__qualname__} must specialize {base.__qualname__} with "
-            f"exactly one consistent list of type arguments"
+            f"exactly one consistent list of type arguments "
+            f"(got {specializations})"
         )
     [specialization] = specializations
     return specialization
@@ -272,20 +302,93 @@ def extract_generic_type_arguments(
     (i.e. one that has Generic[...] as a base class), and allows extracting
     the specializing type arguments so that they can be used as factories.
     """
-    return get_args(_get_specialization(cls, expected_origin))
+    args = get_args(_get_specialization(cls, expected_origin))
+    assert isinstance(args, tuple)
+    return args
 
 
 class DjangoChoicesEnum(StrEnum):
     """Enable a StrEnum to be used for a Django choices field."""
 
+    @enum_property
+    def label(self) -> str:
+        """Return this item's label."""
+        return self
+
     @classproperty
     def choices(cls) -> Generator[tuple[str, str]]:
         """Return a Django model compatible set of choices."""
         for item in cls:
-            yield (item, item)
+            # mypy can't quite follow the maze of enum properties here, but
+            # this works.
+            yield (item, item.label)  # type: ignore[attr-defined]
 
 
 class NotSupportedError(Exception):
     """The requested function is not supported."""
 
     pass
+
+
+@overload
+@contextmanager
+def atomic_writer(
+    path: str | os.PathLike[str],
+    mode: "OpenBinaryModeWriting" = "wb",
+    chmod: int = ...,
+) -> Generator[BinaryIO]: ...
+
+
+@overload
+@contextmanager
+def atomic_writer(
+    path: str | os.PathLike[str], mode: "OpenTextModeWriting", chmod: int = ...
+) -> Generator[TextIO]: ...
+
+
+@contextmanager
+def atomic_writer(
+    path: str | os.PathLike[str],
+    mode: Union["OpenTextModeWriting", "OpenBinaryModeWriting"] = "wb",
+    chmod: int = 0o600,
+) -> Generator[IO[Any]]:
+    """
+    Atomically write to a file.
+
+    The yielded file object is a temporary file in the same directory as the
+    target path.  On exit from the context manager, it is renamed into
+    place.
+    """
+    path = Path(path)
+    with tempfile.NamedTemporaryFile(
+        mode, dir=path.parent, prefix=path.name, suffix=".new", delete=False
+    ) as temp:
+        try:
+            yield temp
+            temp.flush()
+            os.fdatasync(temp)
+            os.fchmod(temp.fileno(), chmod)
+            os.replace(temp.name, path)
+        except Exception:
+            os.unlink(temp.name)
+            raise
+
+
+def debusine_version() -> str | None:
+    """Return Debusine's version, if available."""
+    try:
+        return version("debusine")
+    except PackageNotFoundError:
+        return None
+
+
+Base64BytesAsStr = Annotated[
+    pydantic.Base64Bytes,
+    pydantic.BeforeValidator(
+        lambda x: x.encode(), json_schema_input_type="str"
+    ),
+    pydantic.WrapSerializer(
+        lambda value, handler, info: handler(value, info).decode(),
+        return_type="str",
+    ),
+]
