@@ -13,12 +13,9 @@ import shutil
 import subprocess
 import tempfile
 from pathlib import Path
-from typing import Generic, TypeVar
 
 import yaml
 
-T = TypeVar("T")
-
 
 class InvalidData(ValueError):
     """Exception raised when the user entered invalid data."""
@@ -33,7 +30,7 @@ class EditorInteractionError(RuntimeError):
     """
 
 
-class YamlEditor(Generic[T]):
+class YamlEditor[T]:
     """Let the user edit a data structure as YAML in a text editor."""
 
     def __init__(
@@ -143,5 +140,9 @@ class YamlEditor(Generic[T]):
                     self.message(f"Edits left in {self.editor_file}")
                     return False
             else:
-                self.editor_file.unlink(missing_ok=True)
+                self.cleanup()
                 return True
+
+    def cleanup(self) -> None:
+        """Delete the temporary file we created."""
+        self.editor_file.unlink(missing_ok=True)
