@@ -10,15 +10,12 @@
 """Typing utilities."""
 
 from collections.abc import Callable
-from typing import Any, ParamSpec, TypeVar, cast
-
-T = TypeVar('T')
-P = ParamSpec('P')
+from typing import Any, cast
 
 
 # See https://stackoverflow.com/questions/71253495/how-to-annotate-the-type-of-arguments-forwarded-to-another-function  # noqa: E501
-def copy_signature_from(
-    _origin: Callable[P, T]
+def copy_signature_from[T, **P](
+    _origin: Callable[P, T],
 ) -> Callable[[Callable[..., Any]], Callable[P, T]]:
     """Copy function signature from another one."""
 
