@@ -9,13 +9,16 @@
 
 """Test views for package archives."""
 
+import base64
 import datetime as dt
 import hashlib
 from abc import ABC
 from collections.abc import Mapping
+from contextlib import ExitStack
 from operator import attrgetter
 from pathlib import PurePath
 from typing import Any, ClassVar, overload
+from unittest import mock
 
 from debian.copyright import parse_multiline
 from debian.deb822 import Deb822
@@ -25,13 +28,37 @@ from django.utils import timezone
 from django.utils.cache import has_vary_header
 from pgpy import PGPKey, PGPKeyring
 from pgpy.constants import EllipticCurveOID, PubKeyAlgorithm
-from rest_framework import status
+from rest_framework import HTTP_HEADER_ENCODING, status
 
 from debusine.artifacts.models import CollectionCategory
 from debusine.assets.models import KeyPurpose
-from debusine.db.models import Collection, CollectionItem
+from debusine.db.models import Collection, CollectionItem, Token, Workspace
 from debusine.db.playground import scenarios
 from debusine.test.django import TestCase, TestResponseType
+from debusine.web.archives.views import SigningKeysResponse
+
+
+class SigningKeysResponseTests(TestCase):
+    """Tests for :py:class:`SigningKeysResponse`."""
+
+    def test_render(self) -> None:
+        keys = [
+            PGPKey.new(PubKeyAlgorithm.EdDSA, EllipticCurveOID.Ed25519).pubkey
+            for _ in range(2)
+        ]
+        response = SigningKeysResponse([bytes(key) for key in keys])
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(
+            response.headers["Content-Type"],
+            "application/pgp-keys; charset=utf-8",
+        )
+        assert response.content.startswith(
+            b"-----BEGIN PGP PUBLIC KEY BLOCK-----\n"
+        )
+        self.assertEqual(
+            PGPKeyring(response.content).fingerprints(),
+            {key.fingerprint for key in keys},
+        )
 
 
 class ArchiveViewTests(TestCase, ABC):
@@ -80,17 +107,34 @@ class ArchiveViewTests(TestCase, ABC):
         snapshot: dt.datetime | None = None,
         path: str,
         headers: Mapping[str, Any] | None = None,
+        token: Token | None = None,
     ) -> TestResponseType:
         """Get a file from an archive."""
-        fqdn = settings.DEBUSINE_DEBIAN_ARCHIVE_PRIMARY_FQDN
-        scope_name = self.scenario.scope.name
-        if workspace_name is None:
-            workspace_name = self.scenario.workspace.name
-        url = f"/{scope_name}/{workspace_name}"
-        if snapshot is not None:
-            url += "/" + self.format_snapshot(snapshot)
-        url += f"/{path}"
-        return self.client.get(url, HTTP_HOST=fqdn, headers=headers)
+        with ExitStack() as stack:
+            fqdn = settings.DEBUSINE_DEBIAN_ARCHIVE_PRIMARY_FQDN
+            scope_name = self.scenario.scope.name
+            if workspace_name is None:
+                workspace_name = self.scenario.workspace.name
+            url = f"/{scope_name}/{workspace_name}"
+            if snapshot is not None:
+                url += "/" + self.format_snapshot(snapshot)
+            url += f"/{path}"
+            if token is not None:
+                headers = {**(headers or {})}
+                assert token.user is not None
+                credentials = f"{token.user.username}:{token.key}"
+                base64_credentials = base64.b64encode(
+                    credentials.encode(HTTP_HEADER_ENCODING)
+                ).decode("ascii")
+                headers["Authorization"] = "Basic " + base64_credentials
+                stack.enter_context(
+                    mock.patch(
+                        "debusine.server.middlewares.scopes."
+                        "AuthorizationMiddleware._basic_auth_allowed",
+                        return_value=True,
+                    )
+                )
+            return self.client.get(url, HTTP_HOST=fqdn, headers=headers)
 
     def assert_has_caching_headers(
         self, response: TestResponseType, *, mutable: bool
@@ -104,6 +148,13 @@ class ArchiveViewTests(TestCase, ABC):
             has_vary_header(response, "Authorization")  # type: ignore[arg-type]
         )
 
+    def assertResponse404(
+        self, response: TestResponseType, message: str
+    ) -> None:
+        """Check that the response is a 404 with the given message."""
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+        self.assertEqual(response.context["exception"], message)
+
     def test_workspace_not_found(self) -> None:
         for snapshot in (None, timezone.now()):
             with self.subTest(snapshot=self.format_snapshot(snapshot)):
@@ -113,13 +164,10 @@ class ArchiveViewTests(TestCase, ABC):
                     path=self.example_path,
                 )
 
-                self.assertResponseProblem(
+                self.assertResponse404(
                     response,
-                    "Workspace not found",
-                    detail_pattern=(
-                        "Workspace nonexistent not found in scope debusine"
-                    ),
-                    status_code=status.HTTP_404_NOT_FOUND,
+                    "Workspace nonexistent not found in scope debusine,"
+                    " or you are not authorized to see it",
                 )
                 self.assert_has_caching_headers(
                     response,
@@ -136,14 +184,10 @@ class ArchiveViewTests(TestCase, ABC):
                     snapshot=snapshot, path=self.example_path
                 )
 
-                self.assertResponseProblem(
+                self.assertResponse404(
                     response,
-                    "Archive not found",
-                    detail_pattern=(
-                        f"No {CollectionCategory.ARCHIVE} collection found in "
-                        f"{self.scenario.workspace}"
-                    ),
-                    status_code=status.HTTP_404_NOT_FOUND,
+                    f"No {CollectionCategory.ARCHIVE} collection found in "
+                    f"{self.scenario.workspace}",
                 )
                 self.assert_has_caching_headers(
                     response,
@@ -170,10 +214,8 @@ class ArchiveFileViewTests(ArchiveViewTests, ABC):
                     snapshot=snapshot, path=self.example_path
                 )
 
-                self.assertResponseProblem(
-                    response,
-                    "No FileInArtifact matches the given query.",
-                    status_code=status.HTTP_404_NOT_FOUND,
+                self.assertResponse404(
+                    response, "No FileInArtifact matches the given query."
                 )
                 self.assert_has_caching_headers(
                     response, mutable=self.expect_mutable and snapshot is None
@@ -346,19 +388,22 @@ class ArchiveRootViewTests(ArchiveViewTests):
                 f"{workspace.scope.name}/{workspace.name}",
             )
 
-    def test_honours_content_negotiation(self) -> None:
-        response = self.archive_file_get(
-            path="", headers={"Accept": "text/html"}
-        )
+    def test_private_workspace_not_accessible(self) -> None:
+        self.scenario.workspace.public = False
+        self.scenario.workspace.save()
+        response = self.archive_file_get(path="")
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
+    def test_private_workspace_logged_in(self) -> None:
+        self.scenario.workspace.public = False
+        self.scenario.workspace.save()
+        token = self.scenario.create_user_token()
+        with self.scenario.assign_role(
+            self.scenario.workspace, Workspace.Roles.CONTRIBUTOR
+        ):
+            response = self.archive_file_get(path="", token=token)
         self.assertResponseHTML(response)
 
-        response = self.archive_file_get(
-            path="", headers={"Accept": "application/octet-stream"}
-        )
-
-        self.assertEqual(response.status_code, status.HTTP_406_NOT_ACCEPTABLE)
-
 
 class SuiteRootViewTests(ArchiveViewTests):
     """Test retrieving the root of a suite."""
@@ -506,11 +551,7 @@ class SuiteRootViewTests(ArchiveViewTests):
                     snapshot=snapshot, path="dists/nonexistent/"
                 )
 
-                self.assertResponseProblem(
-                    response,
-                    "Suite not found",
-                    status_code=status.HTTP_404_NOT_FOUND,
-                )
+                self.assertResponse404(response, "Suite not found")
                 self.assert_has_caching_headers(
                     response, mutable=snapshot is None
                 )
@@ -529,29 +570,11 @@ class SuiteRootViewTests(ArchiveViewTests):
                     snapshot=snapshot, path="dists/not-exported/"
                 )
 
-                self.assertResponseProblem(
-                    response,
-                    "Suite not found",
-                    status_code=status.HTTP_404_NOT_FOUND,
-                )
+                self.assertResponse404(response, "Suite not found")
                 self.assert_has_caching_headers(
                     response, mutable=snapshot is None
                 )
 
-    def test_honours_content_negotiation(self) -> None:
-        response = self.archive_file_get(
-            path="dists/bookworm/", headers={"Accept": "text/html"}
-        )
-
-        self.assertResponseHTML(response)
-
-        response = self.archive_file_get(
-            path="dists/bookworm/",
-            headers={"Accept": "application/octet-stream"},
-        )
-
-        self.assertEqual(response.status_code, status.HTTP_406_NOT_ACCEPTABLE)
-
 
 class SigningKeysViewTests(ArchiveViewTests):
     """Test retrieving signing keys for an archive or a suite."""
@@ -623,25 +646,6 @@ class SigningKeysViewTests(ArchiveViewTests):
         )
         self.assert_has_caching_headers(response, mutable=True)
 
-    def test_honours_content_negotiation(self) -> None:
-        response = self.archive_file_get(
-            path="dists/bookworm/signing-keys.asc",
-            headers={"Accept": "application/pgp-keys"},
-        )
-
-        self.assertEqual(response.status_code, status.HTTP_200_OK)
-        self.assertEqual(
-            response.headers["Content-Type"],
-            "application/pgp-keys; charset=utf-8",
-        )
-
-        response = self.archive_file_get(
-            path="dists/bookworm/signing-keys.asc",
-            headers={"Accept": "application/octet-stream"},
-        )
-
-        self.assertEqual(response.status_code, status.HTTP_406_NOT_ACCEPTABLE)
-
 
 class DistsByHashFileViewTests(ArchiveFileViewTests):
     """Test retrieving ``by-hash`` files from ``dists/``."""
@@ -765,10 +769,8 @@ class DistsByHashFileViewTests(ArchiveFileViewTests):
                 )
 
                 if expected_contents is None:
-                    self.assertResponseProblem(
-                        response,
-                        "No FileInArtifact matches the given query.",
-                        status_code=status.HTTP_404_NOT_FOUND,
+                    self.assertResponse404(
+                        response, "No FileInArtifact matches the given query."
                     )
                 else:
                     self.assert_response_ok(
@@ -800,10 +802,8 @@ class DistsByHashFileViewTests(ArchiveFileViewTests):
             path=f"dists/bookworm/main/source/by-hash/SHA256/{sha256}"
         )
 
-        self.assertResponseProblem(
-            response,
-            "No FileInArtifact matches the given query.",
-            status_code=status.HTTP_404_NOT_FOUND,
+        self.assertResponse404(
+            response, "No FileInArtifact matches the given query."
         )
         self.assert_has_caching_headers(response, mutable=False)
 
@@ -940,10 +940,8 @@ class DistsFileViewTests(ArchiveFileViewTests):
                 )
 
                 if expected_contents is None:
-                    self.assertResponseProblem(
-                        response,
-                        "No FileInArtifact matches the given query.",
-                        status_code=status.HTTP_404_NOT_FOUND,
+                    self.assertResponse404(
+                        response, "No FileInArtifact matches the given query."
                     )
                 else:
                     self.assert_response_ok(
@@ -970,10 +968,8 @@ class DistsFileViewTests(ArchiveFileViewTests):
 
         response = self.archive_file_get(path="dists/bookworm/Release")
 
-        self.assertResponseProblem(
-            response,
-            "No FileInArtifact matches the given query.",
-            status_code=status.HTTP_404_NOT_FOUND,
+        self.assertResponse404(
+            response, "No FileInArtifact matches the given query."
         )
         self.assert_has_caching_headers(response, mutable=True)
 
@@ -1211,10 +1207,8 @@ class PoolFileViewTests(ArchiveFileViewTests):
                         mutable=False,
                     )
                 else:
-                    self.assertResponseProblem(
-                        response,
-                        "No FileInArtifact matches the given query.",
-                        status_code=status.HTTP_404_NOT_FOUND,
+                    self.assertResponse404(
+                        response, "No FileInArtifact matches the given query."
                     )
 
     def test_suite_not_exported(self) -> None:
@@ -1239,10 +1233,8 @@ class PoolFileViewTests(ArchiveFileViewTests):
 
         response = self.archive_file_get(path="pool/main/h/hello/hello_1.0.dsc")
 
-        self.assertResponseProblem(
-            response,
-            "No FileInArtifact matches the given query.",
-            status_code=status.HTTP_404_NOT_FOUND,
+        self.assertResponse404(
+            response, "No FileInArtifact matches the given query."
         )
         self.assert_has_caching_headers(response, mutable=False)
 
@@ -1277,10 +1269,8 @@ class PoolFileViewTests(ArchiveFileViewTests):
                 path=f"pool/contrib/h/hello/{name}"
             )
 
-            self.assertResponseProblem(
-                response,
-                "No FileInArtifact matches the given query.",
-                status_code=status.HTTP_404_NOT_FOUND,
+            self.assertResponse404(
+                response, "No FileInArtifact matches the given query."
             )
 
     def test_wrong_source_prefix(self) -> None:
@@ -1312,10 +1302,8 @@ class PoolFileViewTests(ArchiveFileViewTests):
         for name in ("hello_1.0.dsc", "hello_1.0_amd64.deb"):
             response = self.archive_file_get(path=f"pool/main/a/hello/{name}")
 
-            self.assertResponseProblem(
-                response,
-                "No FileInArtifact matches the given query.",
-                status_code=status.HTTP_404_NOT_FOUND,
+            self.assertResponse404(
+                response, "No FileInArtifact matches the given query."
             )
 
     def test_ignores_content_negotiation(self) -> None:
@@ -1420,10 +1408,8 @@ class TopLevelFileViewTests(ArchiveFileViewTests):
                 )
 
                 if expected_contents is None:
-                    self.assertResponseProblem(
-                        response,
-                        "No FileInArtifact matches the given query.",
-                        status_code=status.HTTP_404_NOT_FOUND,
+                    self.assertResponse404(
+                        response, "No FileInArtifact matches the given query."
                     )
                 else:
                     self.assert_response_ok(
