@@ -8,20 +8,21 @@
 # contained in the LICENSE file.
 
 """debusine Web forms."""
-import functools
+
+import datetime as dt
 import shutil
 import tempfile
 from collections.abc import Callable
-from datetime import timedelta
 from pathlib import Path
-from typing import Any, Generic, TYPE_CHECKING, TypeVar, cast
+from typing import Any, TYPE_CHECKING, cast, override
 
+import pydantic
+import yaml
 from django.contrib.auth.models import AnonymousUser
 from django.core.exceptions import ValidationError
 from django.db import transaction
 from django.db.models import Q
 from django.forms import (
-    BaseForm,
     BaseFormSet,
     BooleanField,
     CharField,
@@ -40,21 +41,20 @@ from django.forms import (
     Textarea,
     formset_factory,
 )
+from django.forms.fields import InvalidJSONInput, JSONString
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic  # type: ignore
-
-import yaml
-
-# from debusine.client import LocalArtifact
 from debusine.artifacts import LocalArtifact
-from debusine.artifacts.models import BareDataCategory, TaskTypes
+from debusine.artifacts.local_artifact import NewLocalFile
+from debusine.artifacts.models import (
+    BareDataCategory,
+    CollectionCategory,
+    SINGLETON_COLLECTION_CATEGORIES,
+    TaskTypes,
+)
+from debusine.db.context import context
 from debusine.db.models import (
     Artifact,
     Collection,
-    CollectionItem,
     File,
     FileInArtifact,
     Group,
@@ -66,7 +66,7 @@ from debusine.db.models import (
 from debusine.tasks import BaseTask
 
 if TYPE_CHECKING:
-    from debusine.web.views.ui.workspace import WorkspaceUIHelper
+    from debusine.web.views.ui.workspaces import WorkspaceUI
 
     BaseFormSetBase = BaseFormSet
     ModelFormBase = ModelForm
@@ -91,11 +91,7 @@ else:
     ModelChoiceFieldBase = _ModelChoiceFieldBase
 
 
-_KT = TypeVar("_KT")
-_VT = TypeVar("_VT")
-
-
-class DictWithCallback(dict[_KT, _VT], Generic[_KT, _VT]):
+class DictWithCallback[KT, VT](dict[KT, VT]):
     r"""
     Dictionary that when setting a value it calls a method to process it.
 
@@ -112,13 +108,13 @@ class DictWithCallback(dict[_KT, _VT], Generic[_KT, _VT]):
     """
 
     def __init__(
-        self, callback: Callable[[_VT], None], *args: Any, **kwargs: Any
+        self, callback: Callable[[VT], None], *args: Any, **kwargs: Any
     ) -> None:
         """Create the object."""
         self._callback = callback
         super().__init__(*args, **kwargs)
 
-    def __setitem__(self, key: _KT, value: _VT) -> None:
+    def __setitem__(self, key: KT, value: VT) -> None:
         """Call self._callback(value) and set the value."""
         self._callback(value)
         super().__setitem__(key, value)
@@ -244,51 +240,92 @@ class WorkspaceChoiceField(ModelChoiceFieldBase[Workspace]):
         return obj.name
 
 
-class YamlMixin:
-    """
-    Mixin that handles fields and validate/convert from YAML to a dict.
+class YAMLField(CharField):
+    """Edit structured data, such as a JSONField, as YAML."""
 
-    Usage:
-    In the class inheriting from YamlMixin:
+    # Note: this is mostly copied from django.forms.fields.JSONField
 
-    yaml_fields = ["task_data", "some_other_field"]
-    """
+    default_error_messages = {
+        "invalid": "Enter valid YAML data.",
+    }
+    widget = Textarea
+    dump_kwargs: dict[str, Any] = {
+        "allow_unicode": True,
+        "explicit_end": False,
+        "explicit_start": False,
+        "sort_keys": False,
+    }
 
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
-        """For each self.yaml_fields: create the CharField."""
-        super().__init__(*args, **kwargs)
-
-        assert isinstance(self, BaseForm)
-        assert hasattr(self, "yaml_fields")
-        for name in self.yaml_fields:
-            self.fields[name] = CharField(
-                widget=Textarea,
-                required=False,
-                # This might need to change if it's possible to edit
-                # a form loading data from the database.
-                initial="",
-            )
-
-            self.__setattr__(
-                f"clean_{name}", functools.partial(self._clean_data_yaml, name)
-            )
-
-    def _clean_data_yaml(self, field_name: str) -> Any:
-        """Return object representing the YAML input."""
-        data_yaml = cast(BaseForm, self).cleaned_data[field_name]
+    @override
+    def __init__(
+        self,
+        encoder: Any = None,  # noqa: U100
+        decoder: Any = None,  # noqa: U100
+        **kwargs: Any,
+    ) -> None:
+        if kwargs.get("empty_value") in (dict, list):
+            kwargs["empty_value"] = kwargs["empty_value"]()
+        super().__init__(**kwargs)
+        encoder  # fake usage for Vulture
+        decoder  # fake usage for Vulture
 
+    @override
+    def to_python(self, value: Any) -> Any:
+        if self.disabled:
+            return value
+        if value in self.empty_values:
+            return self.empty_value
+        elif isinstance(value, (list, dict, int, float, JSONString)):
+            return value
         try:
-            task_data = yaml.safe_load(data_yaml)
-        except yaml.YAMLError as exc:
-            raise ValidationError(f"Invalid YAML: {exc}")
+            converted = yaml.safe_load(value)
+        except yaml.YAMLError:
+            raise ValidationError(
+                self.error_messages["invalid"],
+                code="invalid",
+                params={"value": value},
+            )
+        if isinstance(converted, str):
+            return JSONString(converted)
+        else:
+            return converted
 
-        return {} if task_data is None else task_data
+    @override
+    def bound_data(self, data: Any, initial: Any) -> Any:
+        if self.disabled:
+            return initial
+        if data is None:
+            return None
+        try:
+            return yaml.safe_load(data)
+        except yaml.YAMLError:
+            return InvalidJSONInput(data)
+
+    @override
+    def prepare_value(self, value: Any) -> str:
+        if isinstance(value, InvalidJSONInput):
+            return value
+        if value in ("", None):
+            value = self.empty_value
+        res = yaml.safe_dump(value, **self.dump_kwargs)
+        assert isinstance(res, str)
+        return res
+
+    @override
+    def has_changed(self, initial: Any, data: Any) -> bool:
+        if super().has_changed(initial, data):
+            return True
+        # For purposes of seeing whether something has changed, True isn't the
+        # same as 1 and the order of keys doesn't matter.
+        return yaml.safe_dump(initial, sort_keys=True) != yaml.safe_dump(
+            self.to_python(data), sort_keys=True
+        )
 
 
-class WorkRequestForm(YamlMixin, BootstrapMixin, ModelFormBase[WorkRequest]):
+class WorkRequestForm(BootstrapMixin, ModelFormBase[WorkRequest]):
     """Form for creating a Work Request."""
 
-    yaml_fields = ["task_data"]
+    task_data = YAMLField(empty_value=dict, required=False)
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         """Initialize WorkRequestForm."""
@@ -325,6 +362,16 @@ class WorkRequestUnblockForm(BootstrapMixin, Form):
     )
 
 
+class WorkRequestConfirmForm(BootstrapMixin, Form):
+    """Form for confirming a work request."""
+
+    # Django defaults to 10 rows, which is a bit much.  Just make it clear
+    # that we accept multi-line input.
+    comment = CharField(
+        required=False, empty_value=None, widget=Textarea(attrs={"rows": 3})
+    )
+
+
 class MultipleFileInput(ClearableFileInput):
     """ClearableFileInput allowing to select multiple files."""
 
@@ -352,7 +399,7 @@ class MultipleFileField(FileField):
         return [single_file_clean(file, initial) for file in data]
 
 
-class ArtifactForm(BootstrapMixin, YamlMixin, ModelFormBase[Artifact]):
+class ArtifactForm(BootstrapMixin, ModelFormBase[Artifact]):
     """Form for creating artifacts."""
 
     # Deliberately incompatible with BaseForm.files.
@@ -362,8 +409,6 @@ class ArtifactForm(BootstrapMixin, YamlMixin, ModelFormBase[Artifact]):
         min_value=0, initial=None, required=False
     )
 
-    yaml_fields = ["data"]
-
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         """Initialize object."""
         self.user = kwargs.pop("user")
@@ -371,6 +416,9 @@ class ArtifactForm(BootstrapMixin, YamlMixin, ModelFormBase[Artifact]):
 
         super().__init__(*args, **kwargs)
 
+        # Avoid conflicting with Form.data
+        self.fields["data"] = YAMLField(required=False, empty_value=dict)
+
         assert isinstance(self.fields["category"], ChoiceField)
         self.fields["category"].choices = [
             (artifact_category, artifact_category)
@@ -390,7 +438,7 @@ class ArtifactForm(BootstrapMixin, YamlMixin, ModelFormBase[Artifact]):
         instance.created_by = self.user
         instance.workspace = self.workspace
         if self.cleaned_data["expiration_delay_in_days"] is not None:
-            instance.expiration_delay = timedelta(
+            instance.expiration_delay = dt.timedelta(
                 days=self.cleaned_data["expiration_delay_in_days"]
             )
 
@@ -444,17 +492,20 @@ class ArtifactForm(BootstrapMixin, YamlMixin, ModelFormBase[Artifact]):
 
             self._local_files[file.name] = file_path
 
-        # If adding any new fields in this LocalArtifact fields,
-        # make sure that the form has a field with the same name.
-        # If not, adjust the code handling the ValidationError.
-        sub_local_artifact_kwargs = {
-            "category": artifact_category,
-            "data": cleaned_data.get("data"),
-            "files": self._local_files,
-        }
-
         try:
-            SubLocalArtifact(**sub_local_artifact_kwargs)
+            # If adding any new fields in this LocalArtifact fields,
+            # make sure that the form has a field with the same name.
+            # If not, adjust the code handling the ValidationError.
+            SubLocalArtifact._create(
+                data=cleaned_data.get("data"),
+                files=[
+                    NewLocalFile(
+                        file=file_path,
+                        artifact_base_dir=Path(self._temporary_directory.name),
+                    )
+                    for file_path in self._local_files.values()
+                ],
+            )
         except pydantic.ValidationError as exc:
             for error in exc.errors():
                 field_name = error["loc"][0]
@@ -493,10 +544,9 @@ class CollectionSearchForm(BootstrapMixin, Form):
         choices = [("", "All")]
         choices.extend(
             (name, name)
-            for name in CollectionItem.objects.filter(
-                parent_collection=self.instance
+            for name in self.instance.child_items.values_list(
+                "category", flat=True
             )
-            .values_list("category", flat=True)
             .distinct()
             .order_by("category")
         )
@@ -560,7 +610,7 @@ class DaysField(IntegerField):
 
     def prepare_value(self, value: Any) -> Any:
         """Convert a timedelta to days."""
-        if isinstance(value, timedelta):
+        if isinstance(value, dt.timedelta):
             return super().prepare_value(value.days)
         return super().prepare_value(value)
 
@@ -568,7 +618,7 @@ class DaysField(IntegerField):
         """Convert days to timedelta."""
         res = super().to_python(value)
         if res is not None:
-            return timedelta(days=res)
+            return dt.timedelta(days=res)
         return res
 
 
@@ -604,7 +654,7 @@ class WorkspaceInheritanceForm(BootstrapMixin, Form):
     parent = ChoiceField()
 
     def __init__(
-        self, workspace_ui: "WorkspaceUIHelper", *args: Any, **kwargs: Any
+        self, workspace_ui: "WorkspaceUI", *args: Any, **kwargs: Any
     ) -> None:
         """Set help texts for the fields."""
         super().__init__(*args, **kwargs)
@@ -621,23 +671,23 @@ class WorkspaceInheritanceFormSet(BaseFormSetBase[WorkspaceInheritanceForm]):
     deletion_widget = DeletionWidget
 
     def __init__(
-        self, *args: Any, workspace_ui: "WorkspaceUIHelper", **kwargs: Any
+        self, *args: Any, workspace_ui: "WorkspaceUI", **kwargs: Any
     ) -> None:
-        """Store a WorkspaceUIHelper to use to fill in form choices."""
+        """Store a WorkspaceUI to use to fill in form choices."""
         super().__init__(*args, **kwargs)
         self.workspace_ui = workspace_ui
 
     def get_form_kwargs(self, index: int | None) -> dict[str, Any]:
-        """Pass the WorkspaceUIHelper to use to fill in form choices."""
+        """Pass the WorkspaceUI to use to fill in form choices."""
         kwargs = super().get_form_kwargs(index)
         kwargs["workspace_ui"] = self.workspace_ui
         return kwargs
 
     @classmethod
     def formset_factory(
-        cls, workspace_ui: "WorkspaceUIHelper"
+        cls, workspace_ui: "WorkspaceUI"
     ) -> type[BaseFormSetBase[WorkspaceInheritanceForm]]:
-        """Create a Form class for a WorkspaceUIHelper."""
+        """Create a Form class for a WorkspaceUI."""
 
         class Partial(WorkspaceInheritanceFormSet):
             def __init__(
@@ -645,7 +695,7 @@ class WorkspaceInheritanceFormSet(BaseFormSetBase[WorkspaceInheritanceForm]):
                 *args: Any,
                 **kwargs: Any,
             ) -> None:
-                """Store a WorkspaceUIHelper to use to fill in form choices."""
+                """Store a WorkspaceUI to use to fill in form choices."""
                 super().__init__(*args, workspace_ui=workspace_ui, **kwargs)
 
         return formset_factory(
@@ -732,11 +782,147 @@ class TaskConfigurationInspectorForm(BootstrapMixin, Form):
         cast(ChoiceField, self.fields["subject"]).choices = subject_choices
 
         context_choices = [("", "(unspecified)")]
-        for context in (
+        for child_context in (
             children.order_by("data__context")
             .values_list("data__context", flat=True)
             .distinct()
         ):
-            if context is not None:
-                context_choices.append((context, context))
+            if child_context is not None:
+                context_choices.append((child_context, child_context))
         cast(ChoiceField, self.fields["context"]).choices = context_choices
+
+
+class CollectionFormBase(BootstrapMixin, ModelFormBase[Collection]):
+    """Common functions for collection forms."""
+
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        """Initialize object."""
+        super().__init__(*args, **kwargs)
+        # Add measurement unit to interval fields
+        for field_name in (
+            "full_history_retention_period",
+            "metadata_only_retention_period",
+        ):
+            if field := self.fields.get(field_name):
+                field.help_text = field.help_text + " (in days)"
+
+    def check_name(
+        self,
+        workspace: Workspace,
+        name: str,
+        category: CollectionCategory,
+        instance: Collection | None = None,
+    ) -> None:
+        """Check that the name field matches collection constraints."""
+        conflicts = Collection.objects.filter(
+            name=name, workspace=workspace, category=category
+        )
+        if instance is not None:
+            conflicts = conflicts.exclude(pk=instance.pk)
+        if conflicts.exists():
+            self.add_error(
+                "name",
+                f"A collection called {name}@{category}"
+                f" already exists in workspace {workspace}",
+            )
+
+        if category in SINGLETON_COLLECTION_CATEGORIES and name != "_":
+            self.add_error(
+                "name", 'A singleton collection needs to be named "_"'
+            )
+        if category not in SINGLETON_COLLECTION_CATEGORIES and name.startswith(
+            "_"
+        ):
+            self.add_error(
+                "name",
+                'The name of a non-singleton collection cannot start with "_"',
+            )
+
+
+class CollectionUpdateForm(CollectionFormBase):
+    """Form for configuring a collection."""
+
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        """Initialize object."""
+        super().__init__(*args, **kwargs)
+        # Avoid conflicting with Form.data
+        self.fields["data"] = YAMLField(required=False, empty_value=dict)
+
+    def clean(self) -> dict[str, Any]:
+        """Enforce collection name constraints."""
+        cleaned_data = super().clean()
+        assert cleaned_data is not None
+        self.check_name(
+            self.instance.workspace,
+            cleaned_data["name"],
+            CollectionCategory(self.instance.category),
+            instance=self.instance,
+        )
+        return cleaned_data
+
+    class Meta:
+        model = Collection
+        fields = [
+            "name",
+            "full_history_retention_period",
+            "metadata_only_retention_period",
+            "data",
+        ]
+        field_classes = {
+            "full_history_retention_period": DaysField,
+            "metadata_only_retention_period": DaysField,
+        }
+
+
+class CollectionCreateForm(CollectionFormBase):
+    """Form for creating a collection."""
+
+    category = ChoiceField()
+
+    def __init__(self, *args: Any, **kwargs: Any) -> None:
+        """Initialize object."""
+        super().__init__(*args, **kwargs)
+        # Avoid conflicting with Form.data
+        self.fields["data"] = YAMLField(required=False, empty_value=dict)
+
+        assert isinstance(self.fields["category"], ChoiceField)
+        self.fields["category"].choices = [
+            (c, c)
+            for c in sorted(CollectionCategory)
+            if c != CollectionCategory.WORKFLOW_INTERNAL
+        ]
+
+    def clean(self) -> dict[str, Any]:
+        """Enforce collection name constraints."""
+        cleaned_data = super().clean()
+        assert cleaned_data is not None
+        if "name" in cleaned_data and "category" in cleaned_data:
+            self.check_name(
+                context.require_workspace(),
+                str(cleaned_data["name"]),
+                CollectionCategory(cleaned_data["category"]),
+            )
+        return cleaned_data
+
+    @override
+    def save(self, commit: bool = True) -> Collection:
+        instance = super().save(commit=False)
+        instance.workspace = context.require_workspace()
+        instance.retains_artifacts = Collection.RetainsArtifacts.ALWAYS
+        if commit:
+            instance.save()
+        return instance
+
+    class Meta:
+        model = Collection
+        fields = [
+            "name",
+            "category",
+            "full_history_retention_period",
+            "metadata_only_retention_period",
+            "data",
+        ]
+        field_classes = {
+            "full_history_retention_period": DaysField,
+            "metadata_only_retention_period": DaysField,
+        }
