@@ -27,6 +27,7 @@ from debusine.db.context import context
 from debusine.db.models import Scope
 from debusine.db.models.permissions import PermissionUser
 from debusine.db.playground import scenarios
+from debusine.test.django import TestCase
 from debusine.web.helps import HELPS
 from debusine.web.icons import Icons
 from debusine.web.templatetags.debusine import (
@@ -46,13 +47,6 @@ from debusine.web.templatetags.debusine import (
 )
 from debusine.web.views.base import Widget
 
-# templatetags loading code will attempt to import tests, debusine.test
-# dependencies (such as lxml) may not be available at runtime
-try:
-    from debusine.test.django import TestCase
-except ImportError:
-    from unittest import TestCase  # type: ignore[assignment]
-
 
 class DebusineNodeTests(TestCase):
     """Tests for the :py:class:`DebusineNode` class."""
@@ -314,11 +308,6 @@ class WithscopeTests(TestCase):
         super().setUpTestData()
         cls.scope2 = cls.playground.get_or_create_scope("scope2")
 
-    def setUp(self) -> None:
-        """Reset context at the beginning of tests."""
-        super().setUp()
-        context.reset()
-
     def render(self, template_code: str) -> str:
         """Render a template from a string."""
         request = RequestFactory().get("/")
@@ -411,9 +400,8 @@ class WithscopeTests(TestCase):
             TemplateSyntaxError, "withscope requires exactly one argument"
         ):
             self.render(
-                "{% load debusine %}"
-                "{% withscope %}{{scope}}{% endwithscope %}"
-            ),
+                "{% load debusine %}{% withscope %}{{scope}}{% endwithscope %}"
+            )
 
     def test_withscope_toomanyargs(self) -> None:
         """Test withscope with too many args."""
@@ -423,7 +411,7 @@ class WithscopeTests(TestCase):
             self.render(
                 "{% load debusine %}"
                 "{% withscope a b %}{{scope}}{% endwithscope %}"
-            ),
+            )
 
 
 class MockResource:
