@@ -26,6 +26,11 @@ workspace_urlpatterns: list[URLPattern | URLResolver] = [
         views.WorkspaceUpdateView.as_view(),
         name="update",
     ),
+    path(
+        "inheritance/",
+        views.WorkspaceUpdateInheritanceView.as_view(),
+        name="update_inheritance",
+    ),
     path(
         "collection/",
         include(
@@ -63,6 +68,10 @@ workspace_urlpatterns: list[URLPattern | URLResolver] = [
         views.TaskConfigInspectorView.as_view(),
         name="task_configuration_inspector",
     ),
+    path(
+        "groups/",
+        include("debusine.web.urls.groups", namespace="groups"),
+    ),
 ]
 
 urlpatterns = [
