@@ -17,8 +17,9 @@ import os.path
 from collections.abc import Generator, Iterable
 from functools import cached_property
 from pathlib import Path
-from typing import Any, NamedTuple, Self, TYPE_CHECKING
+from typing import Annotated, Any, NamedTuple, Self, TYPE_CHECKING
 
+import pydantic
 import pygments
 import pygments.formatters
 import pygments.lexers
@@ -30,13 +31,9 @@ from django.utils.html import escape, format_html
 from django.utils.http import parse_header_parameters
 from django.utils.safestring import SafeString
 from django.views.generic.base import View
+from pydantic_core import core_schema
 from rest_framework import status
 
-try:
-    import pydantic.v1 as pydantic
-except ImportError:
-    import pydantic  # type: ignore
-
 from debusine.db.models import FileInArtifact
 from debusine.server.views import ProblemResponse
 from debusine.utils import parse_range_header
@@ -158,7 +155,7 @@ def add_line_number(
     return format_html(
         '<a id="L{line_number}{suffix}" href="#L{line_number}{suffix}">'
         '{line_number}</a>'
-        '<div>{line}</div>',
+        '<i>{line}</i>\n',
         line_number=line_number,
         suffix=suffix,
         line=line,
@@ -171,21 +168,24 @@ class LinenoHtmlFormatter(HtmlFormatter[Any]):
     def __init__(self, *args: Any, suffix: str, **kwargs: Any) -> None:
         """Keep a count of line numbers."""
         self.suffix = suffix
+        self.linenumber_count = 0
         super().__init__(*args, **kwargs)
 
     def wrap(  # type: ignore[no-untyped-def]
         self, source
     ) -> Generator[tuple[int, str]]:
         """Format each line with the line number."""
-        lineno = 0
         for formatted, line in source:
             # f can be 1 (line of formatted code) or 0 (Pygments wrapping)
             if formatted:
-                lineno += 1
-                yield 1, add_line_number(
-                    line_number=lineno,
-                    suffix=self.suffix,
-                    line=SafeString(line),
+                self.linenumber_count += 1
+                yield (
+                    1,
+                    add_line_number(
+                        line_number=self.linenumber_count,
+                        suffix=self.suffix,
+                        line=SafeString(line),
+                    ),
                 )
             else:
                 yield 0, line
@@ -276,7 +276,12 @@ class LogFileWidget(FileWidget):
         start_line: int
         title: str | None
         expanded: bool
-        content: SafeString
+        content: Annotated[
+            SafeString,
+            pydantic.GetPydanticSchema(
+                lambda *_: core_schema.is_instance_schema(SafeString)
+            ),
+        ]
 
     template_name = "web/_file_log.html"
 
@@ -292,7 +297,7 @@ class LogFileWidget(FileWidget):
 
         self._sections = sections
 
-        LogFileWidget.RenderedSection.update_forward_refs()
+        LogFileWidget.RenderedSection.model_rebuild()
 
     @staticmethod
     def _add_line_numbers(
@@ -305,9 +310,9 @@ class LogFileWidget(FileWidget):
             )
         )
 
-    def _render(self, file_contents: str, suffix: str) -> list[RenderedSection]:
-        file_contents_list = file_contents.split("\n")
-
+    def _render(
+        self, file_contents: list[str], suffix: str
+    ) -> list[RenderedSection]:
         rendered_sections = []
         line: int = 1
         for section in self._sections:
@@ -320,7 +325,7 @@ class LogFileWidget(FileWidget):
                         title=None,
                         expanded=True,
                         content=self._add_line_numbers(
-                            file_contents_list,
+                            file_contents,
                             start=line,
                             end=section.start_line - 1,
                             suffix=suffix,
@@ -334,7 +339,7 @@ class LogFileWidget(FileWidget):
                     title=section.title,
                     expanded=section.expanded,
                     content=self._add_line_numbers(
-                        file_contents_list,
+                        file_contents,
                         start=section.start_line,
                         end=section.end_line,
                         suffix=suffix,
@@ -344,7 +349,7 @@ class LogFileWidget(FileWidget):
 
             line = section.end_line + 1
 
-        end_line = len(file_contents_list)
+        end_line = len(file_contents)
         if line <= end_line:
             # Add any remaining lines of the file
             rendered_sections.append(
@@ -353,7 +358,7 @@ class LogFileWidget(FileWidget):
                     title=None,
                     expanded=True,
                     content=self._add_line_numbers(
-                        file_contents_list,
+                        file_contents,
                         start=line,
                         end=end_line,
                         suffix=suffix,
@@ -381,8 +386,11 @@ class LogFileWidget(FileWidget):
         file_contents = raw_str.replace("\r", "^M")
         file_contents = file_contents.rstrip("\n")
 
-        context["sections"] = self._render(file_contents, self.suffix())
+        file_contents_list = file_contents.split("\n")
+
+        context["sections"] = self._render(file_contents_list, self.suffix())
         context["suffix"] = self.suffix()
+        context["file_lineno_width"] = max(len(str(len(file_contents_list))), 2)
 
         return context
 
@@ -440,6 +448,9 @@ class TextFileWidget(FileWidget):
                 formatted = pygments.highlight(stream.read(), lexer, formatter)
 
             context["file_content"] = SafeString(formatted)
+            context["file_lineno_width"] = max(
+                len(str(formatter.linenumber_count)), 2
+            )
 
         return context
 
