@@ -16,7 +16,7 @@ elements like page titles and breadcrumb elements.
 
 import abc
 from enum import StrEnum
-from typing import NotRequired, TypedDict, Unpack, override
+from typing import Any, NotRequired, TypedDict, Unpack, override
 
 from django.utils.html import format_html
 from django.utils.safestring import SafeString
@@ -69,7 +69,7 @@ class Place(abc.ABC):
     def is_page_title_visible(self) -> bool:
         """Return True if the page title should be shown."""
 
-    def as_icon(self) -> str:
+    def as_icon(self, **kwargs: Any) -> str:
         """
         Render the icon.
 
@@ -83,7 +83,7 @@ class Place(abc.ABC):
                 """<span class="bi bi-{icon}"></span> """, icon=self.icon
             )
 
-    def as_tooltip(self) -> str:
+    def as_tooltip(self, **kwargs: Any) -> str:
         """Render as a title= attribute."""
         if self.description is not None:
             return format_html(
@@ -92,7 +92,7 @@ class Place(abc.ABC):
         else:
             return SafeString()
 
-    def as_nav(self) -> str:
+    def as_nav(self, **kwargs: Any) -> str:
         """Render as a <nav> link."""
         return format_html(
             """<a class="nav-link btn btn-debusine" href="{url}"{desc}>"""
@@ -103,33 +103,39 @@ class Place(abc.ABC):
             desc=self.as_tooltip(),
         )
 
-    def as_head_title(self) -> str:
+    def as_head_title(self, **kwargs: Any) -> str:
         """Render as a <title> element."""
         if self.parent is None:
             prefix = ""
         else:
-            prefix = " - ".join(p.breadcrumb for p in self.parent.as_parents())
+            prefix = " - ".join(p.breadcrumb for p in self.parent.parents())
             prefix += " - "
         return format_html(
             "<title>{prefix}{title}</title>", prefix=prefix, title=self.title
         )
 
     @abc.abstractmethod
-    def as_page_title(self) -> str:
+    def as_page_title(self, **kwargs: Any) -> str:
         """Render as a page title."""
 
     @abc.abstractmethod
-    def as_breadcrumbs(self) -> str:
+    def as_breadcrumbs(self, **kwargs: Any) -> str:
         """Render as breadcrumbs leading to this Place."""
 
-    def as_button(self) -> str:
-        """Render as a button."""
-        # TODO: we need a way for templates to pass at least class information
+    def as_button(self, **kwargs: Any) -> str:
+        """
+        Render as a button.
+
+        Supported keyword arguments:
+
+        * ``label``: override button label
+        """
+        # TODO: support a way for templates to pass class information
         return format_html(
             """<a class="btn btn-primary" href="{url}"{tooltip}>"""
             """{icon}{title}</a>""",
             url=self.url,
-            title=self.title,
+            title=kwargs.get("label", self.title),
             icon=self.as_icon(),
             tooltip=self.as_tooltip(),
         )
@@ -143,7 +149,7 @@ class PlaceWithoutPageTitle(Place):
         return False
 
     @override
-    def as_page_title(self) -> str:
+    def as_page_title(self, **kwargs: Any) -> str:
         return SafeString()
 
 
@@ -155,7 +161,7 @@ class PlaceWithPageTitle(Place):
         return True
 
     @override
-    def as_page_title(self) -> str:
+    def as_page_title(self, **kwargs: Any) -> str:
         return format_html(
             """<h1 class="mb-4">{title}</h1>""", title=self.title
         )
@@ -169,7 +175,7 @@ class IndexPlace(PlaceWithoutPageTitle):
         return PlaceType.INDEX
 
     @override
-    def as_breadcrumbs(self) -> str:
+    def as_breadcrumbs(self, **kwargs: Any) -> str:
         if self.parent:
             parent = self.parent.as_breadcrumb_parent()
         else:
@@ -199,16 +205,16 @@ class BreadcrumbPlace(Place, abc.ABC):
         #: Short label used for breadcrumbs
         self.breadcrumb = breadcrumb
 
-    def as_parents(self) -> list["BreadcrumbPlace"]:
+    def parents(self, **kwargs: Any) -> list["BreadcrumbPlace"]:
         """Build the parent chain as a list, topmost parent first, self last."""
         if self.parent is None:
             res = []
         else:
-            res = self.parent.as_parents()
+            res = self.parent.parents()
         res.append(self)
         return res
 
-    def as_breadcrumb_parent(self) -> str:
+    def as_breadcrumb_parent(self, **kwargs: Any) -> str:
         """Render as a parent in a breadcrumb list."""
         if self.parent:
             parent = self.parent.as_breadcrumb_parent()
@@ -239,7 +245,7 @@ class ResourcePlace(BreadcrumbPlace, PlaceWithPageTitle):
         return PlaceType.RESOURCE
 
     @override
-    def as_breadcrumbs(self) -> str:
+    def as_breadcrumbs(self, **kwargs: Any) -> str:
         if self.parent:
             parent = self.parent.as_breadcrumb_parent()
         else:
@@ -267,7 +273,7 @@ class ContainerPlace(BreadcrumbPlace, PlaceWithoutPageTitle):
         return PlaceType.CONTAINER
 
     @override
-    def as_breadcrumbs(self) -> str:
+    def as_breadcrumbs(self, **kwargs: Any) -> str:
         if self.parent:
             parent = self.parent.as_breadcrumb_parent()
         else:
