@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """View for QA work request."""
+
 from functools import cached_property
 from typing import Any, override
 
@@ -77,7 +78,7 @@ class QATab(Tab):
         for name, analysis in sorted(regression_analysis.items()):
             if name == "":
                 continue
-            task_name, test_package_name, architecture = name.split(":")
+            task_name, test_package_name, _ = name.split(":")
             if (
                 task_name == "autopkgtest"
                 and test_package_name != package_name
