@@ -12,7 +12,7 @@
 import abc
 from collections.abc import Collection
 from functools import cached_property
-from typing import Any, Generic, NamedTuple, TYPE_CHECKING, TypeVar
+from typing import Any, NamedTuple, TYPE_CHECKING
 
 from django.core.exceptions import ImproperlyConfigured
 from django.db.models import Model, Q, QuerySet
@@ -31,9 +31,6 @@ if TYPE_CHECKING:
     from debusine.web.views.table.table import Table
 
 
-M = TypeVar("M", bound=Model)
-
-
 class FilterWidget(Widget):
     """Base class for menu entry widgets."""
 
@@ -45,7 +42,7 @@ class FilterWidget(Widget):
 class MenuEntry(FilterWidget):
     """Standard menu entry, activating the filter form."""
 
-    def render(self, context: Context) -> str:  # noqa: U100
+    def render(self, context: Context) -> str:  # noqa: ARG002, U100
         """Render the filter as widget."""
         return format_html(
             "<a class='dropdown-item debusine-dropdown-remote'"
@@ -60,7 +57,7 @@ class MenuEntry(FilterWidget):
 class MenuEntryToggle(FilterWidget):
     """Menu entry that toggles the filter value."""
 
-    def render(self, context: Context) -> str:  # noqa: U100
+    def render(self, context: Context) -> str:  # noqa: ARG002, U100
         """Render the filter as widget."""
         if self.filter.value:
             url = self.filter.qs_remove
@@ -133,7 +130,7 @@ class MainEntryToggle(MainEntry):
     template_name = "web/_table_filter_toggle.html"
 
 
-class BoundFilter(Generic[M]):
+class BoundFilter[M: Model]:
     """A Filter bound to a table."""
 
     dom_id: str
@@ -250,10 +247,10 @@ class BoundFilter(Generic[M]):
 
     def add_option(
         self,
-        name: str,  # noqa: U100
-        label: str,  # noqa: U100
-        query: Q,  # noqa: U100
-        icon: str | None = None,  # noqa: U100
+        name: str,  # noqa: ARG002, U100
+        label: str,  # noqa: ARG002, U100
+        query: Q,  # noqa: ARG002, U100
+        icon: str | None = None,  # noqa: ARG002, U100
     ) -> None:
         """Add an option to the selection list."""
         raise ImproperlyConfigured(
@@ -297,7 +294,7 @@ class Filter(Attribute, abc.ABC):
         self.icon = icon
 
     @abc.abstractmethod
-    def filter_queryset(
+    def filter_queryset[M: Model](
         self, queryset: QuerySet[M, M], value: Any
     ) -> QuerySet[M, M]:
         """Filter the queryset using the given filter value."""
@@ -333,7 +330,7 @@ class FilterText(Filter):
         """Return the field name used for matching in Q expressions."""
         return self._q_field or f"{self.name}__contains"
 
-    def filter_queryset(
+    def filter_queryset[M: Model](
         self, queryset: QuerySet[M, M], value: Any
     ) -> QuerySet[M, M]:
         """Filter a queryset."""
@@ -361,7 +358,7 @@ class FilterToggle(Filter):
         super().__init__(label, icon=icon)
         self.q = q
 
-    def filter_queryset(
+    def filter_queryset[M: Model](
         self, queryset: QuerySet[M, M], value: Any
     ) -> QuerySet[M, M]:
         """Filter a queryset."""
@@ -379,7 +376,7 @@ class SelectOption(NamedTuple):
     icon: str | None = None
 
 
-class BoundFilterSelectOne(BoundFilter[M]):
+class BoundFilterSelectOne[M: Model](BoundFilter[M]):
     """Filter specialization handling a set of selectable values."""
 
     def __init__(
@@ -436,8 +433,10 @@ class FilterSelectOne(Filter):
         super().__init__(label, icon=icon)
         self.options = options
 
-    def filter_queryset(
-        self, queryset: QuerySet[M, M], value: Any  # noqa: U100
+    def filter_queryset[M: Model](
+        self,
+        queryset: QuerySet[M, M],  # noqa: ARG002, U100
+        value: Any,  # noqa: ARG002, U100
     ) -> QuerySet[M, M]:
         """Filter a queryset."""
         raise ImproperlyConfigured(
@@ -446,7 +445,7 @@ class FilterSelectOne(Filter):
         )
 
 
-class BoundFilterField(BoundFilter[M]):
+class BoundFilterField[M: Model](BoundFilter[M]):
     """Filter specialization using a Django Form field."""
 
     @cached_property
@@ -524,14 +523,14 @@ class FilterField(Filter):
         """Return the field name used for matching in Q expressions."""
         return self._q_field or f"{self.name}__contains"
 
-    def filter_queryset(
+    def filter_queryset[M: Model](
         self, queryset: QuerySet[M, M], value: Any
     ) -> QuerySet[M, M]:
         """Filter a queryset."""
         return queryset.filter(**{self.q_field: value})
 
 
-class Filters(Widget, Generic[M]):
+class Filters[M: Model](Widget):
     """Filter definitions for a table."""
 
     template_name: str = "web/_table_filters.html"
