@@ -11,16 +11,7 @@
 
 from collections.abc import Sequence
 from functools import cached_property
-from typing import (
-    Any,
-    Generic,
-    Optional,
-    TYPE_CHECKING,
-    TypeAlias,
-    TypeVar,
-    assert_never,
-    cast,
-)
+from typing import Any, Optional, TYPE_CHECKING, assert_never, cast
 
 from django.core.exceptions import ImproperlyConfigured
 from django.db.models import F, Model, QuerySet
@@ -34,9 +25,7 @@ from debusine.web.views.table.declarative import Attribute
 if TYPE_CHECKING:
     from debusine.web.views.table.table import Table
 
-M = TypeVar("M", bound=Model)
-
-OrderBys: TypeAlias = str | F | OrderBy | Sequence[str | F | OrderBy]
+type OrderBys = str | F | OrderBy | Sequence[str | F | OrderBy]
 
 
 def to_order_by(val: str | F | OrderBy) -> OrderBy:
@@ -217,14 +206,14 @@ def compute_sort_icon_current_next(
             return (None, orderings[0])
 
 
-def render_sort_icon(
+def render_sort_icon[M: Model](
     orderings: list["TableOrdering[M]"], for_table: bool = False
 ) -> SafeString:
     """Render an icon showing current ordering."""
     current, next_ = compute_sort_icon_current_next(orderings)
     class_ = "btn"
     if for_table:
-        class_ += " btn-light"
+        class_ += " btn-debusine-toolbar"
     else:
         class_ += " btn-sm"
     if current:
@@ -264,7 +253,7 @@ def render_sort_icon(
         return SafeString()
 
 
-class TableOrdering(Generic[M]):
+class TableOrdering[M: Model]:
     """
     Instantiated ordering option for a table.
 
@@ -347,7 +336,7 @@ class TableOrdering(Generic[M]):
         )
 
 
-class TableOrderings(Generic[M]):
+class TableOrderings[M: Model]:
     """All available table ordering options."""
 
     def __init__(self, table: "Table[M]") -> None:
