@@ -17,6 +17,7 @@ import os.path
 import tarfile
 from pathlib import Path
 from typing import Any, ClassVar, cast
+from unittest import mock
 
 import lxml
 import yaml
@@ -42,6 +43,7 @@ from debusine.db.models import (
     Workspace,
 )
 from debusine.db.playground import scenarios
+from debusine.server.tar import TarArtifact
 from debusine.test.django import (
     AllowAll,
     DenyAll,
@@ -1385,6 +1387,28 @@ class DownloadPathViewTests(ViewTestMixin, PermissionTests):
         response = self.get_artifact(self.tree, "tar.gz")
         self.assertResponseDownloadsTree(response)
 
+    def test_get_artifact_tar_gz_resource_cleanup_on_streaming_interrupted(
+        self,
+    ) -> None:
+        # We create the TarArtifact for the view, to be able to manipulate it
+        # later
+        tar_artifact = TarArtifact(self.tree)
+        self.assertFalse(tar_artifact._closed)
+        with mock.patch(
+            "debusine.web.views.artifacts.TarArtifact",
+            return_value=tar_artifact,
+        ) as ta:
+            response = self.get_artifact(self.tree, "tar.gz")
+        ta.assert_called_with(self.tree, None)
+
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        assert hasattr(response, "streaming_content")
+
+        # Close the response without streaming data
+        self.close_streaming_response(response)
+
+        self.assertTrue(tar_artifact._closed)
+
 
 class DownloadPathViewAuthTests(TestCase):
     """Tests for authorization on the DownloadPathView class."""
