@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Unit tests for DebDiff work request plugin."""
+
 import textwrap
 from typing import ClassVar
 from unittest import mock
@@ -30,9 +31,14 @@ from debusine.db.models import (
     Workspace,
 )
 from debusine.tasks import DebDiff
+from debusine.tasks.models import (
+    DebDiffData,
+    DebDiffDynamicData,
+    DebDiffFlags,
+    DebDiffInput,
+    LookupMultiple,
+)
 from debusine.test.django import TestCase
-from debusine.web.templatetags.artifacts import artifact_link
-from debusine.web.views.debdiff import DebDiffViewWorkRequestPlugin
 from debusine.web.views.tests.utils import ViewTestMixin
 
 
@@ -748,35 +754,38 @@ class DebDiffViewWorkRequestPluginTests(TestCase):
         "extra_flags": ["--dirs", "--nocontrol"],
     }
 
-    def test_get_context_data_no_artifacts(self) -> None:
+    def test_get_context_source_artifacts(self) -> None:
+        source_artifact_original = (
+            self.playground.create_minimal_source_package_artifact()
+        )
+        source_artifact_new = (
+            self.playground.create_minimal_source_package_artifact()
+        )
+        environment = self.playground.create_debian_environment().artifact
+        assert environment is not None
+
         work_request = self.playground.create_worker_task(
             task_name="debdiff",
-            task_data=self.SAMPLE_TASK_DATA,
-        )
-        work_request.dynamic_task_data = {"environment_id": 1}
-        work_request.save()
-        plugin = DebDiffViewWorkRequestPlugin(work_request)
-
-        self.assertEqual(
-            plugin.get_context_data(),
-            {
-                "description_data": {
-                    "environment_id": 1,
-                    "extra_arguments": ["--dirs", "--nocontrol"],
-                },
-                "description_template": "web/_debdiff-description.html",
-            },
+            task_data=DebDiffData(
+                input=DebDiffInput(
+                    source_artifacts=[
+                        source_artifact_original.id,
+                        source_artifact_new.id,
+                    ]
+                ),
+                build_architecture="amd64",
+                environment=environment.id,
+                extra_flags=[DebDiffFlags.DIRS, DebDiffFlags.NOCONTROL],
+            ),
         )
 
-    def test_get_context_data(self) -> None:
-        work_request = self.playground.create_worker_task(
-            task_name="debdiff", task_data=self.SAMPLE_TASK_DATA
-        )
-        work_request.dynamic_task_data = {
-            "environment_id": 1,
-            "input_source_artifacts_ids": [2, 3],
-            "input_binary_artifacts_ids": [[4, 5], [6, 7]],
-        }
+        work_request.dynamic_task_data = DebDiffDynamicData(
+            environment_id=environment.id,
+            input_source_artifacts_ids=[
+                source_artifact_original.id,
+                source_artifact_new.id,
+            ],
+        ).model_dump()
         work_request.save()
 
         response = self.client.get(work_request.get_absolute_url())
@@ -792,12 +801,10 @@ class DebDiffViewWorkRequestPluginTests(TestCase):
         self.assertEqual(
             description_data,
             {
-                "binary_artifacts_new_ids": [6, 7],
-                "binary_artifacts_original_ids": [4, 5],
-                "environment_id": 1,
+                "environment_id": environment.id,
                 "extra_arguments": ["--dirs", "--nocontrol"],
-                "source_artifact_new_id": 3,
-                "source_artifact_original_id": 2,
+                "source_artifact_new_id": source_artifact_new.id,
+                "source_artifact_original_id": source_artifact_original.id,
             },
         )
 
@@ -810,17 +817,16 @@ class DebDiffViewWorkRequestPluginTests(TestCase):
         )
         self.assertTextContentEqual(
             source_artifacts,
-            f"Compare source package {artifact_link(2)} with "
-            f"{artifact_link(3)} using debdiff",
+            "Compare source package hello_1.0-1 with hello_1.0-1 using debdiff",
         )
 
         self.assertFalse(tree.xpath("//p[@id='description-binary_artifacts']"))
 
-        environment = self.assertHasElement(
+        environment_el = self.assertHasElement(
             tree, "//li[@id='description-executed_in_environment']"
         )
         self.assertTextContentEqual(
-            environment, f"Executed in environment {artifact_link(1)}"
+            environment_el, "Executed in environment test"
         )
 
         extra_arguments = self.assertHasElement(
@@ -830,6 +836,133 @@ class DebDiffViewWorkRequestPluginTests(TestCase):
             extra_arguments, "Extra arguments: --dirs --nocontrol"
         )
 
+    def test_get_context_binary_artifacts(self) -> None:
+        binary_artifact_original_1 = (
+            self.playground.create_minimal_binary_package_artifact(
+                srcpkg_name="bye", srcpkg_version="2.0-1"
+            )
+        )
+        binary_artifact_original_2 = (
+            self.playground.create_minimal_binary_package_artifact()
+        )
+
+        binary_artifact_new_1 = (
+            self.playground.create_minimal_binary_package_artifact()
+        )
+        binary_artifact_new_2 = (
+            self.playground.create_minimal_binary_package_artifact()
+        )
+
+        environment = self.playground.create_debian_environment().artifact
+        assert environment is not None
+
+        work_request = self.playground.create_worker_task(
+            task_name="debdiff",
+            task_data=DebDiffData(
+                input=DebDiffInput(
+                    binary_artifacts=[
+                        LookupMultiple(
+                            (
+                                binary_artifact_original_1.id,
+                                binary_artifact_original_2.id,
+                            )
+                        ),
+                        LookupMultiple(
+                            (binary_artifact_new_1.id, binary_artifact_new_2.id)
+                        ),
+                    ]
+                ),
+                build_architecture="amd64",
+                environment=environment.id,
+                extra_flags=[DebDiffFlags.DIRS, DebDiffFlags.NOCONTROL],
+            ),
+        )
+
+        work_request.dynamic_task_data = DebDiffDynamicData(
+            environment_id=environment.id,
+            input_binary_artifacts_ids=[
+                [binary_artifact_original_1.id, binary_artifact_original_2.id],
+                [binary_artifact_new_1.id, binary_artifact_new_2.id],
+            ],
+        ).model_dump()
+        work_request.save()
+
+        response = self.client.get(work_request.get_absolute_url())
+
+        # Check context
+        ctx = response.context
+
+        description_data, description_template = (
+            ctx["description_data"],
+            ctx["description_template"],
+        )
+
+        self.assertEqual(
+            description_data,
+            {
+                "environment_id": environment.id,
+                "extra_arguments": ["--dirs", "--nocontrol"],
+                "binary_artifacts_new_count": 2,
+                "source_package_names": [
+                    "bye_2.0-1",
+                    "hello_1.0-1",
+                ],
+                "binary_artifacts_architecture": "amd64",
+            },
+        )
+
+        self.assertEqual(description_template, "web/_debdiff-description.html")
+
+        tree = self.assertResponseHTML(response)
+
+        binary_artifacts_el = self.assertHasElement(
+            tree, "//p[@id='description-binary_artifacts']"
+        )
+        self.assertTextContentEqual(
+            binary_artifacts_el,
+            "Compare amd64 binaries from source packages "
+            "bye_2.0-1, hello_1.0-1 using debdiff.",
+        )
+
+        self.assertFalse(tree.xpath("//p[@id='description-source_artifacts']"))
+
+        environment_el = self.assertHasElement(
+            tree, "//li[@id='description-executed_in_environment']"
+        )
+        self.assertTextContentEqual(
+            environment_el, "Executed in environment test"
+        )
+
+        extra_arguments = self.assertHasElement(
+            tree, "//li[@id='description-extra_arguments']"
+        )
+        self.assertTextContentEqual(
+            extra_arguments, "Extra arguments: --dirs --nocontrol"
+        )
+
+    def test_get_context_data_description_without_packages(self) -> None:
+        """'dynamic_data' does not contain either source or binary packages."""
+        work_request = self.playground.create_worker_task(
+            task_name="debdiff", task_data=self.SAMPLE_TASK_DATA
+        )
+        environment = self.playground.create_debian_environment().artifact
+        assert environment is not None
+
+        work_request.dynamic_task_data = DebDiffDynamicData(
+            environment_id=environment.id,
+            subject="hello",
+            parameter_summary="hello: 1.0.0-1 → 1.0.0-2",
+        ).model_dump()
+        work_request.save()
+
+        response = self.client.get(work_request.get_absolute_url())
+
+        tree = self.assertResponseHTML(response)
+
+        el = self.assertHasElement(tree, "//p[@id='general-description']")
+
+        self.assertTextContentEqual(el, "Debdiff for hello: 1.0.0-1 → 1.0.0-2")
+
     def test_get_context_data_description_data_empty(self) -> None:
         """'description_data' is {}: 'dynamic_data' is None."""
         work_request = self.playground.create_worker_task(
