@@ -21,7 +21,9 @@ from django.http.response import HttpResponseBase, HttpResponseRedirectBase
 from django.template import engines
 from django.test import override_settings
 from django.utils.datastructures import CaseInsensitiveMapping
+from django.utils.html import escape
 from django.utils.safestring import SafeString, mark_safe
+from pydantic import ValidationError
 from rest_framework import status
 
 from debusine.db.models import File, FileInArtifact
@@ -585,6 +587,7 @@ class FileWidgetTests(ViewTestMixin, TestCase):
                     context,
                     {
                         "file_in_artifact": file,
+                        "file_lineno_width": 2,
                         "file_ui": FileUI.from_file_in_artifact(file),
                         "file_contents_div_id": "file-contents",
                     },
@@ -628,9 +631,9 @@ class FileWidgetTests(ViewTestMixin, TestCase):
             context["file_content"],
             textwrap.dedent(
                 """\
-                <div class="file_highlighted">
-                <a id="L1" href="#L1">1</a><div># Title\n</div>
-                <a id="L2" href="#L2">2</a><div>Text\n</div>
+                <div class="file-contents">
+                <a id="L1" href="#L1">1</a><i># Title\n</i>
+                <a id="L2" href="#L2">2</a><i>Text\n</i>
                 </div>\n
                 """
             ),
@@ -669,7 +672,7 @@ class LogFileWidgetTests(ViewTestMixin, TestCase):
     file: ClassVar[FileInArtifact]
 
     before_contents = (
-        '<div class="file_highlighted"><pre class="m-0 p-0"><span></span>'
+        '<div class="file-contents"><pre class="m-0 p-0"><span></span>'
     )
     after_contents = '</pre></div>'
 
@@ -728,26 +731,26 @@ class LogFileWidgetTests(ViewTestMixin, TestCase):
         self.assertEqual(
             context["sections"],
             [
-                {
-                    "expanded": True,
-                    "content": add_line_numbers(
+                LogFileWidget.RenderedSection(
+                    expanded=True,
+                    content=add_line_numbers(
                         start=1,
                         lines=[
                             "first line",
                             "second line^Mprogress^Mprogress^Mfinished",
                         ],
                     ),
-                    "start_line": 1,
-                    "title": "Start",
-                },
-                {
-                    "expanded": True,
-                    "content": add_line_numbers(
+                    start_line=1,
+                    title="Start",
+                ),
+                LogFileWidget.RenderedSection(
+                    expanded=True,
+                    content=add_line_numbers(
                         start=3, lines=["third line", "fourth line"]
                     ),
-                    "start_line": 3,
-                    "title": "End",
-                },
+                    start_line=3,
+                    title="End",
+                ),
             ],
         )
 
@@ -759,6 +762,7 @@ class LogFileWidgetTests(ViewTestMixin, TestCase):
             {
                 "file_contents_div_id",
                 "file_in_artifact",
+                "file_lineno_width",
                 "file_ui",
                 "sections",
                 "suffix",
@@ -772,9 +776,9 @@ class LogFileWidgetTests(ViewTestMixin, TestCase):
         self.assertEqual(
             context["sections"],
             [
-                {
-                    "start_line": 1,
-                    "content": add_line_numbers(
+                LogFileWidget.RenderedSection(
+                    start_line=1,
+                    content=add_line_numbers(
                         start=1,
                         lines=[
                             "first line",
@@ -783,9 +787,9 @@ class LogFileWidgetTests(ViewTestMixin, TestCase):
                             "fourth line",
                         ],
                     ),
-                    "expanded": True,
-                    "title": None,
-                }
+                    expanded=True,
+                    title=None,
+                )
             ],
         )
 
@@ -809,16 +813,16 @@ class LogFileWidgetTests(ViewTestMixin, TestCase):
         self.assertEqual(
             context["sections"],
             [
-                {
-                    "content": add_line_numbers(
+                LogFileWidget.RenderedSection(
+                    content=add_line_numbers(
                         start=1, suffix="-tag", lines=["first line"]
                     ),
-                    "expanded": True,
-                    "start_line": 1,
-                    "title": None,
-                },
-                {
-                    "content": add_line_numbers(
+                    expanded=True,
+                    start_line=1,
+                    title=None,
+                ),
+                LogFileWidget.RenderedSection(
+                    content=add_line_numbers(
                         start=2,
                         suffix="-tag",
                         lines=[
@@ -826,18 +830,18 @@ class LogFileWidgetTests(ViewTestMixin, TestCase):
                             "third line",
                         ],
                     ),
-                    "expanded": True,
-                    "start_line": 2,
-                    "title": "Middle",
-                },
-                {
-                    "content": add_line_numbers(
+                    expanded=True,
+                    start_line=2,
+                    title="Middle",
+                ),
+                LogFileWidget.RenderedSection(
+                    content=add_line_numbers(
                         start=4, suffix="-tag", lines=["fourth line"]
                     ),
-                    "expanded": True,
-                    "start_line": 4,
-                    "title": None,
-                },
+                    expanded=True,
+                    start_line=4,
+                    title=None,
+                ),
             ],
         )
         self.assertEqual(context["suffix"], "-tag")
@@ -849,6 +853,7 @@ class LogFileWidgetTests(ViewTestMixin, TestCase):
             {
                 "file_contents_div_id",
                 "file_in_artifact",
+                "file_lineno_width",
                 "file_ui",
                 "sections",
                 "suffix",
@@ -902,9 +907,9 @@ class LogFileWidgetTests(ViewTestMixin, TestCase):
             textwrap.dedent(
                 """
                 <a id="L2-big" href="#L2-big">2</a>
-                <div>second &lt;b&gt;line&lt;/b&gt;</div>
+                <i>second &lt;b&gt;line&lt;/b&gt;</i>
                 <a id="L3-big" href="#L3-big">3</a>
-                <div>third &lt;b&gt;line&lt;/b&gt;</div>"""
+                <i>third &lt;b&gt;line&lt;/b&gt;</i>"""
             ),
         )
 
@@ -936,6 +941,31 @@ class LinenoHtmlFormatterTests(TestCase):
         )
 
 
+class RenderedSectionTests(TestCase):
+    """Tests for RenderedSection."""
+
+    def test_content_raise_not_safe_string(self) -> None:
+        with self.assertRaises(ValidationError) as exc:
+            LogFileWidget.RenderedSection(
+                start_line=1,
+                title=None,
+                expanded=True,
+                content="<b>unsafe</b>",
+            )
+
+        self.assertIn("content", str(exc.exception))
+
+    def test_content_validator(self) -> None:
+        # Does not raise
+        rendered_section = LogFileWidget.RenderedSection(
+            start_line=1,
+            title=None,
+            expanded=True,
+            content=escape("<b>safe</b>"),
+        )
+        self.assertIsInstance(rendered_section.content, SafeString)
+
+
 def add_line_numbers(
     *, start: int, lines: list[str], suffix: str = ""
 ) -> SafeString:
