@@ -50,7 +50,14 @@ class WorkflowListViewTests(ViewTestMixin, TestCase):
         )
 
     def assertWorkflowRow(
-        self, row: lxml.objectify.ObjectifiedElement, workflow: WorkRequest
+        self,
+        row: lxml.objectify.ObjectifiedElement,
+        workflow: WorkRequest,
+        expected_status: str,
+        expected_success: int = 0,
+        expected_failure: int = 0,
+        expected_pending: int = 0,
+        expected_blocked: int = 0,
     ) -> None:
         """Ensure the row shows the given work request."""
         line1 = row.div[0]
@@ -58,6 +65,12 @@ class WorkflowListViewTests(ViewTestMixin, TestCase):
         self.assertTextContentEqual(
             line1.div[0], workflow.workflow_display_name_parameters
         )
+        self.assertTextContentEqual(line1.div[1], expected_status)
+        self.assertTextContentEqual(
+            line1.div[2],
+            f"{expected_success}-{expected_failure}"
+            f" {expected_pending}-{expected_blocked}",
+        )
 
         line2 = row.div[1]
         self.assertTextContentEqual(line2.div.a, f"#{workflow.id}")
@@ -105,15 +118,17 @@ class WorkflowListViewTests(ViewTestMixin, TestCase):
         )
         self.playground.create_workflow(template_unused, task_data={})
 
-        wr = self.workflow_1.create_child_worker("noop")
-        wr.started_at = timezone.now()
-        wr.save()
+        wr_success = self.workflow_1.create_child_worker("noop")
+        self.playground.advance_work_request(
+            wr_success, result=WorkRequest.Results.SUCCESS
+        )
+        wr_pending = self.workflow_1.create_child_worker("noop")
+        self.playground.advance_work_request(wr_pending, mark_pending=True)
 
         self.workflow_1.started_at = timezone.now()
         self.workflow_1.save()
 
-        self.workflow_2.completed_at = timezone.now()
-        self.workflow_2.save()
+        self.workflow_2.mark_completed(result=WorkRequest.Results.SUCCESS)
 
         response = self.client.get(
             reverse(
@@ -142,5 +157,13 @@ class WorkflowListViewTests(ViewTestMixin, TestCase):
         # One work request is in a different workspace
         self.assertEqual(len(rows.div), 2)
 
-        self.assertWorkflowRow(rows.div[0], self.workflow_2)
-        self.assertWorkflowRow(rows.div[1], self.workflow_1)
+        self.assertWorkflowRow(
+            rows.div[0], self.workflow_2, expected_status="C S"
+        )
+        self.assertWorkflowRow(
+            rows.div[1],
+            self.workflow_1,
+            expected_status="P",
+            expected_success=1,
+            expected_pending=1,
+        )
