@@ -12,7 +12,7 @@
 import datetime as dt
 import re
 from collections.abc import Callable
-from typing import Any, TypeVar
+from typing import Any
 from unittest import mock
 
 import lxml.etree
@@ -37,8 +37,6 @@ from debusine.test.django import (
 )
 from debusine.web.views.base import Widget
 
-ViewClass = TypeVar("ViewClass", bound=View)
-
 
 class ViewTestMixin(BaseDjangoTestCase):
     """TestCase functions used to test Debusine views."""
@@ -50,7 +48,7 @@ class ViewTestMixin(BaseDjangoTestCase):
         request.user = AnonymousUser()
         return request
 
-    def instantiate_view_class(
+    def instantiate_view_class[ViewClass: View](
         self,
         view_class: type[ViewClass],
         request_or_url: HttpRequest | str,
