@@ -10,7 +10,16 @@
 """UI helpers for model objects."""
 
 # Import modules so their helpers can register themselves
-from debusine.web.views.ui import work_request  # noqa: F401
+from debusine.web.views.ui import (
+    artifacts,  # noqa: F401
+    auth,  # noqa: F401
+    collections,  # noqa: F401
+    scopes,  # noqa: F401
+    work_requests,  # noqa: F401
+    worker_pools,  # noqa: F401
+    workers,  # noqa: F401
+    workspaces,  # noqa: F401
+)
 from debusine.web.views.ui.base import UI
 
 __all__ = ["UI"]
