@@ -60,7 +60,11 @@ import tenacity
 from aiohttp.web_exceptions import HTTPCreated, HTTPNoContent, HTTPOk
 from pydantic import ValidationError
 
-from debusine.artifacts.models import RuntimeStatistics, TaskTypes
+from debusine.artifacts.models import (
+    RuntimeStatistics,
+    TaskTypes,
+    WorkRequestResults,
+)
 from debusine.client.debusine import Debusine
 from debusine.client.exceptions import TokenDisabledError
 from debusine.client.models import WorkRequestResponse
@@ -153,7 +157,7 @@ class Worker:
 
         # BaseTask.execute (e.g. Sbuild.exec) future is stored here (avoids
         # garbage collection deletion)
-        self._task_exec_future: Future[bool] | None = None
+        self._task_exec_future: Future[WorkRequestResults] | None = None
 
         # Used by ThreadPoolExecutor to submit tasks to the main event loop
         self._main_event_loop: asyncio.AbstractEventLoop | None = None
@@ -608,7 +612,7 @@ class Worker:
             await asyncio.to_thread(
                 client.work_request_completed_update,
                 work_request.id,
-                "error",
+                WorkRequestResults.ERROR,
                 OutputData(
                     errors=[
                         OutputDataError(
@@ -632,7 +636,7 @@ class Worker:
             await asyncio.to_thread(
                 client.work_request_completed_update,
                 work_request.id,
-                "error",
+                WorkRequestResults.ERROR,
                 OutputData(
                     errors=[
                         OutputDataError(
@@ -656,7 +660,7 @@ class Worker:
             await asyncio.to_thread(
                 client.work_request_completed_update,
                 work_request.id,
-                "error",
+                WorkRequestResults.ERROR,
                 OutputData(
                     errors=[
                         OutputDataError(
@@ -684,7 +688,9 @@ class Worker:
             self._task_running.execute_logging_exceptions
         )
 
-        def send_task_result(task_exec_future: Future[bool]) -> None:
+        def send_task_result(
+            task_exec_future: Future[WorkRequestResults],
+        ) -> None:
             assert self._main_event_loop is not None
             asyncio.run_coroutine_threadsafe(
                 self._send_task_result(
@@ -720,7 +726,7 @@ class Worker:
     async def _send_task_result(
         self,
         work_request_id: int,
-        task_exec_future: Future[bool],
+        task_exec_future: Future[WorkRequestResults],
         client: Debusine,
     ) -> None:
         """
@@ -758,7 +764,7 @@ class Worker:
                 error_message = "Task: %s Error execute: %s"
                 error_args = (self._task_name, task_exec_future.exception())
                 logging.error(error_message, *error_args)
-                result = 'error'
+                result = WorkRequestResults.ERROR
                 output_data.errors = [
                     OutputDataError(
                         message=error_message % error_args,
@@ -766,7 +772,7 @@ class Worker:
                     )
                 ]
             else:
-                result = 'success' if task_exec_future.result() else 'failure'
+                result = task_exec_future.result()
 
             try:
                 await asyncio.to_thread(
