@@ -27,7 +27,7 @@ class ConfigHandlerTests(TestCase):
 
     @classmethod
     @contextlib.contextmanager
-    def _temporary_config_directory(cls) -> Generator[str, None, None]:
+    def _temporary_config_directory(cls) -> Generator[str]:
         """Create a temporary directory with a config.ini inside."""
         with tempfile.TemporaryDirectory(
             prefix='debusine-Worker-ConfigHandlerTests-'
@@ -167,7 +167,7 @@ class ConfigHandlerTests(TestCase):
     @contextlib.contextmanager
     def _temporary_directory_with_token_file(
         cls, token: str, token_filename: str = "token"
-    ) -> Generator[str, None, None]:
+    ) -> Generator[str]:
         with cls._temporary_config_directory() as temp_directory:
             token_path = os.path.join(temp_directory, token_filename)
             with atomic_writer(token_path, mode="w", chmod=0o600) as fd:
@@ -358,8 +358,8 @@ class ConfigHandlerTests(TestCase):
 
         self.assertRegex(
             "\n".join(logs.output),
-            fr"Cannot open token file: \[Errno 2\] "
-            fr"No such file or directory: '{token_file}.*\.new'",
+            rf"Cannot open token file: \[Errno 2\] "
+            rf"No such file or directory: '{token_file}.*\.new'",
         )
 
     def _mock_config_handle_property(
@@ -434,7 +434,7 @@ class ConfigHandlerTests(TestCase):
     @contextlib.contextmanager
     def configuration_temp_directory(
         cls, configuration: dict[str, str]
-    ) -> Generator[str, None, None]:
+    ) -> Generator[str]:
         """
         Create a context to create a configuration file in a new directory.
 
