@@ -8,6 +8,7 @@
 # contained in the LICENSE file.
 
 """Tests DebusineAsyncHttpClient."""
+
 import asyncio.log
 import itertools
 import logging
@@ -53,7 +54,7 @@ class TestDebusineAsyncHttpClient(server.DebusineAioHTTPTestCase, TestCase):
             {'General': {'api-url': url}}
         )
 
-        config = ConfigHandler(directories=[config_temp_directory])
+        config = ConfigHandler(directories=[config_temp_directory.as_posix()])
         config['General']['log-file'] = '/dev/null'
 
         return config
