@@ -24,7 +24,7 @@ from collections.abc import AsyncGenerator, Awaitable
 from contextlib import asynccontextmanager
 from pathlib import Path
 from textwrap import dedent
-from typing import Any, Literal
+from typing import Any, Literal, override
 from unittest import mock
 from unittest.mock import MagicMock
 
@@ -42,10 +42,13 @@ from multidict import CIMultiDict, CIMultiDictProxy
 from yarl import URL
 
 import debusine.tasks.models as task_models
-from debusine.artifacts.models import RuntimeStatistics, TaskTypes
+from debusine.artifacts.models import (
+    RuntimeStatistics,
+    TaskTypes,
+    WorkRequestResults,
+)
 from debusine.client.debusine import Debusine
 from debusine.client.exceptions import TokenDisabledError
-from debusine.client.models import model_to_json_serializable_dict
 from debusine.tasks import (
     BaseTask,
     BaseTaskWithExecutor,
@@ -96,7 +99,9 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
             {'General': {'api-url': self.api_url}}
         )
 
-        self.config = ConfigHandler(directories=[self.config_temp_directory])
+        self.config = ConfigHandler(
+            directories=[self.config_temp_directory.as_posix()]
+        )
         self.config['General']['log-file'] = '/dev/null'
 
         self.default_sigint_handler = signal.getsignal(signal.SIGINT)
@@ -417,8 +422,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
             ),
         )
         log_message = (
-            'Could not register. Server HTTP status code: 0 '
-            'Body: Not available'
+            'Could not register. Server HTTP status code: 0 Body: Not available'
         )
         with (
             self.assertLogsContains(log_message),
@@ -525,7 +529,8 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
         assert self.worker is not None
 
         async def process_message(
-            msg: aiohttp.WSMessage, client: Debusine  # noqa: U100
+            msg: aiohttp.WSMessage,  # noqa: ARG001, U100
+            client: Debusine,  # noqa: ARG001, U100
         ) -> bool:
             assert self.worker is not None
             await self.worker.close()
@@ -743,14 +748,14 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
                 build_architecture="amd64",
                 backend=BackendType.UNSHARE,
                 environment="debian/match:codename=sid",
-            ).dict()
+            ).model_dump()
         )
         with mock.patch(
             "debusine.tasks.executors.images.ImageCache.image_artifact",
             return_value=create_artifact_response(id=1),
         ):
             self.worker._task_running.executor = UnshareExecutor(
-                mock.create_autospec(Debusine), 1
+                mock.create_autospec(Debusine), 1, workspace="workspace"
             )
         self.worker._task_statistics = RuntimeStatistics()
         GiB = 1024 * 1024 * 1024
@@ -815,7 +820,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
         """`_poll_statistics` ignores tasks without an executor."""
         self.setup_worker()
         assert self.worker is not None
-        self.worker._task_running = Noop({"result": True})
+        self.worker._task_running = Noop({"result": WorkRequestResults.SUCCESS})
         self.worker._task_statistics = RuntimeStatistics()
 
         with mock.patch("asyncio.sleep") as mock_sleep:
@@ -867,7 +872,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
         self,
         task_type: TaskTypes,
         task_name: str,
-        execute_result: bool,
+        execute_result: WorkRequestResults,
         json_result: str,
         worker_type: Literal[
             WorkerType.EXTERNAL, WorkerType.SIGNING
@@ -908,7 +913,9 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
             "debusine.tasks.executors.images.ImageCache.image_artifact",
             return_value=create_artifact_response(id=1),
         ):
-            executor = UnshareExecutor(mock.create_autospec(Debusine), 1)
+            executor = UnshareExecutor(
+                mock.create_autospec(Debusine), 1, workspace="workspace"
+            )
         GiB = 1024 * 1024 * 1024
 
         with (
@@ -986,13 +993,13 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
     async def test_task_is_received_executed_submit_success(self) -> None:
         """Receive a task, execute it and submit success completion."""
         await self.receive_task_submit_result(
-            TaskTypes.WORKER, "sbuild", True, "success"
+            TaskTypes.WORKER, "sbuild", WorkRequestResults.SUCCESS, "success"
         )
 
     async def test_task_is_received_executed_submit_failure(self) -> None:
         """Receive a task, executes it (failure) and submits failure."""
         await self.receive_task_submit_result(
-            TaskTypes.WORKER, "sbuild", False, "failure"
+            TaskTypes.WORKER, "sbuild", WorkRequestResults.FAILURE, "failure"
         )
 
     async def test_print_no_work_request_available(self) -> None:
@@ -1151,7 +1158,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
         self.setup_worker()
         assert self.worker is not None
 
-        def sleep(delay: float) -> None:  # noqa: U100
+        def sleep(delay: float) -> None:  # noqa: ARG001, U100
             self.server_config.get_next_for_worker = (
                 ServerConfig.GetNextForWorkerResponse.VALID_WORK_REQUEST
             )
@@ -1221,9 +1228,11 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
             TASK_VERSION = 1
             TASK_TYPE = TaskTypes.SERVER
 
-            def _execute(self) -> bool:
+            @override
+            def _execute(self) -> WorkRequestResults:
                 raise NotImplementedError()
 
+            @override
             def _upload_work_request_debug_logs(self) -> None:
                 raise NotImplementedError()
 
@@ -1250,7 +1259,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
             workspace="TestWorkspace",
         )
         self.server_config.get_next_for_worker = json_response(
-            model_to_json_serializable_dict(next_work_request)
+            next_work_request.model_dump(mode="json")
         )
 
         await self.assert_execute_work_request_send_and_log_error(
@@ -1271,7 +1280,8 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
             TASK_VERSION = 1
             TASK_TYPE = TaskTypes.SIGNING
 
-            def run(self, execute_directory: Path) -> bool:  # noqa: U100
+            @override
+            def run(self, execute_directory: Path) -> WorkRequestResults:  # noqa: U100
                 raise NotImplementedError()
 
         self.addCleanup(
@@ -1297,7 +1307,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
             workspace="TestWorkspace",
         )
         self.server_config.get_next_for_worker = json_response(
-            model_to_json_serializable_dict(next_work_request)
+            next_work_request.model_dump(mode="json")
         )
 
         await self.assert_execute_work_request_send_and_log_error(
@@ -1326,7 +1336,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
             workspace="TestWorkspace",
         )
         self.server_config.get_next_for_worker = json_response(
-            model_to_json_serializable_dict(next_work_request)
+            next_work_request.model_dump(mode="json")
         )
 
         await self.assert_execute_work_request_send_and_log_error(
@@ -1349,7 +1359,8 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
             TASK_VERSION = 1
             TASK_TYPE = TaskTypes.SIGNING
 
-            def run(self, execute_directory: Path) -> bool:  # noqa: U100
+            @override
+            def run(self, execute_directory: Path) -> WorkRequestResults:  # noqa: U100
                 raise NotImplementedError()
 
         self.addCleanup(
@@ -1375,13 +1386,13 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
             workspace="TestWorkspace",
         )
         self.server_config.get_next_for_worker = json_response(
-            model_to_json_serializable_dict(next_work_request)
+            next_work_request.model_dump(mode="json")
         )
 
         await self.receive_task_submit_result(
             TaskTypes.SIGNING,
             "signingtest",
-            True,
+            WorkRequestResults.SUCCESS,
             "success",
             worker_type=WorkerType.SIGNING,
         )
@@ -1407,7 +1418,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
             workspace="TestWorkspace",
         )
         self.server_config.get_next_for_worker = json_response(
-            model_to_json_serializable_dict(next_work_request)
+            next_work_request.model_dump(mode="json")
         )
 
         await self.assert_execute_work_request_send_and_log_error(
@@ -1547,7 +1558,8 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
         )
         with self.assertLogsContains(log_message, level=logging.DEBUG):
             message_processed = await self.worker._process_message(
-                msg, client  # type: ignore[arg-type]
+                msg,  # type: ignore[arg-type]
+                client,
             )
 
         self.assertFalse(message_processed)
@@ -1584,7 +1596,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
         config_temp_directory = self.create_temp_config_directory(
             {'General': {}}
         )
-        config = ConfigHandler(directories=[config_temp_directory])
+        config = ConfigHandler(directories=[config_temp_directory.as_posix()])
 
         log_message = (
             f'Missing required key "api-url" in General '
@@ -1602,7 +1614,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
     async def test_invalid_configuration_missing_general_section(self) -> None:
         """Worker() raises an exception: [General] section is not available."""
         config_temp_directory = self.create_temp_config_directory({})
-        config = ConfigHandler(directories=[config_temp_directory])
+        config = ConfigHandler(directories=[config_temp_directory.as_posix()])
 
         log_message = (
             f'Missing required section "General" in the configuration file '
@@ -1622,7 +1634,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
             {"General": {"api-url": "http://example.org/"}}
         )
         config = ConfigHandler(
-            directories=[config_temp_directory], require_https=True
+            directories=[config_temp_directory.as_posix()], require_https=True
         )
 
         log_message = (
@@ -1643,7 +1655,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
             {"General": {"api-url": "https://example.org/"}}
         )
         config = ConfigHandler(
-            directories=[config_temp_directory], require_https=True
+            directories=[config_temp_directory.as_posix()], require_https=True
         )
 
         self.setup_worker(config)
@@ -1845,7 +1857,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
         )
 
         self.worker._task_name = "Noop"
-        self.worker._task_running = Noop({"result": False})
+        self.worker._task_running = Noop({"result": WorkRequestResults.FAILURE})
         self.worker._initialize_statistics()
         self.worker._task_running.abort()
 
@@ -1877,7 +1889,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
         """Test signal handler aborts() the task."""
         self.setup_worker()
         assert self.worker is not None
-        self.worker._task_running = Noop({"result": False})
+        self.worker._task_running = Noop({"result": WorkRequestResults.FAILURE})
 
         self.assertFalse(self.worker._task_running.aborted)
 
@@ -1938,7 +1950,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
         assert self.worker is not None
 
         self.worker._task_name = "Noop"
-        self.worker._task_running = Noop({"result": False})
+        self.worker._task_running = Noop({"result": WorkRequestResults.FAILURE})
         self.worker._initialize_statistics()
         task_statistics_poller = self.worker._task_statistics_poller
         assert task_statistics_poller is not None
@@ -2005,7 +2017,7 @@ class WorkerTests(TestCase, server.DebusineAioHTTPTestCase):
         assert self.worker is not None
 
         self.worker._task_name = "Noop"
-        self.worker._task_running = Noop({"result": False})
+        self.worker._task_running = Noop({"result": WorkRequestResults.FAILURE})
         self.worker._initialize_statistics()
         self.worker._task_running.abort()
         client = self.worker._create_client()
